Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineLoggingErrorContext
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineLoggingErrorContext
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
A description of the context in which an error occurred.
Instance Attribute Summary collapse
-
#http_request ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineLoggingHttpRequestContext
HTTP request data that is related to a reported error.
-
#report_location ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineLoggingSourceLocation
Indicates a location in the source code of the service for which errors are reported.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineLoggingErrorContext
constructor
A new instance of GoogleCloudDiscoveryengineLoggingErrorContext.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineLoggingErrorContext
Returns a new instance of GoogleCloudDiscoveryengineLoggingErrorContext.
563 564 565 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 563 def initialize(**args) update!(**args) end |
Instance Attribute Details
#http_request ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineLoggingHttpRequestContext
HTTP request data that is related to a reported error.
Corresponds to the JSON property httpRequest
555 556 557 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 555 def http_request @http_request end |
#report_location ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineLoggingSourceLocation
Indicates a location in the source code of the service for which errors are
reported.
Corresponds to the JSON property reportLocation
561 562 563 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 561 def report_location @report_location end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
568 569 570 571 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 568 def update!(**args) @http_request = args[:http_request] if args.key?(:http_request) @report_location = args[:report_location] if args.key?(:report_location) end |