Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineLoggingErrorLog

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

An error log which is reported to the Error Reporting system.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineLoggingErrorLog

Returns a new instance of GoogleCloudDiscoveryengineLoggingErrorLog.



638
639
640
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 638

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connector_run_payloadGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineLoggingConnectorRunErrorContext

The error payload that is populated on LRO sync APIs, including the following:

  • google.cloud.discoveryengine.v1main.DataConnectorService.SetUpDataConnector
  • google.cloud.discoveryengine.v1main.DataConnectorService.StartConnectorRun Corresponds to the JSON property connectorRunPayload


583
584
585
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 583

def connector_run_payload
  @connector_run_payload
end

#contextGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineLoggingErrorContext

A description of the context in which an error occurred. Corresponds to the JSON property context



588
589
590
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 588

def context
  @context
end

#import_payloadGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineLoggingImportErrorContext

The error payload that is populated on LRO import APIs, including the following: * google.cloud.discoveryengine.v1alpha.DocumentService. ImportDocuments * google.cloud.discoveryengine.v1alpha.UserEventService. ImportUserEvents Corresponds to the JSON property importPayload



596
597
598
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 596

def import_payload
  @import_payload
end

#messageString

A message describing the error. Corresponds to the JSON property message

Returns:

  • (String)


601
602
603
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 601

def message
  @message
end

#request_payloadHash<String,Object>

The API request payload, represented as a protocol buffer. Most API request types are supported—for example: * type.googleapis.com/google.cloud. discoveryengine.v1alpha.DocumentService.CreateDocumentRequest * type. googleapis.com/google.cloud.discoveryengine.v1alpha.UserEventService. WriteUserEventRequest Corresponds to the JSON property requestPayload

Returns:

  • (Hash<String,Object>)


610
611
612
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 610

def request_payload
  @request_payload
end

#response_payloadHash<String,Object>

The API response payload, represented as a protocol buffer. This is used to log some "soft errors", where the response is valid but we consider there are some quality issues like unjoined events. The following API responses are supported, and no PII is included: * google.cloud.discoveryengine.v1alpha. RecommendationService.Recommend * google.cloud.discoveryengine.v1alpha. UserEventService.WriteUserEvent * google.cloud.discoveryengine.v1alpha. UserEventService.CollectUserEvent Corresponds to the JSON property responsePayload

Returns:

  • (Hash<String,Object>)


621
622
623
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 621

def response_payload
  @response_payload
end

#service_contextGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineLoggingServiceContext

Describes a running service that sends errors. Corresponds to the JSON property serviceContext



626
627
628
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 626

def service_context
  @service_context
end

#statusGoogle::Apis::DiscoveryengineV1beta::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property status



636
637
638
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 636

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



643
644
645
646
647
648
649
650
651
652
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 643

def update!(**args)
  @connector_run_payload = args[:connector_run_payload] if args.key?(:connector_run_payload)
  @context = args[:context] if args.key?(:context)
  @import_payload = args[:import_payload] if args.key?(:import_payload)
  @message = args[:message] if args.key?(:message)
  @request_payload = args[:request_payload] if args.key?(:request_payload)
  @response_payload = args[:response_payload] if args.key?(:response_payload)
  @service_context = args[:service_context] if args.key?(:service_context)
  @status = args[:status] if args.key?(:status)
end