Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineLoggingImportErrorContext
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineLoggingImportErrorContext
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
The error payload that is populated on LRO import APIs, including the
following: * google.cloud.discoveryengine.v1alpha.DocumentService.
ImportDocuments * google.cloud.discoveryengine.v1alpha.UserEventService.
ImportUserEvents
Instance Attribute Summary collapse
-
#document ⇒ String
The detailed content which caused the error on importing a document.
-
#gcs_path ⇒ String
Google Cloud Storage file path of the import source.
-
#line_number ⇒ String
Line number of the content in file.
-
#operation ⇒ String
The operation resource name of the LRO.
-
#user_event ⇒ String
The detailed content which caused the error on importing a user event.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineLoggingImportErrorContext
constructor
A new instance of GoogleCloudDiscoveryengineLoggingImportErrorContext.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineLoggingImportErrorContext
Returns a new instance of GoogleCloudDiscoveryengineLoggingImportErrorContext.
708 709 710 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 708 def initialize(**args) update!(**args) end |
Instance Attribute Details
#document ⇒ String
The detailed content which caused the error on importing a document.
Corresponds to the JSON property document
684 685 686 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 684 def document @document end |
#gcs_path ⇒ String
Google Cloud Storage file path of the import source. Can be set for batch
operation error.
Corresponds to the JSON property gcsPath
690 691 692 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 690 def gcs_path @gcs_path end |
#line_number ⇒ String
Line number of the content in file. Should be empty for permission or batch
operation error.
Corresponds to the JSON property lineNumber
696 697 698 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 696 def line_number @line_number end |
#operation ⇒ String
The operation resource name of the LRO.
Corresponds to the JSON property operation
701 702 703 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 701 def operation @operation end |
#user_event ⇒ String
The detailed content which caused the error on importing a user event.
Corresponds to the JSON property userEvent
706 707 708 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 706 def user_event @user_event end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
713 714 715 716 717 718 719 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 713 def update!(**args) @document = args[:document] if args.key?(:document) @gcs_path = args[:gcs_path] if args.key?(:gcs_path) @line_number = args[:line_number] if args.key?(:line_number) @operation = args[:operation] if args.key?(:operation) @user_event = args[:user_event] if args.key?(:user_event) end |