Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ActionConfig
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ActionConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Informations to support actions on the connector.
Instance Attribute Summary collapse
-
#action_params ⇒ Hash<String,Object>
Optional.
-
#create_bap_connection ⇒ Boolean
(also: #create_bap_connection?)
Optional.
-
#is_action_configured ⇒ Boolean
(also: #is_action_configured?)
Output only.
-
#json_action_params ⇒ String
Optional.
-
#service_name ⇒ String
Optional.
-
#use_static_secrets ⇒ Boolean
(also: #use_static_secrets?)
Optional.
-
#user_defined_scopes_mapping ⇒ Hash<String,Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ActionConfigScopeList>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1ActionConfig
constructor
A new instance of GoogleCloudDiscoveryengineV1ActionConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1ActionConfig
Returns a new instance of GoogleCloudDiscoveryengineV1ActionConfig.
837 838 839 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 837 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action_params ⇒ Hash<String,Object>
Optional. Action parameters in structured json format.
Corresponds to the JSON property actionParams
796 797 798 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 796 def action_params @action_params end |
#create_bap_connection ⇒ Boolean Also known as: create_bap_connection?
Optional. Whether to create a BAP connection for the connector.
Corresponds to the JSON property createBapConnection
801 802 803 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 801 def create_bap_connection @create_bap_connection end |
#is_action_configured ⇒ Boolean Also known as: is_action_configured?
Output only. The connector contains the necessary parameters and is configured
to support actions.
Corresponds to the JSON property isActionConfigured
808 809 810 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 808 def is_action_configured @is_action_configured end |
#json_action_params ⇒ String
Optional. Action parameters in json string format.
Corresponds to the JSON property jsonActionParams
814 815 816 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 814 def json_action_params @json_action_params end |
#service_name ⇒ String
Optional. The Service Directory resource name (projects//locations//
namespaces//services/) representing a VPC network endpoint used to connect
to the data source's instance_uri, defined in DataConnector.params. Required
when VPC Service Controls are enabled.
Corresponds to the JSON property serviceName
822 823 824 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 822 def service_name @service_name end |
#use_static_secrets ⇒ Boolean Also known as: use_static_secrets?
Optional. Whether to use static secrets for the connector. If true, the
secrets provided in the action_params will be ignored.
Corresponds to the JSON property useStaticSecrets
828 829 830 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 828 def use_static_secrets @use_static_secrets end |
#user_defined_scopes_mapping ⇒ Hash<String,Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ActionConfigScopeList>
Optional. Mapping from operation name to the list of scopes. Only be populated
if there are user specified scopes.
Corresponds to the JSON property userDefinedScopesMapping
835 836 837 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 835 def user_defined_scopes_mapping @user_defined_scopes_mapping end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
842 843 844 845 846 847 848 849 850 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 842 def update!(**args) @action_params = args[:action_params] if args.key?(:action_params) @create_bap_connection = args[:create_bap_connection] if args.key?(:create_bap_connection) @is_action_configured = args[:is_action_configured] if args.key?(:is_action_configured) @json_action_params = args[:json_action_params] if args.key?(:json_action_params) @service_name = args[:service_name] if args.key?(:service_name) @use_static_secrets = args[:use_static_secrets] if args.key?(:use_static_secrets) @user_defined_scopes_mapping = args[:user_defined_scopes_mapping] if args.key?(:user_defined_scopes_mapping) end |