Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1AgentGatewaySetting
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1AgentGatewaySetting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Agent Gateway setting, which may be attached to Gemini Enterprise resources for egress control of Gemini Enterprise agents to agents and tools outside of Gemini Enterprise.
Instance Attribute Summary collapse
-
#default_egress_agent_gateway ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1AgentGatewaySettingAgentGatewayReference
Reference to an Agent Gateway resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1AgentGatewaySetting
constructor
A new instance of GoogleCloudDiscoveryengineV1AgentGatewaySetting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1AgentGatewaySetting
Returns a new instance of GoogleCloudDiscoveryengineV1AgentGatewaySetting.
910 911 912 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 910 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_egress_agent_gateway ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1AgentGatewaySettingAgentGatewayReference
Reference to an Agent Gateway resource.
Corresponds to the JSON property defaultEgressAgentGateway
908 909 910 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 908 def default_egress_agent_gateway @default_egress_agent_gateway end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
915 916 917 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 915 def update!(**args) @default_egress_agent_gateway = args[:default_egress_agent_gateway] if args.key?(:default_egress_agent_gateway) end |