Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1AssistantGenerationConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Configuration for the generation of the assistant response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1AssistantGenerationConfig

Returns a new instance of GoogleCloudDiscoveryengineV1AssistantGenerationConfig.



1289
1290
1291
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1289

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowed_model_idsArray<String>

Optional. The list of models that are allowed to be used for assistant. Corresponds to the JSON property allowedModelIds

Returns:

  • (Array<String>)


1270
1271
1272
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1270

def allowed_model_ids
  @allowed_model_ids
end

#default_languageString

The default language to use for the generation of the assistant response. Use an ISO 639-1 language code such as en. If not specified, the language will be automatically detected. Corresponds to the JSON property defaultLanguage

Returns:

  • (String)


1277
1278
1279
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1277

def default_language
  @default_language
end

#default_model_idString

Optional. The default model to use for assistant. Corresponds to the JSON property defaultModelId

Returns:

  • (String)


1282
1283
1284
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1282

def default_model_id
  @default_model_id
end

#system_instructionGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1AssistantGenerationConfigSystemInstruction

System instruction, also known as the prompt preamble for LLM calls. Corresponds to the JSON property systemInstruction



1287
1288
1289
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1287

def system_instruction
  @system_instruction
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1294
1295
1296
1297
1298
1299
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1294

def update!(**args)
  @allowed_model_ids = args[:allowed_model_ids] if args.key?(:allowed_model_ids)
  @default_language = args[:default_language] if args.key?(:default_language)
  @default_model_id = args[:default_model_id] if args.key?(:default_model_id)
  @system_instruction = args[:system_instruction] if args.key?(:system_instruction)
end