Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1BapConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

The configuration for the BAP connector.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1BapConfig

Returns a new instance of GoogleCloudDiscoveryengineV1BapConfig.



1394
1395
1396
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1394

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enabled_actionsArray<String>

Optional. The actions enabled on the associated BAP connection. Corresponds to the JSON property enabledActions

Returns:

  • (Array<String>)


1375
1376
1377
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1375

def enabled_actions
  @enabled_actions
end

#supported_connector_modesArray<String>

Required. The supported connector modes for the associated BAP connection. Corresponds to the JSON property supportedConnectorModes

Returns:

  • (Array<String>)


1380
1381
1382
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1380

def supported_connector_modes
  @supported_connector_modes
end

#toolspec_overrideGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1BapConfigToolspecOverride

Customer-facing view of the admin-curated toolspec for a BAP connection. Holds the (simplified) per-tool definitions surfaced to and editable by the admin in the Discovery Engine UI. Mirrors the shape of the backend google.cloud. connectorexecution.v1.ToolspecOverride message, but is intentionally kept as a separate public type so the Discovery Engine API surface can evolve independently of the fed-API surface (AIP-215). Handlers convert between the two via helpers in //cloud/ml/discoveryengine/external_service/v1main/ data_connector_service/lib:bap_custom_tool_util. Corresponds to the JSON property toolspecOverride



1392
1393
1394
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1392

def toolspec_override
  @toolspec_override
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1399
1400
1401
1402
1403
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1399

def update!(**args)
  @enabled_actions = args[:enabled_actions] if args.key?(:enabled_actions)
  @supported_connector_modes = args[:supported_connector_modes] if args.key?(:supported_connector_modes)
  @toolspec_override = args[:toolspec_override] if args.key?(:toolspec_override)
end