Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1BatchUpdateUserLicensesMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Metadata related to the progress of the UserLicenseService. BatchUpdateUserLicenses operation. This will be returned by the google. longrunning.Operation.metadata field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1BatchUpdateUserLicensesMetadata

Returns a new instance of GoogleCloudDiscoveryengineV1BatchUpdateUserLicensesMetadata.



1518
1519
1520
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1518

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Operation create time. Corresponds to the JSON property createTime

Returns:

  • (String)


1500
1501
1502
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1500

def create_time
  @create_time
end

#failure_countFixnum

Count of user licenses that failed to be updated. Corresponds to the JSON property failureCount

Returns:

  • (Fixnum)


1505
1506
1507
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1505

def failure_count
  @failure_count
end

#success_countFixnum

Count of user licenses successfully updated. Corresponds to the JSON property successCount

Returns:

  • (Fixnum)


1510
1511
1512
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1510

def success_count
  @success_count
end

#update_timeString

Operation last update time. If the operation is done, this is also the finish time. Corresponds to the JSON property updateTime

Returns:

  • (String)


1516
1517
1518
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1516

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1523
1524
1525
1526
1527
1528
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1523

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @failure_count = args[:failure_count] if args.key?(:failure_count)
  @success_count = args[:success_count] if args.key?(:success_count)
  @update_time = args[:update_time] if args.key?(:update_time)
end