Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1BatchUpdateUserLicensesResponse
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1BatchUpdateUserLicensesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Response message for UserLicenseService.BatchUpdateUserLicenses method.
Instance Attribute Summary collapse
-
#error_samples ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>
A sample of errors encountered while processing the request.
-
#user_licenses ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1UserLicense>
UserLicenses successfully updated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1BatchUpdateUserLicensesResponse
constructor
A new instance of GoogleCloudDiscoveryengineV1BatchUpdateUserLicensesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1BatchUpdateUserLicensesResponse
Returns a new instance of GoogleCloudDiscoveryengineV1BatchUpdateUserLicensesResponse.
1545 1546 1547 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1545 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_samples ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>
A sample of errors encountered while processing the request.
Corresponds to the JSON property errorSamples
1538 1539 1540 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1538 def error_samples @error_samples end |
#user_licenses ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1UserLicense>
UserLicenses successfully updated.
Corresponds to the JSON property userLicenses
1543 1544 1545 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1543 def user_licenses @user_licenses end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1550 1551 1552 1553 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1550 def update!(**args) @error_samples = args[:error_samples] if args.key?(:error_samples) @user_licenses = args[:user_licenses] if args.key?(:user_licenses) end |