Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1CmekConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Configurations used to enable CMEK data encryption with Cloud KMS keys.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1CmekConfig

Returns a new instance of GoogleCloudDiscoveryengineV1CmekConfig.



1624
1625
1626
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1624

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#is_defaultBoolean Also known as: is_default?

Output only. The default CmekConfig for the Customer. Corresponds to the JSON property isDefault

Returns:

  • (Boolean)


1582
1583
1584
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1582

def is_default
  @is_default
end

#kms_keyString

Required. KMS key resource name which will be used to encrypt resources projects/project/locations/location/keyRings/keyRing/cryptoKeys/keyId`. Corresponds to the JSON propertykmsKey`

Returns:

  • (String)


1589
1590
1591
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1589

def kms_key
  @kms_key
end

#kms_key_versionString

Output only. KMS key version resource name which will be used to encrypt resources /cryptoKeyVersions/keyVersion`. Corresponds to the JSON propertykmsKeyVersion`

Returns:

  • (String)


1595
1596
1597
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1595

def kms_key_version
  @kms_key_version
end

#last_rotation_timestamp_microsFixnum

Output only. The timestamp of the last key rotation. Corresponds to the JSON property lastRotationTimestampMicros

Returns:

  • (Fixnum)


1600
1601
1602
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1600

def last_rotation_timestamp_micros
  @last_rotation_timestamp_micros
end

#nameString

Required. The name of the CmekConfig of the form projects/project/locations/ location/cmekConfig or projects/project/locations/location/cmekConfigs/ cmek_config`. Corresponds to the JSON propertyname`

Returns:

  • (String)


1607
1608
1609
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1607

def name
  @name
end

#notebooklm_stateString

Output only. Whether the NotebookLM Corpus is ready to be used. Corresponds to the JSON property notebooklmState

Returns:

  • (String)


1612
1613
1614
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1612

def notebooklm_state
  @notebooklm_state
end

#single_region_keysArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1SingleRegionKey>

Optional. Single-regional CMEKs that are required for some VAIS features. Corresponds to the JSON property singleRegionKeys



1617
1618
1619
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1617

def single_region_keys
  @single_region_keys
end

#stateString

Output only. The states of the CmekConfig. Corresponds to the JSON property state

Returns:

  • (String)


1622
1623
1624
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1622

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1629

def update!(**args)
  @is_default = args[:is_default] if args.key?(:is_default)
  @kms_key = args[:kms_key] if args.key?(:kms_key)
  @kms_key_version = args[:kms_key_version] if args.key?(:kms_key_version)
  @last_rotation_timestamp_micros = args[:last_rotation_timestamp_micros] if args.key?(:last_rotation_timestamp_micros)
  @name = args[:name] if args.key?(:name)
  @notebooklm_state = args[:notebooklm_state] if args.key?(:notebooklm_state)
  @single_region_keys = args[:single_region_keys] if args.key?(:single_region_keys)
  @state = args[:state] if args.key?(:state)
end