Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1Control
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1Control
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Defines a conditioned behavior to employ during serving. Must be attached to a
ServingConfig to be considered at serving time. Permitted actions dependent on
SolutionType.
Instance Attribute Summary collapse
-
#associated_serving_config_ids ⇒ Array<String>
Output only.
-
#boost_action ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ControlBoostAction
Adjusts order of products in returned list.
-
#conditions ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1Condition>
Determines when the associated action will trigger.
-
#display_name ⇒ String
Required.
-
#filter_action ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ControlFilterAction
Specified which products may be included in results.
-
#name ⇒ String
Immutable.
-
#promote_action ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ControlPromoteAction
Promote certain links based on some trigger queries.
-
#redirect_action ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ControlRedirectAction
Redirects a shopper to the provided URI.
-
#solution_type ⇒ String
Required.
-
#synonyms_action ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ControlSynonymsAction
Creates a set of terms that will act as synonyms of one another.
-
#use_cases ⇒ Array<String>
Specifies the use case for the control.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1Control
constructor
A new instance of GoogleCloudDiscoveryengineV1Control.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1Control
Returns a new instance of GoogleCloudDiscoveryengineV1Control.
1840 1841 1842 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1840 def initialize(**args) update!(**args) end |
Instance Attribute Details
#associated_serving_config_ids ⇒ Array<String>
Output only. List of all ServingConfig IDs this control is attached to. May
take up to 10 minutes to update after changes.
Corresponds to the JSON property associatedServingConfigIds
1775 1776 1777 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1775 def associated_serving_config_ids @associated_serving_config_ids end |
#boost_action ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ControlBoostAction
Adjusts order of products in returned list.
Corresponds to the JSON property boostAction
1780 1781 1782 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1780 def boost_action @boost_action end |
#conditions ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1Condition>
Determines when the associated action will trigger. Omit to always apply the
action. Currently only a single condition may be specified. Otherwise an
INVALID ARGUMENT error is thrown.
Corresponds to the JSON property conditions
1787 1788 1789 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1787 def conditions @conditions end |
#display_name ⇒ String
Required. Human readable name. The identifier used in UI views. Must be UTF-8
encoded string. Length limit is 128 characters. Otherwise an INVALID ARGUMENT
error is thrown.
Corresponds to the JSON property displayName
1794 1795 1796 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1794 def display_name @display_name end |
#filter_action ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ControlFilterAction
Specified which products may be included in results. Uses same filter as boost.
Corresponds to the JSON property filterAction
1799 1800 1801 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1799 def filter_action @filter_action end |
#name ⇒ String
Immutable. Fully qualified name projects/*/locations/global/dataStore/*/
controls/*
Corresponds to the JSON property name
1805 1806 1807 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1805 def name @name end |
#promote_action ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ControlPromoteAction
Promote certain links based on some trigger queries. Example: Promote shoe
store link when searching for shoe keyword. The link can be outside of
associated data store.
Corresponds to the JSON property promoteAction
1812 1813 1814 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1812 def promote_action @promote_action end |
#redirect_action ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ControlRedirectAction
Redirects a shopper to the provided URI.
Corresponds to the JSON property redirectAction
1817 1818 1819 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1817 def redirect_action @redirect_action end |
#solution_type ⇒ String
Required. Immutable. What solution the control belongs to. Must be compatible
with vertical of resource. Otherwise an INVALID ARGUMENT error is thrown.
Corresponds to the JSON property solutionType
1823 1824 1825 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1823 def solution_type @solution_type end |
#synonyms_action ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ControlSynonymsAction
Creates a set of terms that will act as synonyms of one another. Example: "
happy" will also be considered as "glad", "glad" will also be considered as "
happy".
Corresponds to the JSON property synonymsAction
1830 1831 1832 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1830 def synonyms_action @synonyms_action end |
#use_cases ⇒ Array<String>
Specifies the use case for the control. Affects what condition fields can be
set. Only applies to SOLUTION_TYPE_SEARCH. Currently only allow one use case
per control. Must be set when solution_type is SolutionType.
SOLUTION_TYPE_SEARCH.
Corresponds to the JSON property useCases
1838 1839 1840 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1838 def use_cases @use_cases end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1845 1846 1847 1848 1849 1850 1851 1852 1853 1854 1855 1856 1857 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1845 def update!(**args) @associated_serving_config_ids = args[:associated_serving_config_ids] if args.key?(:associated_serving_config_ids) @boost_action = args[:boost_action] if args.key?(:boost_action) @conditions = args[:conditions] if args.key?(:conditions) @display_name = args[:display_name] if args.key?(:display_name) @filter_action = args[:filter_action] if args.key?(:filter_action) @name = args[:name] if args.key?(:name) @promote_action = args[:promote_action] if args.key?(:promote_action) @redirect_action = args[:redirect_action] if args.key?(:redirect_action) @solution_type = args[:solution_type] if args.key?(:solution_type) @synonyms_action = args[:synonyms_action] if args.key?(:synonyms_action) @use_cases = args[:use_cases] if args.key?(:use_cases) end |