Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ControlBoostAction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Adjusts order of products in returned list.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1ControlBoostAction

Returns a new instance of GoogleCloudDiscoveryengineV1ControlBoostAction.



1898
1899
1900
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1898

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#boostFloat

Strength of the boost, which should be in [-1, 1]. Negative boost means demotion. Default is 0.0 (No-op). Corresponds to the JSON property boost

Returns:

  • (Float)


1868
1869
1870
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1868

def boost
  @boost
end

#data_storeString

Required. Specifies which data store's documents can be boosted by this control. Full data store name e.g. projects/123/locations/global/collections/ default_collection/dataStores/default_data_store Corresponds to the JSON property dataStore

Returns:

  • (String)


1875
1876
1877
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1875

def data_store
  @data_store
end

#filterString

Required. Specifies which products to apply the boost to. If no filter is provided all products will be boosted (No-op). Syntax documentation: https:// cloud.google.com/retail/docs/filter-and-order Maximum length is 5000 characters. Otherwise an INVALID ARGUMENT error is thrown. Corresponds to the JSON property filter

Returns:

  • (String)


1883
1884
1885
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1883

def filter
  @filter
end

#fixed_boostFloat

Optional. Strength of the boost, which should be in [-1, 1]. Negative boost means demotion. Default is 0.0 (No-op). Corresponds to the JSON property fixedBoost

Returns:

  • (Float)


1889
1890
1891
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1889

def fixed_boost
  @fixed_boost
end

#interpolation_boost_specGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ControlBoostActionInterpolationBoostSpec

Specification for custom ranking based on customer specified attribute value. It provides more controls for customized ranking than the simple (condition, boost) combination above. Corresponds to the JSON property interpolationBoostSpec



1896
1897
1898
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1896

def interpolation_boost_spec
  @interpolation_boost_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1903
1904
1905
1906
1907
1908
1909
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1903

def update!(**args)
  @boost = args[:boost] if args.key?(:boost)
  @data_store = args[:data_store] if args.key?(:data_store)
  @filter = args[:filter] if args.key?(:filter)
  @fixed_boost = args[:fixed_boost] if args.key?(:fixed_boost)
  @interpolation_boost_spec = args[:interpolation_boost_spec] if args.key?(:interpolation_boost_spec)
end