Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1DataConnectorConnectorMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

User-facing metadata for the connector, shown on the connector detail page ( title, description, short_description, author, note).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1DataConnectorConnectorMetadata

Returns a new instance of GoogleCloudDiscoveryengineV1DataConnectorConnectorMetadata.



2640
2641
2642
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2640

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authorString

Optional. The party that authored the connector, e.g. "Google" or a third- party provider name. Lets end users see who authored a connector (future: third-party-authored connectors). Corresponds to the JSON property author

Returns:

  • (String)


2615
2616
2617
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2615

def author
  @author
end

#descriptionString

Optional. Human-readable description of the connector, shown on the connector detail page. One connector has a single description. Corresponds to the JSON property description

Returns:

  • (String)


2621
2622
2623
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2621

def description
  @description
end

#noteString

Optional. Free-form, multi-line note about the connector's capabilities or a custom note that can be set for the connector. Corresponds to the JSON property note

Returns:

  • (String)


2627
2628
2629
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2627

def note
  @note
end

#short_descriptionString

Optional. Short, subtitle-length description of the connector (e.g. shown beneath the connector name in list and detail views). Corresponds to the JSON property shortDescription

Returns:

  • (String)


2633
2634
2635
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2633

def short_description
  @short_description
end

#titleString

Optional. Display title of the connector. Corresponds to the JSON property title

Returns:

  • (String)


2638
2639
2640
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2638

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2645
2646
2647
2648
2649
2650
2651
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2645

def update!(**args)
  @author = args[:author] if args.key?(:author)
  @description = args[:description] if args.key?(:description)
  @note = args[:note] if args.key?(:note)
  @short_description = args[:short_description] if args.key?(:short_description)
  @title = args[:title] if args.key?(:title)
end