Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1DataConnectorRealtimeSyncConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

The configuration for realtime sync to store additional params for realtime sync.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1DataConnectorRealtimeSyncConfig

Returns a new instance of GoogleCloudDiscoveryengineV1DataConnectorRealtimeSyncConfig.



2748
2749
2750
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2748

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#realtime_sync_secretString

Optional. The ID of the Secret Manager secret used for webhook secret. Corresponds to the JSON property realtimeSyncSecret

Returns:

  • (String)


2735
2736
2737
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2735

def realtime_sync_secret
  @realtime_sync_secret
end

#streaming_errorGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1DataConnectorRealtimeSyncConfigStreamingError

Streaming error details. Corresponds to the JSON property streamingError



2740
2741
2742
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2740

def streaming_error
  @streaming_error
end

#webhook_uriString

Optional. Webhook url for the connector to specify additional params for realtime sync. Corresponds to the JSON property webhookUri

Returns:

  • (String)


2746
2747
2748
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2746

def webhook_uri
  @webhook_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2753
2754
2755
2756
2757
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2753

def update!(**args)
  @realtime_sync_secret = args[:realtime_sync_secret] if args.key?(:realtime_sync_secret)
  @streaming_error = args[:streaming_error] if args.key?(:streaming_error)
  @webhook_uri = args[:webhook_uri] if args.key?(:webhook_uri)
end