Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1DataStoreBillingEstimation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Estimation of data size per data store.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1DataStoreBillingEstimation

Returns a new instance of GoogleCloudDiscoveryengineV1DataStoreBillingEstimation.



3067
3068
3069
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3067

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#structured_data_sizeFixnum

Data size for structured data in terms of bytes. Corresponds to the JSON property structuredDataSize

Returns:

  • (Fixnum)


3040
3041
3042
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3040

def structured_data_size
  @structured_data_size
end

#structured_data_update_timeString

Last updated timestamp for structured data. Corresponds to the JSON property structuredDataUpdateTime

Returns:

  • (String)


3045
3046
3047
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3045

def structured_data_update_time
  @structured_data_update_time
end

#unstructured_data_sizeFixnum

Data size for unstructured data in terms of bytes. Corresponds to the JSON property unstructuredDataSize

Returns:

  • (Fixnum)


3050
3051
3052
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3050

def unstructured_data_size
  @unstructured_data_size
end

#unstructured_data_update_timeString

Last updated timestamp for unstructured data. Corresponds to the JSON property unstructuredDataUpdateTime

Returns:

  • (String)


3055
3056
3057
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3055

def unstructured_data_update_time
  @unstructured_data_update_time
end

#website_data_sizeFixnum

Data size for websites in terms of bytes. Corresponds to the JSON property websiteDataSize

Returns:

  • (Fixnum)


3060
3061
3062
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3060

def website_data_size
  @website_data_size
end

#website_data_update_timeString

Last updated timestamp for websites. Corresponds to the JSON property websiteDataUpdateTime

Returns:

  • (String)


3065
3066
3067
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3065

def website_data_update_time
  @website_data_update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3072
3073
3074
3075
3076
3077
3078
3079
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3072

def update!(**args)
  @structured_data_size = args[:structured_data_size] if args.key?(:structured_data_size)
  @structured_data_update_time = args[:structured_data_update_time] if args.key?(:structured_data_update_time)
  @unstructured_data_size = args[:unstructured_data_size] if args.key?(:unstructured_data_size)
  @unstructured_data_update_time = args[:unstructured_data_update_time] if args.key?(:unstructured_data_update_time)
  @website_data_size = args[:website_data_size] if args.key?(:website_data_size)
  @website_data_update_time = args[:website_data_update_time] if args.key?(:website_data_update_time)
end