Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1DestinationConfig
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1DestinationConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Defines target endpoints used to connect to third-party sources.
Instance Attribute Summary collapse
-
#destinations ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1DestinationConfigDestination>
Optional.
-
#json_params ⇒ String
Additional parameters for this destination config in json string format.
-
#key ⇒ String
Optional.
-
#params ⇒ Hash<String,Object>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1DestinationConfig
constructor
A new instance of GoogleCloudDiscoveryengineV1DestinationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1DestinationConfig
Returns a new instance of GoogleCloudDiscoveryengineV1DestinationConfig.
3533 3534 3535 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3533 def initialize(**args) update!(**args) end |
Instance Attribute Details
#destinations ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1DestinationConfigDestination>
Optional. The destinations for the corresponding key.
Corresponds to the JSON property destinations
3515 3516 3517 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3515 def destinations @destinations end |
#json_params ⇒ String
Additional parameters for this destination config in json string format.
Corresponds to the JSON property jsonParams
3520 3521 3522 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3520 def json_params @json_params end |
#key ⇒ String
Optional. Unique destination identifier that is supported by the connector.
Corresponds to the JSON property key
3525 3526 3527 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3525 def key @key end |
#params ⇒ Hash<String,Object>
Optional. Additional parameters for this destination config in structured json
format.
Corresponds to the JSON property params
3531 3532 3533 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3531 def params @params end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3538 3539 3540 3541 3542 3543 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3538 def update!(**args) @destinations = args[:destinations] if args.key?(:destinations) @json_params = args[:json_params] if args.key?(:json_params) @key = args[:key] if args.key?(:key) @params = args[:params] if args.key?(:params) end |