Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1DocumentProcessingConfigChunkingConfigLayoutBasedChunkingConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Configuration for the layout based chunking.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1DocumentProcessingConfigChunkingConfigLayoutBasedChunkingConfig

Returns a new instance of GoogleCloudDiscoveryengineV1DocumentProcessingConfigChunkingConfigLayoutBasedChunkingConfig.



3650
3651
3652
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3650

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chunk_sizeFixnum

The token size limit for each chunk. Supported values: 100-500 (inclusive). Default value: 500. Corresponds to the JSON property chunkSize

Returns:

  • (Fixnum)


3641
3642
3643
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3641

def chunk_size
  @chunk_size
end

#include_ancestor_headingsBoolean Also known as: include_ancestor_headings?

Whether to include appending different levels of headings to chunks from the middle of the document to prevent context loss. Default value: False. Corresponds to the JSON property includeAncestorHeadings

Returns:

  • (Boolean)


3647
3648
3649
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3647

def include_ancestor_headings
  @include_ancestor_headings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3655
3656
3657
3658
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3655

def update!(**args)
  @chunk_size = args[:chunk_size] if args.key?(:chunk_size)
  @include_ancestor_headings = args[:include_ancestor_headings] if args.key?(:include_ancestor_headings)
end