Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1DocumentProcessingConfigParsingConfigLayoutParsingConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

The layout parsing configurations for documents.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1DocumentProcessingConfigParsingConfigLayoutParsingConfig

Returns a new instance of GoogleCloudDiscoveryengineV1DocumentProcessingConfigParsingConfigLayoutParsingConfig.



3812
3813
3814
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3812

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_get_processed_documentBoolean Also known as: enable_get_processed_document?

Optional. If true, the processed document will be made available for the GetProcessedDocument API. Corresponds to the JSON property enableGetProcessedDocument

Returns:

  • (Boolean)


3768
3769
3770
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3768

def enable_get_processed_document
  @enable_get_processed_document
end

#enable_image_annotationBoolean Also known as: enable_image_annotation?

Optional. If true, the LLM based annotation is added to the image during parsing. Corresponds to the JSON property enableImageAnnotation

Returns:

  • (Boolean)


3775
3776
3777
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3775

def enable_image_annotation
  @enable_image_annotation
end

#enable_llm_layout_parsingBoolean Also known as: enable_llm_layout_parsing?

Optional. If true, the pdf layout will be refined using an LLM. Corresponds to the JSON property enableLlmLayoutParsing

Returns:

  • (Boolean)


3781
3782
3783
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3781

def enable_llm_layout_parsing
  @enable_llm_layout_parsing
end

#enable_table_annotationBoolean Also known as: enable_table_annotation?

Optional. If true, the LLM based annotation is added to the table during parsing. Corresponds to the JSON property enableTableAnnotation

Returns:

  • (Boolean)


3788
3789
3790
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3788

def enable_table_annotation
  @enable_table_annotation
end

#exclude_html_classesArray<String>

Optional. List of HTML classes to exclude from the parsed content. Corresponds to the JSON property excludeHtmlClasses

Returns:

  • (Array<String>)


3794
3795
3796
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3794

def exclude_html_classes
  @exclude_html_classes
end

#exclude_html_elementsArray<String>

Optional. List of HTML elements to exclude from the parsed content. Corresponds to the JSON property excludeHtmlElements

Returns:

  • (Array<String>)


3799
3800
3801
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3799

def exclude_html_elements
  @exclude_html_elements
end

#exclude_html_idsArray<String>

Optional. List of HTML ids to exclude from the parsed content. Corresponds to the JSON property excludeHtmlIds

Returns:

  • (Array<String>)


3804
3805
3806
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3804

def exclude_html_ids
  @exclude_html_ids
end

#structured_content_typesArray<String>

Optional. Contains the required structure types to extract from the document. Supported values: * shareholder-structure Corresponds to the JSON property structuredContentTypes

Returns:

  • (Array<String>)


3810
3811
3812
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3810

def structured_content_types
  @structured_content_types
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3817
3818
3819
3820
3821
3822
3823
3824
3825
3826
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3817

def update!(**args)
  @enable_get_processed_document = args[:enable_get_processed_document] if args.key?(:enable_get_processed_document)
  @enable_image_annotation = args[:enable_image_annotation] if args.key?(:enable_image_annotation)
  @enable_llm_layout_parsing = args[:enable_llm_layout_parsing] if args.key?(:enable_llm_layout_parsing)
  @enable_table_annotation = args[:enable_table_annotation] if args.key?(:enable_table_annotation)
  @exclude_html_classes = args[:exclude_html_classes] if args.key?(:exclude_html_classes)
  @exclude_html_elements = args[:exclude_html_elements] if args.key?(:exclude_html_elements)
  @exclude_html_ids = args[:exclude_html_ids] if args.key?(:exclude_html_ids)
  @structured_content_types = args[:structured_content_types] if args.key?(:structured_content_types)
end