Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1EngineMediaRecommendationEngineConfigMostPopularFeatureConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Feature configurations that are required for creating a Most Popular engine.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1EngineMediaRecommendationEngineConfigMostPopularFeatureConfig

Returns a new instance of GoogleCloudDiscoveryengineV1EngineMediaRecommendationEngineConfigMostPopularFeatureConfig.



4388
4389
4390
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4388

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#time_window_daysFixnum

The time window of which the engine is queried at training and prediction time. Positive integers only. The value translates to the last X days of events. Currently required for the most-popular-items engine. Corresponds to the JSON property timeWindowDays

Returns:

  • (Fixnum)


4386
4387
4388
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4386

def time_window_days
  @time_window_days
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4393
4394
4395
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4393

def update!(**args)
  @time_window_days = args[:time_window_days] if args.key?(:time_window_days)
end