Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1HealthcareFhirConfig
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1HealthcareFhirConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Config to data store for HEALTHCARE_FHIR vertical.
Instance Attribute Summary collapse
-
#enable_configurable_schema ⇒ Boolean
(also: #enable_configurable_schema?)
Whether to enable configurable schema for
HEALTHCARE_FHIRvertical. -
#enable_static_indexing_for_batch_ingestion ⇒ Boolean
(also: #enable_static_indexing_for_batch_ingestion?)
Whether to enable static indexing for
HEALTHCARE_FHIRbatch ingestion. -
#initial_filter_groups ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1HealthcareFhirConfig
constructor
A new instance of GoogleCloudDiscoveryengineV1HealthcareFhirConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1HealthcareFhirConfig
Returns a new instance of GoogleCloudDiscoveryengineV1HealthcareFhirConfig.
4582 4583 4584 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4582 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable_configurable_schema ⇒ Boolean Also known as: enable_configurable_schema?
Whether to enable configurable schema for HEALTHCARE_FHIR vertical. If set
to true, the predefined healthcare fhir schema can be extended for more
customized searching and filtering.
Corresponds to the JSON property enableConfigurableSchema
4561 4562 4563 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4561 def enable_configurable_schema @enable_configurable_schema end |
#enable_static_indexing_for_batch_ingestion ⇒ Boolean Also known as: enable_static_indexing_for_batch_ingestion?
Whether to enable static indexing for HEALTHCARE_FHIR batch ingestion. If
set to true, the batch ingestion will be processed in a static indexing mode
which is slower but more capable of handling larger volume.
Corresponds to the JSON property enableStaticIndexingForBatchIngestion
4569 4570 4571 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4569 def enable_static_indexing_for_batch_ingestion @enable_static_indexing_for_batch_ingestion end |
#initial_filter_groups ⇒ Array<String>
Optional. Names of the Group resources to use as a basis for the initial
patient filter, in format projects/project_id/locations/location_id/
datasets/dataset_id/fhirStores/fhir_store_id/fhir/Group/group_id`. The
filter group must be a FHIR resource name of type Group, and the filter will
be constructed from the direct members of the group which are Patient
resources.
Corresponds to the JSON propertyinitialFilterGroups`
4580 4581 4582 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4580 def initial_filter_groups @initial_filter_groups end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4587 4588 4589 4590 4591 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4587 def update!(**args) @enable_configurable_schema = args[:enable_configurable_schema] if args.key?(:enable_configurable_schema) @enable_static_indexing_for_batch_ingestion = args[:enable_static_indexing_for_batch_ingestion] if args.key?(:enable_static_indexing_for_batch_ingestion) @initial_filter_groups = args[:initial_filter_groups] if args.key?(:initial_filter_groups) end |