Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1IdentityScheduleConfig
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1IdentityScheduleConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
The configuration for the identity data synchronization runs.
Instance Attribute Summary collapse
-
#next_sync_time ⇒ Google::Apis::DiscoveryengineV1beta::GoogleTypeDateTime
Represents civil time (or occasionally physical time).
-
#refresh_interval ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1IdentityScheduleConfig
constructor
A new instance of GoogleCloudDiscoveryengineV1IdentityScheduleConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1IdentityScheduleConfig
Returns a new instance of GoogleCloudDiscoveryengineV1IdentityScheduleConfig.
4579 4580 4581 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4579 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_sync_time ⇒ Google::Apis::DiscoveryengineV1beta::GoogleTypeDateTime
Represents civil time (or occasionally physical time). This type can represent
a civil time in one of a few possible ways: * When utc_offset is set and
time_zone is unset: a civil time on a calendar day with a particular offset
from UTC. * When time_zone is set and utc_offset is unset: a civil time on a
calendar day in a particular time zone. * When neither time_zone nor
utc_offset is set: a civil time on a calendar day in local time. The date is
relative to the Proleptic Gregorian Calendar. If year, month, or day are 0,
the DateTime is considered not to have a specific year, month, or day
respectively. This type may also be used to represent a physical time if all
the date and time fields are set and either case of the time_offset oneof is
set. Consider using Timestamp message for physical time instead. If your use
case also would like to store the user's timezone, that can be done in another
field. This type is more flexible than some applications may want. Make sure
to document and validate your application's limitations.
Corresponds to the JSON property nextSyncTime
4569 4570 4571 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4569 def next_sync_time @next_sync_time end |
#refresh_interval ⇒ String
Optional. The refresh interval to sync the Access Control List information for
the documents ingested by this connector. If not set, the access control list
will be refreshed at the default interval of 30 minutes. The identity refresh
interval can be at least 30 minutes and at most 7 days.
Corresponds to the JSON property refreshInterval
4577 4578 4579 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4577 def refresh_interval @refresh_interval end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4584 4585 4586 4587 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4584 def update!(**args) @next_sync_time = args[:next_sync_time] if args.key?(:next_sync_time) @refresh_interval = args[:refresh_interval] if args.key?(:refresh_interval) end |