Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ImportIdentityMappingsResponse
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ImportIdentityMappingsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Response message for IdentityMappingStoreService.ImportIdentityMappings
Instance Attribute Summary collapse
-
#error_samples ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>
A sample of errors encountered while processing the request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1ImportIdentityMappingsResponse
constructor
A new instance of GoogleCloudDiscoveryengineV1ImportIdentityMappingsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1ImportIdentityMappingsResponse
Returns a new instance of GoogleCloudDiscoveryengineV1ImportIdentityMappingsResponse.
4794 4795 4796 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4794 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_samples ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>
A sample of errors encountered while processing the request.
Corresponds to the JSON property errorSamples
4792 4793 4794 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4792 def error_samples @error_samples end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4799 4800 4801 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4799 def update!(**args) @error_samples = args[:error_samples] if args.key?(:error_samples) end |