Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1LicenseConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Information about users' licenses.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1LicenseConfig

Returns a new instance of GoogleCloudDiscoveryengineV1LicenseConfig.



5124
5125
5126
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5124

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_renewBoolean Also known as: auto_renew?

Optional. Whether the license config should be auto renewed when it reaches the end date. Corresponds to the JSON property autoRenew

Returns:

  • (Boolean)


5029
5030
5031
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5029

def auto_renew
  @auto_renew
end

#early_terminatedBoolean Also known as: early_terminated?

Output only. Indication of whether the subscription is terminated earlier than the expiration date. This is usually terminated by pipeline once the subscription gets terminated from subsv3. Corresponds to the JSON property earlyTerminated

Returns:

  • (Boolean)


5037
5038
5039
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5037

def early_terminated
  @early_terminated
end

#early_termination_dateGoogle::Apis::DiscoveryengineV1beta::GoogleTypeDate

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property earlyTerminationDate



5050
5051
5052
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5050

def early_termination_date
  @early_termination_date
end

#end_dateGoogle::Apis::DiscoveryengineV1beta::GoogleTypeDate

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property endDate



5062
5063
5064
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5062

def end_date
  @end_date
end

#free_trialBoolean Also known as: free_trial?

Optional. Whether the license config is for free trial. Corresponds to the JSON property freeTrial

Returns:

  • (Boolean)


5067
5068
5069
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5067

def free_trial
  @free_trial
end

#gemini_bundleBoolean Also known as: gemini_bundle?

Output only. Whether the license config is for Gemini bundle. Corresponds to the JSON property geminiBundle

Returns:

  • (Boolean)


5073
5074
5075
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5073

def gemini_bundle
  @gemini_bundle
end

#last_user_update_timeString

Optional. Timestamp of the most recent user-initiated update (seat count change or subscription term change). Unlike update_time, this field is only stamped when a customer explicitly updates the license (e.g. via the UI), and is not touched by system-driven writes (subscription pipeline, BALC propagation, etc.). Corresponds to the JSON property lastUserUpdateTime

Returns:

  • (String)


5083
5084
5085
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5083

def last_user_update_time
  @last_user_update_time
end

#license_countFixnum

Required. Number of licenses purchased. Corresponds to the JSON property licenseCount

Returns:

  • (Fixnum)


5088
5089
5090
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5088

def license_count
  @license_count
end

#nameString

Immutable. Identifier. The fully qualified resource name of the license config. Format: projects/project/locations/location/licenseConfigs/ license_config` Corresponds to the JSON propertyname`

Returns:

  • (String)


5095
5096
5097
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5095

def name
  @name
end

#start_dateGoogle::Apis::DiscoveryengineV1beta::GoogleTypeDate

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property startDate



5107
5108
5109
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5107

def start_date
  @start_date
end

#stateString

Output only. The state of the license config. Corresponds to the JSON property state

Returns:

  • (String)


5112
5113
5114
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5112

def state
  @state
end

#subscription_termString

Required. Subscription term. Corresponds to the JSON property subscriptionTerm

Returns:

  • (String)


5117
5118
5119
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5117

def subscription_term
  @subscription_term
end

#subscription_tierString

Required. Subscription tier information for the license config. Corresponds to the JSON property subscriptionTier

Returns:

  • (String)


5122
5123
5124
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5122

def subscription_tier
  @subscription_tier
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5129
5130
5131
5132
5133
5134
5135
5136
5137
5138
5139
5140
5141
5142
5143
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5129

def update!(**args)
  @auto_renew = args[:auto_renew] if args.key?(:auto_renew)
  @early_terminated = args[:early_terminated] if args.key?(:early_terminated)
  @early_termination_date = args[:early_termination_date] if args.key?(:early_termination_date)
  @end_date = args[:end_date] if args.key?(:end_date)
  @free_trial = args[:free_trial] if args.key?(:free_trial)
  @gemini_bundle = args[:gemini_bundle] if args.key?(:gemini_bundle)
  @last_user_update_time = args[:last_user_update_time] if args.key?(:last_user_update_time)
  @license_count = args[:license_count] if args.key?(:license_count)
  @name = args[:name] if args.key?(:name)
  @start_date = args[:start_date] if args.key?(:start_date)
  @state = args[:state] if args.key?(:state)
  @subscription_term = args[:subscription_term] if args.key?(:subscription_term)
  @subscription_tier = args[:subscription_tier] if args.key?(:subscription_tier)
end