Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ProjectCustomerProvidedConfigNotebooklmConfig
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ProjectCustomerProvidedConfigNotebooklmConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Configuration for NotebookLM.
Instance Attribute Summary collapse
-
#data_protection_policy ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ProjectCustomerProvidedConfigNotebooklmConfigDataProtectionPolicy
Data protection policy config for NotebookLM.
-
#model_armor_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ProjectCustomerProvidedConfigNotebooklmConfigModelArmorConfig
Configuration for customer defined Model Armor templates to be used for sanitizing user prompts and LLM responses.
-
#observability_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ObservabilityConfig
Observability config for a resource.
-
#opt_out_notebook_sharing ⇒ Boolean
(also: #opt_out_notebook_sharing?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1ProjectCustomerProvidedConfigNotebooklmConfig
constructor
A new instance of GoogleCloudDiscoveryengineV1ProjectCustomerProvidedConfigNotebooklmConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1ProjectCustomerProvidedConfigNotebooklmConfig
Returns a new instance of GoogleCloudDiscoveryengineV1ProjectCustomerProvidedConfigNotebooklmConfig.
5284 5285 5286 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5284 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_protection_policy ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ProjectCustomerProvidedConfigNotebooklmConfigDataProtectionPolicy
Data protection policy config for NotebookLM.
Corresponds to the JSON property dataProtectionPolicy
5264 5265 5266 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5264 def data_protection_policy @data_protection_policy end |
#model_armor_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ProjectCustomerProvidedConfigNotebooklmConfigModelArmorConfig
Configuration for customer defined Model Armor templates to be used for
sanitizing user prompts and LLM responses.
Corresponds to the JSON property modelArmorConfig
5270 5271 5272 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5270 def model_armor_config @model_armor_config end |
#observability_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ObservabilityConfig
Observability config for a resource.
Corresponds to the JSON property observabilityConfig
5275 5276 5277 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5275 def observability_config @observability_config end |
#opt_out_notebook_sharing ⇒ Boolean Also known as: opt_out_notebook_sharing?
Optional. Whether to disable the notebook sharing feature for the project.
Default to false if not specified.
Corresponds to the JSON property optOutNotebookSharing
5281 5282 5283 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5281 def opt_out_notebook_sharing @opt_out_notebook_sharing end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5289 5290 5291 5292 5293 5294 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5289 def update!(**args) @data_protection_policy = args[:data_protection_policy] if args.key?(:data_protection_policy) @model_armor_config = args[:model_armor_config] if args.key?(:model_armor_config) @observability_config = args[:observability_config] if args.key?(:observability_config) @opt_out_notebook_sharing = args[:opt_out_notebook_sharing] if args.key?(:opt_out_notebook_sharing) end |