Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ProjectServiceTerms

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Metadata about the terms of service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1ProjectServiceTerms

Returns a new instance of GoogleCloudDiscoveryengineV1ProjectServiceTerms.



5404
5405
5406
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5404

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accept_timeString

The last time when the project agreed to the terms of service. Corresponds to the JSON property acceptTime

Returns:

  • (String)


5376
5377
5378
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5376

def accept_time
  @accept_time
end

#decline_timeString

The last time when the project declined or revoked the agreement to terms of service. Corresponds to the JSON property declineTime

Returns:

  • (String)


5382
5383
5384
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5382

def decline_time
  @decline_time
end

#idString

The unique identifier of this terms of service. Available terms: * GA_DATA_USE_TERMS: Terms for data use. When using this as id, the acceptable version to provide is 2022-11-23. Corresponds to the JSON property id

Returns:

  • (String)


5390
5391
5392
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5390

def id
  @id
end

#stateString

Whether the project has accepted/rejected the service terms or it is still pending. Corresponds to the JSON property state

Returns:

  • (String)


5396
5397
5398
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5396

def state
  @state
end

#versionString

The version string of the terms of service. For acceptable values, see the comments for id above. Corresponds to the JSON property version

Returns:

  • (String)


5402
5403
5404
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5402

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5409
5410
5411
5412
5413
5414
5415
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5409

def update!(**args)
  @accept_time = args[:accept_time] if args.key?(:accept_time)
  @decline_time = args[:decline_time] if args.key?(:decline_time)
  @id = args[:id] if args.key?(:id)
  @state = args[:state] if args.key?(:state)
  @version = args[:version] if args.key?(:version)
end