Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1SearchRequestContentSearchSpec
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1SearchRequestContentSearchSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
A specification for configuring the behavior of content search.
Instance Attribute Summary collapse
-
#chunk_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1SearchRequestContentSearchSpecChunkSpec
Specifies the chunk spec to be returned from the search response.
-
#extractive_content_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1SearchRequestContentSearchSpecExtractiveContentSpec
A specification for configuring the extractive content in a search response.
-
#search_result_mode ⇒ String
Specifies the search result mode.
-
#snippet_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1SearchRequestContentSearchSpecSnippetSpec
A specification for configuring snippets in a search response.
-
#summary_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1SearchRequestContentSearchSpecSummarySpec
A specification for configuring a summary returned in a search response.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1SearchRequestContentSearchSpec
constructor
A new instance of GoogleCloudDiscoveryengineV1SearchRequestContentSearchSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1SearchRequestContentSearchSpec
Returns a new instance of GoogleCloudDiscoveryengineV1SearchRequestContentSearchSpec.
5866 5867 5868 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5866 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chunk_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1SearchRequestContentSearchSpecChunkSpec
Specifies the chunk spec to be returned from the search response. Only
available if the SearchRequest.ContentSearchSpec.search_result_mode is set to
CHUNKS
Corresponds to the JSON property chunkSpec
5843 5844 5845 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5843 def chunk_spec @chunk_spec end |
#extractive_content_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1SearchRequestContentSearchSpecExtractiveContentSpec
A specification for configuring the extractive content in a search response.
Corresponds to the JSON property extractiveContentSpec
5848 5849 5850 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5848 def extractive_content_spec @extractive_content_spec end |
#search_result_mode ⇒ String
Specifies the search result mode. If unspecified, the search result mode
defaults to DOCUMENTS.
Corresponds to the JSON property searchResultMode
5854 5855 5856 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5854 def search_result_mode @search_result_mode end |
#snippet_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1SearchRequestContentSearchSpecSnippetSpec
A specification for configuring snippets in a search response.
Corresponds to the JSON property snippetSpec
5859 5860 5861 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5859 def snippet_spec @snippet_spec end |
#summary_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1SearchRequestContentSearchSpecSummarySpec
A specification for configuring a summary returned in a search response.
Corresponds to the JSON property summarySpec
5864 5865 5866 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5864 def summary_spec @summary_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5871 5872 5873 5874 5875 5876 5877 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5871 def update!(**args) @chunk_spec = args[:chunk_spec] if args.key?(:chunk_spec) @extractive_content_spec = args[:extractive_content_spec] if args.key?(:extractive_content_spec) @search_result_mode = args[:search_result_mode] if args.key?(:search_result_mode) @snippet_spec = args[:snippet_spec] if args.key?(:snippet_spec) @summary_spec = args[:summary_spec] if args.key?(:summary_spec) end |