Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1SearchRequestContentSearchSpecSummarySpec
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1SearchRequestContentSearchSpecSummarySpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
A specification for configuring a summary returned in a search response.
Instance Attribute Summary collapse
-
#ignore_adversarial_query ⇒ Boolean
(also: #ignore_adversarial_query?)
Specifies whether to filter out adversarial queries.
-
#ignore_jail_breaking_query ⇒ Boolean
(also: #ignore_jail_breaking_query?)
Optional.
-
#ignore_low_relevant_content ⇒ Boolean
(also: #ignore_low_relevant_content?)
Specifies whether to filter out queries that have low relevance.
-
#ignore_non_summary_seeking_query ⇒ Boolean
(also: #ignore_non_summary_seeking_query?)
Specifies whether to filter out queries that are not summary-seeking.
-
#include_citations ⇒ Boolean
(also: #include_citations?)
Specifies whether to include citations in the summary.
-
#language_code ⇒ String
Language code for Summary.
-
#model_prompt_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1SearchRequestContentSearchSpecSummarySpecModelPromptSpec
Specification of the prompt to use with the model.
-
#model_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1SearchRequestContentSearchSpecSummarySpecModelSpec
Specification of the model.
-
#summary_result_count ⇒ Fixnum
The number of top results to generate the summary from.
-
#use_semantic_chunks ⇒ Boolean
(also: #use_semantic_chunks?)
If true, answer will be generated from most relevant chunks from top search results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1SearchRequestContentSearchSpecSummarySpec
constructor
A new instance of GoogleCloudDiscoveryengineV1SearchRequestContentSearchSpecSummarySpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1SearchRequestContentSearchSpecSummarySpec
Returns a new instance of GoogleCloudDiscoveryengineV1SearchRequestContentSearchSpecSummarySpec.
6097 6098 6099 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6097 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ignore_adversarial_query ⇒ Boolean Also known as: ignore_adversarial_query?
Specifies whether to filter out adversarial queries. The default value is
false. Google employs search-query classification to detect adversarial
queries. No summary is returned if the search query is classified as an
adversarial query. For example, a user might ask a question regarding negative
comments about the company or submit a query designed to generate unsafe,
policy-violating output. If this field is set to true, we skip generating
summaries for adversarial queries and return fallback messages instead.
Corresponds to the JSON property ignoreAdversarialQuery
6009 6010 6011 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6009 def ignore_adversarial_query @ignore_adversarial_query end |
#ignore_jail_breaking_query ⇒ Boolean Also known as: ignore_jail_breaking_query?
Optional. Specifies whether to filter out jail-breaking queries. The default
value is false. Google employs search-query classification to detect jail-
breaking queries. No summary is returned if the search query is classified as
a jail-breaking query. A user might add instructions to the query to change
the tone, style, language, content of the answer, or ask the model to act as a
different entity, e.g. "Reply in the tone of a competing company's CEO". If
this field is set to true, we skip generating summaries for jail-breaking
queries and return fallback messages instead.
Corresponds to the JSON property ignoreJailBreakingQuery
6022 6023 6024 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6022 def ignore_jail_breaking_query @ignore_jail_breaking_query end |
#ignore_low_relevant_content ⇒ Boolean Also known as: ignore_low_relevant_content?
Specifies whether to filter out queries that have low relevance. The default
value is false. If this field is set to false, all search results are used
regardless of relevance to generate answers. If set to true, only queries
with high relevance search results will generate answers.
Corresponds to the JSON property ignoreLowRelevantContent
6031 6032 6033 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6031 def ignore_low_relevant_content @ignore_low_relevant_content end |
#ignore_non_summary_seeking_query ⇒ Boolean Also known as: ignore_non_summary_seeking_query?
Specifies whether to filter out queries that are not summary-seeking. The
default value is false. Google employs search-query classification to detect
summary-seeking queries. No summary is returned if the search query is
classified as a non-summary seeking query. For example, why is the sky blue
and Who is the best soccer player in the world? are summary-seeking queries,
but SFO airport and world cup 2026 are not. They are most likely
navigational queries. If this field is set to true, we skip generating
summaries for non-summary seeking queries and return fallback messages instead.
Corresponds to the JSON property ignoreNonSummarySeekingQuery
6044 6045 6046 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6044 def ignore_non_summary_seeking_query @ignore_non_summary_seeking_query end |
#include_citations ⇒ Boolean Also known as: include_citations?
Specifies whether to include citations in the summary. The default value is
false. When this field is set to true, summaries include in-line citation
numbers. Example summary including citations: BigQuery is Google Cloud's fully
managed and completely serverless enterprise data warehouse [1]. BigQuery
supports all data types, works across clouds, and has built-in machine
learning and business intelligence, all within a unified platform [2, 3]. The
citation numbers refer to the returned search results and are 1-indexed. For
example, [1] means that the sentence is attributed to the first search result.
[2, 3] means that the sentence is attributed to both the second and third
search results.
Corresponds to the JSON property includeCitations
6059 6060 6061 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6059 def include_citations @include_citations end |
#language_code ⇒ String
Language code for Summary. Use language tags defined by BCP47. Note: This is an experimental feature.
Corresponds to the JSON property languageCode
6066 6067 6068 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6066 def language_code @language_code end |
#model_prompt_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1SearchRequestContentSearchSpecSummarySpecModelPromptSpec
Specification of the prompt to use with the model.
Corresponds to the JSON property modelPromptSpec
6071 6072 6073 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6071 def model_prompt_spec @model_prompt_spec end |
#model_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1SearchRequestContentSearchSpecSummarySpecModelSpec
Specification of the model.
Corresponds to the JSON property modelSpec
6076 6077 6078 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6076 def model_spec @model_spec end |
#summary_result_count ⇒ Fixnum
The number of top results to generate the summary from. If the number of
results returned is less than summaryResultCount, the summary is generated
from all of the results. At most 10 results for documents mode, or 50 for
chunks mode, can be used to generate a summary. The chunks mode is used when
SearchRequest.ContentSearchSpec.search_result_mode is set to CHUNKS.
Corresponds to the JSON property summaryResultCount
6085 6086 6087 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6085 def summary_result_count @summary_result_count end |
#use_semantic_chunks ⇒ Boolean Also known as: use_semantic_chunks?
If true, answer will be generated from most relevant chunks from top search
results. This feature will improve summary quality. Note that with this
feature enabled, not all top search results will be referenced and included in
the reference list, so the citation source index only points to the search
results listed in the reference list.
Corresponds to the JSON property useSemanticChunks
6094 6095 6096 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6094 def use_semantic_chunks @use_semantic_chunks end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6102 6103 6104 6105 6106 6107 6108 6109 6110 6111 6112 6113 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6102 def update!(**args) @ignore_adversarial_query = args[:ignore_adversarial_query] if args.key?(:ignore_adversarial_query) @ignore_jail_breaking_query = args[:ignore_jail_breaking_query] if args.key?(:ignore_jail_breaking_query) @ignore_low_relevant_content = args[:ignore_low_relevant_content] if args.key?(:ignore_low_relevant_content) @ignore_non_summary_seeking_query = args[:ignore_non_summary_seeking_query] if args.key?(:ignore_non_summary_seeking_query) @include_citations = args[:include_citations] if args.key?(:include_citations) @language_code = args[:language_code] if args.key?(:language_code) @model_prompt_spec = args[:model_prompt_spec] if args.key?(:model_prompt_spec) @model_spec = args[:model_spec] if args.key?(:model_spec) @summary_result_count = args[:summary_result_count] if args.key?(:summary_result_count) @use_semantic_chunks = args[:use_semantic_chunks] if args.key?(:use_semantic_chunks) end |