Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1SearchRequestContentSearchSpecSummarySpecModelPromptSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Specification of the prompt to use with the model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1SearchRequestContentSearchSpecSummarySpecModelPromptSpec

Returns a new instance of GoogleCloudDiscoveryengineV1SearchRequestContentSearchSpecSummarySpecModelPromptSpec.



6126
6127
6128
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6126

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#preambleString

Text at the beginning of the prompt that instructs the assistant. Examples are available in the user guide. Corresponds to the JSON property preamble

Returns:

  • (String)


6124
6125
6126
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6124

def preamble
  @preamble
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6131
6132
6133
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6131

def update!(**args)
  @preamble = args[:preamble] if args.key?(:preamble)
end