Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1TargetSite

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

A target site for the SiteSearchEngine.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1TargetSite

Returns a new instance of GoogleCloudDiscoveryengineV1TargetSite.



6466
6467
6468
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6466

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#exact_matchBoolean Also known as: exact_match?

Immutable. If set to false, a uri_pattern is generated to include all pages whose address contains the provided_uri_pattern. If set to true, an uri_pattern is generated to try to be an exact match of the provided_uri_pattern or just the specific page if the provided_uri_pattern is a specific one. provided_uri_pattern is always normalized to generate the URI pattern to be used by the search engine. Corresponds to the JSON property exactMatch

Returns:

  • (Boolean)


6413
6414
6415
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6413

def exact_match
  @exact_match
end

#failure_reasonGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1TargetSiteFailureReason

Site search indexing failure reasons. Corresponds to the JSON property failureReason



6419
6420
6421
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6419

def failure_reason
  @failure_reason
end

#generated_uri_patternString

Output only. This is system-generated based on the provided_uri_pattern. Corresponds to the JSON property generatedUriPattern

Returns:

  • (String)


6424
6425
6426
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6424

def generated_uri_pattern
  @generated_uri_pattern
end

#indexing_statusString

Output only. Indexing status. Corresponds to the JSON property indexingStatus

Returns:

  • (String)


6429
6430
6431
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6429

def indexing_status
  @indexing_status
end

#nameString

Output only. The fully qualified resource name of the target site. projects/ project/locations/location/collections/collection/dataStores/data_store/ siteSearchEngine/targetSites/target_site`Thetarget_site_idis system- generated. Corresponds to the JSON propertyname`

Returns:

  • (String)


6437
6438
6439
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6437

def name
  @name
end

#provided_uri_patternString

Required. Input only. The user provided URI pattern from which the generated_uri_pattern is generated. Corresponds to the JSON property providedUriPattern

Returns:

  • (String)


6443
6444
6445
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6443

def provided_uri_pattern
  @provided_uri_pattern
end

#root_domain_uriString

Output only. Root domain of the provided_uri_pattern. Corresponds to the JSON property rootDomainUri

Returns:

  • (String)


6448
6449
6450
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6448

def root_domain_uri
  @root_domain_uri
end

#site_verification_infoGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1SiteVerificationInfo

Verification information for target sites in advanced site search. Corresponds to the JSON property siteVerificationInfo



6453
6454
6455
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6453

def site_verification_info
  @site_verification_info
end

#typeString

The type of the target site, e.g., whether the site is to be included or excluded. Corresponds to the JSON property type

Returns:

  • (String)


6459
6460
6461
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6459

def type
  @type
end

#update_timeString

Output only. The target site's last updated time. Corresponds to the JSON property updateTime

Returns:

  • (String)


6464
6465
6466
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6464

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6471
6472
6473
6474
6475
6476
6477
6478
6479
6480
6481
6482
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6471

def update!(**args)
  @exact_match = args[:exact_match] if args.key?(:exact_match)
  @failure_reason = args[:failure_reason] if args.key?(:failure_reason)
  @generated_uri_pattern = args[:generated_uri_pattern] if args.key?(:generated_uri_pattern)
  @indexing_status = args[:indexing_status] if args.key?(:indexing_status)
  @name = args[:name] if args.key?(:name)
  @provided_uri_pattern = args[:provided_uri_pattern] if args.key?(:provided_uri_pattern)
  @root_domain_uri = args[:root_domain_uri] if args.key?(:root_domain_uri)
  @site_verification_info = args[:site_verification_info] if args.key?(:site_verification_info)
  @type = args[:type] if args.key?(:type)
  @update_time = args[:update_time] if args.key?(:update_time)
end