Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1Tenant

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Tenant information for a connector source. This includes some of the same information stored in the Credential message, but is limited to only what is needed to provide a list of accessible tenants to the user.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1Tenant

Returns a new instance of GoogleCloudDiscoveryengineV1Tenant.



6650
6651
6652
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6650

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Optional display name for the tenant, e.g. "My Slack Team". Corresponds to the JSON property displayName

Returns:

  • (String)


6635
6636
6637
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6635

def display_name
  @display_name
end

#idString

The tenant's instance ID. Examples: Jira ("8594f221-9797-5f78-1fa4- 485e198d7cd0"), Slack ("T123456"). Corresponds to the JSON property id

Returns:

  • (String)


6641
6642
6643
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6641

def id
  @id
end

#uriString

The URI of the tenant, if applicable. For example, the URI of a Jira instance is https://my-jira-instance.atlassian.net, and a Slack tenant does not have a URI. Corresponds to the JSON property uri

Returns:

  • (String)


6648
6649
6650
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6648

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6655
6656
6657
6658
6659
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6655

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @id = args[:id] if args.key?(:id)
  @uri = args[:uri] if args.key?(:uri)
end