Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1TrainCustomModelResponse
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1TrainCustomModelResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Response of the TrainCustomModelRequest. This message is returned by the google.longrunning.Operations.response field.
Instance Attribute Summary collapse
-
#error_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ImportErrorConfig
Configuration of destination for Import related errors.
-
#error_samples ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>
A sample of errors encountered while processing the data.
-
#metrics ⇒ Hash<String,Float>
The metrics of the trained model.
-
#model_name ⇒ String
Fully qualified name of the CustomTuningModel.
-
#model_status ⇒ String
The trained model status.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1TrainCustomModelResponse
constructor
A new instance of GoogleCloudDiscoveryengineV1TrainCustomModelResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1TrainCustomModelResponse
Returns a new instance of GoogleCloudDiscoveryengineV1TrainCustomModelResponse.
6814 6815 6816 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6814 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ImportErrorConfig
Configuration of destination for Import related errors.
Corresponds to the JSON property errorConfig
6787 6788 6789 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6787 def error_config @error_config end |
#error_samples ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>
A sample of errors encountered while processing the data.
Corresponds to the JSON property errorSamples
6792 6793 6794 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6792 def error_samples @error_samples end |
#metrics ⇒ Hash<String,Float>
The metrics of the trained model.
Corresponds to the JSON property metrics
6797 6798 6799 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6797 def metrics @metrics end |
#model_name ⇒ String
Fully qualified name of the CustomTuningModel.
Corresponds to the JSON property modelName
6802 6803 6804 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6802 def model_name @model_name end |
#model_status ⇒ String
The trained model status. Possible values are: * bad-data: The training
data quality is bad. * no-improvement: Tuning didn't improve performance.
Won't deploy. * in-progress: Model training job creation is in progress. *
training: Model is actively training. * evaluating: The model is
evaluating trained metrics. * indexing: The model trained metrics are
indexing. * ready: The model is ready for serving.
Corresponds to the JSON property modelStatus
6812 6813 6814 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6812 def model_status @model_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6819 6820 6821 6822 6823 6824 6825 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6819 def update!(**args) @error_config = args[:error_config] if args.key?(:error_config) @error_samples = args[:error_samples] if args.key?(:error_samples) @metrics = args[:metrics] if args.key?(:metrics) @model_name = args[:model_name] if args.key?(:model_name) @model_status = args[:model_status] if args.key?(:model_status) end |