Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1UserStore
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1UserStore
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Configures metadata that is used for End User entities.
Instance Attribute Summary collapse
-
#default_license_config ⇒ String
Optional.
-
#display_name ⇒ String
The display name of the User Store.
-
#enable_expired_license_auto_update ⇒ Boolean
(also: #enable_expired_license_auto_update?)
Optional.
-
#enable_license_auto_register ⇒ Boolean
(also: #enable_license_auto_register?)
Optional.
-
#name ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1UserStore
constructor
A new instance of GoogleCloudDiscoveryengineV1UserStore.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1UserStore
Returns a new instance of GoogleCloudDiscoveryengineV1UserStore.
7008 7009 7010 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7008 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_license_config ⇒ String
Optional. The default subscription LicenseConfig for the UserStore, if
UserStore.enable_license_auto_register is true, new users will automatically
register under the default subscription. If default LicenseConfig doesn't have
remaining license seats left, new users will not be assigned with license and
will be blocked for Vertex AI Search features. This is used if
license_assignment_tier_rules is not configured.
Corresponds to the JSON property defaultLicenseConfig
6978 6979 6980 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6978 def default_license_config @default_license_config end |
#display_name ⇒ String
The display name of the User Store.
Corresponds to the JSON property displayName
6983 6984 6985 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6983 def display_name @display_name end |
#enable_expired_license_auto_update ⇒ Boolean Also known as: enable_expired_license_auto_update?
Optional. Whether to enable license auto update for users in this User Store.
If true, users with expired licenses will automatically be updated to use the
default license config as long as the default license config has seats left.
Corresponds to the JSON property enableExpiredLicenseAutoUpdate
6990 6991 6992 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6990 def enable_expired_license_auto_update @enable_expired_license_auto_update end |
#enable_license_auto_register ⇒ Boolean Also known as: enable_license_auto_register?
Optional. Whether to enable license auto register for users in this User Store.
If true, new users will automatically register under the default license
config as long as the default license config has seats left.
Corresponds to the JSON property enableLicenseAutoRegister
6998 6999 7000 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6998 def enable_license_auto_register @enable_license_auto_register end |
#name ⇒ String
Immutable. The full resource name of the User Store, in the format of
projects/project/locations/location/userStores/user_store`. This field
must be a UTF-8 encoded string with a length limit of 1024 characters.
Corresponds to the JSON propertyname`
7006 7007 7008 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7006 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7013 7014 7015 7016 7017 7018 7019 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7013 def update!(**args) @default_license_config = args[:default_license_config] if args.key?(:default_license_config) @display_name = args[:display_name] if args.key?(:display_name) @enable_expired_license_auto_update = args[:enable_expired_license_auto_update] if args.key?(:enable_expired_license_auto_update) @enable_license_auto_register = args[:enable_license_auto_register] if args.key?(:enable_license_auto_register) @name = args[:name] if args.key?(:name) end |