Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1WorkspaceConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Config to store data store type configuration for workspace data

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1WorkspaceConfig

Returns a new instance of GoogleCloudDiscoveryengineV1WorkspaceConfig.



7053
7054
7055
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7053

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dasher_customer_idString

Output only. Obfuscated Dasher customer ID. Derived by the server from the project's GCP organization at data store creation time; any value supplied in the request payload is ignored. Corresponds to the JSON property dasherCustomerId

Returns:

  • (String)


7032
7033
7034
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7032

def dasher_customer_id
  @dasher_customer_id
end

#super_admin_email_addressString

Optional. The super admin email address for the workspace that will be used for access token generation. For now we only use it for Native Google Drive connector data ingestion. Corresponds to the JSON property superAdminEmailAddress

Returns:

  • (String)


7039
7040
7041
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7039

def super_admin_email_address
  @super_admin_email_address
end

#super_admin_service_accountString

Optional. The super admin service account for the workspace that will be used for access token generation. For now we only use it for Native Google Drive connector data ingestion. Corresponds to the JSON property superAdminServiceAccount

Returns:

  • (String)


7046
7047
7048
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7046

def 
  @super_admin_service_account
end

#typeString

The Google Workspace data source. Corresponds to the JSON property type

Returns:

  • (String)


7051
7052
7053
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7051

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7058
7059
7060
7061
7062
7063
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7058

def update!(**args)
  @dasher_customer_id = args[:dasher_customer_id] if args.key?(:dasher_customer_id)
  @super_admin_email_address = args[:super_admin_email_address] if args.key?(:super_admin_email_address)
  @super_admin_service_account = args[:super_admin_service_account] if args.key?(:super_admin_service_account)
  @type = args[:type] if args.key?(:type)
end