Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAlertPolicyResourceConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

The resource level alert config. Used in: * UserLicense * EngineUserData The AlertPolicyConfig in data connector is of same usage. No easy way to migrate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAlertPolicyResourceConfig

Returns a new instance of GoogleCloudDiscoveryengineV1alphaAlertPolicyResourceConfig.



7364
7365
7366
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7364

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#alert_enrollmentsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAlertPolicyResourceConfigAlertEnrollment>

Optional. The enrollment state of each alert. Corresponds to the JSON property alertEnrollments



7342
7343
7344
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7342

def alert_enrollments
  @alert_enrollments
end

#alert_policyString

Immutable. The fully qualified resource name of the AlertPolicy. Corresponds to the JSON property alertPolicy

Returns:

  • (String)


7347
7348
7349
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7347

def alert_policy
  @alert_policy
end

#contact_detailsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaContactDetails>

Optional. The contact details for each alert policy. Corresponds to the JSON property contactDetails



7352
7353
7354
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7352

def contact_details
  @contact_details
end

#language_codeString

Optional. The language code used for notifications Corresponds to the JSON property languageCode

Returns:

  • (String)


7357
7358
7359
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7357

def language_code
  @language_code
end

#region_codeString

Optional. The region code used of the user that subscribed to the alert policy. Corresponds to the JSON property regionCode

Returns:

  • (String)


7362
7363
7364
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7362

def region_code
  @region_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7369
7370
7371
7372
7373
7374
7375
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7369

def update!(**args)
  @alert_enrollments = args[:alert_enrollments] if args.key?(:alert_enrollments)
  @alert_policy = args[:alert_policy] if args.key?(:alert_policy)
  @contact_details = args[:contact_details] if args.key?(:contact_details)
  @language_code = args[:language_code] if args.key?(:language_code)
  @region_code = args[:region_code] if args.key?(:region_code)
end