Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAlphaEvolveExperiment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

An experiment is a single run of the AlphaEvolve agent, an evolutionary coding agent powered by LLM for algorithm discovery and optimization.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAlphaEvolveExperiment

Returns a new instance of GoogleCloudDiscoveryengineV1alphaAlphaEvolveExperiment.



7537
7538
7539
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7537

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAlphaEvolveExperimentConfig

Configuration of an experiment. Corresponds to the JSON property config



7507
7508
7509
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7507

def config
  @config
end

#create_timeString

Output only. Time when the experiment was created. Corresponds to the JSON property createTime

Returns:

  • (String)


7512
7513
7514
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7512

def create_time
  @create_time
end

#initial_alpha_evolve_programString

Output only. Specifies the name of the seed program used to start the experiment. Corresponds to the JSON property initialAlphaEvolveProgram

Returns:

  • (String)


7518
7519
7520
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7518

def initial_alpha_evolve_program
  @initial_alpha_evolve_program
end

#nameString

Identifier. The full resource name of the experiment. Format: projects/ project/locations/location/collections/collection/engines/engine/ sessions/session/alphaEvolveExperiments/alpha_evolve_experiment` Corresponds to the JSON propertyname`

Returns:

  • (String)


7525
7526
7527
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7525

def name
  @name
end

#stateString

Output only. The state of the experiment. Corresponds to the JSON property state

Returns:

  • (String)


7530
7531
7532
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7530

def state
  @state
end

#statsGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAlphaEvolveExperimentStats

Stats about the experiment. Corresponds to the JSON property stats



7535
7536
7537
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7535

def stats
  @stats
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7542
7543
7544
7545
7546
7547
7548
7549
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7542

def update!(**args)
  @config = args[:config] if args.key?(:config)
  @create_time = args[:create_time] if args.key?(:create_time)
  @initial_alpha_evolve_program = args[:initial_alpha_evolve_program] if args.key?(:initial_alpha_evolve_program)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @stats = args[:stats] if args.key?(:stats)
end