Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAlphaEvolveExperimentStats

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Stats about the experiment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAlphaEvolveExperimentStats

Returns a new instance of GoogleCloudDiscoveryengineV1alphaAlphaEvolveExperimentStats.



7790
7791
7792
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7790

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#candidates_countFixnum

Output only. Number of candidates generated. Corresponds to the JSON property candidatesCount

Returns:

  • (Fixnum)


7773
7774
7775
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7773

def candidates_count
  @candidates_count
end

#evaluated_candidates_countFixnum

Output only. Number of candidates evaluated. Corresponds to the JSON property evaluatedCandidatesCount

Returns:

  • (Fixnum)


7778
7779
7780
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7778

def evaluated_candidates_count
  @evaluated_candidates_count
end

#input_token_countFixnum

Output only. Number of billed input tokens consumed by the experiment. Corresponds to the JSON property inputTokenCount

Returns:

  • (Fixnum)


7783
7784
7785
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7783

def input_token_count
  @input_token_count
end

#output_token_countFixnum

Output only. Number of billed output tokens consumed by the experiment. Corresponds to the JSON property outputTokenCount

Returns:

  • (Fixnum)


7788
7789
7790
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7788

def output_token_count
  @output_token_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7795
7796
7797
7798
7799
7800
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7795

def update!(**args)
  @candidates_count = args[:candidates_count] if args.key?(:candidates_count)
  @evaluated_candidates_count = args[:evaluated_candidates_count] if args.key?(:evaluated_candidates_count)
  @input_token_count = args[:input_token_count] if args.key?(:input_token_count)
  @output_token_count = args[:output_token_count] if args.key?(:output_token_count)
end