Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAlphaEvolveProgram

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Represents a single program to be used within the context of an AlphaEvolve experiment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAlphaEvolveProgram

Returns a new instance of GoogleCloudDiscoveryengineV1alphaAlphaEvolveProgram.



7851
7852
7853
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7851

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAlphaEvolveProgramContent

A self-contained message containing the content of a program. Can represent a collection of files. Corresponds to the JSON property content



7813
7814
7815
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7813

def content
  @content
end

#create_timeString

Output only. Time when the program was created. Corresponds to the JSON property createTime

Returns:

  • (String)


7818
7819
7820
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7818

def create_time
  @create_time
end

#evaluationGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAlphaEvolveProgramEvaluation

Evaluation results for a program candidate. Corresponds to the JSON property evaluation



7823
7824
7825
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7823

def evaluation
  @evaluation
end

#lock_tokenString

Optional. Lock token for the program. Corresponds to the JSON property lockToken

Returns:

  • (String)


7828
7829
7830
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7828

def lock_token
  @lock_token
end

#nameString

Identifier. Unique identifier for the program. Format: projects/project/ locations/location/collections/collection/engines/engine/sessions/ session/alphaEvolveExperiments/alpha_evolve_experiment/alphaEvolvePrograms/ alpha_evolve_program` Corresponds to the JSON propertyname`

Returns:

  • (String)


7836
7837
7838
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7836

def name
  @name
end

#parent_programsArray<String>

Output only. Optionally specifies which parent programs this program was evolved from. Format: projects/project/locations/location/collections/ collection/engines/engine/sessions/session/alphaEvolveExperiments/ alpha_evolve_experiment/alphaEvolvePrograms/alpha_evolve_program` Corresponds to the JSON propertyparentPrograms`

Returns:

  • (Array<String>)


7844
7845
7846
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7844

def parent_programs
  @parent_programs
end

#stateString

Output only. State of the program. Corresponds to the JSON property state

Returns:

  • (String)


7849
7850
7851
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7849

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7856
7857
7858
7859
7860
7861
7862
7863
7864
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7856

def update!(**args)
  @content = args[:content] if args.key?(:content)
  @create_time = args[:create_time] if args.key?(:create_time)
  @evaluation = args[:evaluation] if args.key?(:evaluation)
  @lock_token = args[:lock_token] if args.key?(:lock_token)
  @name = args[:name] if args.key?(:name)
  @parent_programs = args[:parent_programs] if args.key?(:parent_programs)
  @state = args[:state] if args.key?(:state)
end