Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAlphaEvolveSourceFile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

A single source file with its path, content and metadata.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAlphaEvolveSourceFile

Returns a new instance of GoogleCloudDiscoveryengineV1alphaAlphaEvolveSourceFile.



7893
7894
7895
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7893

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentString

Required. The raw content of the file. This is a string and not bytes, because it should be ultimately processed by the LLM as text. Corresponds to the JSON property content

Returns:

  • (String)


7875
7876
7877
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7875

def content
  @content
end

#descriptionString

Optional. Additional description of the file. Corresponds to the JSON property description

Returns:

  • (String)


7880
7881
7882
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7880

def description
  @description
end

#pathString

Required. The relative path of the file, including the filename. e.g., "src/ main.py", "utils/helpers.js", "README.md" Corresponds to the JSON property path

Returns:

  • (String)


7886
7887
7888
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7886

def path
  @path
end

#program_languageString

Optional. The programming language of the file. Corresponds to the JSON property programLanguage

Returns:

  • (String)


7891
7892
7893
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7891

def program_language
  @program_language
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7898
7899
7900
7901
7902
7903
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7898

def update!(**args)
  @content = args[:content] if args.key?(:content)
  @description = args[:description] if args.key?(:description)
  @path = args[:path] if args.key?(:path)
  @program_language = args[:program_language] if args.key?(:program_language)
end