Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswer

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Defines an answer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAnswer

Returns a new instance of GoogleCloudDiscoveryengineV1alphaAnswer.



8038
8039
8040
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8038

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#answer_skipped_reasonsArray<String>

Additional answer-skipped reasons. This provides the reason for ignored cases. If nothing is skipped, this field is not set. Corresponds to the JSON property answerSkippedReasons

Returns:

  • (Array<String>)


7964
7965
7966
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7964

def answer_skipped_reasons
  @answer_skipped_reasons
end

#answer_textString

The textual answer. Corresponds to the JSON property answerText

Returns:

  • (String)


7969
7970
7971
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7969

def answer_text
  @answer_text
end

#blob_attachmentsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerBlobAttachment>

Output only. List of blob attachments in the answer. Corresponds to the JSON property blobAttachments



7974
7975
7976
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7974

def blob_attachments
  @blob_attachments
end

#citationsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerCitation>

Citations. Corresponds to the JSON property citations



7979
7980
7981
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7979

def citations
  @citations
end

#complete_timeString

Output only. Answer completed timestamp. Corresponds to the JSON property completeTime

Returns:

  • (String)


7984
7985
7986
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7984

def complete_time
  @complete_time
end

#create_timeString

Output only. Answer creation timestamp. Corresponds to the JSON property createTime

Returns:

  • (String)


7989
7990
7991
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7989

def create_time
  @create_time
end

#grounding_scoreFloat

A score in the range of [0, 1] describing how grounded the answer is by the reference chunks. Corresponds to the JSON property groundingScore

Returns:

  • (Float)


7995
7996
7997
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7995

def grounding_score
  @grounding_score
end

#grounding_supportsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerGroundingSupport>

Optional. Grounding supports. Corresponds to the JSON property groundingSupports



8000
8001
8002
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8000

def grounding_supports
  @grounding_supports
end

#nameString

Immutable. Fully qualified name projects/project/locations/global/ collections/collection/engines/engine/sessions/*/answers/* Corresponds to the JSON property name

Returns:

  • (String)


8006
8007
8008
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8006

def name
  @name
end

#query_understanding_infoGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerQueryUnderstandingInfo

Query understanding information. Corresponds to the JSON property queryUnderstandingInfo



8011
8012
8013
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8011

def query_understanding_info
  @query_understanding_info
end

#referencesArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerReference>

References. Corresponds to the JSON property references



8016
8017
8018
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8016

def references
  @references
end

Suggested related questions. Corresponds to the JSON property relatedQuestions

Returns:

  • (Array<String>)


8021
8022
8023
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8021

def related_questions
  @related_questions
end

#safety_ratingsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSafetyRating>

Optional. Safety ratings. Corresponds to the JSON property safetyRatings



8026
8027
8028
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8026

def safety_ratings
  @safety_ratings
end

#stateString

The state of the answer generation. Corresponds to the JSON property state

Returns:

  • (String)


8031
8032
8033
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8031

def state
  @state
end

#stepsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerStep>

Answer generation steps. Corresponds to the JSON property steps



8036
8037
8038
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8036

def steps
  @steps
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8043
8044
8045
8046
8047
8048
8049
8050
8051
8052
8053
8054
8055
8056
8057
8058
8059
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8043

def update!(**args)
  @answer_skipped_reasons = args[:answer_skipped_reasons] if args.key?(:answer_skipped_reasons)
  @answer_text = args[:answer_text] if args.key?(:answer_text)
  @blob_attachments = args[:blob_attachments] if args.key?(:blob_attachments)
  @citations = args[:citations] if args.key?(:citations)
  @complete_time = args[:complete_time] if args.key?(:complete_time)
  @create_time = args[:create_time] if args.key?(:create_time)
  @grounding_score = args[:grounding_score] if args.key?(:grounding_score)
  @grounding_supports = args[:grounding_supports] if args.key?(:grounding_supports)
  @name = args[:name] if args.key?(:name)
  @query_understanding_info = args[:query_understanding_info] if args.key?(:query_understanding_info)
  @references = args[:references] if args.key?(:references)
  @related_questions = args[:related_questions] if args.key?(:related_questions)
  @safety_ratings = args[:safety_ratings] if args.key?(:safety_ratings)
  @state = args[:state] if args.key?(:state)
  @steps = args[:steps] if args.key?(:steps)
end