Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerCitation
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerCitation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Citation info for a segment.
Instance Attribute Summary collapse
-
#end_index ⇒ Fixnum
End of the attributed segment, exclusive.
-
#sources ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerCitationSource>
Citation sources for the attributed segment.
-
#start_index ⇒ Fixnum
Index indicates the start of the segment, measured in bytes (UTF-8 unicode).
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAnswerCitation
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaAnswerCitation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAnswerCitation
Returns a new instance of GoogleCloudDiscoveryengineV1alphaAnswerCitation.
8074 8075 8076 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8074 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_index ⇒ Fixnum
End of the attributed segment, exclusive. Measured in bytes (UTF-8 unicode).
If there are multi-byte characters,such as non-ASCII characters, the index
measurement is longer than the string length.
Corresponds to the JSON property endIndex
8060 8061 8062 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8060 def end_index @end_index end |
#sources ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerCitationSource>
Citation sources for the attributed segment.
Corresponds to the JSON property sources
8065 8066 8067 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8065 def sources @sources end |
#start_index ⇒ Fixnum
Index indicates the start of the segment, measured in bytes (UTF-8 unicode).
If there are multi-byte characters,such as non-ASCII characters, the index
measurement is longer than the string length.
Corresponds to the JSON property startIndex
8072 8073 8074 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8072 def start_index @start_index end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8079 8080 8081 8082 8083 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8079 def update!(**args) @end_index = args[:end_index] if args.key?(:end_index) @sources = args[:sources] if args.key?(:sources) @start_index = args[:start_index] if args.key?(:start_index) end |