Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservationSearchResultChunkInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Chunk information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservationSearchResultChunkInfo

Returns a new instance of GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservationSearchResultChunkInfo.



8031
8032
8033
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8031

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chunkString

Chunk resource name. Corresponds to the JSON property chunk

Returns:

  • (String)


8016
8017
8018
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8016

def chunk
  @chunk
end

#contentString

Chunk textual content. Corresponds to the JSON property content

Returns:

  • (String)


8021
8022
8023
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8021

def content
  @content
end

#relevance_scoreFloat

The relevance of the chunk for a given query. Values range from 0.0 ( completely irrelevant) to 1.0 (completely relevant). This value is for informational purpose only. It may change for the same query and chunk at any time due to a model retraining or change in implementation. Corresponds to the JSON property relevanceScore

Returns:

  • (Float)


8029
8030
8031
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8029

def relevance_score
  @relevance_score
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8036
8037
8038
8039
8040
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8036

def update!(**args)
  @chunk = args[:chunk] if args.key?(:chunk)
  @content = args[:content] if args.key?(:content)
  @relevance_score = args[:relevance_score] if args.key?(:relevance_score)
end