Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistAnswer

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

AssistAnswer resource, main part of AssistResponse.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAssistAnswer

Returns a new instance of GoogleCloudDiscoveryengineV1alphaAssistAnswer.



8749
8750
8751
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8749

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assist_skipped_reasonsArray<String>

Reasons for not answering the assist call. Corresponds to the JSON property assistSkippedReasons

Returns:

  • (Array<String>)


8723
8724
8725
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8723

def assist_skipped_reasons
  @assist_skipped_reasons
end

#customer_policy_enforcement_resultGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistAnswerCustomerPolicyEnforcementResult

Customer policy enforcement results. Contains the results of the various policy checks, like the banned phrases or the Model Armor checks. Corresponds to the JSON property customerPolicyEnforcementResult



8729
8730
8731
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8729

def customer_policy_enforcement_result
  @customer_policy_enforcement_result
end

#nameString

Immutable. Identifier. Resource name of the AssistAnswer. Format: projects/ project/locations/location/collections/collection/engines/engine/ sessions/session/assistAnswers/assist_answer`This field must be a UTF-8 encoded string with a length limit of 1024 characters. Corresponds to the JSON propertyname`

Returns:

  • (String)


8737
8738
8739
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8737

def name
  @name
end

#repliesArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistAnswerReply>

Replies of the assistant. Corresponds to the JSON property replies



8742
8743
8744
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8742

def replies
  @replies
end

#stateString

State of the answer generation. Corresponds to the JSON property state

Returns:

  • (String)


8747
8748
8749
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8747

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8754
8755
8756
8757
8758
8759
8760
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8754

def update!(**args)
  @assist_skipped_reasons = args[:assist_skipped_reasons] if args.key?(:assist_skipped_reasons)
  @customer_policy_enforcement_result = args[:customer_policy_enforcement_result] if args.key?(:customer_policy_enforcement_result)
  @name = args[:name] if args.key?(:name)
  @replies = args[:replies] if args.key?(:replies)
  @state = args[:state] if args.key?(:state)
end