Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistAnswerCustomerPolicyEnforcementResultBannedPhraseEnforcementResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Customer policy enforcement result for the banned phrase policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAssistAnswerCustomerPolicyEnforcementResultBannedPhraseEnforcementResult

Returns a new instance of GoogleCloudDiscoveryengineV1alphaAssistAnswerCustomerPolicyEnforcementResultBannedPhraseEnforcementResult.



8800
8801
8802
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8800

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#banned_phrasesArray<String>

The banned phrases that were found in the query or the answer. Corresponds to the JSON property bannedPhrases

Returns:

  • (Array<String>)


8798
8799
8800
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8798

def banned_phrases
  @banned_phrases
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8805
8806
8807
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8805

def update!(**args)
  @banned_phrases = args[:banned_phrases] if args.key?(:banned_phrases)
end