Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistAnswerReply

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

One part of the multi-part response of the assist call.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAssistAnswerReply

Returns a new instance of GoogleCloudDiscoveryengineV1alphaAssistAnswerReply.



8262
8263
8264
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8262

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

The time when the reply was created. Corresponds to the JSON property createTime

Returns:

  • (String)


8244
8245
8246
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8244

def create_time
  @create_time
end

#grounded_contentGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantGroundedContent

A piece of content and possibly its grounding information. Not all content needs grounding. Phrases like "Of course, I will gladly search it for you." do not need grounding. Corresponds to the JSON property groundedContent



8251
8252
8253
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8251

def grounded_content
  @grounded_content
end

#reply_idString

Output only. When set, uniquely identifies a reply within the AssistAnswer resource. During an AssistantService.StreamAssist call, multiple Reply messages with the same ID can occur within the response stream (across multiple StreamAssistResponse messages). These represent parts of a single Reply message in the final AssistAnswer resource. Corresponds to the JSON property replyId

Returns:

  • (String)


8260
8261
8262
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8260

def reply_id
  @reply_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8267
8268
8269
8270
8271
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8267

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @grounded_content = args[:grounded_content] if args.key?(:grounded_content)
  @reply_id = args[:reply_id] if args.key?(:reply_id)
end