Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantContent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Multi-modal content.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAssistantContent

Returns a new instance of GoogleCloudDiscoveryengineV1alphaAssistantContent.



8942
8943
8944
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8942

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#code_execution_resultGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantContentCodeExecutionResult

Result of executing ExecutableCode. Corresponds to the JSON property codeExecutionResult



8909
8910
8911
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8909

def code_execution_result
  @code_execution_result
end

#executable_codeGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantContentExecutableCode

Code generated by the model that is meant to be executed by the model. Corresponds to the JSON property executableCode



8914
8915
8916
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8914

def executable_code
  @executable_code
end

#fileGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantContentFile

A file, e.g., an audio summary. Corresponds to the JSON property file



8919
8920
8921
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8919

def file
  @file
end

#inline_dataGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantContentBlob

Inline blob. Corresponds to the JSON property inlineData



8924
8925
8926
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8924

def inline_data
  @inline_data
end

#roleString

The producer of the content. Can be "model" or "user". Corresponds to the JSON property role

Returns:

  • (String)


8929
8930
8931
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8929

def role
  @role
end

#textString

Inline text. Corresponds to the JSON property text

Returns:

  • (String)


8934
8935
8936
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8934

def text
  @text
end

#thoughtBoolean Also known as: thought?

Optional. Indicates if the part is thought from the model. Corresponds to the JSON property thought

Returns:

  • (Boolean)


8939
8940
8941
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8939

def thought
  @thought
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8947
8948
8949
8950
8951
8952
8953
8954
8955
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8947

def update!(**args)
  @code_execution_result = args[:code_execution_result] if args.key?(:code_execution_result)
  @executable_code = args[:executable_code] if args.key?(:executable_code)
  @file = args[:file] if args.key?(:file)
  @inline_data = args[:inline_data] if args.key?(:inline_data)
  @role = args[:role] if args.key?(:role)
  @text = args[:text] if args.key?(:text)
  @thought = args[:thought] if args.key?(:thought)
end