Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantGroundedContent
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantGroundedContent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
A piece of content and possibly its grounding information. Not all content needs grounding. Phrases like "Of course, I will gladly search it for you." do not need grounding.
Instance Attribute Summary collapse
-
#citation_metadata ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaCitationMetadata
A collection of source attributions for a piece of content.
-
#content ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantContent
Multi-modal content.
-
#text_grounding_metadata ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantGroundedContentTextGroundingMetadata
Grounding details for text sources.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAssistantGroundedContent
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaAssistantGroundedContent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAssistantGroundedContent
Returns a new instance of GoogleCloudDiscoveryengineV1alphaAssistantGroundedContent.
9082 9083 9084 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9082 def initialize(**args) update!(**args) end |
Instance Attribute Details
#citation_metadata ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaCitationMetadata
A collection of source attributions for a piece of content.
Corresponds to the JSON property citationMetadata
9070 9071 9072 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9070 def @citation_metadata end |
#content ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantContent
Multi-modal content.
Corresponds to the JSON property content
9075 9076 9077 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9075 def content @content end |
#text_grounding_metadata ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantGroundedContentTextGroundingMetadata
Grounding details for text sources.
Corresponds to the JSON property textGroundingMetadata
9080 9081 9082 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9080 def @text_grounding_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9087 9088 9089 9090 9091 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9087 def update!(**args) @citation_metadata = args[:citation_metadata] if args.key?(:citation_metadata) @content = args[:content] if args.key?(:content) @text_grounding_metadata = args[:text_grounding_metadata] if args.key?(:text_grounding_metadata) end |