Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Document metadata.
Instance Attribute Summary collapse
-
#document ⇒ String
Document resource name.
-
#domain ⇒ String
Domain name from the document URI.
-
#language ⇒ String
Corresponds to the JSON property
language. -
#mime_type ⇒ String
The mime type of the document.
-
#page_identifier ⇒ String
Page identifier.
-
#title ⇒ String
Title.
-
#uri ⇒ String
URI for the document.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata
Returns a new instance of GoogleCloudDiscoveryengineV1alphaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata.
9192 9193 9194 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9192 def initialize(**args) update!(**args) end |
Instance Attribute Details
#document ⇒ String
Document resource name.
Corresponds to the JSON property document
9156 9157 9158 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9156 def document @document end |
#domain ⇒ String
Domain name from the document URI. Note that the uri field may contain a URL
that redirects to the actual website, in which case this will contain the
domain name of the target site.
Corresponds to the JSON property domain
9163 9164 9165 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9163 def domain @domain end |
#language ⇒ String
Corresponds to the JSON property language
9168 9169 9170 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9168 def language @language end |
#mime_type ⇒ String
The mime type of the document. https://www.iana.org/assignments/media-types/
media-types.xhtml.
Corresponds to the JSON property mimeType
9174 9175 9176 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9174 def mime_type @mime_type end |
#page_identifier ⇒ String
Page identifier.
Corresponds to the JSON property pageIdentifier
9179 9180 9181 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9179 def page_identifier @page_identifier end |
#title ⇒ String
Title.
Corresponds to the JSON property title
9184 9185 9186 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9184 def title @title end |
#uri ⇒ String
URI for the document. It may contain a URL that redirects to the actual
website.
Corresponds to the JSON property uri
9190 9191 9192 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9190 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9197 9198 9199 9200 9201 9202 9203 9204 9205 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9197 def update!(**args) @document = args[:document] if args.key?(:document) @domain = args[:domain] if args.key?(:domain) @language = args[:language] if args.key?(:language) @mime_type = args[:mime_type] if args.key?(:mime_type) @page_identifier = args[:page_identifier] if args.key?(:page_identifier) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) end |