Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaBatchUpdateUserLicensesMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Metadata related to the progress of the UserLicenseService. BatchUpdateUserLicenses operation. This will be returned by the google. longrunning.Operation.metadata field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaBatchUpdateUserLicensesMetadata

Returns a new instance of GoogleCloudDiscoveryengineV1alphaBatchUpdateUserLicensesMetadata.



9368
9369
9370
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9368

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Operation create time. Corresponds to the JSON property createTime

Returns:

  • (String)


9350
9351
9352
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9350

def create_time
  @create_time
end

#failure_countFixnum

Count of user licenses that failed to be updated. Corresponds to the JSON property failureCount

Returns:

  • (Fixnum)


9355
9356
9357
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9355

def failure_count
  @failure_count
end

#success_countFixnum

Count of user licenses successfully updated. Corresponds to the JSON property successCount

Returns:

  • (Fixnum)


9360
9361
9362
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9360

def success_count
  @success_count
end

#update_timeString

Operation last update time. If the operation is done, this is also the finish time. Corresponds to the JSON property updateTime

Returns:

  • (String)


9366
9367
9368
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9366

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9373
9374
9375
9376
9377
9378
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9373

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @failure_count = args[:failure_count] if args.key?(:failure_count)
  @success_count = args[:success_count] if args.key?(:success_count)
  @update_time = args[:update_time] if args.key?(:update_time)
end