Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaBatchUpdateUserLicensesResponse
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaBatchUpdateUserLicensesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Response message for UserLicenseService.BatchUpdateUserLicenses method.
Instance Attribute Summary collapse
-
#error_samples ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>
A sample of errors encountered while processing the request.
-
#user_licenses ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaUserLicense>
UserLicenses successfully updated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaBatchUpdateUserLicensesResponse
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaBatchUpdateUserLicensesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaBatchUpdateUserLicensesResponse
Returns a new instance of GoogleCloudDiscoveryengineV1alphaBatchUpdateUserLicensesResponse.
9385 9386 9387 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9385 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_samples ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>
A sample of errors encountered while processing the request.
Corresponds to the JSON property errorSamples
9378 9379 9380 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9378 def error_samples @error_samples end |
#user_licenses ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaUserLicense>
UserLicenses successfully updated.
Corresponds to the JSON property userLicenses
9383 9384 9385 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9383 def user_licenses @user_licenses end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9390 9391 9392 9393 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9390 def update!(**args) @error_samples = args[:error_samples] if args.key?(:error_samples) @user_licenses = args[:user_licenses] if args.key?(:user_licenses) end |