Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaCitation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Source attributions for content.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaCitation

Returns a new instance of GoogleCloudDiscoveryengineV1alphaCitation.



8881
8882
8883
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8881

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_indexFixnum

Output only. End index into the content. Corresponds to the JSON property endIndex

Returns:

  • (Fixnum)


8847
8848
8849
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8847

def end_index
  @end_index
end

#licenseString

Output only. License of the attribution. Corresponds to the JSON property license

Returns:

  • (String)


8852
8853
8854
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8852

def license
  @license
end

#publication_dateGoogle::Apis::DiscoveryengineV1beta::GoogleTypeDate

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property publicationDate



8864
8865
8866
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8864

def publication_date
  @publication_date
end

#start_indexFixnum

Output only. Start index into the content. Corresponds to the JSON property startIndex

Returns:

  • (Fixnum)


8869
8870
8871
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8869

def start_index
  @start_index
end

#titleString

Output only. Title of the attribution. Corresponds to the JSON property title

Returns:

  • (String)


8874
8875
8876
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8874

def title
  @title
end

#uriString

Output only. Url reference of the attribution. Corresponds to the JSON property uri

Returns:

  • (String)


8879
8880
8881
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8879

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8886
8887
8888
8889
8890
8891
8892
8893
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8886

def update!(**args)
  @end_index = args[:end_index] if args.key?(:end_index)
  @license = args[:license] if args.key?(:license)
  @publication_date = args[:publication_date] if args.key?(:publication_date)
  @start_index = args[:start_index] if args.key?(:start_index)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end