Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaCollection
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaCollection
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Collection is a container for configuring resources and access to a set of DataStores.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#data_connector ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataConnector
Manages the connection to external data sources for all data stores grouped under a Collection.
-
#display_name ⇒ String
Required.
-
#name ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaCollection
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaCollection.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaCollection
Returns a new instance of GoogleCloudDiscoveryengineV1alphaCollection.
9033 9034 9035 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9033 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp the Collection was created at.
Corresponds to the JSON property createTime
9008 9009 9010 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9008 def create_time @create_time end |
#data_connector ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataConnector
Manages the connection to external data sources for all data stores grouped
under a Collection. It's a singleton resource of Collection. The
initialization is only supported through DataConnectorService.
SetUpDataConnector method, which will create a new Collection and initialize
its DataConnector.
Corresponds to the JSON property dataConnector
9017 9018 9019 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9017 def data_connector @data_connector end |
#display_name ⇒ String
Required. The Collection display name. This field must be a UTF-8 encoded
string with a length limit of 128 characters. Otherwise, an INVALID_ARGUMENT
error is returned.
Corresponds to the JSON property displayName
9024 9025 9026 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9024 def display_name @display_name end |
#name ⇒ String
Immutable. The full resource name of the Collection. Format: projects/
project/locations/location/collections/collection_id`. This field must be
a UTF-8 encoded string with a length limit of 1024 characters.
Corresponds to the JSON propertyname`
9031 9032 9033 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9031 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9038 9039 9040 9041 9042 9043 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9038 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @data_connector = args[:data_connector] if args.key?(:data_connector) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) end |