Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaConnectorRun

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

A data sync run of DataConnector. After DataConnector is successfully initialized, data syncs are scheduled at DataConnector.refresh_interval. A ConnectorRun represents a data sync either in the past or onging that the moment. //

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaConnectorRun

Returns a new instance of GoogleCloudDiscoveryengineV1alphaConnectorRun.



9819
9820
9821
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9819

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_timeString

Output only. The time when the connector run ended. Corresponds to the JSON property endTime

Returns:

  • (String)


9772
9773
9774
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9772

def end_time
  @end_time
end

#entity_runsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaConnectorRunEntityRun>

Output only. The details of the entities synced at the ConnectorRun. Each ConnectorRun consists of syncing one or more entities. Corresponds to the JSON property entityRuns



9778
9779
9780
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9778

def entity_runs
  @entity_runs
end

#errorsArray<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>

Contains info about errors incurred during the sync. Only exist if running into an error state. Contains error code and error message. Use with the state field. Corresponds to the JSON property errors



9785
9786
9787
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9785

def errors
  @errors
end

#latest_pause_timeString

Output only. The time when the connector run was most recently paused. Corresponds to the JSON property latestPauseTime

Returns:

  • (String)


9790
9791
9792
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9790

def latest_pause_time
  @latest_pause_time
end

#nameString

Output only. The full resource name of the Connector Run. Format: projects/*/ locations/*/collections/*/dataConnector/connectorRuns/*. The connector_run_id is system-generated. Corresponds to the JSON property name

Returns:

  • (String)


9797
9798
9799
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9797

def name
  @name
end

#start_timeString

Output only. The time when the connector run started. Corresponds to the JSON property startTime

Returns:

  • (String)


9802
9803
9804
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9802

def start_time
  @start_time
end

#stateString

Output only. The state of the sync run. Corresponds to the JSON property state

Returns:

  • (String)


9807
9808
9809
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9807

def state
  @state
end

#state_update_timeString

Timestamp at which the connector run sync state was last updated. Corresponds to the JSON property stateUpdateTime

Returns:

  • (String)


9812
9813
9814
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9812

def state_update_time
  @state_update_time
end

#triggerString

Output only. The trigger for this ConnectorRun. Corresponds to the JSON property trigger

Returns:

  • (String)


9817
9818
9819
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9817

def trigger
  @trigger
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9824
9825
9826
9827
9828
9829
9830
9831
9832
9833
9834
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9824

def update!(**args)
  @end_time = args[:end_time] if args.key?(:end_time)
  @entity_runs = args[:entity_runs] if args.key?(:entity_runs)
  @errors = args[:errors] if args.key?(:errors)
  @latest_pause_time = args[:latest_pause_time] if args.key?(:latest_pause_time)
  @name = args[:name] if args.key?(:name)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @state_update_time = args[:state_update_time] if args.key?(:state_update_time)
  @trigger = args[:trigger] if args.key?(:trigger)
end