Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaControlBoostAction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Adjusts order of products in returned list.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaControlBoostAction

Returns a new instance of GoogleCloudDiscoveryengineV1alphaControlBoostAction.



10125
10126
10127
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10125

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#boostFloat

Strength of the boost, which should be in [-1, 1]. Negative boost means demotion. Default is 0.0 (No-op). Corresponds to the JSON property boost

Returns:

  • (Float)


10095
10096
10097
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10095

def boost
  @boost
end

#data_storeString

Required. Specifies which data store's documents can be boosted by this control. Full data store name e.g. projects/123/locations/global/collections/ default_collection/dataStores/default_data_store Corresponds to the JSON property dataStore

Returns:

  • (String)


10102
10103
10104
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10102

def data_store
  @data_store
end

#filterString

Required. Specifies which products to apply the boost to. If no filter is provided all products will be boosted (No-op). Syntax documentation: https:// cloud.google.com/retail/docs/filter-and-order Maximum length is 5000 characters. Otherwise an INVALID ARGUMENT error is thrown. Corresponds to the JSON property filter

Returns:

  • (String)


10110
10111
10112
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10110

def filter
  @filter
end

#fixed_boostFloat

Optional. Strength of the boost, which should be in [-1, 1]. Negative boost means demotion. Default is 0.0 (No-op). Corresponds to the JSON property fixedBoost

Returns:

  • (Float)


10116
10117
10118
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10116

def fixed_boost
  @fixed_boost
end

#interpolation_boost_specGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaControlBoostActionInterpolationBoostSpec

Specification for custom ranking based on customer specified attribute value. It provides more controls for customized ranking than the simple (condition, boost) combination above. Corresponds to the JSON property interpolationBoostSpec



10123
10124
10125
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10123

def interpolation_boost_spec
  @interpolation_boost_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10130
10131
10132
10133
10134
10135
10136
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10130

def update!(**args)
  @boost = args[:boost] if args.key?(:boost)
  @data_store = args[:data_store] if args.key?(:data_store)
  @filter = args[:filter] if args.key?(:filter)
  @fixed_boost = args[:fixed_boost] if args.key?(:fixed_boost)
  @interpolation_boost_spec = args[:interpolation_boost_spec] if args.key?(:interpolation_boost_spec)
end