Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaControlPromoteAction
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaControlPromoteAction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Promote certain links based on some trigger queries. Example: Promote shoe
store link when searching for shoe keyword. The link can be outside of
associated data store.
Instance Attribute Summary collapse
-
#data_store ⇒ String
Required.
-
#search_link_promotion ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchLinkPromotion
Promotion proto includes uri and other helping information to display the promotion.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaControlPromoteAction
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaControlPromoteAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaControlPromoteAction
Returns a new instance of GoogleCloudDiscoveryengineV1alphaControlPromoteAction.
10206 10207 10208 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10206 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_store ⇒ String
Required. Data store with which this promotion is attached to.
Corresponds to the JSON property dataStore
10198 10199 10200 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10198 def data_store @data_store end |
#search_link_promotion ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchLinkPromotion
Promotion proto includes uri and other helping information to display the
promotion.
Corresponds to the JSON property searchLinkPromotion
10204 10205 10206 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10204 def search_link_promotion @search_link_promotion end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10211 10212 10213 10214 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10211 def update!(**args) @data_store = args[:data_store] if args.key?(:data_store) @search_link_promotion = args[:search_link_promotion] if args.key?(:search_link_promotion) end |