Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataConnectorConnectorMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

User-facing metadata for the connector, shown on the connector detail page ( title, description, short_description, author, note).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaDataConnectorConnectorMetadata

Returns a new instance of GoogleCloudDiscoveryengineV1alphaDataConnectorConnectorMetadata.



10921
10922
10923
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10921

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authorString

Optional. The party that authored the connector, e.g. "Google" or a third- party provider name. Lets end users see who authored a connector (future: third-party-authored connectors). Corresponds to the JSON property author

Returns:

  • (String)


10896
10897
10898
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10896

def author
  @author
end

#descriptionString

Optional. Human-readable description of the connector, shown on the connector detail page. One connector has a single description. Corresponds to the JSON property description

Returns:

  • (String)


10902
10903
10904
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10902

def description
  @description
end

#noteString

Optional. Free-form, multi-line note about the connector's capabilities or a custom note that can be set for the connector. Corresponds to the JSON property note

Returns:

  • (String)


10908
10909
10910
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10908

def note
  @note
end

#short_descriptionString

Optional. Short, subtitle-length description of the connector (e.g. shown beneath the connector name in list and detail views). Corresponds to the JSON property shortDescription

Returns:

  • (String)


10914
10915
10916
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10914

def short_description
  @short_description
end

#titleString

Optional. Display title of the connector. Corresponds to the JSON property title

Returns:

  • (String)


10919
10920
10921
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10919

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10926
10927
10928
10929
10930
10931
10932
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10926

def update!(**args)
  @author = args[:author] if args.key?(:author)
  @description = args[:description] if args.key?(:description)
  @note = args[:note] if args.key?(:note)
  @short_description = args[:short_description] if args.key?(:short_description)
  @title = args[:title] if args.key?(:title)
end