Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataConnectorEndUserConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Any params and credentials used specifically for EUA connectors.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaDataConnectorEndUserConfig

Returns a new instance of GoogleCloudDiscoveryengineV1alphaDataConnectorEndUserConfig.



10962
10963
10964
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10962

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_paramsHash<String,Object>

Optional. Any additional parameters needed for EUA. Corresponds to the JSON property additionalParams

Returns:

  • (Hash<String,Object>)


10942
10943
10944
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10942

def additional_params
  @additional_params
end

#auth_paramsHash<String,Object>

Optional. Any authentication parameters specific to EUA connectors. Corresponds to the JSON property authParams

Returns:

  • (Hash<String,Object>)


10947
10948
10949
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10947

def auth_params
  @auth_params
end

#json_auth_paramsString

Optional. Any authentication parameters specific to EUA connectors in json string format. Corresponds to the JSON property jsonAuthParams

Returns:

  • (String)


10953
10954
10955
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10953

def json_auth_params
  @json_auth_params
end

#tenantGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaTenant

Tenant information for a connector source. This includes some of the same information stored in the Credential message, but is limited to only what is needed to provide a list of accessible tenants to the user. Corresponds to the JSON property tenant



10960
10961
10962
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10960

def tenant
  @tenant
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10967
10968
10969
10970
10971
10972
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10967

def update!(**args)
  @additional_params = args[:additional_params] if args.key?(:additional_params)
  @auth_params = args[:auth_params] if args.key?(:auth_params)
  @json_auth_params = args[:json_auth_params] if args.key?(:json_auth_params)
  @tenant = args[:tenant] if args.key?(:tenant)
end