Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataConnectorRealtimeSyncConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

The configuration for realtime sync to store additional params for realtime sync.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaDataConnectorRealtimeSyncConfig

Returns a new instance of GoogleCloudDiscoveryengineV1alphaDataConnectorRealtimeSyncConfig.



11044
11045
11046
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11044

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#realtime_sync_secretString

Optional. The ID of the Secret Manager secret used for webhook secret. Corresponds to the JSON property realtimeSyncSecret

Returns:

  • (String)


11031
11032
11033
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11031

def realtime_sync_secret
  @realtime_sync_secret
end

#streaming_errorGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataConnectorRealtimeSyncConfigStreamingError

Streaming error details. Corresponds to the JSON property streamingError



11036
11037
11038
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11036

def streaming_error
  @streaming_error
end

#webhook_uriString

Optional. Webhook url for the connector to specify additional params for realtime sync. Corresponds to the JSON property webhookUri

Returns:

  • (String)


11042
11043
11044
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11042

def webhook_uri
  @webhook_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11049
11050
11051
11052
11053
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11049

def update!(**args)
  @realtime_sync_secret = args[:realtime_sync_secret] if args.key?(:realtime_sync_secret)
  @streaming_error = args[:streaming_error] if args.key?(:streaming_error)
  @webhook_uri = args[:webhook_uri] if args.key?(:webhook_uri)
end