Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataStoreBillingEstimation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Estimation of data size per data store.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaDataStoreBillingEstimation

Returns a new instance of GoogleCloudDiscoveryengineV1alphaDataStoreBillingEstimation.



11425
11426
11427
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11425

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#structured_data_sizeFixnum

Data size for structured data in terms of bytes. Corresponds to the JSON property structuredDataSize

Returns:

  • (Fixnum)


11398
11399
11400
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11398

def structured_data_size
  @structured_data_size
end

#structured_data_update_timeString

Last updated timestamp for structured data. Corresponds to the JSON property structuredDataUpdateTime

Returns:

  • (String)


11403
11404
11405
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11403

def structured_data_update_time
  @structured_data_update_time
end

#unstructured_data_sizeFixnum

Data size for unstructured data in terms of bytes. Corresponds to the JSON property unstructuredDataSize

Returns:

  • (Fixnum)


11408
11409
11410
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11408

def unstructured_data_size
  @unstructured_data_size
end

#unstructured_data_update_timeString

Last updated timestamp for unstructured data. Corresponds to the JSON property unstructuredDataUpdateTime

Returns:

  • (String)


11413
11414
11415
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11413

def unstructured_data_update_time
  @unstructured_data_update_time
end

#website_data_sizeFixnum

Data size for websites in terms of bytes. Corresponds to the JSON property websiteDataSize

Returns:

  • (Fixnum)


11418
11419
11420
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11418

def website_data_size
  @website_data_size
end

#website_data_update_timeString

Last updated timestamp for websites. Corresponds to the JSON property websiteDataUpdateTime

Returns:

  • (String)


11423
11424
11425
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11423

def website_data_update_time
  @website_data_update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11430
11431
11432
11433
11434
11435
11436
11437
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11430

def update!(**args)
  @structured_data_size = args[:structured_data_size] if args.key?(:structured_data_size)
  @structured_data_update_time = args[:structured_data_update_time] if args.key?(:structured_data_update_time)
  @unstructured_data_size = args[:unstructured_data_size] if args.key?(:unstructured_data_size)
  @unstructured_data_update_time = args[:unstructured_data_update_time] if args.key?(:unstructured_data_update_time)
  @website_data_size = args[:website_data_size] if args.key?(:website_data_size)
  @website_data_update_time = args[:website_data_update_time] if args.key?(:website_data_update_time)
end