Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDestinationConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Defines target endpoints used to connect to third-party sources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaDestinationConfig

Returns a new instance of GoogleCloudDiscoveryengineV1alphaDestinationConfig.



12032
12033
12034
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12032

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destinationsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDestinationConfigDestination>

Optional. The destinations for the corresponding key. Corresponds to the JSON property destinations



12014
12015
12016
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12014

def destinations
  @destinations
end

#json_paramsString

Additional parameters for this destination config in json string format. Corresponds to the JSON property jsonParams

Returns:

  • (String)


12019
12020
12021
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12019

def json_params
  @json_params
end

#keyString

Optional. Unique destination identifier that is supported by the connector. Corresponds to the JSON property key

Returns:

  • (String)


12024
12025
12026
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12024

def key
  @key
end

#paramsHash<String,Object>

Optional. Additional parameters for this destination config in structured json format. Corresponds to the JSON property params

Returns:

  • (Hash<String,Object>)


12030
12031
12032
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12030

def params
  @params
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12037
12038
12039
12040
12041
12042
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12037

def update!(**args)
  @destinations = args[:destinations] if args.key?(:destinations)
  @json_params = args[:json_params] if args.key?(:json_params)
  @key = args[:key] if args.key?(:key)
  @params = args[:params] if args.key?(:params)
end