Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDocumentProcessingConfigParsingConfigLayoutParsingConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

The layout parsing configurations for documents.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaDocumentProcessingConfigParsingConfigLayoutParsingConfig

Returns a new instance of GoogleCloudDiscoveryengineV1alphaDocumentProcessingConfigParsingConfigLayoutParsingConfig.



12206
12207
12208
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12206

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_get_processed_documentBoolean Also known as: enable_get_processed_document?

Optional. If true, the processed document will be made available for the GetProcessedDocument API. Corresponds to the JSON property enableGetProcessedDocument

Returns:

  • (Boolean)


12162
12163
12164
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12162

def enable_get_processed_document
  @enable_get_processed_document
end

#enable_image_annotationBoolean Also known as: enable_image_annotation?

Optional. If true, the LLM based annotation is added to the image during parsing. Corresponds to the JSON property enableImageAnnotation

Returns:

  • (Boolean)


12169
12170
12171
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12169

def enable_image_annotation
  @enable_image_annotation
end

#enable_llm_layout_parsingBoolean Also known as: enable_llm_layout_parsing?

Optional. If true, the pdf layout will be refined using an LLM. Corresponds to the JSON property enableLlmLayoutParsing

Returns:

  • (Boolean)


12175
12176
12177
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12175

def enable_llm_layout_parsing
  @enable_llm_layout_parsing
end

#enable_table_annotationBoolean Also known as: enable_table_annotation?

Optional. If true, the LLM based annotation is added to the table during parsing. Corresponds to the JSON property enableTableAnnotation

Returns:

  • (Boolean)


12182
12183
12184
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12182

def enable_table_annotation
  @enable_table_annotation
end

#exclude_html_classesArray<String>

Optional. List of HTML classes to exclude from the parsed content. Corresponds to the JSON property excludeHtmlClasses

Returns:

  • (Array<String>)


12188
12189
12190
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12188

def exclude_html_classes
  @exclude_html_classes
end

#exclude_html_elementsArray<String>

Optional. List of HTML elements to exclude from the parsed content. Corresponds to the JSON property excludeHtmlElements

Returns:

  • (Array<String>)


12193
12194
12195
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12193

def exclude_html_elements
  @exclude_html_elements
end

#exclude_html_idsArray<String>

Optional. List of HTML ids to exclude from the parsed content. Corresponds to the JSON property excludeHtmlIds

Returns:

  • (Array<String>)


12198
12199
12200
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12198

def exclude_html_ids
  @exclude_html_ids
end

#structured_content_typesArray<String>

Optional. Contains the required structure types to extract from the document. Supported values: * shareholder-structure Corresponds to the JSON property structuredContentTypes

Returns:

  • (Array<String>)


12204
12205
12206
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12204

def structured_content_types
  @structured_content_types
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12211
12212
12213
12214
12215
12216
12217
12218
12219
12220
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12211

def update!(**args)
  @enable_get_processed_document = args[:enable_get_processed_document] if args.key?(:enable_get_processed_document)
  @enable_image_annotation = args[:enable_image_annotation] if args.key?(:enable_image_annotation)
  @enable_llm_layout_parsing = args[:enable_llm_layout_parsing] if args.key?(:enable_llm_layout_parsing)
  @enable_table_annotation = args[:enable_table_annotation] if args.key?(:enable_table_annotation)
  @exclude_html_classes = args[:exclude_html_classes] if args.key?(:exclude_html_classes)
  @exclude_html_elements = args[:exclude_html_elements] if args.key?(:exclude_html_elements)
  @exclude_html_ids = args[:exclude_html_ids] if args.key?(:exclude_html_ids)
  @structured_content_types = args[:structured_content_types] if args.key?(:structured_content_types)
end