Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngineMediaRecommendationEngineConfigMostPopularFeatureConfig
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngineMediaRecommendationEngineConfigMostPopularFeatureConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Feature configurations that are required for creating a Most Popular engine.
Instance Attribute Summary collapse
-
#time_window_days ⇒ Fixnum
The time window of which the engine is queried at training and prediction time.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaEngineMediaRecommendationEngineConfigMostPopularFeatureConfig
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaEngineMediaRecommendationEngineConfigMostPopularFeatureConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaEngineMediaRecommendationEngineConfigMostPopularFeatureConfig
Returns a new instance of GoogleCloudDiscoveryengineV1alphaEngineMediaRecommendationEngineConfigMostPopularFeatureConfig.
12133 12134 12135 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12133 def initialize(**args) update!(**args) end |
Instance Attribute Details
#time_window_days ⇒ Fixnum
The time window of which the engine is queried at training and prediction time.
Positive integers only. The value translates to the last X days of events.
Currently required for the most-popular-items engine.
Corresponds to the JSON property timeWindowDays
12131 12132 12133 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12131 def time_window_days @time_window_days end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12138 12139 12140 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12138 def update!(**args) @time_window_days = args[:time_window_days] if args.key?(:time_window_days) end |