Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngineMediaRecommendationEngineConfigRecommendedForYouFeatureConfig
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngineMediaRecommendationEngineConfigRecommendedForYouFeatureConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Additional feature configurations for creating a recommended-for-you engine.
Instance Attribute Summary collapse
-
#context_event_type ⇒ String
The type of event with which the engine is queried at prediction time.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaEngineMediaRecommendationEngineConfigRecommendedForYouFeatureConfig
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaEngineMediaRecommendationEngineConfigRecommendedForYouFeatureConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaEngineMediaRecommendationEngineConfigRecommendedForYouFeatureConfig
Returns a new instance of GoogleCloudDiscoveryengineV1alphaEngineMediaRecommendationEngineConfigRecommendedForYouFeatureConfig.
12183 12184 12185 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12183 def initialize(**args) update!(**args) end |
Instance Attribute Details
#context_event_type ⇒ String
The type of event with which the engine is queried at prediction time. If set
to generic, only view-item, media-play,and media-complete will be used
as context-event in engine training. If set to view-home-page, view-home-
page will also be used as context-events in addition to view-item, media-
play, and media-complete. Currently supported for the recommended-for-you
engine. Currently supported values: view-home-page, generic.
Corresponds to the JSON property contextEventType
12181 12182 12183 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12181 def context_event_type @context_event_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12188 12189 12190 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12188 def update!(**args) @context_event_type = args[:context_event_type] if args.key?(:context_event_type) end |