Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngineRecommendationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Additional information of a recommendation engine.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaEngineRecommendationMetadata

Returns a new instance of GoogleCloudDiscoveryengineV1alphaEngineRecommendationMetadata.



13059
13060
13061
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13059

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_stateString

Output only. The state of data requirements for this engine: DATA_OK and DATA_ERROR. Engine cannot be trained if the data is in DATA_ERROR state. Engine can have DATA_ERROR state even if serving state is ACTIVE: engines were trained successfully before, but cannot be refreshed because the underlying engine no longer has sufficient data for training. Corresponds to the JSON property dataState

Returns:

  • (String)


13030
13031
13032
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13030

def data_state
  @data_state
end

#last_train_timeString

Output only. The timestamp when the latest successful training finished. Only applicable on Media Recommendation engines. Corresponds to the JSON property lastTrainTime

Returns:

  • (String)


13036
13037
13038
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13036

def last_train_time
  @last_train_time
end

#last_tune_timeString

Output only. The timestamp when the latest successful tune finished. Only applicable on Media Recommendation engines. Corresponds to the JSON property lastTuneTime

Returns:

  • (String)


13042
13043
13044
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13042

def last_tune_time
  @last_tune_time
end

#serving_stateString

Output only. The serving state of the engine: ACTIVE, NOT_ACTIVE. Corresponds to the JSON property servingState

Returns:

  • (String)


13047
13048
13049
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13047

def serving_state
  @serving_state
end

#tuning_operationString

Output only. The latest tune operation id associated with the engine. Only applicable on Media Recommendation engines. If present, this operation id can be used to determine if there is an ongoing tune for this engine. To check the operation status, send the GetOperation request with this operation id in the engine resource format. If no tuning has happened for this engine, the string is empty. Corresponds to the JSON property tuningOperation

Returns:

  • (String)


13057
13058
13059
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13057

def tuning_operation
  @tuning_operation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13064
13065
13066
13067
13068
13069
13070
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13064

def update!(**args)
  @data_state = args[:data_state] if args.key?(:data_state)
  @last_train_time = args[:last_train_time] if args.key?(:last_train_time)
  @last_tune_time = args[:last_tune_time] if args.key?(:last_tune_time)
  @serving_state = args[:serving_state] if args.key?(:serving_state)
  @tuning_operation = args[:tuning_operation] if args.key?(:tuning_operation)
end