Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEvaluation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

An evaluation is a single execution (or run) of an evaluation process. It encapsulates the state of the evaluation and the resulting data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaEvaluation

Returns a new instance of GoogleCloudDiscoveryengineV1alphaEvaluation.



13230
13231
13232
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13230

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp the Evaluation was created at. Corresponds to the JSON property createTime

Returns:

  • (String)


13186
13187
13188
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13186

def create_time
  @create_time
end

#end_timeString

Output only. Timestamp the Evaluation was completed at. Corresponds to the JSON property endTime

Returns:

  • (String)


13191
13192
13193
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13191

def end_time
  @end_time
end

#errorGoogle::Apis::DiscoveryengineV1beta::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



13201
13202
13203
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13201

def error
  @error
end

#error_samplesArray<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>

Output only. A sample of errors encountered while processing the request. Corresponds to the JSON property errorSamples



13206
13207
13208
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13206

def error_samples
  @error_samples
end

#evaluation_specGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEvaluationEvaluationSpec

Describes the specification of the evaluation. Corresponds to the JSON property evaluationSpec



13211
13212
13213
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13211

def evaluation_spec
  @evaluation_spec
end

#nameString

Identifier. The full resource name of the Evaluation, in the format of projects/project/locations/location/evaluations/evaluation`. This field must be a UTF-8 encoded string with a length limit of 1024 characters. Corresponds to the JSON propertyname`

Returns:

  • (String)


13218
13219
13220
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13218

def name
  @name
end

#quality_metricsGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaQualityMetrics

Describes the metrics produced by the evaluation. Corresponds to the JSON property qualityMetrics



13223
13224
13225
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13223

def quality_metrics
  @quality_metrics
end

#stateString

Output only. The state of the evaluation. Corresponds to the JSON property state

Returns:

  • (String)


13228
13229
13230
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13228

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13235
13236
13237
13238
13239
13240
13241
13242
13243
13244
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13235

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @error = args[:error] if args.key?(:error)
  @error_samples = args[:error_samples] if args.key?(:error_samples)
  @evaluation_spec = args[:evaluation_spec] if args.key?(:evaluation_spec)
  @name = args[:name] if args.key?(:name)
  @quality_metrics = args[:quality_metrics] if args.key?(:quality_metrics)
  @state = args[:state] if args.key?(:state)
end