Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaExportMetricsMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Metadata related to the progress of the Export operation. This is returned by the google.longrunning.Operation.metadata field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaExportMetricsMetadata

Returns a new instance of GoogleCloudDiscoveryengineV1alphaExportMetricsMetadata.



12474
12475
12476
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12474

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Operation create time. Corresponds to the JSON property createTime

Returns:

  • (String)


12466
12467
12468
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12466

def create_time
  @create_time
end

#update_timeString

Operation last update time. If the operation is done, this is also the finish time. Corresponds to the JSON property updateTime

Returns:

  • (String)


12472
12473
12474
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12472

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12479
12480
12481
12482
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12479

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @update_time = args[:update_time] if args.key?(:update_time)
end