Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaImportCompletionSuggestionsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Response of the CompletionService.ImportCompletionSuggestions method. If the long running operation is done, this message is returned by the google. longrunning.Operations.response field if the operation is successful.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaImportCompletionSuggestionsResponse

Returns a new instance of GoogleCloudDiscoveryengineV1alphaImportCompletionSuggestionsResponse.



13759
13760
13761
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13759

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaImportErrorConfig

Configuration of destination for Import related errors. Corresponds to the JSON property errorConfig



13752
13753
13754
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13752

def error_config
  @error_config
end

#error_samplesArray<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>

A sample of errors encountered while processing the request. Corresponds to the JSON property errorSamples



13757
13758
13759
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13757

def error_samples
  @error_samples
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13764
13765
13766
13767
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13764

def update!(**args)
  @error_config = args[:error_config] if args.key?(:error_config)
  @error_samples = args[:error_samples] if args.key?(:error_samples)
end