Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaImportIdentityMappingsResponse
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaImportIdentityMappingsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Response message for IdentityMappingStoreService.ImportIdentityMappings
Instance Attribute Summary collapse
-
#error_samples ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>
A sample of errors encountered while processing the request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaImportIdentityMappingsResponse
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaImportIdentityMappingsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaImportIdentityMappingsResponse
Returns a new instance of GoogleCloudDiscoveryengineV1alphaImportIdentityMappingsResponse.
13878 13879 13880 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13878 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_samples ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>
A sample of errors encountered while processing the request.
Corresponds to the JSON property errorSamples
13876 13877 13878 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13876 def error_samples @error_samples end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13883 13884 13885 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13883 def update!(**args) @error_samples = args[:error_samples] if args.key?(:error_samples) end |