Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaImportUserEventsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Response of the ImportUserEventsRequest. If the long running operation was successful, then this message is returned by the google.longrunning.Operations. response field if the operation was successful.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaImportUserEventsResponse

Returns a new instance of GoogleCloudDiscoveryengineV1alphaImportUserEventsResponse.



14078
14079
14080
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14078

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaImportErrorConfig

Configuration of destination for Import related errors. Corresponds to the JSON property errorConfig



14060
14061
14062
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14060

def error_config
  @error_config
end

#error_samplesArray<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>

A sample of errors encountered while processing the request. Corresponds to the JSON property errorSamples



14065
14066
14067
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14065

def error_samples
  @error_samples
end

#joined_events_countFixnum

Count of user events imported with complete existing Documents. Corresponds to the JSON property joinedEventsCount

Returns:

  • (Fixnum)


14070
14071
14072
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14070

def joined_events_count
  @joined_events_count
end

#unjoined_events_countFixnum

Count of user events imported, but with Document information not found in the existing Branch. Corresponds to the JSON property unjoinedEventsCount

Returns:

  • (Fixnum)


14076
14077
14078
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14076

def unjoined_events_count
  @unjoined_events_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14083
14084
14085
14086
14087
14088
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14083

def update!(**args)
  @error_config = args[:error_config] if args.key?(:error_config)
  @error_samples = args[:error_samples] if args.key?(:error_samples)
  @joined_events_count = args[:joined_events_count] if args.key?(:joined_events_count)
  @unjoined_events_count = args[:unjoined_events_count] if args.key?(:unjoined_events_count)
end