Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaListSessionsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Request for ListSessions method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaListSessionsRequest

Returns a new instance of GoogleCloudDiscoveryengineV1alphaListSessionsRequest.



14350
14351
14352
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14350

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#filterString

A comma-separated list of fields to filter by, in EBNF grammar. The supported fields are: * user_pseudo_id * state * display_name * starred * is_pinned * labels * create_time * update_time * collaborative_project Examples: * user_pseudo_id = some_id * display_name = "some_name" * starred = true * is_pinned=true AND (NOT labels:hidden) * create_time > " 1970-01-01T12:00:00Z" * collaborative_project = "projects/123/locations/ global/collections/default_collection/engines/" "default_engine/ collaborative_projects/cp1" Corresponds to the JSON property filter

Returns:

  • (String)


14321
14322
14323
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14321

def filter
  @filter
end

#order_byString

A comma-separated list of fields to order by, sorted in ascending order. Use " desc" after a field name for descending. Supported fields: * update_time * create_time * session_name * is_pinned * display_name Example: * update_time desc * create_time * is_pinned desc,update_time desc: list sessions by is_pinned first, then by update_time. Corresponds to the JSON property orderBy

Returns:

  • (String)


14330
14331
14332
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14330

def order_by
  @order_by
end

#page_sizeFixnum

Maximum number of results to return. If unspecified, defaults to 50. Max allowed value is 1000. Corresponds to the JSON property pageSize

Returns:

  • (Fixnum)


14336
14337
14338
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14336

def page_size
  @page_size
end

#page_tokenString

A page token, received from a previous ListSessions call. Provide this to retrieve the subsequent page. Corresponds to the JSON property pageToken

Returns:

  • (String)


14342
14343
14344
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14342

def page_token
  @page_token
end

#parentString

Required. The data store resource name. Format: projects/project/locations/ location/collections/collection/dataStores/data_store_id` Corresponds to the JSON propertyparent`

Returns:

  • (String)


14348
14349
14350
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14348

def parent
  @parent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14355
14356
14357
14358
14359
14360
14361
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14355

def update!(**args)
  @filter = args[:filter] if args.key?(:filter)
  @order_by = args[:order_by] if args.key?(:order_by)
  @page_size = args[:page_size] if args.key?(:page_size)
  @page_token = args[:page_token] if args.key?(:page_token)
  @parent = args[:parent] if args.key?(:parent)
end