Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaProjectCustomerProvidedConfigNotebooklmConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Configuration for NotebookLM.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaProjectCustomerProvidedConfigNotebooklmConfig

Returns a new instance of GoogleCloudDiscoveryengineV1alphaProjectCustomerProvidedConfigNotebooklmConfig.



14691
14692
14693
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14691

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_protection_policyGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaProjectCustomerProvidedConfigNotebooklmConfigDataProtectionPolicy

Data protection policy config for NotebookLM. Corresponds to the JSON property dataProtectionPolicy



14671
14672
14673
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14671

def data_protection_policy
  @data_protection_policy
end

#model_armor_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaProjectCustomerProvidedConfigNotebooklmConfigModelArmorConfig

Configuration for customer defined Model Armor templates to be used for sanitizing user prompts and LLM responses. Corresponds to the JSON property modelArmorConfig



14677
14678
14679
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14677

def model_armor_config
  @model_armor_config
end

#observability_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaObservabilityConfig

Observability config for a resource. Corresponds to the JSON property observabilityConfig



14682
14683
14684
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14682

def observability_config
  @observability_config
end

#opt_out_notebook_sharingBoolean Also known as: opt_out_notebook_sharing?

Optional. Whether to disable the notebook sharing feature for the project. Default to false if not specified. Corresponds to the JSON property optOutNotebookSharing

Returns:

  • (Boolean)


14688
14689
14690
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14688

def opt_out_notebook_sharing
  @opt_out_notebook_sharing
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14696
14697
14698
14699
14700
14701
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14696

def update!(**args)
  @data_protection_policy = args[:data_protection_policy] if args.key?(:data_protection_policy)
  @model_armor_config = args[:model_armor_config] if args.key?(:model_armor_config)
  @observability_config = args[:observability_config] if args.key?(:observability_config)
  @opt_out_notebook_sharing = args[:opt_out_notebook_sharing] if args.key?(:opt_out_notebook_sharing)
end