Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaProjectServiceTerms

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Metadata about the terms of service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaProjectServiceTerms

Returns a new instance of GoogleCloudDiscoveryengineV1alphaProjectServiceTerms.



14811
14812
14813
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14811

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accept_timeString

The last time when the project agreed to the terms of service. Corresponds to the JSON property acceptTime

Returns:

  • (String)


14783
14784
14785
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14783

def accept_time
  @accept_time
end

#decline_timeString

The last time when the project declined or revoked the agreement to terms of service. Corresponds to the JSON property declineTime

Returns:

  • (String)


14789
14790
14791
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14789

def decline_time
  @decline_time
end

#idString

The unique identifier of this terms of service. Available terms: * GA_DATA_USE_TERMS: Terms for data use. When using this as id, the acceptable version to provide is 2022-11-23. Corresponds to the JSON property id

Returns:

  • (String)


14797
14798
14799
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14797

def id
  @id
end

#stateString

Whether the project has accepted/rejected the service terms or it is still pending. Corresponds to the JSON property state

Returns:

  • (String)


14803
14804
14805
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14803

def state
  @state
end

#versionString

The version string of the terms of service. For acceptable values, see the comments for id above. Corresponds to the JSON property version

Returns:

  • (String)


14809
14810
14811
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14809

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14816
14817
14818
14819
14820
14821
14822
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14816

def update!(**args)
  @accept_time = args[:accept_time] if args.key?(:accept_time)
  @decline_time = args[:decline_time] if args.key?(:decline_time)
  @id = args[:id] if args.key?(:id)
  @state = args[:state] if args.key?(:state)
  @version = args[:version] if args.key?(:version)
end