Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaPurgeDocumentsMetadata
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaPurgeDocumentsMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Metadata related to the progress of the PurgeDocuments operation. This will be returned by the google.longrunning.Operation.metadata field.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Operation create time.
-
#failure_count ⇒ Fixnum
Count of entries that encountered errors while processing.
-
#ignored_count ⇒ Fixnum
Count of entries that were ignored as entries were not found.
-
#success_count ⇒ Fixnum
Count of entries that were deleted successfully.
-
#update_time ⇒ String
Operation last update time.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaPurgeDocumentsMetadata
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaPurgeDocumentsMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaPurgeDocumentsMetadata
Returns a new instance of GoogleCloudDiscoveryengineV1alphaPurgeDocumentsMetadata.
15046 15047 15048 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15046 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Operation create time.
Corresponds to the JSON property createTime
15023 15024 15025 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15023 def create_time @create_time end |
#failure_count ⇒ Fixnum
Count of entries that encountered errors while processing.
Corresponds to the JSON property failureCount
15028 15029 15030 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15028 def failure_count @failure_count end |
#ignored_count ⇒ Fixnum
Count of entries that were ignored as entries were not found.
Corresponds to the JSON property ignoredCount
15033 15034 15035 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15033 def ignored_count @ignored_count end |
#success_count ⇒ Fixnum
Count of entries that were deleted successfully.
Corresponds to the JSON property successCount
15038 15039 15040 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15038 def success_count @success_count end |
#update_time ⇒ String
Operation last update time. If the operation is done, this is also the finish
time.
Corresponds to the JSON property updateTime
15044 15045 15046 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15044 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15051 15052 15053 15054 15055 15056 15057 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15051 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @failure_count = args[:failure_count] if args.key?(:failure_count) @ignored_count = args[:ignored_count] if args.key?(:ignored_count) @success_count = args[:success_count] if args.key?(:success_count) @update_time = args[:update_time] if args.key?(:update_time) end |