Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaPurgeDocumentsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Response message for DocumentService.PurgeDocuments method. If the long running operation is successfully done, then this message is returned by the google.longrunning.Operations.response field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaPurgeDocumentsResponse

Returns a new instance of GoogleCloudDiscoveryengineV1alphaPurgeDocumentsResponse.



15092
15093
15094
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15092

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#purge_countFixnum

The total count of documents purged as a result of the operation. Corresponds to the JSON property purgeCount

Returns:

  • (Fixnum)


15083
15084
15085
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15083

def purge_count
  @purge_count
end

#purge_sampleArray<String>

A sample of document names that will be deleted. Only populated if force is set to false. A max of 100 names will be returned and the names are chosen at random. Corresponds to the JSON property purgeSample

Returns:

  • (Array<String>)


15090
15091
15092
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15090

def purge_sample
  @purge_sample
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15097
15098
15099
15100
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15097

def update!(**args)
  @purge_count = args[:purge_count] if args.key?(:purge_count)
  @purge_sample = args[:purge_sample] if args.key?(:purge_sample)
end