Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaPurgeUserEventsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Response of the PurgeUserEventsRequest. If the long running operation is successfully done, then this message is returned by the google.longrunning. Operations.response field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaPurgeUserEventsResponse

Returns a new instance of GoogleCloudDiscoveryengineV1alphaPurgeUserEventsResponse.



15191
15192
15193
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15191

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#purge_countFixnum

The total count of events purged as a result of the operation. Corresponds to the JSON property purgeCount

Returns:

  • (Fixnum)


15189
15190
15191
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15189

def purge_count
  @purge_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15196
15197
15198
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15196

def update!(**args)
  @purge_count = args[:purge_count] if args.key?(:purge_count)
end