Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaReplacePatientFilterRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Request for DataStoreService.ReplacePatientFilter method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaReplacePatientFilterRequest

Returns a new instance of GoogleCloudDiscoveryengineV1alphaReplacePatientFilterRequest.



14896
14897
14898
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14896

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_storeString

Required. Full resource name of DataStore, such as projects/project/ locations/location/collections/collection_id/dataStores/data_store_id`. If the caller does not have permission to access the DataStore, regardless of whether or not it exists, a PERMISSION_DENIED error is returned. If the requested DataStore does not exist, a NOT_FOUND error is returned. If the requested DataStore already has a patient filter, an ALREADY_EXISTS error will be returned. Corresponds to the JSON propertydataStore`

Returns:

  • (String)


14879
14880
14881
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14879

def data_store
  @data_store
end

#filter_groupsArray<String>

Required. Names of the Group resources to use as a basis for the list of patients for the new patient filter, in format projects/project_id/ locations/location_id/datasets/dataset_id/fhirStores/fhir_store_id/fhir/ Group/group_id`. if the caller does not have permission to access the FHIR store, regardless of whether it exists, PERMISSION_DENIED error is returned. If the discovery engine service account does not have permission to access the FHIR store, regardless of whether or not it exists, a PERMISSION_DENIED error is returned. If the group is not found at the location, a RESOURCE_NOT_FOUND error will be returned. The filter group must be a FHIR resource name of type Group, and the new filter will be constructed from the direct members of the group which are Patient resources. Corresponds to the JSON propertyfilterGroups`

Returns:

  • (Array<String>)


14894
14895
14896
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14894

def filter_groups
  @filter_groups
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14901
14902
14903
14904
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14901

def update!(**args)
  @data_store = args[:data_store] if args.key?(:data_store)
  @filter_groups = args[:filter_groups] if args.key?(:filter_groups)
end