Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestBoostSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Boost specification to boost certain documents.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaSearchRequestBoostSpec

Returns a new instance of GoogleCloudDiscoveryengineV1alphaSearchRequestBoostSpec.



15725
15726
15727
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15725

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#condition_boost_specsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestBoostSpecConditionBoostSpec>

Condition boost specifications. If a document matches multiple conditions in the specifications, boost scores from these specifications are all applied and combined in a non-linear way. Maximum number of specifications is 20. Corresponds to the JSON property conditionBoostSpecs



15723
15724
15725
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15723

def condition_boost_specs
  @condition_boost_specs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15730
15731
15732
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15730

def update!(**args)
  @condition_boost_specs = args[:condition_boost_specs] if args.key?(:condition_boost_specs)
end