Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestBoostSpecConditionBoostSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Boost applies to documents which match a condition.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaSearchRequestBoostSpecConditionBoostSpec

Returns a new instance of GoogleCloudDiscoveryengineV1alphaSearchRequestBoostSpecConditionBoostSpec.



16427
16428
16429
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16427

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#boostFloat

Strength of the condition boost, which should be in [-1, 1]. Negative boost means demotion. Default is 0.0. Setting to 1.0 gives the document a big promotion. However, it does not necessarily mean that the boosted document will be the top result at all times, nor that other documents will be excluded. Results could still be shown even when none of them matches the condition. And results that are significantly more relevant to the search query can still trump your heavily favored but irrelevant documents. Setting to -1.0 gives the document a big demotion. However, results that are deeply relevant might still be shown. The document will have an upstream battle to get a fairly high ranking, but it is not blocked out completely. Setting to 0.0 means no boost applied. The boosting condition is ignored. Only one of the (condition, boost) combination or the boost_control_spec below are set. If both are set then the global boost is ignored and the more fine-grained boost_control_spec is applied. Corresponds to the JSON property boost

Returns:

  • (Float)


16409
16410
16411
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16409

def boost
  @boost
end

#boost_control_specGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestBoostSpecConditionBoostSpecBoostControlSpec

Specification for custom ranking based on customer specified attribute value. It provides more controls for customized ranking than the simple (condition, boost) combination above. Corresponds to the JSON property boostControlSpec



16416
16417
16418
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16416

def boost_control_spec
  @boost_control_spec
end

#conditionString

An expression which specifies a boost condition. The syntax and supported fields are the same as a filter expression. See SearchRequest.filter for detail syntax and limitations. Examples: * To boost documents with document ID "doc_1" or "doc_2", and color "Red" or "Blue": (document_id: ANY("doc_1", " doc_2")) AND (color: ANY("Red", "Blue")) Corresponds to the JSON property condition

Returns:

  • (String)


16425
16426
16427
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16425

def condition
  @condition
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16432
16433
16434
16435
16436
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16432

def update!(**args)
  @boost = args[:boost] if args.key?(:boost)
  @boost_control_spec = args[:boost_control_spec] if args.key?(:boost_control_spec)
  @condition = args[:condition] if args.key?(:condition)
end