Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestFacetSpecFacetKey

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Specifies how a facet is computed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaSearchRequestFacetSpecFacetKey

Returns a new instance of GoogleCloudDiscoveryengineV1alphaSearchRequestFacetSpecFacetKey.



17305
17306
17307
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17305

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#case_insensitiveBoolean Also known as: case_insensitive?

True to make facet keys case insensitive when getting faceting values with prefixes or contains; false otherwise. Corresponds to the JSON property caseInsensitive

Returns:

  • (Boolean)


17253
17254
17255
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17253

def case_insensitive
  @case_insensitive
end

#containsArray<String>

Only get facet values that contain the given strings. For example, suppose " category" has three values "Action > 2022", "Action > 2021" and "Sci-Fi > 2022" . If set "contains" to "2022", the "category" facet only contains "Action > 2022" and "Sci-Fi > 2022". Only supported on textual fields. Maximum is 10. Corresponds to the JSON property contains

Returns:

  • (Array<String>)


17262
17263
17264
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17262

def contains
  @contains
end

#intervalsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaInterval>

Set only if values should be bucketed into intervals. Must be set for facets with numerical values. Must not be set for facet with text values. Maximum number of intervals is 30. Corresponds to the JSON property intervals



17269
17270
17271
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17269

def intervals
  @intervals
end

#keyString

Required. Supported textual and numerical facet keys in Document object, over which the facet values are computed. Facet key is case-sensitive. Corresponds to the JSON property key

Returns:

  • (String)


17275
17276
17277
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17275

def key
  @key
end

#order_byString

The order in which documents are returned. Allowed values are: * "count desc", which means order by SearchResponse.Facet.values.count descending. * "value desc", which means order by SearchResponse.Facet.values.value descending. Only applies to textual facets. If not set, textual values are sorted in natural order; numerical intervals are sorted in the order given by FacetSpec.FacetKey.intervals. Corresponds to the JSON property orderBy

Returns:

  • (String)


17285
17286
17287
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17285

def order_by
  @order_by
end

#prefixesArray<String>

Only get facet values that start with the given string prefix. For example, suppose "category" has three values "Action > 2022", "Action > 2021" and "Sci- Fi > 2022". If set "prefixes" to "Action", the "category" facet only contains " Action > 2022" and "Action > 2021". Only supported on textual fields. Maximum is 10. Corresponds to the JSON property prefixes

Returns:

  • (Array<String>)


17294
17295
17296
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17294

def prefixes
  @prefixes
end

#restricted_valuesArray<String>

Only get facet for the given restricted values. Only supported on textual fields. For example, suppose "category" has three values "Action > 2022", " Action > 2021" and "Sci-Fi > 2022". If set "restricted_values" to "Action > 2022", the "category" facet only contains "Action > 2022". Only supported on textual fields. Maximum is 10. Corresponds to the JSON property restrictedValues

Returns:

  • (Array<String>)


17303
17304
17305
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17303

def restricted_values
  @restricted_values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17310
17311
17312
17313
17314
17315
17316
17317
17318
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17310

def update!(**args)
  @case_insensitive = args[:case_insensitive] if args.key?(:case_insensitive)
  @contains = args[:contains] if args.key?(:contains)
  @intervals = args[:intervals] if args.key?(:intervals)
  @key = args[:key] if args.key?(:key)
  @order_by = args[:order_by] if args.key?(:order_by)
  @prefixes = args[:prefixes] if args.key?(:prefixes)
  @restricted_values = args[:restricted_values] if args.key?(:restricted_values)
end