Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestSessionSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Session specification.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaSearchRequestSessionSpec

Returns a new instance of GoogleCloudDiscoveryengineV1alphaSearchRequestSessionSpec.



16632
16633
16634
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16632

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#query_idString

If set, the search result gets stored to the "turn" specified by this query ID. Example: Let's say the session looks like this: session name: ".../sessions/ xxx" turns query text: "What is foo?" query_id: ".../questions/yyy" answer: "Foo is ..." turns query text: "How about bar then?" query_id: ". ../questions/zzz" The user can call /search API with a request like this: session: ".../sessions/xxx" session_spec query_id: ".../questions/zzz" Then, the API stores the search result, associated with the last turn. The stored search result can be used by a subsequent /answer API call (with the session ID and the query ID specified). Also, it is possible to call /search and /answer in parallel with the same session ID & query ID. Corresponds to the JSON property queryId

Returns:

  • (String)


16621
16622
16623
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16621

def query_id
  @query_id
end

#search_result_persistence_countFixnum

The number of top search results to persist. The persisted search results can be used for the subsequent /answer api call. This field is similar to the summary_result_count field in SearchRequest.ContentSearchSpec.SummarySpec. summary_result_count. At most 10 results for documents mode, or 50 for chunks mode. Corresponds to the JSON property searchResultPersistenceCount

Returns:

  • (Fixnum)


16630
16631
16632
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16630

def search_result_persistence_count
  @search_result_persistence_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16637
16638
16639
16640
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16637

def update!(**args)
  @query_id = args[:query_id] if args.key?(:query_id)
  @search_result_persistence_count = args[:search_result_persistence_count] if args.key?(:search_result_persistence_count)
end