Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaUpdateSessionRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Request for UpdateSession method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaUpdateSessionRequest

Returns a new instance of GoogleCloudDiscoveryengineV1alphaUpdateSessionRequest.



18361
18362
18363
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18361

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#sessionGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSession

External session proto definition. Corresponds to the JSON property session



18352
18353
18354
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18352

def session
  @session
end

#update_maskString

Indicates which fields in the provided Session to update. The following are NOT supported: * Session.name If not set or empty, all supported fields are updated. Corresponds to the JSON property updateMask

Returns:

  • (String)


18359
18360
18361
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18359

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18366
18367
18368
18369
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18366

def update!(**args)
  @session = args[:session] if args.key?(:session)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end