Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaUserInfoPreciseLocation
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaUserInfoPreciseLocation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Precise location info with multiple representation options.
Instance Attribute Summary collapse
-
#address ⇒ String
Location represented by a natural language address.
-
#point ⇒ Google::Apis::DiscoveryengineV1beta::GoogleTypeLatLng
An object that represents a latitude/longitude pair.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaUserInfoPreciseLocation
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaUserInfoPreciseLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaUserInfoPreciseLocation
Returns a new instance of GoogleCloudDiscoveryengineV1alphaUserInfoPreciseLocation.
18475 18476 18477 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18475 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address ⇒ String
Location represented by a natural language address. Will later be geocoded and
converted to either a point or a polygon.
Corresponds to the JSON property address
18465 18466 18467 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18465 def address @address end |
#point ⇒ Google::Apis::DiscoveryengineV1beta::GoogleTypeLatLng
An object that represents a latitude/longitude pair. This is expressed as a
pair of doubles to represent degrees latitude and degrees longitude. Unless
specified otherwise, this object must conform to the WGS84 standard. Values
must be within normalized ranges.
Corresponds to the JSON property point
18473 18474 18475 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18473 def point @point end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18480 18481 18482 18483 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18480 def update!(**args) @address = args[:address] if args.key?(:address) @point = args[:point] if args.key?(:point) end |