Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponseContentSuggestion
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponseContentSuggestion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Suggestions as content.
Instance Attribute Summary collapse
-
#content_type ⇒ String
The type of the content suggestion.
-
#data_store ⇒ String
The name of the dataStore that this suggestion belongs to.
-
#destination_uri ⇒ String
The destination uri of the content suggestion.
-
#document ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocument
Document captures all raw metadata information of items to be recommended or searched.
-
#icon_uri ⇒ String
The icon uri of the content suggestion.
-
#score ⇒ Float
The score of each suggestion.
-
#suggestion ⇒ String
The suggestion for the query.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponseContentSuggestion
constructor
A new instance of GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponseContentSuggestion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponseContentSuggestion
Returns a new instance of GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponseContentSuggestion.
18888 18889 18890 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18888 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content_type ⇒ String
The type of the content suggestion.
Corresponds to the JSON property contentType
18855 18856 18857 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18855 def content_type @content_type end |
#data_store ⇒ String
The name of the dataStore that this suggestion belongs to.
Corresponds to the JSON property dataStore
18860 18861 18862 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18860 def data_store @data_store end |
#destination_uri ⇒ String
The destination uri of the content suggestion.
Corresponds to the JSON property destinationUri
18865 18866 18867 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18865 def destination_uri @destination_uri end |
#document ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocument
Document captures all raw metadata information of items to be recommended or
searched.
Corresponds to the JSON property document
18871 18872 18873 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18871 def document @document end |
#icon_uri ⇒ String
The icon uri of the content suggestion.
Corresponds to the JSON property iconUri
18876 18877 18878 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18876 def icon_uri @icon_uri end |
#score ⇒ Float
The score of each suggestion. The score is in the range of [0, 1].
Corresponds to the JSON property score
18881 18882 18883 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18881 def score @score end |
#suggestion ⇒ String
The suggestion for the query.
Corresponds to the JSON property suggestion
18886 18887 18888 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18886 def suggestion @suggestion end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18893 18894 18895 18896 18897 18898 18899 18900 18901 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18893 def update!(**args) @content_type = args[:content_type] if args.key?(:content_type) @data_store = args[:data_store] if args.key?(:data_store) @destination_uri = args[:destination_uri] if args.key?(:destination_uri) @document = args[:document] if args.key?(:document) @icon_uri = args[:icon_uri] if args.key?(:icon_uri) @score = args[:score] if args.key?(:score) @suggestion = args[:suggestion] if args.key?(:suggestion) end |