Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponseQuerySuggestion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Suggestions as search queries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponseQuerySuggestion

Returns a new instance of GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponseQuerySuggestion.



18986
18987
18988
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18986

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#completable_field_pathsArray<String>

The unique document field paths that serve as the source of this suggestion if it was generated from completable fields. This field is only populated for the document-completable model. Corresponds to the JSON property completableFieldPaths

Returns:

  • (Array<String>)


18969
18970
18971
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18969

def completable_field_paths
  @completable_field_paths
end

#data_storeArray<String>

The name of the dataStore that this suggestion belongs to. Corresponds to the JSON property dataStore

Returns:

  • (Array<String>)


18974
18975
18976
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18974

def data_store
  @data_store
end

#scoreFloat

The score of each suggestion. The score is in the range of [0, 1]. Corresponds to the JSON property score

Returns:

  • (Float)


18979
18980
18981
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18979

def score
  @score
end

#suggestionString

The suggestion for the query. Corresponds to the JSON property suggestion

Returns:

  • (String)


18984
18985
18986
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18984

def suggestion
  @suggestion
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18991
18992
18993
18994
18995
18996
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18991

def update!(**args)
  @completable_field_paths = args[:completable_field_paths] if args.key?(:completable_field_paths)
  @data_store = args[:data_store] if args.key?(:data_store)
  @score = args[:score] if args.key?(:score)
  @suggestion = args[:suggestion] if args.key?(:suggestion)
end