Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerGenerationSpecUserDefinedClassifierSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

The specification for user defined classifier.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerGenerationSpecUserDefinedClassifierSpec

Returns a new instance of GoogleCloudDiscoveryengineV1betaAnswerGenerationSpecUserDefinedClassifierSpec.



19425
19426
19427
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19425

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_user_defined_classifierBoolean Also known as: enable_user_defined_classifier?

Optional. Whether or not to enable and include user defined classifier. Corresponds to the JSON property enableUserDefinedClassifier

Returns:

  • (Boolean)


19387
19388
19389
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19387

def enable_user_defined_classifier
  @enable_user_defined_classifier
end

#model_idString

Optional. The model id to be used for the user defined classifier. Corresponds to the JSON property modelId

Returns:

  • (String)


19393
19394
19395
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19393

def model_id
  @model_id
end

#preambleString

Optional. The preamble to be used for the user defined classifier. Corresponds to the JSON property preamble

Returns:

  • (String)


19398
19399
19400
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19398

def preamble
  @preamble
end

#seedFixnum

Optional. The seed value to be used for the user defined classifier. Corresponds to the JSON property seed

Returns:

  • (Fixnum)


19403
19404
19405
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19403

def seed
  @seed
end

#task_markerString

Optional. The task marker to be used for the user defined classifier. Corresponds to the JSON property taskMarker

Returns:

  • (String)


19408
19409
19410
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19408

def task_marker
  @task_marker
end

#temperatureFloat

Optional. The temperature value to be used for the user defined classifier. Corresponds to the JSON property temperature

Returns:

  • (Float)


19413
19414
19415
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19413

def temperature
  @temperature
end

#top_kFixnum

Optional. The top-k value to be used for the user defined classifier. Corresponds to the JSON property topK

Returns:

  • (Fixnum)


19418
19419
19420
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19418

def top_k
  @top_k
end

#top_pFloat

Optional. The top-p value to be used for the user defined classifier. Corresponds to the JSON property topP

Returns:

  • (Float)


19423
19424
19425
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19423

def top_p
  @top_p
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19430
19431
19432
19433
19434
19435
19436
19437
19438
19439
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19430

def update!(**args)
  @enable_user_defined_classifier = args[:enable_user_defined_classifier] if args.key?(:enable_user_defined_classifier)
  @model_id = args[:model_id] if args.key?(:model_id)
  @preamble = args[:preamble] if args.key?(:preamble)
  @seed = args[:seed] if args.key?(:seed)
  @task_marker = args[:task_marker] if args.key?(:task_marker)
  @temperature = args[:temperature] if args.key?(:temperature)
  @top_k = args[:top_k] if args.key?(:top_k)
  @top_p = args[:top_p] if args.key?(:top_p)
end