Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequest
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Request message for ConversationalSearchService.AnswerQuery method.
Instance Attribute Summary collapse
-
#answer_generation_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestAnswerGenerationSpec
Answer generation specification.
-
#asynchronous_mode ⇒ Boolean
(also: #asynchronous_mode?)
Deprecated: This field is deprecated.
-
#end_user_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestEndUserSpec
End user specification.
-
#grounding_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestGroundingSpec
Grounding specification.
-
#query ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaQuery
Defines a user inputed query.
-
#query_understanding_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestQueryUnderstandingSpec
Query understanding specification.
-
#related_questions_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestRelatedQuestionsSpec
Related questions specification.
-
#safety_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSafetySpec
Safety specification.
-
#search_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpec
Search specification.
-
#session ⇒ String
The session resource name.
-
#user_labels ⇒ Hash<String,String>
The user labels applied to a resource must meet the following requirements: * Each resource can have multiple labels, up to a maximum of 64.
-
#user_pseudo_id ⇒ String
A unique identifier for tracking visitors.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerQueryRequest
constructor
A new instance of GoogleCloudDiscoveryengineV1betaAnswerQueryRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerQueryRequest
Returns a new instance of GoogleCloudDiscoveryengineV1betaAnswerQueryRequest.
19478 19479 19480 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19478 def initialize(**args) update!(**args) end |
Instance Attribute Details
#answer_generation_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestAnswerGenerationSpec
Answer generation specification.
Corresponds to the JSON property answerGenerationSpec
19393 19394 19395 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19393 def answer_generation_spec @answer_generation_spec end |
#asynchronous_mode ⇒ Boolean Also known as: asynchronous_mode?
Deprecated: This field is deprecated. Streaming Answer API will be supported.
Asynchronous mode control. If enabled, the response will be returned with
answer/session resource name without final answer. The API users need to do
the polling to get the latest status of answer/session by calling
ConversationalSearchService.GetAnswer or ConversationalSearchService.
GetSession method.
Corresponds to the JSON property asynchronousMode
19403 19404 19405 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19403 def asynchronous_mode @asynchronous_mode end |
#end_user_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestEndUserSpec
End user specification.
Corresponds to the JSON property endUserSpec
19409 19410 19411 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19409 def end_user_spec @end_user_spec end |
#grounding_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestGroundingSpec
Grounding specification.
Corresponds to the JSON property groundingSpec
19414 19415 19416 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19414 def grounding_spec @grounding_spec end |
#query ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaQuery
Defines a user inputed query.
Corresponds to the JSON property query
19419 19420 19421 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19419 def query @query end |
#query_understanding_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestQueryUnderstandingSpec
Query understanding specification.
Corresponds to the JSON property queryUnderstandingSpec
19424 19425 19426 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19424 def query_understanding_spec @query_understanding_spec end |
#related_questions_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestRelatedQuestionsSpec
Related questions specification.
Corresponds to the JSON property relatedQuestionsSpec
19429 19430 19431 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19429 def @related_questions_spec end |
#safety_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSafetySpec
Safety specification. There are two use cases: 1. when only safety_spec.enable is set, the BLOCK_LOW_AND_ABOVE threshold will be applied for all categories.
- when safety_spec.enable is set and some safety_settings are set, only
specified safety_settings are applied.
Corresponds to the JSON property
safetySpec
19437 19438 19439 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19437 def safety_spec @safety_spec end |
#search_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpec
Search specification.
Corresponds to the JSON property searchSpec
19442 19443 19444 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19442 def search_spec @search_spec end |
#session ⇒ String
The session resource name. Not required. When session field is not set, the
API is in sessionless mode. We support auto session mode: users can use the
wildcard symbol - as session ID. A new ID will be automatically generated
and assigned.
Corresponds to the JSON property session
19450 19451 19452 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19450 def session @session end |
#user_labels ⇒ Hash<String,String>
The user labels applied to a resource must meet the following requirements: *
Each resource can have multiple labels, up to a maximum of 64. * Each label
must be a key-value pair. * Keys have a minimum length of 1 character and a
maximum length of 63 characters and cannot be empty. Values can be empty and
have a maximum length of 63 characters. * Keys and values can contain only
lowercase letters, numeric characters, underscores, and dashes. All characters
must use UTF-8 encoding, and international characters are allowed. * The key
portion of a label must be unique. However, you can use the same key with
multiple resources. * Keys must start with a lowercase letter or international
character. See Google Cloud Document for more details.
Corresponds to the JSON property userLabels
19465 19466 19467 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19465 def user_labels @user_labels end |
#user_pseudo_id ⇒ String
A unique identifier for tracking visitors. For example, this could be
implemented with an HTTP cookie, which should be able to uniquely identify a
visitor on a single device. This unique identifier should not change if the
visitor logs in or out of the website. This field should NOT have a fixed
value such as unknown_visitor. The field must be a UTF-8 encoded string with
a length limit of 128 characters. Otherwise, an INVALID_ARGUMENT error is
returned.
Corresponds to the JSON property userPseudoId
19476 19477 19478 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19476 def user_pseudo_id @user_pseudo_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19483 19484 19485 19486 19487 19488 19489 19490 19491 19492 19493 19494 19495 19496 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19483 def update!(**args) @answer_generation_spec = args[:answer_generation_spec] if args.key?(:answer_generation_spec) @asynchronous_mode = args[:asynchronous_mode] if args.key?(:asynchronous_mode) @end_user_spec = args[:end_user_spec] if args.key?(:end_user_spec) @grounding_spec = args[:grounding_spec] if args.key?(:grounding_spec) @query = args[:query] if args.key?(:query) @query_understanding_spec = args[:query_understanding_spec] if args.key?(:query_understanding_spec) @related_questions_spec = args[:related_questions_spec] if args.key?(:related_questions_spec) @safety_spec = args[:safety_spec] if args.key?(:safety_spec) @search_spec = args[:search_spec] if args.key?(:search_spec) @session = args[:session] if args.key?(:session) @user_labels = args[:user_labels] if args.key?(:user_labels) @user_pseudo_id = args[:user_pseudo_id] if args.key?(:user_pseudo_id) end |