Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Unstructured document information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfo

Returns a new instance of GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfo.



20293
20294
20295
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20293

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#documentString

Document resource name. Corresponds to the JSON property document

Returns:

  • (String)


20262
20263
20264
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20262

def document
  @document
end

#document_contextsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfoDocumentContext>

List of document contexts. The content will be used for Answer Generation. This is supposed to be the main content of the document that can be long and comprehensive. Corresponds to the JSON property documentContexts



20269
20270
20271
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20269

def document_contexts
  @document_contexts
end

#extractive_answersArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfoExtractiveAnswer>

Deprecated: This field is deprecated and will have no effect on the Answer generation. Please use document_contexts and extractive_segments fields. List of extractive answers. Corresponds to the JSON property extractiveAnswers



20276
20277
20278
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20276

def extractive_answers
  @extractive_answers
end

#extractive_segmentsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfoExtractiveSegment>

List of extractive segments. Corresponds to the JSON property extractiveSegments



20281
20282
20283
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20281

def extractive_segments
  @extractive_segments
end

#titleString

Title. Corresponds to the JSON property title

Returns:

  • (String)


20286
20287
20288
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20286

def title
  @title
end

#uriString

URI for the document. Corresponds to the JSON property uri

Returns:

  • (String)


20291
20292
20293
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20291

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20298
20299
20300
20301
20302
20303
20304
20305
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20298

def update!(**args)
  @document = args[:document] if args.key?(:document)
  @document_contexts = args[:document_contexts] if args.key?(:document_contexts)
  @extractive_answers = args[:extractive_answers] if args.key?(:extractive_answers)
  @extractive_segments = args[:extractive_segments] if args.key?(:extractive_segments)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end