Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerReferenceChunkInfo
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerReferenceChunkInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Chunk information.
Instance Attribute Summary collapse
-
#blob_attachment_indexes ⇒ Array<Fixnum>
Output only.
-
#chunk ⇒ String
Chunk resource name.
-
#content ⇒ String
Chunk textual content.
-
#document_metadata ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerReferenceChunkInfoDocumentMetadata
Document metadata.
-
#relevance_score ⇒ Float
The relevance of the chunk for a given query.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerReferenceChunkInfo
constructor
A new instance of GoogleCloudDiscoveryengineV1betaAnswerReferenceChunkInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerReferenceChunkInfo
Returns a new instance of GoogleCloudDiscoveryengineV1betaAnswerReferenceChunkInfo.
20517 20518 20519 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20517 def initialize(**args) update!(**args) end |
Instance Attribute Details
#blob_attachment_indexes ⇒ Array<Fixnum>
Output only. Stores indexes of blobattachments linked to this chunk.
Corresponds to the JSON property blobAttachmentIndexes
20492 20493 20494 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20492 def @blob_attachment_indexes end |
#chunk ⇒ String
Chunk resource name.
Corresponds to the JSON property chunk
20497 20498 20499 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20497 def chunk @chunk end |
#content ⇒ String
Chunk textual content.
Corresponds to the JSON property content
20502 20503 20504 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20502 def content @content end |
#document_metadata ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerReferenceChunkInfoDocumentMetadata
Document metadata.
Corresponds to the JSON property documentMetadata
20507 20508 20509 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20507 def @document_metadata end |
#relevance_score ⇒ Float
The relevance of the chunk for a given query. Values range from 0.0 (
completely irrelevant) to 1.0 (completely relevant). This value is for
informational purpose only. It may change for the same query and chunk at any
time due to a model retraining or change in implementation.
Corresponds to the JSON property relevanceScore
20515 20516 20517 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20515 def relevance_score @relevance_score end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20522 20523 20524 20525 20526 20527 20528 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20522 def update!(**args) @blob_attachment_indexes = args[:blob_attachment_indexes] if args.key?(:blob_attachment_indexes) @chunk = args[:chunk] if args.key?(:chunk) @content = args[:content] if args.key?(:content) @document_metadata = args[:document_metadata] if args.key?(:document_metadata) @relevance_score = args[:relevance_score] if args.key?(:relevance_score) end |