Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerReferenceUnstructuredDocumentInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Unstructured document information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerReferenceUnstructuredDocumentInfo

Returns a new instance of GoogleCloudDiscoveryengineV1betaAnswerReferenceUnstructuredDocumentInfo.



20656
20657
20658
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20656

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chunk_contentsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerReferenceUnstructuredDocumentInfoChunkContent>

List of cited chunk contents derived from document content. Corresponds to the JSON property chunkContents



20633
20634
20635
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20633

def chunk_contents
  @chunk_contents
end

#documentString

Document resource name. Corresponds to the JSON property document

Returns:

  • (String)


20638
20639
20640
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20638

def document
  @document
end

#struct_dataHash<String,Object>

The structured JSON metadata for the document. It is populated from the struct data from the Chunk in search result. Corresponds to the JSON property structData

Returns:

  • (Hash<String,Object>)


20644
20645
20646
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20644

def struct_data
  @struct_data
end

#titleString

Title. Corresponds to the JSON property title

Returns:

  • (String)


20649
20650
20651
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20649

def title
  @title
end

#uriString

URI for the document. Corresponds to the JSON property uri

Returns:

  • (String)


20654
20655
20656
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20654

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20661
20662
20663
20664
20665
20666
20667
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20661

def update!(**args)
  @chunk_contents = args[:chunk_contents] if args.key?(:chunk_contents)
  @document = args[:document] if args.key?(:document)
  @struct_data = args[:struct_data] if args.key?(:struct_data)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end