Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerStepActionObservation
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerStepActionObservation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Observation.
Instance Attribute Summary collapse
-
#search_results ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerStepActionObservationSearchResult>
Search results observed by the search action, it can be snippets info or chunk info, depending on the citation type set by the user.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerStepActionObservation
constructor
A new instance of GoogleCloudDiscoveryengineV1betaAnswerStepActionObservation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerStepActionObservation
Returns a new instance of GoogleCloudDiscoveryengineV1betaAnswerStepActionObservation.
20776 20777 20778 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20776 def initialize(**args) update!(**args) end |
Instance Attribute Details
#search_results ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerStepActionObservationSearchResult>
Search results observed by the search action, it can be snippets info or chunk
info, depending on the citation type set by the user.
Corresponds to the JSON property searchResults
20774 20775 20776 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20774 def search_results @search_results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20781 20782 20783 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20781 def update!(**args) @search_results = args[:search_results] if args.key?(:search_results) end |