Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerStepActionObservationSearchResultChunkInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Chunk information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerStepActionObservationSearchResultChunkInfo

Returns a new instance of GoogleCloudDiscoveryengineV1betaAnswerStepActionObservationSearchResultChunkInfo.



19849
19850
19851
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19849

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chunkString

Chunk resource name. Corresponds to the JSON property chunk

Returns:

  • (String)


19834
19835
19836
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19834

def chunk
  @chunk
end

#contentString

Chunk textual content. Corresponds to the JSON property content

Returns:

  • (String)


19839
19840
19841
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19839

def content
  @content
end

#relevance_scoreFloat

The relevance of the chunk for a given query. Values range from 0.0 ( completely irrelevant) to 1.0 (completely relevant). This value is for informational purpose only. It may change for the same query and chunk at any time due to a model retraining or change in implementation. Corresponds to the JSON property relevanceScore

Returns:

  • (Float)


19847
19848
19849
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19847

def relevance_score
  @relevance_score
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19854
19855
19856
19857
19858
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19854

def update!(**args)
  @chunk = args[:chunk] if args.key?(:chunk)
  @content = args[:content] if args.key?(:content)
  @relevance_score = args[:relevance_score] if args.key?(:relevance_score)
end