Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistAnswerCustomerPolicyEnforcementResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Customer policy enforcement results. Contains the results of the various policy checks, like the banned phrases or the Model Armor checks.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistAnswerCustomerPolicyEnforcementResult

Returns a new instance of GoogleCloudDiscoveryengineV1betaAssistAnswerCustomerPolicyEnforcementResult.



20985
20986
20987
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20985

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#policy_resultsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistAnswerCustomerPolicyEnforcementResultPolicyEnforcementResult>

Customer policy enforcement results. Populated only if the assist call was skipped due to a policy violation. It contains results from those filters that blocked the processing of the query. Corresponds to the JSON property policyResults



20972
20973
20974
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20972

def policy_results
  @policy_results
end

#verdictString

Final verdict of the customer policy enforcement. If only one policy blocked the processing, the verdict is BLOCK. Corresponds to the JSON property verdict

Returns:

  • (String)


20978
20979
20980
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20978

def verdict
  @verdict
end

#violation_sourceString

Output only. The source of the violation. Corresponds to the JSON property violationSource

Returns:

  • (String)


20983
20984
20985
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20983

def violation_source
  @violation_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20990
20991
20992
20993
20994
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20990

def update!(**args)
  @policy_results = args[:policy_results] if args.key?(:policy_results)
  @verdict = args[:verdict] if args.key?(:verdict)
  @violation_source = args[:violation_source] if args.key?(:violation_source)
end