Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistAnswerReply

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

One part of the multi-part response of the assist call.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistAnswerReply

Returns a new instance of GoogleCloudDiscoveryengineV1betaAssistAnswerReply.



20275
20276
20277
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20275

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

The time when the reply was created. Corresponds to the JSON property createTime

Returns:

  • (String)


20266
20267
20268
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20266

def create_time
  @create_time
end

#grounded_contentGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantGroundedContent

A piece of content and possibly its grounding information. Not all content needs grounding. Phrases like "Of course, I will gladly search it for you." do not need grounding. Corresponds to the JSON property groundedContent



20273
20274
20275
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20273

def grounded_content
  @grounded_content
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20280
20281
20282
20283
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20280

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @grounded_content = args[:grounded_content] if args.key?(:grounded_content)
end