Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantContent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Multi-modal content.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistantContent

Returns a new instance of GoogleCloudDiscoveryengineV1betaAssistantContent.



21244
21245
21246
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21244

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#code_execution_resultGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantContentCodeExecutionResult

Result of executing ExecutableCode. Corresponds to the JSON property codeExecutionResult



21211
21212
21213
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21211

def code_execution_result
  @code_execution_result
end

#executable_codeGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantContentExecutableCode

Code generated by the model that is meant to be executed by the model. Corresponds to the JSON property executableCode



21216
21217
21218
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21216

def executable_code
  @executable_code
end

#fileGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantContentFile

A file, e.g., an audio summary. Corresponds to the JSON property file



21221
21222
21223
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21221

def file
  @file
end

#inline_dataGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantContentBlob

Inline blob. Corresponds to the JSON property inlineData



21226
21227
21228
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21226

def inline_data
  @inline_data
end

#roleString

The producer of the content. Can be "model" or "user". Corresponds to the JSON property role

Returns:

  • (String)


21231
21232
21233
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21231

def role
  @role
end

#textString

Inline text. Corresponds to the JSON property text

Returns:

  • (String)


21236
21237
21238
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21236

def text
  @text
end

#thoughtBoolean Also known as: thought?

Optional. Indicates if the part is thought from the model. Corresponds to the JSON property thought

Returns:

  • (Boolean)


21241
21242
21243
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21241

def thought
  @thought
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21249
21250
21251
21252
21253
21254
21255
21256
21257
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21249

def update!(**args)
  @code_execution_result = args[:code_execution_result] if args.key?(:code_execution_result)
  @executable_code = args[:executable_code] if args.key?(:executable_code)
  @file = args[:file] if args.key?(:file)
  @inline_data = args[:inline_data] if args.key?(:inline_data)
  @role = args[:role] if args.key?(:role)
  @text = args[:text] if args.key?(:text)
  @thought = args[:thought] if args.key?(:thought)
end