Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantCustomerPolicyModelArmorConfig
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantCustomerPolicyModelArmorConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Configuration for customer defined Model Armor templates to be used for sanitizing user prompts and assistant responses.
Instance Attribute Summary collapse
-
#failure_mode ⇒ String
Optional.
-
#response_template ⇒ String
Optional.
-
#user_prompt_template ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistantCustomerPolicyModelArmorConfig
constructor
A new instance of GoogleCloudDiscoveryengineV1betaAssistantCustomerPolicyModelArmorConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistantCustomerPolicyModelArmorConfig
Returns a new instance of GoogleCloudDiscoveryengineV1betaAssistantCustomerPolicyModelArmorConfig.
20645 20646 20647 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20645 def initialize(**args) update!(**args) end |
Instance Attribute Details
#failure_mode ⇒ String
Optional. Defines the failure mode for Model Armor sanitization.
Corresponds to the JSON property failureMode
20627 20628 20629 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20627 def failure_mode @failure_mode end |
#response_template ⇒ String
Optional. The resource name of the Model Armor template for sanitizing
assistant responses. Format: projects/project/locations/location/
templates/template_id`If not specified, no sanitization will be applied to
the assistant response.
Corresponds to the JSON propertyresponseTemplate`
20635 20636 20637 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20635 def response_template @response_template end |
#user_prompt_template ⇒ String
Optional. The resource name of the Model Armor template for sanitizing user
prompts. Format: projects/project/locations/location/templates/
template_id`If not specified, no sanitization will be applied to the user
prompt.
Corresponds to the JSON propertyuserPromptTemplate`
20643 20644 20645 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20643 def user_prompt_template @user_prompt_template end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20650 20651 20652 20653 20654 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20650 def update!(**args) @failure_mode = args[:failure_mode] if args.key?(:failure_mode) @response_template = args[:response_template] if args.key?(:response_template) @user_prompt_template = args[:user_prompt_template] if args.key?(:user_prompt_template) end |