Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantGenerationConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Configuration for the generation of the assistant response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistantGenerationConfig

Returns a new instance of GoogleCloudDiscoveryengineV1betaAssistantGenerationConfig.



21495
21496
21497
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21495

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowed_model_idsArray<String>

Optional. The list of models that are allowed to be used for assistant. Corresponds to the JSON property allowedModelIds

Returns:

  • (Array<String>)


21476
21477
21478
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21476

def allowed_model_ids
  @allowed_model_ids
end

#default_languageString

The default language to use for the generation of the assistant response. Use an ISO 639-1 language code such as en. If not specified, the language will be automatically detected. Corresponds to the JSON property defaultLanguage

Returns:

  • (String)


21483
21484
21485
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21483

def default_language
  @default_language
end

#default_model_idString

Optional. The default model to use for assistant. Corresponds to the JSON property defaultModelId

Returns:

  • (String)


21488
21489
21490
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21488

def default_model_id
  @default_model_id
end

#system_instructionGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantGenerationConfigSystemInstruction

System instruction, also known as the prompt preamble for LLM calls. Corresponds to the JSON property systemInstruction



21493
21494
21495
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21493

def system_instruction
  @system_instruction
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21500
21501
21502
21503
21504
21505
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21500

def update!(**args)
  @allowed_model_ids = args[:allowed_model_ids] if args.key?(:allowed_model_ids)
  @default_language = args[:default_language] if args.key?(:default_language)
  @default_model_id = args[:default_model_id] if args.key?(:default_model_id)
  @system_instruction = args[:system_instruction] if args.key?(:system_instruction)
end