Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantGenerationConfigSystemInstruction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

System instruction, also known as the prompt preamble for LLM calls.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistantGenerationConfigSystemInstruction

Returns a new instance of GoogleCloudDiscoveryengineV1betaAssistantGenerationConfigSystemInstruction.



21382
21383
21384
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21382

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_system_instructionString

Optional. Additional system instruction that will be added to the default system instruction. Corresponds to the JSON property additionalSystemInstruction

Returns:

  • (String)


21380
21381
21382
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21380

def additional_system_instruction
  @additional_system_instruction
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21387
21388
21389
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21387

def update!(**args)
  @additional_system_instruction = args[:additional_system_instruction] if args.key?(:additional_system_instruction)
end