Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Document metadata.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata

Returns a new instance of GoogleCloudDiscoveryengineV1betaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata.



21652
21653
21654
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21652

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#documentString

Document resource name. Corresponds to the JSON property document

Returns:

  • (String)


21616
21617
21618
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21616

def document
  @document
end

#domainString

Domain name from the document URI. Note that the uri field may contain a URL that redirects to the actual website, in which case this will contain the domain name of the target site. Corresponds to the JSON property domain

Returns:

  • (String)


21623
21624
21625
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21623

def domain
  @domain
end

#languageString

Corresponds to the JSON property language

Returns:

  • (String)


21628
21629
21630
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21628

def language
  @language
end

#mime_typeString

The mime type of the document. https://www.iana.org/assignments/media-types/ media-types.xhtml. Corresponds to the JSON property mimeType

Returns:

  • (String)


21634
21635
21636
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21634

def mime_type
  @mime_type
end

#page_identifierString

Page identifier. Corresponds to the JSON property pageIdentifier

Returns:

  • (String)


21639
21640
21641
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21639

def page_identifier
  @page_identifier
end

#titleString

Title. Corresponds to the JSON property title

Returns:

  • (String)


21644
21645
21646
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21644

def title
  @title
end

#uriString

URI for the document. It may contain a URL that redirects to the actual website. Corresponds to the JSON property uri

Returns:

  • (String)


21650
21651
21652
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21650

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21657
21658
21659
21660
21661
21662
21663
21664
21665
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21657

def update!(**args)
  @document = args[:document] if args.key?(:document)
  @domain = args[:domain] if args.key?(:domain)
  @language = args[:language] if args.key?(:language)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
  @page_identifier = args[:page_identifier] if args.key?(:page_identifier)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end