Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantGroundedContentTextGroundingMetadataSegment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Grounding information for a segment of the text.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistantGroundedContentTextGroundingMetadataSegment

Returns a new instance of GoogleCloudDiscoveryengineV1betaAssistantGroundedContentTextGroundingMetadataSegment.



21713
21714
21715
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21713

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_indexFixnum

End of the segment, exclusive. Corresponds to the JSON property endIndex

Returns:

  • (Fixnum)


21689
21690
21691
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21689

def end_index
  @end_index
end

#grounding_scoreFloat

Score for the segment. Corresponds to the JSON property groundingScore

Returns:

  • (Float)


21694
21695
21696
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21694

def grounding_score
  @grounding_score
end

#reference_indicesArray<Fixnum>

References for the segment. Corresponds to the JSON property referenceIndices

Returns:

  • (Array<Fixnum>)


21699
21700
21701
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21699

def reference_indices
  @reference_indices
end

#start_indexFixnum

Zero-based index indicating the start of the segment, measured in bytes of a UTF-8 string (i.e. characters encoded on multiple bytes have a length of more than one). Corresponds to the JSON property startIndex

Returns:

  • (Fixnum)


21706
21707
21708
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21706

def start_index
  @start_index
end

#textString

The text segment itself. Corresponds to the JSON property text

Returns:

  • (String)


21711
21712
21713
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21711

def text
  @text
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21718
21719
21720
21721
21722
21723
21724
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21718

def update!(**args)
  @end_index = args[:end_index] if args.key?(:end_index)
  @grounding_score = args[:grounding_score] if args.key?(:grounding_score)
  @reference_indices = args[:reference_indices] if args.key?(:reference_indices)
  @start_index = args[:start_index] if args.key?(:start_index)
  @text = args[:text] if args.key?(:text)
end