Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaBatchGetDocumentsMetadataResponseDocumentMetadata
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaBatchGetDocumentsMetadataResponseDocumentMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
The metadata of a Document.
Instance Attribute Summary collapse
-
#data_ingestion_source ⇒ String
The data ingestion source of the Document.
-
#last_refreshed_time ⇒ String
The timestamp of the last time the Document was last indexed.
-
#matcher_value ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaBatchGetDocumentsMetadataResponseDocumentMetadataMatcherValue
The value of the matcher that was used to match the Document.
-
#state ⇒ String
The state of the document.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaBatchGetDocumentsMetadataResponseDocumentMetadata
constructor
A new instance of GoogleCloudDiscoveryengineV1betaBatchGetDocumentsMetadataResponseDocumentMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaBatchGetDocumentsMetadataResponseDocumentMetadata
Returns a new instance of GoogleCloudDiscoveryengineV1betaBatchGetDocumentsMetadataResponseDocumentMetadata.
21100 21101 21102 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21100 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_ingestion_source ⇒ String
The data ingestion source of the Document. Allowed values are: * batch: Data
ingested via Batch API, e.g., ImportDocuments. * streaming Data ingested via
Streaming API, e.g., FHIR streaming.
Corresponds to the JSON property dataIngestionSource
21083 21084 21085 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21083 def data_ingestion_source @data_ingestion_source end |
#last_refreshed_time ⇒ String
The timestamp of the last time the Document was last indexed.
Corresponds to the JSON property lastRefreshedTime
21088 21089 21090 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21088 def last_refreshed_time @last_refreshed_time end |
#matcher_value ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaBatchGetDocumentsMetadataResponseDocumentMetadataMatcherValue
The value of the matcher that was used to match the Document.
Corresponds to the JSON property matcherValue
21093 21094 21095 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21093 def matcher_value @matcher_value end |
#state ⇒ String
The state of the document.
Corresponds to the JSON property state
21098 21099 21100 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21098 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21105 21106 21107 21108 21109 21110 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21105 def update!(**args) @data_ingestion_source = args[:data_ingestion_source] if args.key?(:data_ingestion_source) @last_refreshed_time = args[:last_refreshed_time] if args.key?(:last_refreshed_time) @matcher_value = args[:matcher_value] if args.key?(:matcher_value) @state = args[:state] if args.key?(:state) end |