Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaBatchUpdateUserLicensesMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Metadata related to the progress of the UserLicenseService. BatchUpdateUserLicenses operation. This will be returned by the google. longrunning.Operation.metadata field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaBatchUpdateUserLicensesMetadata

Returns a new instance of GoogleCloudDiscoveryengineV1betaBatchUpdateUserLicensesMetadata.



21811
21812
21813
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21811

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Operation create time. Corresponds to the JSON property createTime

Returns:

  • (String)


21793
21794
21795
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21793

def create_time
  @create_time
end

#failure_countFixnum

Count of user licenses that failed to be updated. Corresponds to the JSON property failureCount

Returns:

  • (Fixnum)


21798
21799
21800
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21798

def failure_count
  @failure_count
end

#success_countFixnum

Count of user licenses successfully updated. Corresponds to the JSON property successCount

Returns:

  • (Fixnum)


21803
21804
21805
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21803

def success_count
  @success_count
end

#update_timeString

Operation last update time. If the operation is done, this is also the finish time. Corresponds to the JSON property updateTime

Returns:

  • (String)


21809
21810
21811
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21809

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21816
21817
21818
21819
21820
21821
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21816

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @failure_count = args[:failure_count] if args.key?(:failure_count)
  @success_count = args[:success_count] if args.key?(:success_count)
  @update_time = args[:update_time] if args.key?(:update_time)
end