Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaBatchUpdateUserLicensesResponse
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaBatchUpdateUserLicensesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Response message for UserLicenseService.BatchUpdateUserLicenses method.
Instance Attribute Summary collapse
-
#error_samples ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>
A sample of errors encountered while processing the request.
-
#user_licenses ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaUserLicense>
UserLicenses successfully updated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaBatchUpdateUserLicensesResponse
constructor
A new instance of GoogleCloudDiscoveryengineV1betaBatchUpdateUserLicensesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaBatchUpdateUserLicensesResponse
Returns a new instance of GoogleCloudDiscoveryengineV1betaBatchUpdateUserLicensesResponse.
21043 21044 21045 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21043 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_samples ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>
A sample of errors encountered while processing the request.
Corresponds to the JSON property errorSamples
21036 21037 21038 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21036 def error_samples @error_samples end |
#user_licenses ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaUserLicense>
UserLicenses successfully updated.
Corresponds to the JSON property userLicenses
21041 21042 21043 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21041 def user_licenses @user_licenses end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21048 21049 21050 21051 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21048 def update!(**args) @error_samples = args[:error_samples] if args.key?(:error_samples) @user_licenses = args[:user_licenses] if args.key?(:user_licenses) end |