Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaBigtableOptionsBigtableColumn

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

The column of the Bigtable.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaBigtableOptionsBigtableColumn

Returns a new instance of GoogleCloudDiscoveryengineV1betaBigtableOptionsBigtableColumn.



22200
22201
22202
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22200

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#encodingString

The encoding mode of the values when the type is not STRING. Acceptable encoding values are: * TEXT: indicates values are alphanumeric text strings.

  • BINARY: indicates values are encoded using HBase Bytes.toBytes family of functions. This can be overridden for a specific column by listing that column in columns and specifying an encoding for it. Corresponds to the JSON property encoding

Returns:

  • (String)


22176
22177
22178
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22176

def encoding
  @encoding
end

#field_nameString

The field name to use for this column in the document. The name has to match the pattern a-zA-Z0-9*. If not set, it is parsed from the qualifier bytes with best effort. However, due to different naming patterns, field name collisions could happen, where parsing behavior is undefined. Corresponds to the JSON property fieldName

Returns:

  • (String)


22184
22185
22186
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22184

def field_name
  @field_name
end

#qualifierString

Required. Qualifier of the column. If it cannot be decoded with utf-8, use a base-64 encoded string instead. Corresponds to the JSON property qualifier NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


22191
22192
22193
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22191

def qualifier
  @qualifier
end

#typeString

The type of values in this column family. The values are expected to be encoded using HBase Bytes.toBytes function when the encoding value is set to BINARY. Corresponds to the JSON property type

Returns:

  • (String)


22198
22199
22200
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22198

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22205
22206
22207
22208
22209
22210
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22205

def update!(**args)
  @encoding = args[:encoding] if args.key?(:encoding)
  @field_name = args[:field_name] if args.key?(:field_name)
  @qualifier = args[:qualifier] if args.key?(:qualifier)
  @type = args[:type] if args.key?(:type)
end