Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaBigtableSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

The Cloud Bigtable source for importing data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaBigtableSource

Returns a new instance of GoogleCloudDiscoveryengineV1betaBigtableSource.



22299
22300
22301
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22299

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bigtable_optionsGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaBigtableOptions

The Bigtable Options object that contains information to support the import. Corresponds to the JSON property bigtableOptions



22281
22282
22283
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22281

def bigtable_options
  @bigtable_options
end

#instance_idString

Required. The instance ID of the Cloud Bigtable that needs to be imported. Corresponds to the JSON property instanceId

Returns:

  • (String)


22286
22287
22288
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22286

def instance_id
  @instance_id
end

#project_idString

The project ID that contains the Bigtable source. Has a length limit of 128 characters. If not specified, inherits the project ID from the parent request. Corresponds to the JSON property projectId

Returns:

  • (String)


22292
22293
22294
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22292

def project_id
  @project_id
end

#table_idString

Required. The table ID of the Cloud Bigtable that needs to be imported. Corresponds to the JSON property tableId

Returns:

  • (String)


22297
22298
22299
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22297

def table_id
  @table_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22304
22305
22306
22307
22308
22309
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22304

def update!(**args)
  @bigtable_options = args[:bigtable_options] if args.key?(:bigtable_options)
  @instance_id = args[:instance_id] if args.key?(:instance_id)
  @project_id = args[:project_id] if args.key?(:project_id)
  @table_id = args[:table_id] if args.key?(:table_id)
end