Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCheckGroundingRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Request message for GroundedGenerationService.CheckGrounding method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaCheckGroundingRequest

Returns a new instance of GoogleCloudDiscoveryengineV1betaCheckGroundingRequest.



22210
22211
22212
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22210

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#answer_candidateString

Answer candidate to check. It can have a maximum length of 4096 tokens. Corresponds to the JSON property answerCandidate

Returns:

  • (String)


22183
22184
22185
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22183

def answer_candidate
  @answer_candidate
end

#factsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaGroundingFact>

List of facts for the grounding check. We support up to 200 facts. Corresponds to the JSON property facts



22188
22189
22190
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22188

def facts
  @facts
end

#grounding_specGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCheckGroundingSpec

Specification for the grounding check. Corresponds to the JSON property groundingSpec



22193
22194
22195
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22193

def grounding_spec
  @grounding_spec
end

#user_labelsHash<String,String>

The user labels applied to a resource must meet the following requirements: * Each resource can have multiple labels, up to a maximum of 64. * Each label must be a key-value pair. * Keys have a minimum length of 1 character and a maximum length of 63 characters and cannot be empty. Values can be empty and have a maximum length of 63 characters. * Keys and values can contain only lowercase letters, numeric characters, underscores, and dashes. All characters must use UTF-8 encoding, and international characters are allowed. * The key portion of a label must be unique. However, you can use the same key with multiple resources. * Keys must start with a lowercase letter or international character. See Google Cloud Document for more details. Corresponds to the JSON property userLabels

Returns:

  • (Hash<String,String>)


22208
22209
22210
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22208

def user_labels
  @user_labels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22215
22216
22217
22218
22219
22220
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22215

def update!(**args)
  @answer_candidate = args[:answer_candidate] if args.key?(:answer_candidate)
  @facts = args[:facts] if args.key?(:facts)
  @grounding_spec = args[:grounding_spec] if args.key?(:grounding_spec)
  @user_labels = args[:user_labels] if args.key?(:user_labels)
end