Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCheckGroundingResponse
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCheckGroundingResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Response message for the GroundedGenerationService.CheckGrounding method.
Instance Attribute Summary collapse
-
#cited_chunks ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaFactChunk>
List of facts cited across all claims in the answer candidate.
-
#cited_facts ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCheckGroundingResponseCheckGroundingFactChunk>
List of facts cited across all claims in the answer candidate.
-
#claims ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCheckGroundingResponseClaim>
Claim texts and citation info across all claims in the answer candidate.
-
#support_score ⇒ Float
The support score for the input answer candidate.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaCheckGroundingResponse
constructor
A new instance of GoogleCloudDiscoveryengineV1betaCheckGroundingResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaCheckGroundingResponse
Returns a new instance of GoogleCloudDiscoveryengineV1betaCheckGroundingResponse.
22387 22388 22389 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22387 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cited_chunks ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaFactChunk>
List of facts cited across all claims in the answer candidate. These are
derived from the facts supplied in the request.
Corresponds to the JSON property citedChunks
22367 22368 22369 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22367 def cited_chunks @cited_chunks end |
#cited_facts ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCheckGroundingResponseCheckGroundingFactChunk>
List of facts cited across all claims in the answer candidate. These are
derived from the facts supplied in the request.
Corresponds to the JSON property citedFacts
22373 22374 22375 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22373 def cited_facts @cited_facts end |
#claims ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCheckGroundingResponseClaim>
Claim texts and citation info across all claims in the answer candidate.
Corresponds to the JSON property claims
22378 22379 22380 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22378 def claims @claims end |
#support_score ⇒ Float
The support score for the input answer candidate. Higher the score, higher is
the fraction of claims that are supported by the provided facts. This is
always set when a response is returned.
Corresponds to the JSON property supportScore
22385 22386 22387 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22385 def support_score @support_score end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22392 22393 22394 22395 22396 22397 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22392 def update!(**args) @cited_chunks = args[:cited_chunks] if args.key?(:cited_chunks) @cited_facts = args[:cited_facts] if args.key?(:cited_facts) @claims = args[:claims] if args.key?(:claims) @support_score = args[:support_score] if args.key?(:support_score) end |