Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaChunkAnnotationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaChunkAnnotationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
The annotation metadata includes structured content in the current chunk.
Instance Attribute Summary collapse
-
#image_id ⇒ String
Output only.
-
#structured_content ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaChunkStructuredContent
The structured content information.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaChunkAnnotationMetadata
constructor
A new instance of GoogleCloudDiscoveryengineV1betaChunkAnnotationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaChunkAnnotationMetadata
Returns a new instance of GoogleCloudDiscoveryengineV1betaChunkAnnotationMetadata.
21813 21814 21815 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21813 def initialize(**args) update!(**args) end |
Instance Attribute Details
#image_id ⇒ String
Output only. Image id is provided if the structured content is based on an
image.
Corresponds to the JSON property imageId
21806 21807 21808 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21806 def image_id @image_id end |
#structured_content ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaChunkStructuredContent
The structured content information.
Corresponds to the JSON property structuredContent
21811 21812 21813 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21811 def structured_content @structured_content end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21818 21819 21820 21821 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21818 def update!(**args) @image_id = args[:image_id] if args.key?(:image_id) @structured_content = args[:structured_content] if args.key?(:structured_content) end |