Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCitation
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCitation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Source attributions for content.
Instance Attribute Summary collapse
-
#end_index ⇒ Fixnum
Output only.
-
#license ⇒ String
Output only.
-
#publication_date ⇒ Google::Apis::DiscoveryengineV1beta::GoogleTypeDate
Represents a whole or partial calendar date, such as a birthday.
-
#start_index ⇒ Fixnum
Output only.
-
#title ⇒ String
Output only.
-
#uri ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaCitation
constructor
A new instance of GoogleCloudDiscoveryengineV1betaCitation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaCitation
Returns a new instance of GoogleCloudDiscoveryengineV1betaCitation.
22661 22662 22663 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22661 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_index ⇒ Fixnum
Output only. End index into the content.
Corresponds to the JSON property endIndex
22627 22628 22629 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22627 def end_index @end_index end |
#license ⇒ String
Output only. License of the attribution.
Corresponds to the JSON property license
22632 22633 22634 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22632 def license @license end |
#publication_date ⇒ Google::Apis::DiscoveryengineV1beta::GoogleTypeDate
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property publicationDate
22644 22645 22646 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22644 def publication_date @publication_date end |
#start_index ⇒ Fixnum
Output only. Start index into the content.
Corresponds to the JSON property startIndex
22649 22650 22651 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22649 def start_index @start_index end |
#title ⇒ String
Output only. Title of the attribution.
Corresponds to the JSON property title
22654 22655 22656 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22654 def title @title end |
#uri ⇒ String
Output only. Url reference of the attribution.
Corresponds to the JSON property uri
22659 22660 22661 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22659 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22666 22667 22668 22669 22670 22671 22672 22673 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22666 def update!(**args) @end_index = args[:end_index] if args.key?(:end_index) @license = args[:license] if args.key?(:license) @publication_date = args[:publication_date] if args.key?(:publication_date) @start_index = args[:start_index] if args.key?(:start_index) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) end |