Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCmekConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Configurations used to enable CMEK data encryption with Cloud KMS keys.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaCmekConfig

Returns a new instance of GoogleCloudDiscoveryengineV1betaCmekConfig.



22803
22804
22805
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22803

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#is_defaultBoolean Also known as: is_default?

Output only. The default CmekConfig for the Customer. Corresponds to the JSON property isDefault

Returns:

  • (Boolean)


22761
22762
22763
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22761

def is_default
  @is_default
end

#kms_keyString

Required. KMS key resource name which will be used to encrypt resources projects/project/locations/location/keyRings/keyRing/cryptoKeys/keyId`. Corresponds to the JSON propertykmsKey`

Returns:

  • (String)


22768
22769
22770
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22768

def kms_key
  @kms_key
end

#kms_key_versionString

Output only. KMS key version resource name which will be used to encrypt resources /cryptoKeyVersions/keyVersion`. Corresponds to the JSON propertykmsKeyVersion`

Returns:

  • (String)


22774
22775
22776
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22774

def kms_key_version
  @kms_key_version
end

#last_rotation_timestamp_microsFixnum

Output only. The timestamp of the last key rotation. Corresponds to the JSON property lastRotationTimestampMicros

Returns:

  • (Fixnum)


22779
22780
22781
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22779

def last_rotation_timestamp_micros
  @last_rotation_timestamp_micros
end

#nameString

Required. The name of the CmekConfig of the form projects/project/locations/ location/cmekConfig or projects/project/locations/location/cmekConfigs/ cmek_config`. Corresponds to the JSON propertyname`

Returns:

  • (String)


22786
22787
22788
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22786

def name
  @name
end

#notebooklm_stateString

Output only. Whether the NotebookLM Corpus is ready to be used. Corresponds to the JSON property notebooklmState

Returns:

  • (String)


22791
22792
22793
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22791

def notebooklm_state
  @notebooklm_state
end

#single_region_keysArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSingleRegionKey>

Optional. Single-regional CMEKs that are required for some VAIS features. Corresponds to the JSON property singleRegionKeys



22796
22797
22798
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22796

def single_region_keys
  @single_region_keys
end

#stateString

Output only. The states of the CmekConfig. Corresponds to the JSON property state

Returns:

  • (String)


22801
22802
22803
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22801

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22808
22809
22810
22811
22812
22813
22814
22815
22816
22817
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22808

def update!(**args)
  @is_default = args[:is_default] if args.key?(:is_default)
  @kms_key = args[:kms_key] if args.key?(:kms_key)
  @kms_key_version = args[:kms_key_version] if args.key?(:kms_key_version)
  @last_rotation_timestamp_micros = args[:last_rotation_timestamp_micros] if args.key?(:last_rotation_timestamp_micros)
  @name = args[:name] if args.key?(:name)
  @notebooklm_state = args[:notebooklm_state] if args.key?(:notebooklm_state)
  @single_region_keys = args[:single_region_keys] if args.key?(:single_region_keys)
  @state = args[:state] if args.key?(:state)
end