Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCondition

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Defines circumstances to be checked before allowing a behavior

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaCondition

Returns a new instance of GoogleCloudDiscoveryengineV1betaCondition.



22105
22106
22107
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22105

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#active_time_rangeArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaConditionTimeRange>

Range of time(s) specifying when condition is active. Maximum of 10 time ranges. Corresponds to the JSON property activeTimeRange



22090
22091
22092
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22090

def active_time_range
  @active_time_range
end

#query_regexString

Optional. Query regex to match the whole search query. Cannot be set when Condition.query_terms is set. Only supported for Basic Site Search promotion serving controls. Corresponds to the JSON property queryRegex

Returns:

  • (String)


22097
22098
22099
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22097

def query_regex
  @query_regex
end

#query_termsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaConditionQueryTerm>

Search only A list of terms to match the query on. Cannot be set when Condition.query_regex is set. Maximum of 10 query terms. Corresponds to the JSON property queryTerms



22103
22104
22105
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22103

def query_terms
  @query_terms
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22110
22111
22112
22113
22114
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22110

def update!(**args)
  @active_time_range = args[:active_time_range] if args.key?(:active_time_range)
  @query_regex = args[:query_regex] if args.key?(:query_regex)
  @query_terms = args[:query_terms] if args.key?(:query_terms)
end