Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaConditionQueryTerm

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Matcher for search request query

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaConditionQueryTerm

Returns a new instance of GoogleCloudDiscoveryengineV1betaConditionQueryTerm.



23150
23151
23152
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23150

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#full_matchBoolean Also known as: full_match?

Whether the search query needs to exactly match the query term. Corresponds to the JSON property fullMatch

Returns:

  • (Boolean)


23140
23141
23142
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23140

def full_match
  @full_match
end

#valueString

The specific query value to match against Must be lowercase, must be UTF-8. Can have at most 3 space separated terms if full_match is true. Cannot be an empty string. Maximum length of 5000 characters. Corresponds to the JSON property value

Returns:

  • (String)


23148
23149
23150
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23148

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23155
23156
23157
23158
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23155

def update!(**args)
  @full_match = args[:full_match] if args.key?(:full_match)
  @value = args[:value] if args.key?(:value)
end