Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCustomTuningModel
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCustomTuningModel
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Metadata that describes a custom tuned model.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Deprecated: Timestamp the Model was created at.
-
#display_name ⇒ String
The display name of the model.
-
#error_message ⇒ String
Currently this is only populated if the model state is
INPUT_VALIDATION_FAILED. -
#metrics ⇒ Hash<String,Float>
The metrics of the trained model.
-
#model_state ⇒ String
The state that the model is in (e.g.
TRAININGorTRAINING_FAILED). -
#model_version ⇒ Fixnum
The version of the model.
-
#name ⇒ String
Required.
-
#training_start_time ⇒ String
Timestamp the model training was initiated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaCustomTuningModel
constructor
A new instance of GoogleCloudDiscoveryengineV1betaCustomTuningModel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaCustomTuningModel
Returns a new instance of GoogleCloudDiscoveryengineV1betaCustomTuningModel.
23211 23212 23213 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23211 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Deprecated: Timestamp the Model was created at.
Corresponds to the JSON property createTime
23170 23171 23172 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23170 def create_time @create_time end |
#display_name ⇒ String
The display name of the model.
Corresponds to the JSON property displayName
23175 23176 23177 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23175 def display_name @display_name end |
#error_message ⇒ String
Currently this is only populated if the model state is
INPUT_VALIDATION_FAILED.
Corresponds to the JSON property errorMessage
23181 23182 23183 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23181 def @error_message end |
#metrics ⇒ Hash<String,Float>
The metrics of the trained model.
Corresponds to the JSON property metrics
23186 23187 23188 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23186 def metrics @metrics end |
#model_state ⇒ String
The state that the model is in (e.g.TRAINING or TRAINING_FAILED).
Corresponds to the JSON property modelState
23191 23192 23193 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23191 def model_state @model_state end |
#model_version ⇒ Fixnum
The version of the model.
Corresponds to the JSON property modelVersion
23196 23197 23198 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23196 def model_version @model_version end |
#name ⇒ String
Required. The fully qualified resource name of the model. Format: projects/
project/locations/location/collections/collection/dataStores/data_store/
customTuningModels/custom_tuning_model`. Model must be an alpha-numerical
string with limit of 40 characters.
Corresponds to the JSON propertyname`
23204 23205 23206 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23204 def name @name end |
#training_start_time ⇒ String
Timestamp the model training was initiated.
Corresponds to the JSON property trainingStartTime
23209 23210 23211 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23209 def training_start_time @training_start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23216 23217 23218 23219 23220 23221 23222 23223 23224 23225 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23216 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @error_message = args[:error_message] if args.key?(:error_message) @metrics = args[:metrics] if args.key?(:metrics) @model_state = args[:model_state] if args.key?(:model_state) @model_version = args[:model_version] if args.key?(:model_version) @name = args[:name] if args.key?(:name) @training_start_time = args[:training_start_time] if args.key?(:training_start_time) end |