Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDataStore

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

DataStore captures global settings and configs at the DataStore level.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaDataStore

Returns a new instance of GoogleCloudDiscoveryengineV1betaDataStore.



24174
24175
24176
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24174

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#acl_enabledBoolean Also known as: acl_enabled?

Immutable. Whether data in the DataStore has ACL information. If set to true, the source data must have ACL. ACL will be ingested when data is ingested by DocumentService.ImportDocuments methods. When ACL is enabled for the DataStore, Document can't be accessed by calling DocumentService.GetDocument or DocumentService.ListDocuments. Currently ACL is only supported in GENERIC industry vertical with non-PUBLIC_WEBSITE content config. Corresponds to the JSON property aclEnabled

Returns:

  • (Boolean)


24038
24039
24040
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24038

def acl_enabled
  @acl_enabled
end

#advanced_site_search_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAdvancedSiteSearchConfig

Configuration data for advance site search. Corresponds to the JSON property advancedSiteSearchConfig



24044
24045
24046
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24044

def advanced_site_search_config
  @advanced_site_search_config
end

#billing_estimationGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDataStoreBillingEstimation

Estimation of data size per data store. Corresponds to the JSON property billingEstimation



24049
24050
24051
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24049

def billing_estimation
  @billing_estimation
end

#cmek_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCmekConfig

Configurations used to enable CMEK data encryption with Cloud KMS keys. Corresponds to the JSON property cmekConfig



24054
24055
24056
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24054

def cmek_config
  @cmek_config
end

#configurable_billing_approachString

Optional. Configuration for configurable billing approach. See Corresponds to the JSON property configurableBillingApproach

Returns:

  • (String)


24059
24060
24061
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24059

def configurable_billing_approach
  @configurable_billing_approach
end

#configurable_billing_approach_update_timeString

Output only. The timestamp when configurable_billing_approach was last updated. Corresponds to the JSON property configurableBillingApproachUpdateTime

Returns:

  • (String)


24064
24065
24066
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24064

def configurable_billing_approach_update_time
  @configurable_billing_approach_update_time
end

#content_configString

Immutable. The content config of the data store. If this field is unset, the server behavior defaults to ContentConfig.NO_CONTENT. Corresponds to the JSON property contentConfig

Returns:

  • (String)


24070
24071
24072
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24070

def content_config
  @content_config
end

#create_timeString

Output only. Timestamp the DataStore was created at. Corresponds to the JSON property createTime

Returns:

  • (String)


24075
24076
24077
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24075

def create_time
  @create_time
end

#default_schema_idString

Output only. The id of the default Schema associated to this data store. Corresponds to the JSON property defaultSchemaId

Returns:

  • (String)


24080
24081
24082
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24080

def default_schema_id
  @default_schema_id
end

#display_nameString

Required. The data store display name. This field must be a UTF-8 encoded string with a length limit of 128 characters. Otherwise, an INVALID_ARGUMENT error is returned. Corresponds to the JSON property displayName

Returns:

  • (String)


24087
24088
24089
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24087

def display_name
  @display_name
end

#document_processing_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocumentProcessingConfig

A singleton resource of DataStore. If it's empty when DataStore is created and DataStore is set to DataStore.ContentConfig.CONTENT_REQUIRED, the default parser will default to digital parser. Corresponds to the JSON property documentProcessingConfig



24094
24095
24096
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24094

def document_processing_config
  @document_processing_config
end

#federated_search_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDataStoreFederatedSearchConfig

Stores information for federated search. Corresponds to the JSON property federatedSearchConfig



24099
24100
24101
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24099

def federated_search_config
  @federated_search_config
end

#healthcare_fhir_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaHealthcareFhirConfig

Config to data store for HEALTHCARE_FHIR vertical. Corresponds to the JSON property healthcareFhirConfig



24104
24105
24106
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24104

def healthcare_fhir_config
  @healthcare_fhir_config
end

#identity_mapping_storeString

Immutable. The fully qualified resource name of the associated IdentityMappingStore. This field can only be set for acl_enabled DataStores with THIRD_PARTY or GSUITE IdP. Format: projects/project/locations/ location/identityMappingStores/identity_mapping_store`. Corresponds to the JSON propertyidentityMappingStore`

Returns:

  • (String)


24112
24113
24114
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24112

def identity_mapping_store
  @identity_mapping_store
end

#industry_verticalString

Immutable. The industry vertical that the data store registers. Corresponds to the JSON property industryVertical

Returns:

  • (String)


24117
24118
24119
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24117

def industry_vertical
  @industry_vertical
end

#is_infobot_faq_data_storeBoolean Also known as: is_infobot_faq_data_store?

Optional. If set, this DataStore is an Infobot FAQ DataStore. Corresponds to the JSON property isInfobotFaqDataStore

Returns:

  • (Boolean)


24122
24123
24124
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24122

def is_infobot_faq_data_store
  @is_infobot_faq_data_store
end

#kms_key_nameString

Input only. The KMS key to be used to protect this DataStore at creation time. Must be set for requests that need to comply with CMEK Org Policy protections. If this field is set and processed successfully, the DataStore will be protected by the KMS key, as indicated in the cmek_config field. Corresponds to the JSON property kmsKeyName

Returns:

  • (String)


24131
24132
24133
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24131

def kms_key_name
  @kms_key_name
end

#language_infoGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaLanguageInfo

Language info for DataStore. Corresponds to the JSON property languageInfo



24136
24137
24138
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24136

def language_info
  @language_info
end

#nameString

Immutable. Identifier. The full resource name of the data store. Format: projects/project/locations/location/collections/collection_id/dataStores/ data_store_id`. This field must be a UTF-8 encoded string with a length limit of 1024 characters. Corresponds to the JSON propertyname`

Returns:

  • (String)


24144
24145
24146
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24144

def name
  @name
end

#natural_language_query_understanding_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaNaturalLanguageQueryUnderstandingConfig

Configuration for Natural Language Query Understanding. Corresponds to the JSON property naturalLanguageQueryUnderstandingConfig



24149
24150
24151
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24149

def natural_language_query_understanding_config
  @natural_language_query_understanding_config
end

#serving_config_data_storeGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDataStoreServingConfigDataStore

Stores information regarding the serving configurations at DataStore level. Corresponds to the JSON property servingConfigDataStore



24154
24155
24156
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24154

def serving_config_data_store
  @serving_config_data_store
end

#solution_typesArray<String>

The solutions that the data store enrolls. Available solutions for each industry_vertical: * MEDIA: SOLUTION_TYPE_RECOMMENDATION and SOLUTION_TYPE_SEARCH. * SITE_SEARCH: SOLUTION_TYPE_SEARCH is automatically enrolled. Other solutions cannot be enrolled. Corresponds to the JSON property solutionTypes

Returns:

  • (Array<String>)


24162
24163
24164
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24162

def solution_types
  @solution_types
end

#starting_schemaGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSchema

Defines the structure and layout of a type of document data. Corresponds to the JSON property startingSchema



24167
24168
24169
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24167

def starting_schema
  @starting_schema
end

#workspace_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaWorkspaceConfig

Config to store data store type configuration for workspace data Corresponds to the JSON property workspaceConfig



24172
24173
24174
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24172

def workspace_config
  @workspace_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24179
24180
24181
24182
24183
24184
24185
24186
24187
24188
24189
24190
24191
24192
24193
24194
24195
24196
24197
24198
24199
24200
24201
24202
24203
24204
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24179

def update!(**args)
  @acl_enabled = args[:acl_enabled] if args.key?(:acl_enabled)
  @advanced_site_search_config = args[:advanced_site_search_config] if args.key?(:advanced_site_search_config)
  @billing_estimation = args[:billing_estimation] if args.key?(:billing_estimation)
  @cmek_config = args[:cmek_config] if args.key?(:cmek_config)
  @configurable_billing_approach = args[:configurable_billing_approach] if args.key?(:configurable_billing_approach)
  @configurable_billing_approach_update_time = args[:configurable_billing_approach_update_time] if args.key?(:configurable_billing_approach_update_time)
  @content_config = args[:content_config] if args.key?(:content_config)
  @create_time = args[:create_time] if args.key?(:create_time)
  @default_schema_id = args[:default_schema_id] if args.key?(:default_schema_id)
  @display_name = args[:display_name] if args.key?(:display_name)
  @document_processing_config = args[:document_processing_config] if args.key?(:document_processing_config)
  @federated_search_config = args[:federated_search_config] if args.key?(:federated_search_config)
  @healthcare_fhir_config = args[:healthcare_fhir_config] if args.key?(:healthcare_fhir_config)
  @identity_mapping_store = args[:identity_mapping_store] if args.key?(:identity_mapping_store)
  @industry_vertical = args[:industry_vertical] if args.key?(:industry_vertical)
  @is_infobot_faq_data_store = args[:is_infobot_faq_data_store] if args.key?(:is_infobot_faq_data_store)
  @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name)
  @language_info = args[:language_info] if args.key?(:language_info)
  @name = args[:name] if args.key?(:name)
  @natural_language_query_understanding_config = args[:natural_language_query_understanding_config] if args.key?(:natural_language_query_understanding_config)
  @serving_config_data_store = args[:serving_config_data_store] if args.key?(:serving_config_data_store)
  @solution_types = args[:solution_types] if args.key?(:solution_types)
  @starting_schema = args[:starting_schema] if args.key?(:starting_schema)
  @workspace_config = args[:workspace_config] if args.key?(:workspace_config)
end