Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocument

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Document captures all raw metadata information of items to be recommended or searched.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaDocument

Returns a new instance of GoogleCloudDiscoveryengineV1betaDocument.



24851
24852
24853
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24851

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#acl_infoGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocumentAclInfo

ACL Information of the Document. Corresponds to the JSON property aclInfo



24785
24786
24787
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24785

def acl_info
  @acl_info
end

#contentGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocumentContent

Unstructured data linked to this document. Corresponds to the JSON property content



24790
24791
24792
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24790

def content
  @content
end

#derived_struct_dataHash<String,Object>

Output only. This field is OUTPUT_ONLY. It contains derived data that are not in the original input document. Corresponds to the JSON property derivedStructData

Returns:

  • (Hash<String,Object>)


24796
24797
24798
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24796

def derived_struct_data
  @derived_struct_data
end

#idString

Immutable. The identifier of the document. Id should conform to RFC-1034 standard with a length limit of 128 characters. Corresponds to the JSON property id

Returns:

  • (String)


24803
24804
24805
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24803

def id
  @id
end

#index_statusGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocumentIndexStatus

Index status of the document. Corresponds to the JSON property indexStatus



24808
24809
24810
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24808

def index_status
  @index_status
end

#index_timeString

Output only. The time when the document was last indexed. If this field is populated, it means the document has been indexed. While documents typically become searchable within seconds of indexing, it can sometimes take up to a few hours. If this field is not populated, it means the document has never been indexed. Corresponds to the JSON property indexTime

Returns:

  • (String)


24817
24818
24819
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24817

def index_time
  @index_time
end

#json_dataString

The JSON string representation of the document. It should conform to the registered Schema or an INVALID_ARGUMENT error is thrown. Corresponds to the JSON property jsonData

Returns:

  • (String)


24823
24824
24825
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24823

def json_data
  @json_data
end

#nameString

Immutable. The full resource name of the document. Format: projects/project/ locations/location/collections/collection/dataStores/data_store/branches/ branch/documents/document_id`. This field must be a UTF-8 encoded string with a length limit of 1024 characters. Corresponds to the JSON propertyname`

Returns:

  • (String)


24831
24832
24833
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24831

def name
  @name
end

#parent_document_idString

The identifier of the parent document. Currently supports at most two level document hierarchy. Id should conform to RFC-1034 standard with a length limit of 63 characters. Corresponds to the JSON property parentDocumentId

Returns:

  • (String)


24838
24839
24840
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24838

def parent_document_id
  @parent_document_id
end

#schema_idString

The identifier of the schema located in the same data store. Corresponds to the JSON property schemaId

Returns:

  • (String)


24843
24844
24845
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24843

def schema_id
  @schema_id
end

#struct_dataHash<String,Object>

The structured JSON data for the document. It should conform to the registered Schema or an INVALID_ARGUMENT error is thrown. Corresponds to the JSON property structData

Returns:

  • (Hash<String,Object>)


24849
24850
24851
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24849

def struct_data
  @struct_data
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24856
24857
24858
24859
24860
24861
24862
24863
24864
24865
24866
24867
24868
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24856

def update!(**args)
  @acl_info = args[:acl_info] if args.key?(:acl_info)
  @content = args[:content] if args.key?(:content)
  @derived_struct_data = args[:derived_struct_data] if args.key?(:derived_struct_data)
  @id = args[:id] if args.key?(:id)
  @index_status = args[:index_status] if args.key?(:index_status)
  @index_time = args[:index_time] if args.key?(:index_time)
  @json_data = args[:json_data] if args.key?(:json_data)
  @name = args[:name] if args.key?(:name)
  @parent_document_id = args[:parent_document_id] if args.key?(:parent_document_id)
  @schema_id = args[:schema_id] if args.key?(:schema_id)
  @struct_data = args[:struct_data] if args.key?(:struct_data)
end