Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocumentContent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Unstructured data linked to this document.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaDocumentContent

Returns a new instance of GoogleCloudDiscoveryengineV1betaDocumentContent.



23959
23960
23961
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23959

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#mime_typeString

The MIME type of the content. Supported types: * application/pdf (PDF, only native PDFs are supported for now) * text/html (HTML) * text/plain (TXT) * application/xml or text/xml (XML) * application/json (JSON) * application/vnd.openxmlformats-officedocument.wordprocessingml.document (DOCX)

  • application/vnd.openxmlformats-officedocument.presentationml.presentation (PPTX) * application/vnd.openxmlformats-officedocument.spreadsheetml.sheet ( XLSX) * application/vnd.ms-excel.sheet.macroenabled.12 (XLSM) The following types are supported only if layout parser is enabled in the data store: * image/bmp (BMP) * image/gif (GIF) * image/jpeg (JPEG) * image/png (PNG)
  • image/tiff (TIFF) See https://www.iana.org/assignments/media-types/media- types.xhtml. Corresponds to the JSON property mimeType

Returns:

  • (String)


23939
23940
23941
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23939

def mime_type
  @mime_type
end

#raw_bytesString

The content represented as a stream of bytes. The maximum length is 1,000,000 bytes (1 MB / ~0.95 MiB). Note: As with all bytes fields, this field is represented as pure binary in Protocol Buffers and base64-encoded string in JSON. For example, abc123!?$*&()'-=@~ should be represented as YWJjMTIzIT8kKiYoKSctPUB+ in JSON. See https://developers.google.com/protocol- buffers/docs/proto3#json. Corresponds to the JSON property rawBytes NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


23950
23951
23952
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23950

def raw_bytes
  @raw_bytes
end

#uriString

The URI of the content. Only Cloud Storage URIs (e.g. gs://bucket-name/path/ to/file) are supported. The maximum file size is 2.5 MB for text-based formats, 200 MB for other formats. Corresponds to the JSON property uri

Returns:

  • (String)


23957
23958
23959
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23957

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23964
23965
23966
23967
23968
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23964

def update!(**args)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
  @raw_bytes = args[:raw_bytes] if args.key?(:raw_bytes)
  @uri = args[:uri] if args.key?(:uri)
end