Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocumentInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Detailed document information associated with a user event.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaDocumentInfo

Returns a new instance of GoogleCloudDiscoveryengineV1betaDocumentInfo.



25071
25072
25073
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25071

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversion_valueFloat

Optional. The conversion value associated with this Document. Must be set if UserEvent.event_type is "conversion". For example, a value of 1000 signifies that 1000 seconds were spent viewing a Document for the watch conversion type. Corresponds to the JSON property conversionValue

Returns:

  • (Float)


25032
25033
25034
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25032

def conversion_value
  @conversion_value
end

#idString

The Document resource ID. Corresponds to the JSON property id

Returns:

  • (String)


25037
25038
25039
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25037

def id
  @id
end

#joinedBoolean Also known as: joined?

Output only. Whether the referenced Document can be found in the data store. Corresponds to the JSON property joined

Returns:

  • (Boolean)


25042
25043
25044
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25042

def joined
  @joined
end

#nameString

The Document resource full name, of the form: projects/project/locations/ location/collections/collection_id/dataStores/data_store_id/branches/ branch_id/documents/document_id` Corresponds to the JSON propertyname`

Returns:

  • (String)


25050
25051
25052
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25050

def name
  @name
end

#promotion_idsArray<String>

The promotion IDs associated with this Document. Currently, this field is restricted to at most one ID. Corresponds to the JSON property promotionIds

Returns:

  • (Array<String>)


25056
25057
25058
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25056

def promotion_ids
  @promotion_ids
end

#quantityFixnum

Quantity of the Document associated with the user event. Defaults to 1. For example, this field is 2 if two quantities of the same Document are involved in a add-to-cart event. Required for events of the following event types: * add-to-cart * purchase Corresponds to the JSON property quantity

Returns:

  • (Fixnum)


25064
25065
25066
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25064

def quantity
  @quantity
end

#uriString

The Document URI - only allowed for website data stores. Corresponds to the JSON property uri

Returns:

  • (String)


25069
25070
25071
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25069

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25076
25077
25078
25079
25080
25081
25082
25083
25084
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25076

def update!(**args)
  @conversion_value = args[:conversion_value] if args.key?(:conversion_value)
  @id = args[:id] if args.key?(:id)
  @joined = args[:joined] if args.key?(:joined)
  @name = args[:name] if args.key?(:name)
  @promotion_ids = args[:promotion_ids] if args.key?(:promotion_ids)
  @quantity = args[:quantity] if args.key?(:quantity)
  @uri = args[:uri] if args.key?(:uri)
end