Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocumentProcessingConfigParsingConfigOcrParsingConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

The OCR parsing configurations for documents.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaDocumentProcessingConfigParsingConfigOcrParsingConfig

Returns a new instance of GoogleCloudDiscoveryengineV1betaDocumentProcessingConfigParsingConfigOcrParsingConfig.



25146
25147
25148
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25146

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enhanced_document_elementsArray<String>

[DEPRECATED] This field is deprecated. To use the additional enhanced document elements processing, please switch to layout_parsing_config. Corresponds to the JSON property enhancedDocumentElements

Returns:

  • (Array<String>)


25137
25138
25139
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25137

def enhanced_document_elements
  @enhanced_document_elements
end

#use_native_textBoolean Also known as: use_native_text?

If true, will use native text instead of OCR text on pages containing native text. Corresponds to the JSON property useNativeText

Returns:

  • (Boolean)


25143
25144
25145
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25143

def use_native_text
  @use_native_text
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25151
25152
25153
25154
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25151

def update!(**args)
  @enhanced_document_elements = args[:enhanced_document_elements] if args.key?(:enhanced_document_elements)
  @use_native_text = args[:use_native_text] if args.key?(:use_native_text)
end