Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaEngineKnowledgeGraphConfig
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaEngineKnowledgeGraphConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Configuration message for the Knowledge Graph.
Instance Attribute Summary collapse
-
#cloud_knowledge_graph_types ⇒ Array<String>
Specify entity types to support.
-
#enable_cloud_knowledge_graph ⇒ Boolean
(also: #enable_cloud_knowledge_graph?)
Whether to enable the Cloud Knowledge Graph for the engine.
-
#enable_private_knowledge_graph ⇒ Boolean
(also: #enable_private_knowledge_graph?)
Whether to enable the Private Knowledge Graph for the engine.
-
#feature_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaEngineKnowledgeGraphConfigFeatureConfig
Feature config for the Knowledge Graph.
-
#private_knowledge_graph_types ⇒ Array<String>
Specify entity types to support.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaEngineKnowledgeGraphConfig
constructor
A new instance of GoogleCloudDiscoveryengineV1betaEngineKnowledgeGraphConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaEngineKnowledgeGraphConfig
Returns a new instance of GoogleCloudDiscoveryengineV1betaEngineKnowledgeGraphConfig.
25787 25788 25789 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25787 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cloud_knowledge_graph_types ⇒ Array<String>
Specify entity types to support.
Corresponds to the JSON property cloudKnowledgeGraphTypes
25761 25762 25763 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25761 def cloud_knowledge_graph_types @cloud_knowledge_graph_types end |
#enable_cloud_knowledge_graph ⇒ Boolean Also known as: enable_cloud_knowledge_graph?
Whether to enable the Cloud Knowledge Graph for the engine. Defaults to false
if not specified.
Corresponds to the JSON property enableCloudKnowledgeGraph
25767 25768 25769 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25767 def enable_cloud_knowledge_graph @enable_cloud_knowledge_graph end |
#enable_private_knowledge_graph ⇒ Boolean Also known as: enable_private_knowledge_graph?
Whether to enable the Private Knowledge Graph for the engine. Defaults to
false if not specified.
Corresponds to the JSON property enablePrivateKnowledgeGraph
25774 25775 25776 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25774 def enable_private_knowledge_graph @enable_private_knowledge_graph end |
#feature_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaEngineKnowledgeGraphConfigFeatureConfig
Feature config for the Knowledge Graph.
Corresponds to the JSON property featureConfig
25780 25781 25782 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25780 def feature_config @feature_config end |
#private_knowledge_graph_types ⇒ Array<String>
Specify entity types to support.
Corresponds to the JSON property privateKnowledgeGraphTypes
25785 25786 25787 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25785 def private_knowledge_graph_types @private_knowledge_graph_types end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25792 25793 25794 25795 25796 25797 25798 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25792 def update!(**args) @cloud_knowledge_graph_types = args[:cloud_knowledge_graph_types] if args.key?(:cloud_knowledge_graph_types) @enable_cloud_knowledge_graph = args[:enable_cloud_knowledge_graph] if args.key?(:enable_cloud_knowledge_graph) @enable_private_knowledge_graph = args[:enable_private_knowledge_graph] if args.key?(:enable_private_knowledge_graph) @feature_config = args[:feature_config] if args.key?(:feature_config) @private_knowledge_graph_types = args[:private_knowledge_graph_types] if args.key?(:private_knowledge_graph_types) end |