Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaEngineMediaRecommendationEngineConfigRecommendedForYouFeatureConfig
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaEngineMediaRecommendationEngineConfigRecommendedForYouFeatureConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Additional feature configurations for creating a recommended-for-you engine.
Instance Attribute Summary collapse
-
#context_event_type ⇒ String
The type of event with which the engine is queried at prediction time.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaEngineMediaRecommendationEngineConfigRecommendedForYouFeatureConfig
constructor
A new instance of GoogleCloudDiscoveryengineV1betaEngineMediaRecommendationEngineConfigRecommendedForYouFeatureConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaEngineMediaRecommendationEngineConfigRecommendedForYouFeatureConfig
Returns a new instance of GoogleCloudDiscoveryengineV1betaEngineMediaRecommendationEngineConfigRecommendedForYouFeatureConfig.
24961 24962 24963 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24961 def initialize(**args) update!(**args) end |
Instance Attribute Details
#context_event_type ⇒ String
The type of event with which the engine is queried at prediction time. If set
to generic, only view-item, media-play,and media-complete will be used
as context-event in engine training. If set to view-home-page, view-home-
page will also be used as context-events in addition to view-item, media-
play, and media-complete. Currently supported for the recommended-for-you
engine. Currently supported values: view-home-page, generic.
Corresponds to the JSON property contextEventType
24959 24960 24961 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24959 def context_event_type @context_event_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24966 24967 24968 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24966 def update!(**args) @context_event_type = args[:context_event_type] if args.key?(:context_event_type) end |