Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaFactChunk

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Fact Chunk.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaFactChunk

Returns a new instance of GoogleCloudDiscoveryengineV1betaFactChunk.



26190
26191
26192
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26190

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chunk_textString

Text content of the fact chunk. Can be at most 10K characters long. Corresponds to the JSON property chunkText

Returns:

  • (String)


26156
26157
26158
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26156

def chunk_text
  @chunk_text
end

#domainString

The domain of the source. Corresponds to the JSON property domain

Returns:

  • (String)


26161
26162
26163
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26161

def domain
  @domain
end

#indexFixnum

The index of this chunk. Currently, only used for the streaming mode. Corresponds to the JSON property index

Returns:

  • (Fixnum)


26166
26167
26168
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26166

def index
  @index
end

#sourceString

Source from which this fact chunk was retrieved. If it was retrieved from the GroundingFacts provided in the request then this field will contain the index of the specific fact from which this chunk was retrieved. Corresponds to the JSON property source

Returns:

  • (String)


26173
26174
26175
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26173

def source
  @source
end

#source_metadataHash<String,String>

More fine-grained information for the source reference. Corresponds to the JSON property sourceMetadata

Returns:

  • (Hash<String,String>)


26178
26179
26180
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26178

def 
  @source_metadata
end

#titleString

The title of the source. Corresponds to the JSON property title

Returns:

  • (String)


26183
26184
26185
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26183

def title
  @title
end

#uriString

The URI of the source. Corresponds to the JSON property uri

Returns:

  • (String)


26188
26189
26190
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26188

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26195
26196
26197
26198
26199
26200
26201
26202
26203
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26195

def update!(**args)
  @chunk_text = args[:chunk_text] if args.key?(:chunk_text)
  @domain = args[:domain] if args.key?(:domain)
  @index = args[:index] if args.key?(:index)
  @source = args[:source] if args.key?(:source)
  @source_metadata = args[:source_metadata] if args.key?(:source_metadata)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end