Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaFeedback

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Information about the user feedback. This information will be used for logging and metrics purpose.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaFeedback

Returns a new instance of GoogleCloudDiscoveryengineV1betaFeedback.



26117
26118
26119
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26117

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#commentString

Optional. The additional user comment of the feedback if user gives a thumb down. Corresponds to the JSON property comment

Returns:

  • (String)


26077
26078
26079
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26077

def comment
  @comment
end

#component_versionString

Optional. The version of the component that this report is being sent from. Corresponds to the JSON property componentVersion

Returns:

  • (String)


26082
26083
26084
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26082

def component_version
  @component_version
end

#conversation_infoGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaFeedbackConversationInfo

The conversation information such as the question index and session name. Corresponds to the JSON property conversationInfo



26087
26088
26089
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26087

def conversation_info
  @conversation_info
end

#data_terms_acceptedBoolean Also known as: data_terms_accepted?

Optional. Whether the customer accepted data use terms. Corresponds to the JSON property dataTermsAccepted

Returns:

  • (Boolean)


26092
26093
26094
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26092

def data_terms_accepted
  @data_terms_accepted
end

#feedback_sourceString

Optional. The UI component the user feedback comes from, which could be GOOGLE_CONSOLE, GOOGLE_WIDGET, GOOGLE_WEBAPP. Corresponds to the JSON property feedbackSource

Returns:

  • (String)


26099
26100
26101
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26099

def feedback_source
  @feedback_source
end

#feedback_typeString

Required. Indicate whether the user gives a positive or negative feedback. If the user gives a negative feedback, there might be more feedback details. Corresponds to the JSON property feedbackType

Returns:

  • (String)


26105
26106
26107
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26105

def feedback_type
  @feedback_type
end

#llm_model_versionString

The version of the LLM model that was used to generate the response. Corresponds to the JSON property llmModelVersion

Returns:

  • (String)


26110
26111
26112
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26110

def llm_model_version
  @llm_model_version
end

#reasonsArray<String>

Optional. The reason if user gives a thumb down. Corresponds to the JSON property reasons

Returns:

  • (Array<String>)


26115
26116
26117
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26115

def reasons
  @reasons
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26122
26123
26124
26125
26126
26127
26128
26129
26130
26131
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26122

def update!(**args)
  @comment = args[:comment] if args.key?(:comment)
  @component_version = args[:component_version] if args.key?(:component_version)
  @conversation_info = args[:conversation_info] if args.key?(:conversation_info)
  @data_terms_accepted = args[:data_terms_accepted] if args.key?(:data_terms_accepted)
  @feedback_source = args[:feedback_source] if args.key?(:feedback_source)
  @feedback_type = args[:feedback_type] if args.key?(:feedback_type)
  @llm_model_version = args[:llm_model_version] if args.key?(:llm_model_version)
  @reasons = args[:reasons] if args.key?(:reasons)
end