Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaHealthcareFhirConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Config to data store for HEALTHCARE_FHIR vertical.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaHealthcareFhirConfig

Returns a new instance of GoogleCloudDiscoveryengineV1betaHealthcareFhirConfig.



25763
25764
25765
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25763

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_configurable_schemaBoolean Also known as: enable_configurable_schema?

Whether to enable configurable schema for HEALTHCARE_FHIR vertical. If set to true, the predefined healthcare fhir schema can be extended for more customized searching and filtering. Corresponds to the JSON property enableConfigurableSchema

Returns:

  • (Boolean)


25742
25743
25744
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25742

def enable_configurable_schema
  @enable_configurable_schema
end

#enable_static_indexing_for_batch_ingestionBoolean Also known as: enable_static_indexing_for_batch_ingestion?

Whether to enable static indexing for HEALTHCARE_FHIR batch ingestion. If set to true, the batch ingestion will be processed in a static indexing mode which is slower but more capable of handling larger volume. Corresponds to the JSON property enableStaticIndexingForBatchIngestion

Returns:

  • (Boolean)


25750
25751
25752
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25750

def enable_static_indexing_for_batch_ingestion
  @enable_static_indexing_for_batch_ingestion
end

#initial_filter_groupsArray<String>

Optional. Names of the Group resources to use as a basis for the initial patient filter, in format projects/project_id/locations/location_id/ datasets/dataset_id/fhirStores/fhir_store_id/fhir/Group/group_id`. The filter group must be a FHIR resource name of type Group, and the filter will be constructed from the direct members of the group which are Patient resources. Corresponds to the JSON propertyinitialFilterGroups`

Returns:

  • (Array<String>)


25761
25762
25763
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25761

def initial_filter_groups
  @initial_filter_groups
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25768
25769
25770
25771
25772
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25768

def update!(**args)
  @enable_configurable_schema = args[:enable_configurable_schema] if args.key?(:enable_configurable_schema)
  @enable_static_indexing_for_batch_ingestion = args[:enable_static_indexing_for_batch_ingestion] if args.key?(:enable_static_indexing_for_batch_ingestion)
  @initial_filter_groups = args[:initial_filter_groups] if args.key?(:initial_filter_groups)
end