Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaIdentityMappingEntry

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Identity Mapping Entry that maps an external identity to an internal identity.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaIdentityMappingEntry

Returns a new instance of GoogleCloudDiscoveryengineV1betaIdentityMappingEntry.



26505
26506
26507
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26505

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#external_identityString

Required. Identity outside the customer identity provider. The length limit of external identity will be of 100 characters. Corresponds to the JSON property externalIdentity

Returns:

  • (String)


26484
26485
26486
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26484

def external_identity
  @external_identity
end

#external_identity_nameString

Optional. The name of the external identity. Corresponds to the JSON property externalIdentityName

Returns:

  • (String)


26489
26490
26491
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26489

def external_identity_name
  @external_identity_name
end

#group_idString

Group identifier. For Google Workspace user account, group_id should be the google workspace group email. For non-google identity provider, group_id is the mapped group identifier configured during the workforcepool config. Corresponds to the JSON property groupId

Returns:

  • (String)


26496
26497
26498
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26496

def group_id
  @group_id
end

#user_idString

User identifier. For Google Workspace user account, user_id should be the google workspace user email. For non-google identity provider, user_id is the mapped user identifier configured during the workforcepool config. Corresponds to the JSON property userId

Returns:

  • (String)


26503
26504
26505
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26503

def user_id
  @user_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26510
26511
26512
26513
26514
26515
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26510

def update!(**args)
  @external_identity = args[:external_identity] if args.key?(:external_identity)
  @external_identity_name = args[:external_identity_name] if args.key?(:external_identity_name)
  @group_id = args[:group_id] if args.key?(:group_id)
  @user_id = args[:user_id] if args.key?(:user_id)
end