Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaImportDocumentsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Response of the ImportDocumentsRequest. If the long running operation is done, then this message is returned by the google.longrunning.Operations.response field if the operation was successful.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaImportDocumentsResponse

Returns a new instance of GoogleCloudDiscoveryengineV1betaImportDocumentsResponse.



27080
27081
27082
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27080

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaImportErrorConfig

Configuration of destination for Import related errors. Corresponds to the JSON property errorConfig



27073
27074
27075
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27073

def error_config
  @error_config
end

#error_samplesArray<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>

A sample of errors encountered while processing the request. Corresponds to the JSON property errorSamples



27078
27079
27080
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27078

def error_samples
  @error_samples
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27085
27086
27087
27088
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27085

def update!(**args)
  @error_config = args[:error_config] if args.key?(:error_config)
  @error_samples = args[:error_samples] if args.key?(:error_samples)
end