Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaImportUserEventsMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Metadata related to the progress of the Import operation. This is returned by the google.longrunning.Operation.metadata field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaImportUserEventsMetadata

Returns a new instance of GoogleCloudDiscoveryengineV1betaImportUserEventsMetadata.



27427
27428
27429
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27427

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Operation create time. Corresponds to the JSON property createTime

Returns:

  • (String)


27409
27410
27411
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27409

def create_time
  @create_time
end

#failure_countFixnum

Count of entries that encountered errors while processing. Corresponds to the JSON property failureCount

Returns:

  • (Fixnum)


27414
27415
27416
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27414

def failure_count
  @failure_count
end

#success_countFixnum

Count of entries that were processed successfully. Corresponds to the JSON property successCount

Returns:

  • (Fixnum)


27419
27420
27421
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27419

def success_count
  @success_count
end

#update_timeString

Output only. Operation last update time. If the operation is done, this is also the finish time. Corresponds to the JSON property updateTime

Returns:

  • (String)


27425
27426
27427
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27425

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27432
27433
27434
27435
27436
27437
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27432

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @failure_count = args[:failure_count] if args.key?(:failure_count)
  @success_count = args[:success_count] if args.key?(:success_count)
  @update_time = args[:update_time] if args.key?(:update_time)
end