Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaListControlsResponse
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaListControlsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Response for ListControls method.
Instance Attribute Summary collapse
-
#controls ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaControl>
All the Controls for a given data store.
-
#next_page_token ⇒ String
Pagination token, if not returned indicates the last page.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaListControlsResponse
constructor
A new instance of GoogleCloudDiscoveryengineV1betaListControlsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaListControlsResponse
Returns a new instance of GoogleCloudDiscoveryengineV1betaListControlsResponse.
27644 27645 27646 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27644 def initialize(**args) update!(**args) end |
Instance Attribute Details
#controls ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaControl>
All the Controls for a given data store.
Corresponds to the JSON property controls
27637 27638 27639 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27637 def controls @controls end |
#next_page_token ⇒ String
Pagination token, if not returned indicates the last page.
Corresponds to the JSON property nextPageToken
27642 27643 27644 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27642 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27649 27650 27651 27652 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27649 def update!(**args) @controls = args[:controls] if args.key?(:controls) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |