Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaListConversationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaListConversationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Response for ListConversations method.
Instance Attribute Summary collapse
-
#conversations ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaConversation>
All the Conversations for a given data store.
-
#next_page_token ⇒ String
Pagination token, if not returned indicates the last page.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaListConversationsResponse
constructor
A new instance of GoogleCloudDiscoveryengineV1betaListConversationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaListConversationsResponse
Returns a new instance of GoogleCloudDiscoveryengineV1betaListConversationsResponse.
26811 26812 26813 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26811 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversations ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaConversation>
All the Conversations for a given data store.
Corresponds to the JSON property conversations
26804 26805 26806 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26804 def conversations @conversations end |
#next_page_token ⇒ String
Pagination token, if not returned indicates the last page.
Corresponds to the JSON property nextPageToken
26809 26810 26811 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26809 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26816 26817 26818 26819 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26816 def update!(**args) @conversations = args[:conversations] if args.key?(:conversations) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |