Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaPageInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Detailed page information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaPageInfo

Returns a new instance of GoogleCloudDiscoveryengineV1betaPageInfo.



28536
28537
28538
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28536

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#page_categoryString

The most specific category associated with a category page. To represent full path of category, use '>' sign to separate different hierarchies. If '>' is part of the category name, replace it with other character(s). Category pages include special pages such as sales or promotions. For instance, a special sale page may have the category hierarchy: "pageCategory" : "Sales > 2017 Black Friday Deals". Required for view-category-page events. Other event types should not set this field. Otherwise, an INVALID_ARGUMENT error is returned. Corresponds to the JSON property pageCategory

Returns:

  • (String)


28508
28509
28510
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28508

def page_category
  @page_category
end

#pageview_idString

A unique ID of a web page view. This should be kept the same for all user events triggered from the same pageview. For example, an item detail page view could trigger multiple events as the user is browsing the page. The pageview_id property should be kept the same for all these events so that they can be grouped together properly. When using the client side event reporting with JavaScript pixel and Google Tag Manager, this value is filled in automatically. Corresponds to the JSON property pageviewId

Returns:

  • (String)


28519
28520
28521
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28519

def pageview_id
  @pageview_id
end

#referrer_uriString

The referrer URL of the current page. When using the client side event reporting with JavaScript pixel and Google Tag Manager, this value is filled in automatically. However, some browser privacy restrictions may cause this field to be empty. Corresponds to the JSON property referrerUri

Returns:

  • (String)


28527
28528
28529
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28527

def referrer_uri
  @referrer_uri
end

#uriString

Complete URL (window.location.href) of the user's current page. When using the client side event reporting with JavaScript pixel and Google Tag Manager, this value is filled in automatically. Maximum length 5,000 characters. Corresponds to the JSON property uri

Returns:

  • (String)


28534
28535
28536
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28534

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28541
28542
28543
28544
28545
28546
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28541

def update!(**args)
  @page_category = args[:page_category] if args.key?(:page_category)
  @pageview_id = args[:pageview_id] if args.key?(:pageview_id)
  @referrer_uri = args[:referrer_uri] if args.key?(:referrer_uri)
  @uri = args[:uri] if args.key?(:uri)
end