Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaPanelInfo
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaPanelInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Detailed panel information associated with a user event.
Instance Attribute Summary collapse
-
#display_name ⇒ String
The display name of the panel.
-
#documents ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocumentInfo>
Optional.
-
#panel_id ⇒ String
Required.
-
#panel_position ⇒ Fixnum
The ordered position of the panel, if shown to the user with other panels.
-
#total_panels ⇒ Fixnum
The total number of panels, including this one, shown to the user.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaPanelInfo
constructor
A new instance of GoogleCloudDiscoveryengineV1betaPanelInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaPanelInfo
Returns a new instance of GoogleCloudDiscoveryengineV1betaPanelInfo.
28466 28467 28468 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28466 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
The display name of the panel.
Corresponds to the JSON property displayName
28442 28443 28444 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28442 def display_name @display_name end |
#documents ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocumentInfo>
Optional. The document IDs associated with this panel.
Corresponds to the JSON property documents
28447 28448 28449 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28447 def documents @documents end |
#panel_id ⇒ String
Required. The panel ID.
Corresponds to the JSON property panelId
28452 28453 28454 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28452 def panel_id @panel_id end |
#panel_position ⇒ Fixnum
The ordered position of the panel, if shown to the user with other panels. If
set, then total_panels must also be set.
Corresponds to the JSON property panelPosition
28458 28459 28460 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28458 def panel_position @panel_position end |
#total_panels ⇒ Fixnum
The total number of panels, including this one, shown to the user. Must be set
if panel_position is set.
Corresponds to the JSON property totalPanels
28464 28465 28466 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28464 def total_panels @total_panels end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28471 28472 28473 28474 28475 28476 28477 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28471 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @documents = args[:documents] if args.key?(:documents) @panel_id = args[:panel_id] if args.key?(:panel_id) @panel_position = args[:panel_position] if args.key?(:panel_position) @total_panels = args[:total_panels] if args.key?(:total_panels) end |