Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaPrincipal
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaPrincipal
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Principal identifier of a user or a group.
Instance Attribute Summary collapse
-
#external_entity_id ⇒ String
For 3P application identities which are not present in the customer identity provider.
-
#group_id ⇒ String
Group identifier.
-
#user_id ⇒ String
User identifier.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaPrincipal
constructor
A new instance of GoogleCloudDiscoveryengineV1betaPrincipal.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaPrincipal
Returns a new instance of GoogleCloudDiscoveryengineV1betaPrincipal.
28495 28496 28497 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28495 def initialize(**args) update!(**args) end |
Instance Attribute Details
#external_entity_id ⇒ String
For 3P application identities which are not present in the customer identity
provider.
Corresponds to the JSON property externalEntityId
28477 28478 28479 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28477 def external_entity_id @external_entity_id end |
#group_id ⇒ String
Group identifier. For Google Workspace user account, group_id should be the
google workspace group email. For non-google identity provider user account,
group_id is the mapped group identifier configured during the workforcepool
config.
Corresponds to the JSON property groupId
28485 28486 28487 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28485 def group_id @group_id end |
#user_id ⇒ String
User identifier. For Google Workspace user account, user_id should be the
google workspace user email. For non-google identity provider user account,
user_id is the mapped user identifier configured during the workforcepool
config.
Corresponds to the JSON property userId
28493 28494 28495 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28493 def user_id @user_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28500 28501 28502 28503 28504 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28500 def update!(**args) @external_entity_id = args[:external_entity_id] if args.key?(:external_entity_id) @group_id = args[:group_id] if args.key?(:group_id) @user_id = args[:user_id] if args.key?(:user_id) end |