Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaProjectCustomerProvidedConfigNotebooklmConfig
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaProjectCustomerProvidedConfigNotebooklmConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Configuration for NotebookLM.
Instance Attribute Summary collapse
-
#data_protection_policy ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaProjectCustomerProvidedConfigNotebooklmConfigDataProtectionPolicy
Data protection policy config for NotebookLM.
-
#model_armor_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaProjectCustomerProvidedConfigNotebooklmConfigModelArmorConfig
Configuration for customer defined Model Armor templates to be used for sanitizing user prompts and LLM responses.
-
#observability_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaObservabilityConfig
Observability config for a resource.
-
#opt_out_notebook_sharing ⇒ Boolean
(also: #opt_out_notebook_sharing?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaProjectCustomerProvidedConfigNotebooklmConfig
constructor
A new instance of GoogleCloudDiscoveryengineV1betaProjectCustomerProvidedConfigNotebooklmConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaProjectCustomerProvidedConfigNotebooklmConfig
Returns a new instance of GoogleCloudDiscoveryengineV1betaProjectCustomerProvidedConfigNotebooklmConfig.
28093 28094 28095 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28093 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_protection_policy ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaProjectCustomerProvidedConfigNotebooklmConfigDataProtectionPolicy
Data protection policy config for NotebookLM.
Corresponds to the JSON property dataProtectionPolicy
28073 28074 28075 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28073 def data_protection_policy @data_protection_policy end |
#model_armor_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaProjectCustomerProvidedConfigNotebooklmConfigModelArmorConfig
Configuration for customer defined Model Armor templates to be used for
sanitizing user prompts and LLM responses.
Corresponds to the JSON property modelArmorConfig
28079 28080 28081 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28079 def model_armor_config @model_armor_config end |
#observability_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaObservabilityConfig
Observability config for a resource.
Corresponds to the JSON property observabilityConfig
28084 28085 28086 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28084 def observability_config @observability_config end |
#opt_out_notebook_sharing ⇒ Boolean Also known as: opt_out_notebook_sharing?
Optional. Whether to disable the notebook sharing feature for the project.
Default to false if not specified.
Corresponds to the JSON property optOutNotebookSharing
28090 28091 28092 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28090 def opt_out_notebook_sharing @opt_out_notebook_sharing end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28098 28099 28100 28101 28102 28103 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28098 def update!(**args) @data_protection_policy = args[:data_protection_policy] if args.key?(:data_protection_policy) @model_armor_config = args[:model_armor_config] if args.key?(:model_armor_config) @observability_config = args[:observability_config] if args.key?(:observability_config) @opt_out_notebook_sharing = args[:opt_out_notebook_sharing] if args.key?(:opt_out_notebook_sharing) end |