Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaProjectCustomerProvidedConfigNotebooklmConfigModelArmorConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Configuration for customer defined Model Armor templates to be used for sanitizing user prompts and LLM responses.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaProjectCustomerProvidedConfigNotebooklmConfigModelArmorConfig

Returns a new instance of GoogleCloudDiscoveryengineV1betaProjectCustomerProvidedConfigNotebooklmConfigModelArmorConfig.



28977
28978
28979
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28977

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#response_templateString

Optional. The resource name of the Model Armor Template for sanitizing LLM responses. Format: projects/project/locations/location/templates/ template_id If not specified, no sanitization will be applied to the LLM response. Corresponds to the JSON property responseTemplate

Returns:

  • (String)


28967
28968
28969
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28967

def response_template
  @response_template
end

#user_prompt_templateString

Optional. The resource name of the Model Armor Template for sanitizing user prompts. Format: projects/project/locations/location/templates/ template_id If not specified, no sanitization will be applied to the user prompt. Corresponds to the JSON property userPromptTemplate

Returns:

  • (String)


28975
28976
28977
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28975

def user_prompt_template
  @user_prompt_template
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28982
28983
28984
28985
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28982

def update!(**args)
  @response_template = args[:response_template] if args.key?(:response_template)
  @user_prompt_template = args[:user_prompt_template] if args.key?(:user_prompt_template)
end