Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaProjectServiceTerms

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Metadata about the terms of service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaProjectServiceTerms

Returns a new instance of GoogleCloudDiscoveryengineV1betaProjectServiceTerms.



28859
28860
28861
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28859

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accept_timeString

The last time when the project agreed to the terms of service. Corresponds to the JSON property acceptTime

Returns:

  • (String)


28831
28832
28833
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28831

def accept_time
  @accept_time
end

#decline_timeString

The last time when the project declined or revoked the agreement to terms of service. Corresponds to the JSON property declineTime

Returns:

  • (String)


28837
28838
28839
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28837

def decline_time
  @decline_time
end

#idString

The unique identifier of this terms of service. Available terms: * GA_DATA_USE_TERMS: Terms for data use. When using this as id, the acceptable version to provide is 2022-11-23. Corresponds to the JSON property id

Returns:

  • (String)


28845
28846
28847
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28845

def id
  @id
end

#stateString

Whether the project has accepted/rejected the service terms or it is still pending. Corresponds to the JSON property state

Returns:

  • (String)


28851
28852
28853
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28851

def state
  @state
end

#versionString

The version string of the terms of service. For acceptable values, see the comments for id above. Corresponds to the JSON property version

Returns:

  • (String)


28857
28858
28859
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28857

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28864
28865
28866
28867
28868
28869
28870
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28864

def update!(**args)
  @accept_time = args[:accept_time] if args.key?(:accept_time)
  @decline_time = args[:decline_time] if args.key?(:decline_time)
  @id = args[:id] if args.key?(:id)
  @state = args[:state] if args.key?(:state)
  @version = args[:version] if args.key?(:version)
end