Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaProvisionProjectRequestSaasParams

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Parameters for Agentspace.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaProvisionProjectRequestSaasParams

Returns a new instance of GoogleCloudDiscoveryengineV1betaProvisionProjectRequestSaasParams.



28294
28295
28296
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28294

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accept_biz_qosBoolean Also known as: accept_biz_qos?

Optional. Set to true to specify that caller has read and would like to give consent to the [Terms for Agent Space quality of service]. Corresponds to the JSON property acceptBizQos

Returns:

  • (Boolean)


28284
28285
28286
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28284

def accept_biz_qos
  @accept_biz_qos
end

#is_bizBoolean Also known as: is_biz?

Optional. Indicates if the current request is for Biz edition (= true) or not ( = false). Corresponds to the JSON property isBiz

Returns:

  • (Boolean)


28291
28292
28293
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28291

def is_biz
  @is_biz
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28299
28300
28301
28302
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28299

def update!(**args)
  @accept_biz_qos = args[:accept_biz_qos] if args.key?(:accept_biz_qos)
  @is_biz = args[:is_biz] if args.key?(:is_biz)
end