Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaPurgeDocumentsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Request message for DocumentService.PurgeDocuments method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaPurgeDocumentsRequest

Returns a new instance of GoogleCloudDiscoveryengineV1betaPurgeDocumentsRequest.



29107
29108
29109
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29107

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaPurgeErrorConfig

Configuration of destination for Purge related errors. Corresponds to the JSON property errorConfig



29081
29082
29083
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29081

def error_config
  @error_config
end

#filterString

Required. Filter matching documents to purge. Only currently supported value is * (all items). Corresponds to the JSON property filter

Returns:

  • (String)


29087
29088
29089
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29087

def filter
  @filter
end

#forceBoolean Also known as: force?

Actually performs the purge. If force is set to false, return the expected purge count without deleting any documents. Corresponds to the JSON property force

Returns:

  • (Boolean)


29093
29094
29095
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29093

def force
  @force
end

#gcs_sourceGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaGcsSource

Cloud Storage location for input content. Corresponds to the JSON property gcsSource



29099
29100
29101
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29099

def gcs_source
  @gcs_source
end

#inline_sourceGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaPurgeDocumentsRequestInlineSource

The inline source for the input config for DocumentService.PurgeDocuments method. Corresponds to the JSON property inlineSource



29105
29106
29107
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29105

def inline_source
  @inline_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29112
29113
29114
29115
29116
29117
29118
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29112

def update!(**args)
  @error_config = args[:error_config] if args.key?(:error_config)
  @filter = args[:filter] if args.key?(:filter)
  @force = args[:force] if args.key?(:force)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @inline_source = args[:inline_source] if args.key?(:inline_source)
end