Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaPurgeDocumentsRequestInlineSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

The inline source for the input config for DocumentService.PurgeDocuments method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaPurgeDocumentsRequestInlineSource

Returns a new instance of GoogleCloudDiscoveryengineV1betaPurgeDocumentsRequestInlineSource.



28422
28423
28424
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28422

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#documentsArray<String>

Required. A list of full resource name of documents to purge. In the format projects/*/locations/*/collections/*/dataStores/*/branches/*/documents/*. Recommended max of 100 items. Corresponds to the JSON property documents

Returns:

  • (Array<String>)


28420
28421
28422
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28420

def documents
  @documents
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28427
28428
28429
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28427

def update!(**args)
  @documents = args[:documents] if args.key?(:documents)
end