Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaPurgeErrorConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Configuration of destination for Purge related errors.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaPurgeErrorConfig

Returns a new instance of GoogleCloudDiscoveryengineV1betaPurgeErrorConfig.



28472
28473
28474
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28472

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gcs_prefixString

Cloud Storage prefix for purge errors. This must be an empty, existing Cloud Storage directory. Purge errors are written to sharded files in this directory, one per line, as a JSON-encoded google.rpc.Status message. Corresponds to the JSON property gcsPrefix

Returns:

  • (String)


28470
28471
28472
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28470

def gcs_prefix
  @gcs_prefix
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28477
28478
28479
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28477

def update!(**args)
  @gcs_prefix = args[:gcs_prefix] if args.key?(:gcs_prefix)
end