Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaPurgeIdentityMappingsRequestInlineSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

The inline source to purge identity mapping entries from.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaPurgeIdentityMappingsRequestInlineSource

Returns a new instance of GoogleCloudDiscoveryengineV1betaPurgeIdentityMappingsRequestInlineSource.



29179
29180
29181
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29179

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#identity_mapping_entriesArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaIdentityMappingEntry>

A maximum of 10000 entries can be purged at one time Corresponds to the JSON property identityMappingEntries



29177
29178
29179
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29177

def identity_mapping_entries
  @identity_mapping_entries
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29184
29185
29186
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29184

def update!(**args)
  @identity_mapping_entries = args[:identity_mapping_entries] if args.key?(:identity_mapping_entries)
end