Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaRankingRecord

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Record message for RankService.Rank method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaRankingRecord

Returns a new instance of GoogleCloudDiscoveryengineV1betaRankingRecord.



29690
29691
29692
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29690

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentString

The content of the record. Empty by default. At least one of title or content should be set otherwise an INVALID_ARGUMENT error is thrown. Corresponds to the JSON property content

Returns:

  • (String)


29670
29671
29672
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29670

def content
  @content
end

#idString

The unique ID to represent the record. Corresponds to the JSON property id

Returns:

  • (String)


29675
29676
29677
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29675

def id
  @id
end

#scoreFloat

The score of this record based on the given query and selected model. The score will be rounded to 4 decimal places. If the score is close to 0, it will be rounded to 0.00001 to avoid returning unset. Corresponds to the JSON property score

Returns:

  • (Float)


29682
29683
29684
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29682

def score
  @score
end

#titleString

The title of the record. Empty by default. At least one of title or content should be set otherwise an INVALID_ARGUMENT error is thrown. Corresponds to the JSON property title

Returns:

  • (String)


29688
29689
29690
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29688

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29695
29696
29697
29698
29699
29700
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29695

def update!(**args)
  @content = args[:content] if args.key?(:content)
  @id = args[:id] if args.key?(:id)
  @score = args[:score] if args.key?(:score)
  @title = args[:title] if args.key?(:title)
end