Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaRecommendRequest
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaRecommendRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Request message for Recommend method.
Instance Attribute Summary collapse
-
#filter ⇒ String
Filter for restricting recommendation results with a length limit of 5,000 characters.
-
#page_size ⇒ Fixnum
Maximum number of results to return.
-
#params ⇒ Hash<String,Object>
Additional domain specific parameters for the recommendations.
-
#user_event ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaUserEvent
UserEvent captures all metadata information Discovery Engine API needs to know about how end users interact with your website.
-
#user_labels ⇒ Hash<String,String>
The user labels applied to a resource must meet the following requirements: * Each resource can have multiple labels, up to a maximum of 64.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
Use validate only mode for this recommendation query.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaRecommendRequest
constructor
A new instance of GoogleCloudDiscoveryengineV1betaRecommendRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaRecommendRequest
Returns a new instance of GoogleCloudDiscoveryengineV1betaRecommendRequest.
28651 28652 28653 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28651 def initialize(**args) update!(**args) end |
Instance Attribute Details
#filter ⇒ String
Filter for restricting recommendation results with a length limit of 5,000
characters. Currently, only filter expressions on the filter_tags attribute
is supported. Examples: * (filter_tags: ANY("Red", "Blue") OR filter_tags:
ANY("Hot", "Cold")) * (filter_tags: ANY("Red", "Blue")) AND NOT (filter_tags:
ANY("Green")) If attributeFilteringSyntax is set to true under the params
field, then attribute-based expressions are expected instead of the above
described tag-based syntax. Examples: * (language: ANY("en", "es")) AND NOT (
categories: ANY("Movie")) * (available: true) AND (language: ANY("en", "es"))
OR (categories: ANY("Movie")) If your filter blocks all results, the API
returns generic (unfiltered) popular Documents. If you only want results
strictly matching the filters, set strictFiltering to true in
RecommendRequest.params to receive empty results instead. Note that the API
never returns Documents with storageStatus as EXPIRED or DELETED
regardless of filter choices.
Corresponds to the JSON property filter
28594 28595 28596 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28594 def filter @filter end |
#page_size ⇒ Fixnum
Maximum number of results to return. Set this property to the number of
recommendation results needed. If zero, the service chooses a reasonable
default. The maximum allowed value is 100. Values above 100 are set to 100.
Corresponds to the JSON property pageSize
28601 28602 28603 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28601 def page_size @page_size end |
#params ⇒ Hash<String,Object>
Additional domain specific parameters for the recommendations. Allowed values:
returnDocument: Boolean. If set totrue, the associated Document object is returned in RecommendResponse.RecommendationResult.document. *returnScore: Boolean. If set to true, the recommendation score corresponding to each returned Document is set in RecommendResponse.RecommendationResult.metadata. The given score indicates the probability of a Document conversion given the user's context and history. *strictFiltering: Boolean. True by default. If set tofalse, the service returns generic (unfiltered) popular Documents instead of empty if your filter blocks all recommendation results. *diversityLevel: String. Default empty. If set to be non-empty, then it needs to be one of: *no-diversity*low-diversity*medium-diversity*high- diversity*auto-diversityThis gives request-level control and adjusts recommendation results based on Document category. *attributeFilteringSyntax: Boolean. False by default. If set to true, thefilterfield is interpreted according to the new, attribute-based syntax. Corresponds to the JSON propertyparams
28620 28621 28622 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28620 def params @params end |
#user_event ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaUserEvent
UserEvent captures all metadata information Discovery Engine API needs to know
about how end users interact with your website.
Corresponds to the JSON property userEvent
28626 28627 28628 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28626 def user_event @user_event end |
#user_labels ⇒ Hash<String,String>
The user labels applied to a resource must meet the following requirements: *
Each resource can have multiple labels, up to a maximum of 64. * Each label
must be a key-value pair. * Keys have a minimum length of 1 character and a
maximum length of 63 characters and cannot be empty. Values can be empty and
have a maximum length of 63 characters. * Keys and values can contain only
lowercase letters, numeric characters, underscores, and dashes. All characters
must use UTF-8 encoding, and international characters are allowed. * The key
portion of a label must be unique. However, you can use the same key with
multiple resources. * Keys must start with a lowercase letter or international
character. See Requirements for labels for more details.
Corresponds to the JSON property userLabels
28641 28642 28643 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28641 def user_labels @user_labels end |
#validate_only ⇒ Boolean Also known as: validate_only?
Use validate only mode for this recommendation query. If set to true, a fake
model is used that returns arbitrary Document IDs. Note that the validate only
mode should only be used for testing the API, or if the model is not ready.
Corresponds to the JSON property validateOnly
28648 28649 28650 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28648 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28656 28657 28658 28659 28660 28661 28662 28663 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28656 def update!(**args) @filter = args[:filter] if args.key?(:filter) @page_size = args[:page_size] if args.key?(:page_size) @params = args[:params] if args.key?(:params) @user_event = args[:user_event] if args.key?(:user_event) @user_labels = args[:user_labels] if args.key?(:user_labels) @validate_only = args[:validate_only] if args.key?(:validate_only) end |