Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaRecommendResponse
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaRecommendResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Response message for Recommend method.
Instance Attribute Summary collapse
-
#attribution_token ⇒ String
A unique attribution token.
-
#missing_ids ⇒ Array<String>
IDs of documents in the request that were missing from the default Branch associated with the requested ServingConfig.
-
#results ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaRecommendResponseRecommendationResult>
A list of recommended Documents.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
True if RecommendRequest.validate_only was set.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaRecommendResponse
constructor
A new instance of GoogleCloudDiscoveryengineV1betaRecommendResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaRecommendResponse
Returns a new instance of GoogleCloudDiscoveryengineV1betaRecommendResponse.
29826 29827 29828 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29826 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attribution_token ⇒ String
A unique attribution token. This should be included in the UserEvent logs
resulting from this recommendation, which enables accurate attribution of
recommendation model performance.
Corresponds to the JSON property attributionToken
29806 29807 29808 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29806 def attribution_token @attribution_token end |
#missing_ids ⇒ Array<String>
IDs of documents in the request that were missing from the default Branch
associated with the requested ServingConfig.
Corresponds to the JSON property missingIds
29812 29813 29814 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29812 def missing_ids @missing_ids end |
#results ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaRecommendResponseRecommendationResult>
A list of recommended Documents. The order represents the ranking (from the
most relevant Document to the least).
Corresponds to the JSON property results
29818 29819 29820 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29818 def results @results end |
#validate_only ⇒ Boolean Also known as: validate_only?
True if RecommendRequest.validate_only was set.
Corresponds to the JSON property validateOnly
29823 29824 29825 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29823 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29831 29832 29833 29834 29835 29836 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29831 def update!(**args) @attribution_token = args[:attribution_token] if args.key?(:attribution_token) @missing_ids = args[:missing_ids] if args.key?(:missing_ids) @results = args[:results] if args.key?(:results) @validate_only = args[:validate_only] if args.key?(:validate_only) end |