Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaRecommendResponseRecommendationResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

RecommendationResult represents a generic recommendation result with associated metadata.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaRecommendResponseRecommendationResult

Returns a new instance of GoogleCloudDiscoveryengineV1betaRecommendResponseRecommendationResult.



29037
29038
29039
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29037

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#documentGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocument

Document captures all raw metadata information of items to be recommended or searched. Corresponds to the JSON property document



29023
29024
29025
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29023

def document
  @document
end

#idString

Resource ID of the recommended Document. Corresponds to the JSON property id

Returns:

  • (String)


29028
29029
29030
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29028

def id
  @id
end

#metadataHash<String,Object>

Additional Document metadata or annotations. Possible values: * score: Recommendation score in double value. Is set if returnScore is set to true in RecommendRequest.params. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,Object>)


29035
29036
29037
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29035

def 
  @metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29042
29043
29044
29045
29046
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29042

def update!(**args)
  @document = args[:document] if args.key?(:document)
  @id = args[:id] if args.key?(:id)
  @metadata = args[:metadata] if args.key?(:metadata)
end