Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSampleQuery

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Sample Query captures metadata to be used for evaluation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSampleQuery

Returns a new instance of GoogleCloudDiscoveryengineV1betaSampleQuery.



30078
30079
30080
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30078

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp the SampleQuery was created at. Corresponds to the JSON property createTime

Returns:

  • (String)


30063
30064
30065
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30063

def create_time
  @create_time
end

#nameString

Identifier. The full resource name of the sample query, in the format of projects/project/locations/location/sampleQuerySets/sample_query_set/ sampleQueries/sample_query`. This field must be a UTF-8 encoded string with a length limit of 1024 characters. Corresponds to the JSON propertyname`

Returns:

  • (String)


30071
30072
30073
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30071

def name
  @name
end

#query_entryGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSampleQueryQueryEntry

Query Entry captures metadata to be used for search evaluation. Corresponds to the JSON property queryEntry



30076
30077
30078
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30076

def query_entry
  @query_entry
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30083
30084
30085
30086
30087
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30083

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @name = args[:name] if args.key?(:name)
  @query_entry = args[:query_entry] if args.key?(:query_entry)
end