Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSchema

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Defines the structure and layout of a type of document data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSchema

Returns a new instance of GoogleCloudDiscoveryengineV1betaSchema.



30212
30213
30214
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30212

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#json_schemaString

The JSON representation of the schema. Corresponds to the JSON property jsonSchema

Returns:

  • (String)


30197
30198
30199
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30197

def json_schema
  @json_schema
end

#nameString

Immutable. The full resource name of the schema, in the format of projects/ project/locations/location/collections/collection/dataStores/data_store/ schemas/schema`. This field must be a UTF-8 encoded string with a length limit of 1024 characters. Corresponds to the JSON propertyname`

Returns:

  • (String)


30205
30206
30207
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30205

def name
  @name
end

#struct_schemaHash<String,Object>

The structured representation of the schema. Corresponds to the JSON property structSchema

Returns:

  • (Hash<String,Object>)


30210
30211
30212
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30210

def struct_schema
  @struct_schema
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30217
30218
30219
30220
30221
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30217

def update!(**args)
  @json_schema = args[:json_schema] if args.key?(:json_schema)
  @name = args[:name] if args.key?(:name)
  @struct_schema = args[:struct_schema] if args.key?(:struct_schema)
end