Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchLinkPromotion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Promotion proto includes uri and other helping information to display the promotion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchLinkPromotion

Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchLinkPromotion.



30488
30489
30490
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30488

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Optional. The Promotion description. Maximum length: 200 characters. Corresponds to the JSON property description

Returns:

  • (String)


30456
30457
30458
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30456

def description
  @description
end

#documentString

Optional. The Document the user wants to promote. For site search, leave unset and only populate uri. Can be set along with uri. Corresponds to the JSON property document

Returns:

  • (String)


30462
30463
30464
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30462

def document
  @document
end

#enabledBoolean Also known as: enabled?

Optional. The enabled promotion will be returned for any serving configs associated with the parent of the control this promotion is attached to. This flag is used for basic site search only. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


30469
30470
30471
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30469

def enabled
  @enabled
end

#image_uriString

Optional. The promotion thumbnail image url. Corresponds to the JSON property imageUri

Returns:

  • (String)


30475
30476
30477
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30475

def image_uri
  @image_uri
end

#titleString

Required. The title of the promotion. Maximum length: 160 characters. Corresponds to the JSON property title

Returns:

  • (String)


30480
30481
30482
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30480

def title
  @title
end

#uriString

Optional. The URL for the page the user wants to promote. Must be set for site search. For other verticals, this is optional. Corresponds to the JSON property uri

Returns:

  • (String)


30486
30487
30488
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30486

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30493
30494
30495
30496
30497
30498
30499
30500
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30493

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @document = args[:document] if args.key?(:document)
  @enabled = args[:enabled] if args.key?(:enabled)
  @image_uri = args[:image_uri] if args.key?(:image_uri)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end