Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpec
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
A specification for configuring the behavior of content search.
Instance Attribute Summary collapse
-
#chunk_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpecChunkSpec
Specifies the chunk spec to be returned from the search response.
-
#extractive_content_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpecExtractiveContentSpec
A specification for configuring the extractive content in a search response.
-
#search_result_mode ⇒ String
Specifies the search result mode.
-
#snippet_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpecSnippetSpec
A specification for configuring snippets in a search response.
-
#summary_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpecSummarySpec
A specification for configuring a summary returned in a search response.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpec
constructor
A new instance of GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpec
Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpec.
30299 30300 30301 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30299 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chunk_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpecChunkSpec
Specifies the chunk spec to be returned from the search response. Only
available if the SearchRequest.ContentSearchSpec.search_result_mode is set to
CHUNKS
Corresponds to the JSON property chunkSpec
30276 30277 30278 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30276 def chunk_spec @chunk_spec end |
#extractive_content_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpecExtractiveContentSpec
A specification for configuring the extractive content in a search response.
Corresponds to the JSON property extractiveContentSpec
30281 30282 30283 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30281 def extractive_content_spec @extractive_content_spec end |
#search_result_mode ⇒ String
Specifies the search result mode. If unspecified, the search result mode
defaults to DOCUMENTS.
Corresponds to the JSON property searchResultMode
30287 30288 30289 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30287 def search_result_mode @search_result_mode end |
#snippet_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpecSnippetSpec
A specification for configuring snippets in a search response.
Corresponds to the JSON property snippetSpec
30292 30293 30294 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30292 def snippet_spec @snippet_spec end |
#summary_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpecSummarySpec
A specification for configuring a summary returned in a search response.
Corresponds to the JSON property summarySpec
30297 30298 30299 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30297 def summary_spec @summary_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30304 30305 30306 30307 30308 30309 30310 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30304 def update!(**args) @chunk_spec = args[:chunk_spec] if args.key?(:chunk_spec) @extractive_content_spec = args[:extractive_content_spec] if args.key?(:extractive_content_spec) @search_result_mode = args[:search_result_mode] if args.key?(:search_result_mode) @snippet_spec = args[:snippet_spec] if args.key?(:snippet_spec) @summary_spec = args[:summary_spec] if args.key?(:summary_spec) end |