Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpecSummarySpecModelPromptSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Specification of the prompt to use with the model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpecSummarySpecModelPromptSpec

Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpecSummarySpecModelPromptSpec.



31265
31266
31267
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31265

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#preambleString

Text at the beginning of the prompt that instructs the assistant. Examples are available in the user guide. Corresponds to the JSON property preamble

Returns:

  • (String)


31263
31264
31265
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31263

def preamble
  @preamble
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31270
31271
31272
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31270

def update!(**args)
  @preamble = args[:preamble] if args.key?(:preamble)
end