Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestCrowdingSpec
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestCrowdingSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Specification for crowding. Crowding improves the diversity of search results by limiting the number of results that share the same field value. For example, crowding on the color field with a max_count of 3 and mode DROP_CROWDED_RESULTS will return at most 3 results with the same color across all pages.
Instance Attribute Summary collapse
-
#field ⇒ String
The field to use for crowding.
-
#max_count ⇒ Fixnum
The maximum number of documents to keep per value of the field.
-
#mode ⇒ String
Mode to use for documents that are crowded away.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchRequestCrowdingSpec
constructor
A new instance of GoogleCloudDiscoveryengineV1betaSearchRequestCrowdingSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchRequestCrowdingSpec
Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchRequestCrowdingSpec.
31486 31487 31488 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31486 def initialize(**args) update!(**args) end |
Instance Attribute Details
#field ⇒ String
The field to use for crowding. Documents can be crowded by a field in the
Document object. Crowding field is case sensitive.
Corresponds to the JSON property field
31471 31472 31473 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31471 def field @field end |
#max_count ⇒ Fixnum
The maximum number of documents to keep per value of the field. Once there are
at least max_count previous results which contain the same value for the given
field (according to the order specified in order_by), later results with the
same value are "crowded away". If not specified, the default value is 1.
Corresponds to the JSON property maxCount
31479 31480 31481 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31479 def max_count @max_count end |
#mode ⇒ String
Mode to use for documents that are crowded away.
Corresponds to the JSON property mode
31484 31485 31486 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31484 def mode @mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31491 31492 31493 31494 31495 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31491 def update!(**args) @field = args[:field] if args.key?(:field) @max_count = args[:max_count] if args.key?(:max_count) @mode = args[:mode] if args.key?(:mode) end |