Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseGeoSearchDebugInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Debug information specifically related to forward geocoding issues arising from Geolocation Search.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchResponseGeoSearchDebugInfo

Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchResponseGeoSearchDebugInfo.



32136
32137
32138
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32136

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_messageString

The error produced. Corresponds to the JSON property errorMessage

Returns:

  • (String)


32129
32130
32131
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32129

def error_message
  @error_message
end

#original_address_queryString

The address from which forward geocoding ingestion produced issues. Corresponds to the JSON property originalAddressQuery

Returns:

  • (String)


32134
32135
32136
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32134

def original_address_query
  @original_address_query
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32141
32142
32143
32144
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32141

def update!(**args)
  @error_message = args[:error_message] if args.key?(:error_message)
  @original_address_query = args[:original_address_query] if args.key?(:original_address_query)
end