Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Information describing what natural language understanding was done on the input query.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfo

Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfo.



32289
32290
32291
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32289

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#classified_intentsArray<String>

The classified intents from the input query. Corresponds to the JSON property classifiedIntents

Returns:

  • (Array<String>)


32271
32272
32273
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32271

def classified_intents
  @classified_intents
end

#extracted_filtersString

The filters that were extracted from the input query. Corresponds to the JSON property extractedFilters

Returns:

  • (String)


32276
32277
32278
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32276

def extracted_filters
  @extracted_filters
end

#rewritten_queryString

Rewritten input query minus the extracted filters. Corresponds to the JSON property rewrittenQuery

Returns:

  • (String)


32281
32282
32283
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32281

def rewritten_query
  @rewritten_query
end

#structured_extracted_filterGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilter

The filters that were extracted from the input query represented in a structured form. Corresponds to the JSON property structuredExtractedFilter



32287
32288
32289
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32287

def structured_extracted_filter
  @structured_extracted_filter
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32294
32295
32296
32297
32298
32299
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32294

def update!(**args)
  @classified_intents = args[:classified_intents] if args.key?(:classified_intents)
  @extracted_filters = args[:extracted_filters] if args.key?(:extracted_filters)
  @rewritten_query = args[:rewritten_query] if args.key?(:rewritten_query)
  @structured_extracted_filter = args[:structured_extracted_filter] if args.key?(:structured_extracted_filter)
end