Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterNumberConstraint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Constraint expression of a number field. Example: price < 100.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterNumberConstraint

Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterNumberConstraint.



32556
32557
32558
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32556

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#comparisonString

The comparison operation performed between the field value and the value specified in the constraint. Corresponds to the JSON property comparison

Returns:

  • (String)


32539
32540
32541
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32539

def comparison
  @comparison
end

#field_nameString

Name of the numerical field as defined in the schema. Corresponds to the JSON property fieldName

Returns:

  • (String)


32544
32545
32546
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32544

def field_name
  @field_name
end

#query_segmentString

Identifies the keywords within the search query that match a filter. Corresponds to the JSON property querySegment

Returns:

  • (String)


32549
32550
32551
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32549

def query_segment
  @query_segment
end

#valueFloat

The value specified in the numerical constraint. Corresponds to the JSON property value

Returns:

  • (Float)


32554
32555
32556
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32554

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32561
32562
32563
32564
32565
32566
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32561

def update!(**args)
  @comparison = args[:comparison] if args.key?(:comparison)
  @field_name = args[:field_name] if args.key?(:field_name)
  @query_segment = args[:query_segment] if args.key?(:query_segment)
  @value = args[:value] if args.key?(:value)
end