Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSearchResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Represents the search results.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchResponseSearchResult

Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchResponseSearchResult.



32725
32726
32727
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32725

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chunkGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaChunk

Chunk captures all raw metadata information of items to be recommended or searched in the chunk mode. Corresponds to the JSON property chunk



32697
32698
32699
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32697

def chunk
  @chunk
end

#documentGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocument

Document captures all raw metadata information of items to be recommended or searched. Corresponds to the JSON property document



32703
32704
32705
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32703

def document
  @document
end

#idString

Document.id of the searched Document. Corresponds to the JSON property id

Returns:

  • (String)


32708
32709
32710
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32708

def id
  @id
end

#model_scoresHash<String,Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDoubleList>

Output only. Google provided available scores. Corresponds to the JSON property modelScores



32713
32714
32715
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32713

def model_scores
  @model_scores
end

#rank_signalsGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSearchResultRankSignals

A set of ranking signals. Corresponds to the JSON property rankSignals



32718
32719
32720
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32718

def rank_signals
  @rank_signals
end

#retrieval_signalsGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSearchResultRetrievalSignals

Contains a set of signals used by the relevance filter. Corresponds to the JSON property retrievalSignals



32723
32724
32725
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32723

def retrieval_signals
  @retrieval_signals
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32730
32731
32732
32733
32734
32735
32736
32737
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32730

def update!(**args)
  @chunk = args[:chunk] if args.key?(:chunk)
  @document = args[:document] if args.key?(:document)
  @id = args[:id] if args.key?(:id)
  @model_scores = args[:model_scores] if args.key?(:model_scores)
  @rank_signals = args[:rank_signals] if args.key?(:rank_signals)
  @retrieval_signals = args[:retrieval_signals] if args.key?(:retrieval_signals)
end