Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Summary of the top N search results specified by the summary spec.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchResponseSummary

Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchResponseSummary.



32063
32064
32065
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32063

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#safety_attributesGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSummarySafetyAttributes

Safety Attribute categories and their associated confidence scores. Corresponds to the JSON property safetyAttributes



32045
32046
32047
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32045

def safety_attributes
  @safety_attributes
end

#summary_skipped_reasonsArray<String>

Additional summary-skipped reasons. This provides the reason for ignored cases. If nothing is skipped, this field is not set. Corresponds to the JSON property summarySkippedReasons

Returns:

  • (Array<String>)


32051
32052
32053
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32051

def summary_skipped_reasons
  @summary_skipped_reasons
end

#summary_textString

The summary content. Corresponds to the JSON property summaryText

Returns:

  • (String)


32056
32057
32058
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32056

def summary_text
  @summary_text
end

#summary_with_metadataGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSummarySummaryWithMetadata

Summary with metadata information. Corresponds to the JSON property summaryWithMetadata



32061
32062
32063
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32061

def 
  @summary_with_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32068
32069
32070
32071
32072
32073
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32068

def update!(**args)
  @safety_attributes = args[:safety_attributes] if args.key?(:safety_attributes)
  @summary_skipped_reasons = args[:summary_skipped_reasons] if args.key?(:summary_skipped_reasons)
  @summary_text = args[:summary_text] if args.key?(:summary_text)
  @summary_with_metadata = args[:summary_with_metadata] if args.key?(:summary_with_metadata)
end