Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSummaryReference

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Document reference.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchResponseSummaryReference

Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchResponseSummaryReference.



33046
33047
33048
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33046

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chunk_contentsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSummaryReferenceChunkContent>

List of cited chunk contents derived from document content. Corresponds to the JSON property chunkContents



33027
33028
33029
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33027

def chunk_contents
  @chunk_contents
end

#documentString

Required. Document.name of the document. Full resource name of the referenced document, in the format projects/*/locations/*/collections/*/dataStores/*/ branches/*/documents/*. Corresponds to the JSON property document

Returns:

  • (String)


33034
33035
33036
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33034

def document
  @document
end

#titleString

Title of the document. Corresponds to the JSON property title

Returns:

  • (String)


33039
33040
33041
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33039

def title
  @title
end

#uriString

Cloud Storage or HTTP uri for the document. Corresponds to the JSON property uri

Returns:

  • (String)


33044
33045
33046
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33044

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33051
33052
33053
33054
33055
33056
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33051

def update!(**args)
  @chunk_contents = args[:chunk_contents] if args.key?(:chunk_contents)
  @document = args[:document] if args.key?(:document)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end