Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaServingConfigMediaConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Specifies the configurations needed for Media Discovery. Currently we support:

  • demote_content_watched: Threshold for watched content demotion. Customers can specify if using watched content demotion or use viewed detail page. Using the content watched demotion, customers need to specify the watched minutes or percentage exceeds the threshold, the content will be demoted in the recommendation result. * promote_fresh_content: cutoff days for fresh content promotion. Customers can specify if using content freshness promotion. If the content was published within the cutoff days, the content will be promoted in the recommendation result. Can only be set if SolutionType is SOLUTION_TYPE_RECOMMENDATION.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaServingConfigMediaConfig

Returns a new instance of GoogleCloudDiscoveryengineV1betaServingConfigMediaConfig.



33456
33457
33458
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33456

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#content_freshness_cutoff_daysFixnum

Specifies the content freshness used for recommendation result. Contents will be demoted if contents were published for more than content freshness cutoff days. Corresponds to the JSON property contentFreshnessCutoffDays

Returns:

  • (Fixnum)


33428
33429
33430
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33428

def content_freshness_cutoff_days
  @content_freshness_cutoff_days
end

#content_watched_percentage_thresholdFloat

Specifies the content watched percentage threshold for demotion. Threshold value must be between [0, 1.0] inclusive. Corresponds to the JSON property contentWatchedPercentageThreshold

Returns:

  • (Float)


33434
33435
33436
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33434

def content_watched_percentage_threshold
  @content_watched_percentage_threshold
end

#content_watched_seconds_thresholdFloat

Specifies the content watched minutes threshold for demotion. Corresponds to the JSON property contentWatchedSecondsThreshold

Returns:

  • (Float)


33439
33440
33441
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33439

def content_watched_seconds_threshold
  @content_watched_seconds_threshold
end

#demote_content_watched_past_daysFixnum

Optional. Specifies the number of days to look back for demoting watched content. If set to zero or unset, defaults to the maximum of 365 days. Corresponds to the JSON property demoteContentWatchedPastDays

Returns:

  • (Fixnum)


33445
33446
33447
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33445

def demote_content_watched_past_days
  @demote_content_watched_past_days
end

#demotion_event_typeString

Specifies the event type used for demoting recommendation result. Currently supported values: * view-item: Item viewed. * media-play: Start/resume watching a video, playing a song, etc. * media-complete: Finished or stopped midway through a video, song, etc. If unset, watch history demotion will not be applied. Content freshness demotion will still be applied. Corresponds to the JSON property demotionEventType

Returns:

  • (String)


33454
33455
33456
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33454

def demotion_event_type
  @demotion_event_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33461
33462
33463
33464
33465
33466
33467
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33461

def update!(**args)
  @content_freshness_cutoff_days = args[:content_freshness_cutoff_days] if args.key?(:content_freshness_cutoff_days)
  @content_watched_percentage_threshold = args[:content_watched_percentage_threshold] if args.key?(:content_watched_percentage_threshold)
  @content_watched_seconds_threshold = args[:content_watched_seconds_threshold] if args.key?(:content_watched_seconds_threshold)
  @demote_content_watched_past_days = args[:demote_content_watched_past_days] if args.key?(:demote_content_watched_past_days)
  @demotion_event_type = args[:demotion_event_type] if args.key?(:demotion_event_type)
end