Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSession

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

External session proto definition.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSession

Returns a new instance of GoogleCloudDiscoveryengineV1betaSession.



33532
33533
33534
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33532

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Optional. The display name of the session. This field is used to identify the session in the UI. By default, the display name is the first turn query text in the session. Corresponds to the JSON property displayName

Returns:

  • (String)


33479
33480
33481
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33479

def display_name
  @display_name
end

#end_timeString

Output only. The time the session finished. Corresponds to the JSON property endTime

Returns:

  • (String)


33484
33485
33486
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33484

def end_time
  @end_time
end

#is_pinnedBoolean Also known as: is_pinned?

Optional. Whether the session is pinned, pinned session will be displayed on the top of the session list. Corresponds to the JSON property isPinned

Returns:

  • (Boolean)


33490
33491
33492
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33490

def is_pinned
  @is_pinned
end

#labelsArray<String>

Optional. The labels for the session. Can be set as filter in ListSessionsRequest. Corresponds to the JSON property labels

Returns:

  • (Array<String>)


33497
33498
33499
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33497

def labels
  @labels
end

#nameString

Immutable. Fully qualified name projects/project/locations/global/ collections/collection/engines/engine/sessions/* Corresponds to the JSON property name

Returns:

  • (String)


33503
33504
33505
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33503

def name
  @name
end

#pending_async_assist_operation_idString

Output only. Full resource name of an in-progress AsyncAssist operation for this session, e.g. projects/*/locations/*/collections/*/engines/*/sessions/*/ operations/*. Set when the operation starts and cleared when it finishes. Corresponds to the JSON property pendingAsyncAssistOperationId

Returns:

  • (String)


33510
33511
33512
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33510

def pending_async_assist_operation_id
  @pending_async_assist_operation_id
end

#start_timeString

Output only. The time the session started. Corresponds to the JSON property startTime

Returns:

  • (String)


33515
33516
33517
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33515

def start_time
  @start_time
end

#stateString

The state of the session. Corresponds to the JSON property state

Returns:

  • (String)


33520
33521
33522
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33520

def state
  @state
end

#turnsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSessionTurn>

Turns. Corresponds to the JSON property turns



33525
33526
33527
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33525

def turns
  @turns
end

#user_pseudo_idString

A unique identifier for tracking users. Corresponds to the JSON property userPseudoId

Returns:

  • (String)


33530
33531
33532
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33530

def user_pseudo_id
  @user_pseudo_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33537
33538
33539
33540
33541
33542
33543
33544
33545
33546
33547
33548
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33537

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @end_time = args[:end_time] if args.key?(:end_time)
  @is_pinned = args[:is_pinned] if args.key?(:is_pinned)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @pending_async_assist_operation_id = args[:pending_async_assist_operation_id] if args.key?(:pending_async_assist_operation_id)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @turns = args[:turns] if args.key?(:turns)
  @user_pseudo_id = args[:user_pseudo_id] if args.key?(:user_pseudo_id)
end