Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaStreamAssistRequestGenerationSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Assistant generation specification for the request. This allows to override the default generation configuration at the engine level.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaStreamAssistRequestGenerationSpec

Returns a new instance of GoogleCloudDiscoveryengineV1betaStreamAssistRequestGenerationSpec.



33061
33062
33063
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33061

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#model_idString

Optional. The Vertex AI model_id used for the generative model. If not set, the default Assistant model will be used. Corresponds to the JSON property modelId

Returns:

  • (String)


33059
33060
33061
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33059

def model_id
  @model_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33066
33067
33068
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33066

def update!(**args)
  @model_id = args[:model_id] if args.key?(:model_id)
end