Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaStreamAssistRequestToolsSpecVertexAiSearchSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Specification of the Vertex AI Search tool.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaStreamAssistRequestToolsSpecVertexAiSearchSpec

Returns a new instance of GoogleCloudDiscoveryengineV1betaStreamAssistRequestToolsSpecVertexAiSearchSpec.



32841
32842
32843
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32841

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_store_specsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestDataStoreSpec>

Optional. Specs defining DataStores to filter on in a search call and configurations for those data stores. This is only considered for Engines with multiple data stores. Corresponds to the JSON property dataStoreSpecs



32824
32825
32826
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32824

def data_store_specs
  @data_store_specs
end

#filterString

Optional. The filter syntax consists of an expression language for constructing a predicate from one or more fields of the documents being filtered. Filter expression is case-sensitive. If this field is unrecognizable, an INVALID_ARGUMENT is returned. Filtering in Vertex AI Search is done by mapping the LHS filter key to a key property defined in the Vertex AI Search backend -- this mapping is defined by the customer in their schema. For example a media customer might have a field 'name' in their schema. In this case the filter would look like this: filter --> name:'ANY("king kong")' For more information about filtering including syntax and filter operators, see Filter Corresponds to the JSON property filter

Returns:

  • (String)


32839
32840
32841
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32839

def filter
  @filter
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32846
32847
32848
32849
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32846

def update!(**args)
  @data_store_specs = args[:data_store_specs] if args.key?(:data_store_specs)
  @filter = args[:filter] if args.key?(:filter)
end