Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaStreamAssistResponseConnectorAuthError
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaStreamAssistResponseConnectorAuthError
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Describes an authentication error for a specific data connector.
Instance Attribute Summary collapse
-
#data_connector ⇒ String
Resource name of the data connector that failed authentication.
-
#error_message ⇒ String
Human-readable error message describing the auth failure.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaStreamAssistResponseConnectorAuthError
constructor
A new instance of GoogleCloudDiscoveryengineV1betaStreamAssistResponseConnectorAuthError.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaStreamAssistResponseConnectorAuthError
Returns a new instance of GoogleCloudDiscoveryengineV1betaStreamAssistResponseConnectorAuthError.
33937 33938 33939 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33937 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_connector ⇒ String
Resource name of the data connector that failed authentication.
Corresponds to the JSON property dataConnector
33930 33931 33932 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33930 def data_connector @data_connector end |
#error_message ⇒ String
Human-readable error message describing the auth failure.
Corresponds to the JSON property errorMessage
33935 33936 33937 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33935 def @error_message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33942 33943 33944 33945 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33942 def update!(**args) @data_connector = args[:data_connector] if args.key?(:data_connector) @error_message = args[:error_message] if args.key?(:error_message) end |