Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaTargetSite
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaTargetSite
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
A target site for the SiteSearchEngine.
Instance Attribute Summary collapse
-
#exact_match ⇒ Boolean
(also: #exact_match?)
Immutable.
-
#failure_reason ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaTargetSiteFailureReason
Site search indexing failure reasons.
-
#generated_uri_pattern ⇒ String
Output only.
-
#indexing_status ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#provided_uri_pattern ⇒ String
Required.
-
#root_domain_uri ⇒ String
Output only.
-
#site_verification_info ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSiteVerificationInfo
Verification information for target sites in advanced site search.
-
#type ⇒ String
The type of the target site, e.g., whether the site is to be included or excluded.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaTargetSite
constructor
A new instance of GoogleCloudDiscoveryengineV1betaTargetSite.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaTargetSite
Returns a new instance of GoogleCloudDiscoveryengineV1betaTargetSite.
34223 34224 34225 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34223 def initialize(**args) update!(**args) end |
Instance Attribute Details
#exact_match ⇒ Boolean Also known as: exact_match?
Immutable. If set to false, a uri_pattern is generated to include all pages
whose address contains the provided_uri_pattern. If set to true, an
uri_pattern is generated to try to be an exact match of the
provided_uri_pattern or just the specific page if the provided_uri_pattern is
a specific one. provided_uri_pattern is always normalized to generate the URI
pattern to be used by the search engine.
Corresponds to the JSON property exactMatch
34170 34171 34172 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34170 def exact_match @exact_match end |
#failure_reason ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaTargetSiteFailureReason
Site search indexing failure reasons.
Corresponds to the JSON property failureReason
34176 34177 34178 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34176 def failure_reason @failure_reason end |
#generated_uri_pattern ⇒ String
Output only. This is system-generated based on the provided_uri_pattern.
Corresponds to the JSON property generatedUriPattern
34181 34182 34183 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34181 def generated_uri_pattern @generated_uri_pattern end |
#indexing_status ⇒ String
Output only. Indexing status.
Corresponds to the JSON property indexingStatus
34186 34187 34188 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34186 def indexing_status @indexing_status end |
#name ⇒ String
Output only. The fully qualified resource name of the target site. projects/
project/locations/location/collections/collection/dataStores/data_store/
siteSearchEngine/targetSites/target_site`Thetarget_site_idis system-
generated.
Corresponds to the JSON propertyname`
34194 34195 34196 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34194 def name @name end |
#provided_uri_pattern ⇒ String
Required. Input only. The user provided URI pattern from which the
generated_uri_pattern is generated.
Corresponds to the JSON property providedUriPattern
34200 34201 34202 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34200 def provided_uri_pattern @provided_uri_pattern end |
#root_domain_uri ⇒ String
Output only. Root domain of the provided_uri_pattern.
Corresponds to the JSON property rootDomainUri
34205 34206 34207 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34205 def root_domain_uri @root_domain_uri end |
#site_verification_info ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSiteVerificationInfo
Verification information for target sites in advanced site search.
Corresponds to the JSON property siteVerificationInfo
34210 34211 34212 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34210 def site_verification_info @site_verification_info end |
#type ⇒ String
The type of the target site, e.g., whether the site is to be included or
excluded.
Corresponds to the JSON property type
34216 34217 34218 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34216 def type @type end |
#update_time ⇒ String
Output only. The target site's last updated time.
Corresponds to the JSON property updateTime
34221 34222 34223 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34221 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34228 34229 34230 34231 34232 34233 34234 34235 34236 34237 34238 34239 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34228 def update!(**args) @exact_match = args[:exact_match] if args.key?(:exact_match) @failure_reason = args[:failure_reason] if args.key?(:failure_reason) @generated_uri_pattern = args[:generated_uri_pattern] if args.key?(:generated_uri_pattern) @indexing_status = args[:indexing_status] if args.key?(:indexing_status) @name = args[:name] if args.key?(:name) @provided_uri_pattern = args[:provided_uri_pattern] if args.key?(:provided_uri_pattern) @root_domain_uri = args[:root_domain_uri] if args.key?(:root_domain_uri) @site_verification_info = args[:site_verification_info] if args.key?(:site_verification_info) @type = args[:type] if args.key?(:type) @update_time = args[:update_time] if args.key?(:update_time) end |