Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaTuneEngineRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Request to manually start a tuning process now (instead of waiting for the periodically scheduled tuning to happen).

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaTuneEngineRequest

Returns a new instance of GoogleCloudDiscoveryengineV1betaTuneEngineRequest.



33392
33393
33394
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33392

def initialize(**args)
   update!(**args)
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33397
33398
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33397

def update!(**args)
end