Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaUserEvent
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaUserEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
UserEvent captures all metadata information Discovery Engine API needs to know about how end users interact with your website.
Instance Attribute Summary collapse
-
#attributes ⇒ Hash<String,Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCustomAttribute>
Extra user event features to include in the recommendation model.
-
#attribution_token ⇒ String
Token to attribute an API response to user action(s) to trigger the event.
-
#completion_info ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCompletionInfo
Detailed completion information including completion attribution token and clicked completion info.
-
#conversion_type ⇒ String
Optional.
-
#data_store ⇒ String
The DataStore resource full name, of the form
projects/project/locations/location/collections/collection_id/dataStores/data_store_id``. -
#direct_user_request ⇒ Boolean
(also: #direct_user_request?)
Should set to true if the request is made directly from the end user, in which case the UserEvent.user_info.user_agent can be populated from the HTTP request.
-
#documents ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocumentInfo>
List of Documents associated with this user event.
-
#engine ⇒ String
The Engine resource name, in the form of
projects/project/locations/location/collections/collection_id/engines/engine_id``. -
#entity ⇒ String
Optional.
-
#event_time ⇒ String
Only required for UserEventService.ImportUserEvents method.
-
#event_type ⇒ String
Required.
-
#feedback ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaFeedback
Information about the user feedback.
-
#filter ⇒ String
Optional.
-
#media_info ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaMediaInfo
Media-specific user event information.
-
#page_info ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaPageInfo
Detailed page information.
-
#panel ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaPanelInfo
Detailed panel information associated with a user event.
-
#panels ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaPanelInfo>
Optional.
-
#promotion_ids ⇒ Array<String>
The promotion IDs if this is an event associated with promotions.
-
#search_info ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchInfo
Detailed search information.
-
#session_id ⇒ String
A unique identifier for tracking a visitor session with a length limit of 128 bytes.
-
#tag_ids ⇒ Array<String>
A list of identifiers for the independent experiment groups this user event belongs to.
-
#transaction_info ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaTransactionInfo
A transaction represents the entire purchase transaction.
-
#user_info ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaUserInfo
Information of an end user.
-
#user_pseudo_id ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaUserEvent
constructor
A new instance of GoogleCloudDiscoveryengineV1betaUserEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaUserEvent
Returns a new instance of GoogleCloudDiscoveryengineV1betaUserEvent.
34880 34881 34882 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34880 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attributes ⇒ Hash<String,Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCustomAttribute>
Extra user event features to include in the recommendation model. These
attributes must NOT contain data that needs to be parsed or processed further,
e.g. JSON or other encodings. If you provide custom attributes for ingested
user events, also include them in the user events that you associate with
prediction requests. Custom attribute formatting must be consistent between
imported events and events provided with prediction requests. This lets the
Discovery Engine API use those custom attributes when training models and
serving predictions, which helps improve recommendation quality. This field
needs to pass all below criteria, otherwise an INVALID_ARGUMENT error is
returned: * The key must be a UTF-8 encoded string with a length limit of 5,
000 characters. * For text attributes, at most 400 values are allowed. Empty
values are not allowed. Each value must be a UTF-8 encoded string with a
length limit of 256 characters. * For number attributes, at most 400 values
are allowed. For product recommendations, an example of extra user information
is traffic_channel, which is how a user arrives at the site. Users can
arrive at the site by coming to the site directly, coming through Google
search, or in other ways.
Corresponds to the JSON property attributes
34688 34689 34690 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34688 def attributes @attributes end |
#attribution_token ⇒ String
Token to attribute an API response to user action(s) to trigger the event.
Highly recommended for user events that are the result of
RecommendationService.Recommend. This field enables accurate attribution of
recommendation model performance. The value must be one of: *
RecommendResponse.attribution_token for events that are the result of
RecommendationService.Recommend. * SearchResponse.attribution_token for events
that are the result of SearchService.Search. This token enables us to
accurately attribute page view or conversion completion back to the event and
the particular predict response containing this clicked/purchased product. If
user clicks on product K in the recommendation results, pass RecommendResponse.
attribution_token as a URL parameter to product K's page. When recording
events on product K's page, log the RecommendResponse.attribution_token to
this field.
Corresponds to the JSON property attributionToken
34705 34706 34707 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34705 def attribution_token @attribution_token end |
#completion_info ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCompletionInfo
Detailed completion information including completion attribution token and
clicked completion info.
Corresponds to the JSON property completionInfo
34711 34712 34713 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34711 def completion_info @completion_info end |
#conversion_type ⇒ String
Optional. Conversion type. Required if UserEvent.event_type is conversion.
This is a customer-defined conversion name in lowercase letters or numbers
separated by "-", such as "watch", "good-visit" etc. Do not set the field if
UserEvent.event_type is not conversion. This mixes the custom conversion
event with predefined events like search, view-item etc.
Corresponds to the JSON property conversionType
34720 34721 34722 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34720 def conversion_type @conversion_type end |
#data_store ⇒ String
The DataStore resource full name, of the form projects/project/locations/
location/collections/collection_id/dataStores/data_store_id`. Optional.
Only required for user events whose data store can't by determined by
UserEvent.engine or UserEvent.documents. If data store is set in the parent of
write/import/collect user event requests, this field can be omitted.
Corresponds to the JSON propertydataStore`
34729 34730 34731 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34729 def data_store @data_store end |
#direct_user_request ⇒ Boolean Also known as: direct_user_request?
Should set to true if the request is made directly from the end user, in which
case the UserEvent.user_info.user_agent can be populated from the HTTP request.
This flag should be set only if the API request is made directly from the end
user such as a mobile app (and not if a gateway or a server is processing and
pushing the user events). This should not be set when using the JavaScript tag
in UserEventService.CollectUserEvent.
Corresponds to the JSON property directUserRequest
34739 34740 34741 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34739 def direct_user_request @direct_user_request end |
#documents ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocumentInfo>
List of Documents associated with this user event. This field is optional
except for the following event types: * view-item * add-to-cart *
purchase * media-play * media-complete In a search event, this field
represents the documents returned to the end user on the current page (the end
user may have not finished browsing the whole page yet). When a new page is
returned to the end user, after pagination/filtering/ordering even for the
same query, a new search event with different UserEvent.documents is desired.
Corresponds to the JSON property documents
34751 34752 34753 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34751 def documents @documents end |
#engine ⇒ String
The Engine resource name, in the form of projects/project/locations/
location/collections/collection_id/engines/engine_id`. Optional. Only
required for Engine produced user events. For example, user events from
blended search.
Corresponds to the JSON propertyengine`
34759 34760 34761 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34759 def engine @engine end |
#entity ⇒ String
Optional. Represents the entity for customers that may run multiple different
entities, domains, sites or regions, for example, Google US, Google Ads,
Waymo, google.com, youtube.com, etc. We recommend that you set entity
to get better per-entity search, completion, and prediction results.
Corresponds to the JSON property entity
34767 34768 34769 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34767 def entity @entity end |
#event_time ⇒ String
Only required for UserEventService.ImportUserEvents method. Timestamp of when
the user event happened.
Corresponds to the JSON property eventTime
34773 34774 34775 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34773 def event_time @event_time end |
#event_type ⇒ String
Required. User event type. Allowed values are: Generic values: * search:
Search for Documents. * view-item: Detailed page view of a Document. * view-
item-list: View of a panel or ordered list of Documents. * view-home-page:
View of the home page. * view-category-page: View of a category page, e.g.
Home > Men > Jeans Retail-related values: * add-to-cart: Add an item(s) to
cart, e.g. in Retail online shopping * purchase: Purchase an item(s) Media-
related values: * media-play: Start/resume watching a video, playing a song,
etc. * media-complete: Finished or stopped midway through a video, song, etc.
Custom conversion value: * conversion: Customer defined conversion event.
Corresponds to the JSON property eventType
34786 34787 34788 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34786 def event_type @event_type end |
#feedback ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaFeedback
Information about the user feedback. This information will be used for logging
and metrics purpose.
Corresponds to the JSON property feedback
34792 34793 34794 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34792 def feedback @feedback end |
#filter ⇒ String
Optional. The filter syntax consists of an expression language for
constructing a predicate from one or more fields of the documents being
filtered. One example is for search events, the associated SearchRequest may
contain a filter expression in SearchRequest.filter conforming to https://
google.aip.dev/160#filtering. Similarly, for view-item-list events that are
generated from a RecommendRequest, this field may be populated directly from
RecommendRequest.filter conforming to https://google.aip.dev/160#filtering.
The value must be a UTF-8 encoded string with a length limit of 1,000
characters. Otherwise, an INVALID_ARGUMENT error is returned.
Corresponds to the JSON property filter
34805 34806 34807 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34805 def filter @filter end |
#media_info ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaMediaInfo
Media-specific user event information.
Corresponds to the JSON property mediaInfo
34810 34811 34812 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34810 def media_info @media_info end |
#page_info ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaPageInfo
Detailed page information.
Corresponds to the JSON property pageInfo
34815 34816 34817 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34815 def page_info @page_info end |
#panel ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaPanelInfo
Detailed panel information associated with a user event.
Corresponds to the JSON property panel
34820 34821 34822 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34820 def panel @panel end |
#panels ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaPanelInfo>
Optional. List of panels associated with this event. Used for page-level
impression data.
Corresponds to the JSON property panels
34826 34827 34828 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34826 def panels @panels end |
#promotion_ids ⇒ Array<String>
The promotion IDs if this is an event associated with promotions. Currently,
this field is restricted to at most one ID.
Corresponds to the JSON property promotionIds
34832 34833 34834 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34832 def promotion_ids @promotion_ids end |
#search_info ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchInfo
Detailed search information.
Corresponds to the JSON property searchInfo
34837 34838 34839 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34837 def search_info @search_info end |
#session_id ⇒ String
A unique identifier for tracking a visitor session with a length limit of 128
bytes. A session is an aggregation of an end user behavior in a time span. A
general guideline to populate the session_id: 1. If user has no activity for
30 min, a new session_id should be assigned. 2. The session_id should be
unique across users, suggest use uuid or add UserEvent.user_pseudo_id as
prefix.
Corresponds to the JSON property sessionId
34847 34848 34849 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34847 def session_id @session_id end |
#tag_ids ⇒ Array<String>
A list of identifiers for the independent experiment groups this user event
belongs to. This is used to distinguish between user events associated with
different experiment setups.
Corresponds to the JSON property tagIds
34854 34855 34856 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34854 def tag_ids @tag_ids end |
#transaction_info ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaTransactionInfo
A transaction represents the entire purchase transaction.
Corresponds to the JSON property transactionInfo
34859 34860 34861 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34859 def transaction_info @transaction_info end |
#user_info ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaUserInfo
Information of an end user.
Corresponds to the JSON property userInfo
34864 34865 34866 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34864 def user_info @user_info end |
#user_pseudo_id ⇒ String
Required. A unique identifier for tracking visitors. For example, this could
be implemented with an HTTP cookie, which should be able to uniquely identify
a visitor on a single device. This unique identifier should not change if the
visitor log in/out of the website. Do not set the field to the same fixed ID
for different users. This mixes the event history of those users together,
which results in degraded model quality. The field must be a UTF-8 encoded
string with a length limit of 128 characters. Otherwise, an INVALID_ARGUMENT
error is returned. The field should not contain PII or user-data. We recommend
to use Google Analytics Client ID for this field.
Corresponds to the JSON property userPseudoId
34878 34879 34880 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34878 def user_pseudo_id @user_pseudo_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34885 34886 34887 34888 34889 34890 34891 34892 34893 34894 34895 34896 34897 34898 34899 34900 34901 34902 34903 34904 34905 34906 34907 34908 34909 34910 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34885 def update!(**args) @attributes = args[:attributes] if args.key?(:attributes) @attribution_token = args[:attribution_token] if args.key?(:attribution_token) @completion_info = args[:completion_info] if args.key?(:completion_info) @conversion_type = args[:conversion_type] if args.key?(:conversion_type) @data_store = args[:data_store] if args.key?(:data_store) @direct_user_request = args[:direct_user_request] if args.key?(:direct_user_request) @documents = args[:documents] if args.key?(:documents) @engine = args[:engine] if args.key?(:engine) @entity = args[:entity] if args.key?(:entity) @event_time = args[:event_time] if args.key?(:event_time) @event_type = args[:event_type] if args.key?(:event_type) @feedback = args[:feedback] if args.key?(:feedback) @filter = args[:filter] if args.key?(:filter) @media_info = args[:media_info] if args.key?(:media_info) @page_info = args[:page_info] if args.key?(:page_info) @panel = args[:panel] if args.key?(:panel) @panels = args[:panels] if args.key?(:panels) @promotion_ids = args[:promotion_ids] if args.key?(:promotion_ids) @search_info = args[:search_info] if args.key?(:search_info) @session_id = args[:session_id] if args.key?(:session_id) @tag_ids = args[:tag_ids] if args.key?(:tag_ids) @transaction_info = args[:transaction_info] if args.key?(:transaction_info) @user_info = args[:user_info] if args.key?(:user_info) @user_pseudo_id = args[:user_pseudo_id] if args.key?(:user_pseudo_id) end |