Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaUserInfoPreciseLocation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Precise location info with multiple representation options.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaUserInfoPreciseLocation

Returns a new instance of GoogleCloudDiscoveryengineV1betaUserInfoPreciseLocation.



34980
34981
34982
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34980

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addressString

Location represented by a natural language address. Will later be geocoded and converted to either a point or a polygon. Corresponds to the JSON property address

Returns:

  • (String)


34970
34971
34972
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34970

def address
  @address
end

#pointGoogle::Apis::DiscoveryengineV1beta::GoogleTypeLatLng

An object that represents a latitude/longitude pair. This is expressed as a pair of doubles to represent degrees latitude and degrees longitude. Unless specified otherwise, this object must conform to the WGS84 standard. Values must be within normalized ranges. Corresponds to the JSON property point



34978
34979
34980
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34978

def point
  @point
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34985
34986
34987
34988
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34985

def update!(**args)
  @address = args[:address] if args.key?(:address)
  @point = args[:point] if args.key?(:point)
end