Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaUserLicense
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaUserLicense
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
User License information assigned by the admin.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#last_login_time ⇒ String
Output only.
-
#license_assignment_state ⇒ String
Output only.
-
#license_config ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
-
#user_principal ⇒ String
Required.
-
#user_profile ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaUserLicense
constructor
A new instance of GoogleCloudDiscoveryengineV1betaUserLicense.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaUserLicense
Returns a new instance of GoogleCloudDiscoveryengineV1betaUserLicense.
35038 35039 35040 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35038 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. User created timestamp.
Corresponds to the JSON property createTime
34998 34999 35000 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34998 def create_time @create_time end |
#last_login_time ⇒ String
Output only. User last logged in time. If the user has not logged in yet, this
field will be empty.
Corresponds to the JSON property lastLoginTime
35004 35005 35006 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35004 def last_login_time @last_login_time end |
#license_assignment_state ⇒ String
Output only. License assignment state of the user. If the user is assigned
with a license config, the user login will be assigned with the license; If
the user's license assignment state is unassigned or unspecified, no license
config will be associated to the user;
Corresponds to the JSON property licenseAssignmentState
35012 35013 35014 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35012 def license_assignment_state @license_assignment_state end |
#license_config ⇒ String
Optional. The full resource name of the Subscription(LicenseConfig) assigned
to the user.
Corresponds to the JSON property licenseConfig
35018 35019 35020 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35018 def license_config @license_config end |
#update_time ⇒ String
Output only. User update timestamp.
Corresponds to the JSON property updateTime
35023 35024 35025 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35023 def update_time @update_time end |
#user_principal ⇒ String
Required. Immutable. The user principal of the User, could be email address or
other prinical identifier. This field is immutable. Admin assign licenses
based on the user principal.
Corresponds to the JSON property userPrincipal
35030 35031 35032 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35030 def user_principal @user_principal end |
#user_profile ⇒ String
Optional. The user profile. We user user full name(First name + Last name) as
user profile.
Corresponds to the JSON property userProfile
35036 35037 35038 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35036 def user_profile @user_profile end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35043 35044 35045 35046 35047 35048 35049 35050 35051 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35043 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @last_login_time = args[:last_login_time] if args.key?(:last_login_time) @license_assignment_state = args[:license_assignment_state] if args.key?(:license_assignment_state) @license_config = args[:license_config] if args.key?(:license_config) @update_time = args[:update_time] if args.key?(:update_time) @user_principal = args[:user_principal] if args.key?(:user_principal) @user_profile = args[:user_profile] if args.key?(:user_profile) end |