Class: Google::Apis::DiscoveryengineV1beta::GoogleLongrunningListOperationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleLongrunningListOperationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
The response message for Operations.ListOperations.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
The standard List next-page token.
-
#operations ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleLongrunningOperation>
A list of operations that matches the specified filter in the request.
-
#unreachable ⇒ Array<String>
Unordered list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleLongrunningListOperationsResponse
constructor
A new instance of GoogleLongrunningListOperationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleLongrunningListOperationsResponse
Returns a new instance of GoogleLongrunningListOperationsResponse.
35255 35256 35257 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35255 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
The standard List next-page token.
Corresponds to the JSON property nextPageToken
35240 35241 35242 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35240 def next_page_token @next_page_token end |
#operations ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleLongrunningOperation>
A list of operations that matches the specified filter in the request.
Corresponds to the JSON property operations
35245 35246 35247 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35245 def operations @operations end |
#unreachable ⇒ Array<String>
Unordered list. Unreachable resources. Populated when the request sets
ListOperationsRequest.return_partial_success and reads across collections.
For example, when attempting to list all resources across all supported
locations.
Corresponds to the JSON property unreachable
35253 35254 35255 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35253 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35260 35261 35262 35263 35264 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35260 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @operations = args[:operations] if args.key?(:operations) @unreachable = args[:unreachable] if args.key?(:unreachable) end |