Class: Google::Apis::DiscoveryengineV1beta::GoogleMonitoringV3Point
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleMonitoringV3Point
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
A single data point in a time series.
Instance Attribute Summary collapse
-
#interval ⇒ Google::Apis::DiscoveryengineV1beta::GoogleMonitoringV3TimeInterval
A time interval extending just after a start time through an end time.
-
#value ⇒ Google::Apis::DiscoveryengineV1beta::GoogleMonitoringV3TypedValue
A single strongly-typed value.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleMonitoringV3Point
constructor
A new instance of GoogleMonitoringV3Point.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleMonitoringV3Point
Returns a new instance of GoogleMonitoringV3Point.
35498 35499 35500 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35498 def initialize(**args) update!(**args) end |
Instance Attribute Details
#interval ⇒ Google::Apis::DiscoveryengineV1beta::GoogleMonitoringV3TimeInterval
A time interval extending just after a start time through an end time. If the
start time is the same as the end time, then the interval represents a single
point in time.
Corresponds to the JSON property interval
35491 35492 35493 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35491 def interval @interval end |
#value ⇒ Google::Apis::DiscoveryengineV1beta::GoogleMonitoringV3TypedValue
A single strongly-typed value.
Corresponds to the JSON property value
35496 35497 35498 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35496 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35503 35504 35505 35506 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35503 def update!(**args) @interval = args[:interval] if args.key?(:interval) @value = args[:value] if args.key?(:value) end |