Class: Google::Apis::DiscoveryengineV1beta::GoogleMonitoringV3TimeSeries

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

A collection of data points that describes the time-varying values of a metric. A time series is identified by a combination of a fully-specified monitored resource and a fully-specified metric. This type is used for both listing and creating time series.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleMonitoringV3TimeSeries

Returns a new instance of GoogleMonitoringV3TimeSeries.



35633
35634
35635
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35633

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Input only. A detailed description of the time series that will be associated with the google.api.MetricDescriptor for the metric. Once set, this field cannot be changed through CreateTimeSeries. Corresponds to the JSON property description

Returns:

  • (String)


35564
35565
35566
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35564

def description
  @description
end

#metadataGoogle::Apis::DiscoveryengineV1beta::GoogleApiMonitoredResourceMetadata

Auxiliary metadata for a MonitoredResource object. MonitoredResource objects contain the minimum set of information to uniquely identify a monitored resource instance. There is some other useful auxiliary metadata. Monitoring and Logging use an ingestion pipeline to extract metadata for cloud resources of all types, and store the metadata in this message. Corresponds to the JSON property metadata



35573
35574
35575
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35573

def 
  @metadata
end

#metricGoogle::Apis::DiscoveryengineV1beta::GoogleApiMetric

A specific metric, identified by specifying values for all of the labels of a MetricDescriptor. Corresponds to the JSON property metric



35579
35580
35581
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35579

def metric
  @metric
end

#metric_kindString

The metric kind of the time series. When listing time series, this metric kind might be different from the metric kind of the associated metric if this time series is an alignment or reduction of other time series. When creating a time series, this field is optional. If present, it must be the same as the metric kind of the associated metric. If the associated metric's descriptor must be auto-created, then this field specifies the metric kind of the new descriptor and must be either GAUGE (the default) or CUMULATIVE. Corresponds to the JSON property metricKind

Returns:

  • (String)


35590
35591
35592
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35590

def metric_kind
  @metric_kind
end

#pointsArray<Google::Apis::DiscoveryengineV1beta::GoogleMonitoringV3Point>

The data points of this time series. When listing time series, points are returned in reverse time order. When creating a time series, this field must contain exactly one point and the point's type must be the same as the value type of the associated metric. If the associated metric's descriptor must be auto-created, then the value type of the descriptor is determined by the point' s type, which must be BOOL, INT64, DOUBLE, or DISTRIBUTION. Corresponds to the JSON property points



35600
35601
35602
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35600

def points
  @points
end

#resourceGoogle::Apis::DiscoveryengineV1beta::GoogleApiMonitoredResource

An object representing a resource that can be used for monitoring, logging, billing, or other purposes. Examples include virtual machine instances, databases, and storage devices such as disks. The type field identifies a MonitoredResourceDescriptor object that describes the resource's schema. Information in the labels field identifies the actual resource and its attributes according to the schema. For example, a particular Compute Engine VM instance could be represented by the following object, because the MonitoredResourceDescriptor for "gce_instance" has labels "project_id", " instance_id" and "zone": "type": "gce_instance", "labels": "project_id": "my-project", "instance_id": "12345678901234", "zone": "us-central1-a" ` Corresponds to the JSON propertyresource`



35614
35615
35616
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35614

def resource
  @resource
end

#unitString

The units in which the metric value is reported. It is only applicable if the value_type is INT64, DOUBLE, or DISTRIBUTION. The unit defines the representation of the stored metric values. This field can only be changed through CreateTimeSeries when it is empty. Corresponds to the JSON property unit

Returns:

  • (String)


35622
35623
35624
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35622

def unit
  @unit
end

#value_typeString

The value type of the time series. When listing time series, this value type might be different from the value type of the associated metric if this time series is an alignment or reduction of other time series. When creating a time series, this field is optional. If present, it must be the same as the type of the data in the points field. Corresponds to the JSON property valueType

Returns:

  • (String)


35631
35632
35633
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35631

def value_type
  @value_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35638
35639
35640
35641
35642
35643
35644
35645
35646
35647
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35638

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @metadata = args[:metadata] if args.key?(:metadata)
  @metric = args[:metric] if args.key?(:metric)
  @metric_kind = args[:metric_kind] if args.key?(:metric_kind)
  @points = args[:points] if args.key?(:points)
  @resource = args[:resource] if args.key?(:resource)
  @unit = args[:unit] if args.key?(:unit)
  @value_type = args[:value_type] if args.key?(:value_type)
end