Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1AnswerGenerationSpecUserDefinedClassifierSpec
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1AnswerGenerationSpecUserDefinedClassifierSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
The specification for user defined classifier.
Instance Attribute Summary collapse
-
#enable_user_defined_classifier ⇒ Boolean
(also: #enable_user_defined_classifier?)
Optional.
-
#model_id ⇒ String
Optional.
-
#preamble ⇒ String
Optional.
-
#seed ⇒ Fixnum
Optional.
-
#task_marker ⇒ String
Optional.
-
#temperature ⇒ Float
Optional.
-
#top_k ⇒ Fixnum
Optional.
-
#top_p ⇒ Float
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1AnswerGenerationSpecUserDefinedClassifierSpec
constructor
A new instance of GoogleCloudDiscoveryengineV1AnswerGenerationSpecUserDefinedClassifierSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1AnswerGenerationSpecUserDefinedClassifierSpec
Returns a new instance of GoogleCloudDiscoveryengineV1AnswerGenerationSpecUserDefinedClassifierSpec.
1054 1055 1056 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1054 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable_user_defined_classifier ⇒ Boolean Also known as: enable_user_defined_classifier?
Optional. Whether or not to enable and include user defined classifier.
Corresponds to the JSON property enableUserDefinedClassifier
1016 1017 1018 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1016 def enable_user_defined_classifier @enable_user_defined_classifier end |
#model_id ⇒ String
Optional. The model id to be used for the user defined classifier.
Corresponds to the JSON property modelId
1022 1023 1024 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1022 def model_id @model_id end |
#preamble ⇒ String
Optional. The preamble to be used for the user defined classifier.
Corresponds to the JSON property preamble
1027 1028 1029 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1027 def preamble @preamble end |
#seed ⇒ Fixnum
Optional. The seed value to be used for the user defined classifier.
Corresponds to the JSON property seed
1032 1033 1034 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1032 def seed @seed end |
#task_marker ⇒ String
Optional. The task marker to be used for the user defined classifier.
Corresponds to the JSON property taskMarker
1037 1038 1039 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1037 def task_marker @task_marker end |
#temperature ⇒ Float
Optional. The temperature value to be used for the user defined classifier.
Corresponds to the JSON property temperature
1042 1043 1044 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1042 def temperature @temperature end |
#top_k ⇒ Fixnum
Optional. The top-k value to be used for the user defined classifier.
Corresponds to the JSON property topK
1047 1048 1049 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1047 def top_k @top_k end |
#top_p ⇒ Float
Optional. The top-p value to be used for the user defined classifier.
Corresponds to the JSON property topP
1052 1053 1054 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1052 def top_p @top_p end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 1059 def update!(**args) @enable_user_defined_classifier = args[:enable_user_defined_classifier] if args.key?(:enable_user_defined_classifier) @model_id = args[:model_id] if args.key?(:model_id) @preamble = args[:preamble] if args.key?(:preamble) @seed = args[:seed] if args.key?(:seed) @task_marker = args[:task_marker] if args.key?(:task_marker) @temperature = args[:temperature] if args.key?(:temperature) @top_k = args[:top_k] if args.key?(:top_k) @top_p = args[:top_p] if args.key?(:top_p) end |