Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1DataConnectorEndUserConfig
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1DataConnectorEndUserConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Any params and credentials used specifically for EUA connectors.
Instance Attribute Summary collapse
-
#additional_params ⇒ Hash<String,Object>
Optional.
-
#auth_params ⇒ Hash<String,Object>
Optional.
-
#json_auth_params ⇒ String
Optional.
-
#tenant ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1Tenant
Tenant information for a connector source.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1DataConnectorEndUserConfig
constructor
A new instance of GoogleCloudDiscoveryengineV1DataConnectorEndUserConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1DataConnectorEndUserConfig
Returns a new instance of GoogleCloudDiscoveryengineV1DataConnectorEndUserConfig.
2689 2690 2691 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2689 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_params ⇒ Hash<String,Object>
Optional. Any additional parameters needed for EUA.
Corresponds to the JSON property additionalParams
2669 2670 2671 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2669 def additional_params @additional_params end |
#auth_params ⇒ Hash<String,Object>
Optional. Any authentication parameters specific to EUA connectors.
Corresponds to the JSON property authParams
2674 2675 2676 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2674 def auth_params @auth_params end |
#json_auth_params ⇒ String
Optional. Any authentication parameters specific to EUA connectors in json
string format.
Corresponds to the JSON property jsonAuthParams
2680 2681 2682 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2680 def json_auth_params @json_auth_params end |
#tenant ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1Tenant
Tenant information for a connector source. This includes some of the same
information stored in the Credential message, but is limited to only what is
needed to provide a list of accessible tenants to the user.
Corresponds to the JSON property tenant
2687 2688 2689 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2687 def tenant @tenant end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2694 2695 2696 2697 2698 2699 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2694 def update!(**args) @additional_params = args[:additional_params] if args.key?(:additional_params) @auth_params = args[:auth_params] if args.key?(:auth_params) @json_auth_params = args[:json_auth_params] if args.key?(:json_auth_params) @tenant = args[:tenant] if args.key?(:tenant) end |