Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1DataConnectorEndUserConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Any params and credentials used specifically for EUA connectors.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1DataConnectorEndUserConfig

Returns a new instance of GoogleCloudDiscoveryengineV1DataConnectorEndUserConfig.



2622
2623
2624
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2622

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_paramsHash<String,Object>

Optional. Any additional parameters needed for EUA. Corresponds to the JSON property additionalParams

Returns:

  • (Hash<String,Object>)


2602
2603
2604
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2602

def additional_params
  @additional_params
end

#auth_paramsHash<String,Object>

Optional. Any authentication parameters specific to EUA connectors. Corresponds to the JSON property authParams

Returns:

  • (Hash<String,Object>)


2607
2608
2609
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2607

def auth_params
  @auth_params
end

#json_auth_paramsString

Optional. Any authentication parameters specific to EUA connectors in json string format. Corresponds to the JSON property jsonAuthParams

Returns:

  • (String)


2613
2614
2615
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2613

def json_auth_params
  @json_auth_params
end

#tenantGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1Tenant

Tenant information for a connector source. This includes some of the same information stored in the Credential message, but is limited to only what is needed to provide a list of accessible tenants to the user. Corresponds to the JSON property tenant



2620
2621
2622
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2620

def tenant
  @tenant
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2627
2628
2629
2630
2631
2632
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2627

def update!(**args)
  @additional_params = args[:additional_params] if args.key?(:additional_params)
  @auth_params = args[:auth_params] if args.key?(:auth_params)
  @json_auth_params = args[:json_auth_params] if args.key?(:json_auth_params)
  @tenant = args[:tenant] if args.key?(:tenant)
end