Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1DataConnectorEndUserConfig
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1DataConnectorEndUserConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Any params and credentials used specifically for EUA connectors.
Instance Attribute Summary collapse
-
#additional_params ⇒ Hash<String,Object>
Optional.
-
#auth_params ⇒ Hash<String,Object>
Optional.
-
#json_auth_params ⇒ String
Optional.
-
#tenant ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1Tenant
Tenant information for a connector source.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1DataConnectorEndUserConfig
constructor
A new instance of GoogleCloudDiscoveryengineV1DataConnectorEndUserConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1DataConnectorEndUserConfig
Returns a new instance of GoogleCloudDiscoveryengineV1DataConnectorEndUserConfig.
2612 2613 2614 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2612 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_params ⇒ Hash<String,Object>
Optional. Any additional parameters needed for EUA.
Corresponds to the JSON property additionalParams
2592 2593 2594 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2592 def additional_params @additional_params end |
#auth_params ⇒ Hash<String,Object>
Optional. Any authentication parameters specific to EUA connectors.
Corresponds to the JSON property authParams
2597 2598 2599 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2597 def auth_params @auth_params end |
#json_auth_params ⇒ String
Optional. Any authentication parameters specific to EUA connectors in json
string format.
Corresponds to the JSON property jsonAuthParams
2603 2604 2605 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2603 def json_auth_params @json_auth_params end |
#tenant ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1Tenant
Tenant information for a connector source. This includes some of the same
information stored in the Credential message, but is limited to only what is
needed to provide a list of accessible tenants to the user.
Corresponds to the JSON property tenant
2610 2611 2612 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2610 def tenant @tenant end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2617 2618 2619 2620 2621 2622 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2617 def update!(**args) @additional_params = args[:additional_params] if args.key?(:additional_params) @auth_params = args[:auth_params] if args.key?(:auth_params) @json_auth_params = args[:json_auth_params] if args.key?(:json_auth_params) @tenant = args[:tenant] if args.key?(:tenant) end |