Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1DataConnectorRealtimeSyncConfigStreamingError

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Streaming error details.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1DataConnectorRealtimeSyncConfigStreamingError

Returns a new instance of GoogleCloudDiscoveryengineV1DataConnectorRealtimeSyncConfigStreamingError.



2787
2788
2789
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2787

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::DiscoveryengineV1beta::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



2780
2781
2782
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2780

def error
  @error
end

#streaming_error_reasonString

Optional. Streaming error. Corresponds to the JSON property streamingErrorReason

Returns:

  • (String)


2785
2786
2787
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2785

def streaming_error_reason
  @streaming_error_reason
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2792
2793
2794
2795
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2792

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @streaming_error_reason = args[:streaming_error_reason] if args.key?(:streaming_error_reason)
end