Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1DataConnectorRealtimeSyncConfigStreamingError

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Streaming error details.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1DataConnectorRealtimeSyncConfigStreamingError

Returns a new instance of GoogleCloudDiscoveryengineV1DataConnectorRealtimeSyncConfigStreamingError.



2720
2721
2722
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2720

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::DiscoveryengineV1beta::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



2713
2714
2715
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2713

def error
  @error
end

#streaming_error_reasonString

Optional. Streaming error. Corresponds to the JSON property streamingErrorReason

Returns:

  • (String)


2718
2719
2720
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2718

def streaming_error_reason
  @streaming_error_reason
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2725
2726
2727
2728
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2725

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @streaming_error_reason = args[:streaming_error_reason] if args.key?(:streaming_error_reason)
end