Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1DataConnectorSourceEntity

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Represents an entity in the data source. For example, the Account object in Salesforce.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1DataConnectorSourceEntity

Returns a new instance of GoogleCloudDiscoveryengineV1DataConnectorSourceEntity.



2773
2774
2775
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2773

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_storeString

Output only. The full resource name of the associated data store for the source entity. Format: projects/*/locations/*/collections/*/dataStores/*. When the connector is initialized by the DataConnectorService. SetUpDataConnector method, a DataStore is automatically created for each source entity. Corresponds to the JSON property dataStore

Returns:

  • (String)


2733
2734
2735
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2733

def data_store
  @data_store
end

#entity_nameString

The name of the entity. Supported values by data source: * Salesforce: Lead, Opportunity, Contact, Account, Case, Contract, Campaign * Jira: Issue * Confluence: Content, Space Corresponds to the JSON property entityName

Returns:

  • (String)


2740
2741
2742
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2740

def entity_name
  @entity_name
end

#healthcare_fhir_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1HealthcareFhirConfig

Config to data store for HEALTHCARE_FHIR vertical. Corresponds to the JSON property healthcareFhirConfig



2745
2746
2747
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2745

def healthcare_fhir_config
  @healthcare_fhir_config
end

#json_paramsString

The parameters for the entity to facilitate data ingestion in json string format. Corresponds to the JSON property jsonParams

Returns:

  • (String)


2751
2752
2753
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2751

def json_params
  @json_params
end

#key_property_mappingsHash<String,String>

Attributes for indexing. Key: Field name. Value: The key property to map a field to, such as title, and description. Supported key properties: * title: The title for data record. This would be displayed on search results. * description: The description for data record. This would be displayed on search results. Corresponds to the JSON property keyPropertyMappings

Returns:

  • (Hash<String,String>)


2760
2761
2762
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2760

def key_property_mappings
  @key_property_mappings
end

#paramsHash<String,Object>

The parameters for the entity to facilitate data ingestion in structured json format. Corresponds to the JSON property params

Returns:

  • (Hash<String,Object>)


2766
2767
2768
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2766

def params
  @params
end

#starting_schemaGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1Schema

Defines the structure and layout of a type of document data. Corresponds to the JSON property startingSchema



2771
2772
2773
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2771

def starting_schema
  @starting_schema
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2778
2779
2780
2781
2782
2783
2784
2785
2786
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2778

def update!(**args)
  @data_store = args[:data_store] if args.key?(:data_store)
  @entity_name = args[:entity_name] if args.key?(:entity_name)
  @healthcare_fhir_config = args[:healthcare_fhir_config] if args.key?(:healthcare_fhir_config)
  @json_params = args[:json_params] if args.key?(:json_params)
  @key_property_mappings = args[:key_property_mappings] if args.key?(:key_property_mappings)
  @params = args[:params] if args.key?(:params)
  @starting_schema = args[:starting_schema] if args.key?(:starting_schema)
end