Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1DataStore
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1DataStore
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
DataStore captures global settings and configs at the DataStore level.
Instance Attribute Summary collapse
-
#acl_enabled ⇒ Boolean
(also: #acl_enabled?)
Immutable.
-
#advanced_site_search_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1AdvancedSiteSearchConfig
Configuration data for advance site search.
-
#billing_estimation ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1DataStoreBillingEstimation
Estimation of data size per data store.
-
#cmek_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1CmekConfig
Configurations used to enable CMEK data encryption with Cloud KMS keys.
-
#configurable_billing_approach ⇒ String
Optional.
-
#configurable_billing_approach_update_time ⇒ String
Output only.
-
#content_config ⇒ String
Immutable.
-
#create_time ⇒ String
Output only.
-
#default_schema_id ⇒ String
Output only.
-
#display_name ⇒ String
Required.
-
#document_processing_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1DocumentProcessingConfig
A singleton resource of DataStore.
-
#federated_search_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1DataStoreFederatedSearchConfig
Stores information for federated search.
-
#healthcare_fhir_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1HealthcareFhirConfig
Config to data store for
HEALTHCARE_FHIRvertical. -
#identity_mapping_store ⇒ String
Immutable.
-
#industry_vertical ⇒ String
Immutable.
-
#is_infobot_faq_data_store ⇒ Boolean
(also: #is_infobot_faq_data_store?)
Optional.
-
#kms_key_name ⇒ String
Input only.
-
#name ⇒ String
Immutable.
-
#natural_language_query_understanding_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1NaturalLanguageQueryUnderstandingConfig
Configuration for Natural Language Query Understanding.
-
#serving_config_data_store ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1DataStoreServingConfigDataStore
Stores information regarding the serving configurations at DataStore level.
-
#solution_types ⇒ Array<String>
The solutions that the data store enrolls.
-
#starting_schema ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1Schema
Defines the structure and layout of a type of document data.
-
#workspace_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1WorkspaceConfig
Config to store data store type configuration for workspace data Corresponds to the JSON property
workspaceConfig.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1DataStore
constructor
A new instance of GoogleCloudDiscoveryengineV1DataStore.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1DataStore
Returns a new instance of GoogleCloudDiscoveryengineV1DataStore.
3001 3002 3003 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3001 def initialize(**args) update!(**args) end |
Instance Attribute Details
#acl_enabled ⇒ Boolean Also known as: acl_enabled?
Immutable. Whether data in the DataStore has ACL information. If set to true,
the source data must have ACL. ACL will be ingested when data is ingested by
DocumentService.ImportDocuments methods. When ACL is enabled for the DataStore,
Document can't be accessed by calling DocumentService.GetDocument or
DocumentService.ListDocuments. Currently ACL is only supported in GENERIC
industry vertical with non-PUBLIC_WEBSITE content config.
Corresponds to the JSON property aclEnabled
2870 2871 2872 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2870 def acl_enabled @acl_enabled end |
#advanced_site_search_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1AdvancedSiteSearchConfig
Configuration data for advance site search.
Corresponds to the JSON property advancedSiteSearchConfig
2876 2877 2878 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2876 def advanced_site_search_config @advanced_site_search_config end |
#billing_estimation ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1DataStoreBillingEstimation
Estimation of data size per data store.
Corresponds to the JSON property billingEstimation
2881 2882 2883 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2881 def billing_estimation @billing_estimation end |
#cmek_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1CmekConfig
Configurations used to enable CMEK data encryption with Cloud KMS keys.
Corresponds to the JSON property cmekConfig
2886 2887 2888 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2886 def cmek_config @cmek_config end |
#configurable_billing_approach ⇒ String
Optional. Configuration for configurable billing approach. See
Corresponds to the JSON property configurableBillingApproach
2891 2892 2893 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2891 def configurable_billing_approach @configurable_billing_approach end |
#configurable_billing_approach_update_time ⇒ String
Output only. The timestamp when configurable_billing_approach was last updated.
Corresponds to the JSON property configurableBillingApproachUpdateTime
2896 2897 2898 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2896 def configurable_billing_approach_update_time @configurable_billing_approach_update_time end |
#content_config ⇒ String
Immutable. The content config of the data store. If this field is unset, the
server behavior defaults to ContentConfig.NO_CONTENT.
Corresponds to the JSON property contentConfig
2902 2903 2904 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2902 def content_config @content_config end |
#create_time ⇒ String
Output only. Timestamp the DataStore was created at.
Corresponds to the JSON property createTime
2907 2908 2909 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2907 def create_time @create_time end |
#default_schema_id ⇒ String
Output only. The id of the default Schema associated to this data store.
Corresponds to the JSON property defaultSchemaId
2912 2913 2914 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2912 def default_schema_id @default_schema_id end |
#display_name ⇒ String
Required. The data store display name. This field must be a UTF-8 encoded
string with a length limit of 128 characters. Otherwise, an INVALID_ARGUMENT
error is returned.
Corresponds to the JSON property displayName
2919 2920 2921 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2919 def display_name @display_name end |
#document_processing_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1DocumentProcessingConfig
A singleton resource of DataStore. If it's empty when DataStore is created and
DataStore is set to DataStore.ContentConfig.CONTENT_REQUIRED, the default
parser will default to digital parser.
Corresponds to the JSON property documentProcessingConfig
2926 2927 2928 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2926 def document_processing_config @document_processing_config end |
#federated_search_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1DataStoreFederatedSearchConfig
Stores information for federated search.
Corresponds to the JSON property federatedSearchConfig
2931 2932 2933 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2931 def federated_search_config @federated_search_config end |
#healthcare_fhir_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1HealthcareFhirConfig
Config to data store for HEALTHCARE_FHIR vertical.
Corresponds to the JSON property healthcareFhirConfig
2936 2937 2938 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2936 def healthcare_fhir_config @healthcare_fhir_config end |
#identity_mapping_store ⇒ String
Immutable. The fully qualified resource name of the associated
IdentityMappingStore. This field can only be set for acl_enabled DataStores
with THIRD_PARTY or GSUITE IdP. Format: projects/project/locations/
location/identityMappingStores/identity_mapping_store`.
Corresponds to the JSON propertyidentityMappingStore`
2944 2945 2946 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2944 def identity_mapping_store @identity_mapping_store end |
#industry_vertical ⇒ String
Immutable. The industry vertical that the data store registers.
Corresponds to the JSON property industryVertical
2949 2950 2951 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2949 def industry_vertical @industry_vertical end |
#is_infobot_faq_data_store ⇒ Boolean Also known as: is_infobot_faq_data_store?
Optional. If set, this DataStore is an Infobot FAQ DataStore.
Corresponds to the JSON property isInfobotFaqDataStore
2954 2955 2956 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2954 def is_infobot_faq_data_store @is_infobot_faq_data_store end |
#kms_key_name ⇒ String
Input only. The KMS key to be used to protect this DataStore at creation time.
Must be set for requests that need to comply with CMEK Org Policy protections.
If this field is set and processed successfully, the DataStore will be
protected by the KMS key, as indicated in the cmek_config field.
Corresponds to the JSON property kmsKeyName
2963 2964 2965 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2963 def kms_key_name @kms_key_name end |
#name ⇒ String
Immutable. Identifier. The full resource name of the data store. Format:
projects/project/locations/location/collections/collection_id/dataStores/
data_store_id`. This field must be a UTF-8 encoded string with a length
limit of 1024 characters.
Corresponds to the JSON propertyname`
2971 2972 2973 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2971 def name @name end |
#natural_language_query_understanding_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1NaturalLanguageQueryUnderstandingConfig
Configuration for Natural Language Query Understanding.
Corresponds to the JSON property naturalLanguageQueryUnderstandingConfig
2976 2977 2978 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2976 def natural_language_query_understanding_config @natural_language_query_understanding_config end |
#serving_config_data_store ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1DataStoreServingConfigDataStore
Stores information regarding the serving configurations at DataStore level.
Corresponds to the JSON property servingConfigDataStore
2981 2982 2983 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2981 def serving_config_data_store @serving_config_data_store end |
#solution_types ⇒ Array<String>
The solutions that the data store enrolls. Available solutions for each
industry_vertical: * MEDIA: SOLUTION_TYPE_RECOMMENDATION and
SOLUTION_TYPE_SEARCH. * SITE_SEARCH: SOLUTION_TYPE_SEARCH is
automatically enrolled. Other solutions cannot be enrolled.
Corresponds to the JSON property solutionTypes
2989 2990 2991 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2989 def solution_types @solution_types end |
#starting_schema ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1Schema
Defines the structure and layout of a type of document data.
Corresponds to the JSON property startingSchema
2994 2995 2996 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2994 def starting_schema @starting_schema end |
#workspace_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1WorkspaceConfig
Config to store data store type configuration for workspace data
Corresponds to the JSON property workspaceConfig
2999 3000 3001 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2999 def workspace_config @workspace_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 3020 3021 3022 3023 3024 3025 3026 3027 3028 3029 3030 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3006 def update!(**args) @acl_enabled = args[:acl_enabled] if args.key?(:acl_enabled) @advanced_site_search_config = args[:advanced_site_search_config] if args.key?(:advanced_site_search_config) @billing_estimation = args[:billing_estimation] if args.key?(:billing_estimation) @cmek_config = args[:cmek_config] if args.key?(:cmek_config) @configurable_billing_approach = args[:configurable_billing_approach] if args.key?(:configurable_billing_approach) @configurable_billing_approach_update_time = args[:configurable_billing_approach_update_time] if args.key?(:configurable_billing_approach_update_time) @content_config = args[:content_config] if args.key?(:content_config) @create_time = args[:create_time] if args.key?(:create_time) @default_schema_id = args[:default_schema_id] if args.key?(:default_schema_id) @display_name = args[:display_name] if args.key?(:display_name) @document_processing_config = args[:document_processing_config] if args.key?(:document_processing_config) @federated_search_config = args[:federated_search_config] if args.key?(:federated_search_config) @healthcare_fhir_config = args[:healthcare_fhir_config] if args.key?(:healthcare_fhir_config) @identity_mapping_store = args[:identity_mapping_store] if args.key?(:identity_mapping_store) @industry_vertical = args[:industry_vertical] if args.key?(:industry_vertical) @is_infobot_faq_data_store = args[:is_infobot_faq_data_store] if args.key?(:is_infobot_faq_data_store) @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name) @name = args[:name] if args.key?(:name) @natural_language_query_understanding_config = args[:natural_language_query_understanding_config] if args.key?(:natural_language_query_understanding_config) @serving_config_data_store = args[:serving_config_data_store] if args.key?(:serving_config_data_store) @solution_types = args[:solution_types] if args.key?(:solution_types) @starting_schema = args[:starting_schema] if args.key?(:starting_schema) @workspace_config = args[:workspace_config] if args.key?(:workspace_config) end |