Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1DataStore

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

DataStore captures global settings and configs at the DataStore level.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1DataStore

Returns a new instance of GoogleCloudDiscoveryengineV1DataStore.



2932
2933
2934
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2932

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#acl_enabledBoolean Also known as: acl_enabled?

Immutable. Whether data in the DataStore has ACL information. If set to true, the source data must have ACL. ACL will be ingested when data is ingested by DocumentService.ImportDocuments methods. When ACL is enabled for the DataStore, Document can't be accessed by calling DocumentService.GetDocument or DocumentService.ListDocuments. Currently ACL is only supported in GENERIC industry vertical with non-PUBLIC_WEBSITE content config. Corresponds to the JSON property aclEnabled

Returns:

  • (Boolean)


2801
2802
2803
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2801

def acl_enabled
  @acl_enabled
end

#advanced_site_search_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1AdvancedSiteSearchConfig

Configuration data for advance site search. Corresponds to the JSON property advancedSiteSearchConfig



2807
2808
2809
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2807

def advanced_site_search_config
  @advanced_site_search_config
end

#billing_estimationGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1DataStoreBillingEstimation

Estimation of data size per data store. Corresponds to the JSON property billingEstimation



2812
2813
2814
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2812

def billing_estimation
  @billing_estimation
end

#cmek_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1CmekConfig

Configurations used to enable CMEK data encryption with Cloud KMS keys. Corresponds to the JSON property cmekConfig



2817
2818
2819
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2817

def cmek_config
  @cmek_config
end

#configurable_billing_approachString

Optional. Configuration for configurable billing approach. See Corresponds to the JSON property configurableBillingApproach

Returns:

  • (String)


2822
2823
2824
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2822

def configurable_billing_approach
  @configurable_billing_approach
end

#configurable_billing_approach_update_timeString

Output only. The timestamp when configurable_billing_approach was last updated. Corresponds to the JSON property configurableBillingApproachUpdateTime

Returns:

  • (String)


2827
2828
2829
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2827

def configurable_billing_approach_update_time
  @configurable_billing_approach_update_time
end

#content_configString

Immutable. The content config of the data store. If this field is unset, the server behavior defaults to ContentConfig.NO_CONTENT. Corresponds to the JSON property contentConfig

Returns:

  • (String)


2833
2834
2835
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2833

def content_config
  @content_config
end

#create_timeString

Output only. Timestamp the DataStore was created at. Corresponds to the JSON property createTime

Returns:

  • (String)


2838
2839
2840
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2838

def create_time
  @create_time
end

#default_schema_idString

Output only. The id of the default Schema associated to this data store. Corresponds to the JSON property defaultSchemaId

Returns:

  • (String)


2843
2844
2845
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2843

def default_schema_id
  @default_schema_id
end

#display_nameString

Required. The data store display name. This field must be a UTF-8 encoded string with a length limit of 128 characters. Otherwise, an INVALID_ARGUMENT error is returned. Corresponds to the JSON property displayName

Returns:

  • (String)


2850
2851
2852
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2850

def display_name
  @display_name
end

#document_processing_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1DocumentProcessingConfig

A singleton resource of DataStore. If it's empty when DataStore is created and DataStore is set to DataStore.ContentConfig.CONTENT_REQUIRED, the default parser will default to digital parser. Corresponds to the JSON property documentProcessingConfig



2857
2858
2859
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2857

def document_processing_config
  @document_processing_config
end

#federated_search_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1DataStoreFederatedSearchConfig

Stores information for federated search. Corresponds to the JSON property federatedSearchConfig



2862
2863
2864
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2862

def federated_search_config
  @federated_search_config
end

#healthcare_fhir_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1HealthcareFhirConfig

Config to data store for HEALTHCARE_FHIR vertical. Corresponds to the JSON property healthcareFhirConfig



2867
2868
2869
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2867

def healthcare_fhir_config
  @healthcare_fhir_config
end

#identity_mapping_storeString

Immutable. The fully qualified resource name of the associated IdentityMappingStore. This field can only be set for acl_enabled DataStores with THIRD_PARTY or GSUITE IdP. Format: projects/project/locations/ location/identityMappingStores/identity_mapping_store`. Corresponds to the JSON propertyidentityMappingStore`

Returns:

  • (String)


2875
2876
2877
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2875

def identity_mapping_store
  @identity_mapping_store
end

#industry_verticalString

Immutable. The industry vertical that the data store registers. Corresponds to the JSON property industryVertical

Returns:

  • (String)


2880
2881
2882
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2880

def industry_vertical
  @industry_vertical
end

#is_infobot_faq_data_storeBoolean Also known as: is_infobot_faq_data_store?

Optional. If set, this DataStore is an Infobot FAQ DataStore. Corresponds to the JSON property isInfobotFaqDataStore

Returns:

  • (Boolean)


2885
2886
2887
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2885

def is_infobot_faq_data_store
  @is_infobot_faq_data_store
end

#kms_key_nameString

Input only. The KMS key to be used to protect this DataStore at creation time. Must be set for requests that need to comply with CMEK Org Policy protections. If this field is set and processed successfully, the DataStore will be protected by the KMS key, as indicated in the cmek_config field. Corresponds to the JSON property kmsKeyName

Returns:

  • (String)


2894
2895
2896
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2894

def kms_key_name
  @kms_key_name
end

#nameString

Immutable. Identifier. The full resource name of the data store. Format: projects/project/locations/location/collections/collection_id/dataStores/ data_store_id`. This field must be a UTF-8 encoded string with a length limit of 1024 characters. Corresponds to the JSON propertyname`

Returns:

  • (String)


2902
2903
2904
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2902

def name
  @name
end

#natural_language_query_understanding_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1NaturalLanguageQueryUnderstandingConfig

Configuration for Natural Language Query Understanding. Corresponds to the JSON property naturalLanguageQueryUnderstandingConfig



2907
2908
2909
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2907

def natural_language_query_understanding_config
  @natural_language_query_understanding_config
end

#serving_config_data_storeGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1DataStoreServingConfigDataStore

Stores information regarding the serving configurations at DataStore level. Corresponds to the JSON property servingConfigDataStore



2912
2913
2914
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2912

def serving_config_data_store
  @serving_config_data_store
end

#solution_typesArray<String>

The solutions that the data store enrolls. Available solutions for each industry_vertical: * MEDIA: SOLUTION_TYPE_RECOMMENDATION and SOLUTION_TYPE_SEARCH. * SITE_SEARCH: SOLUTION_TYPE_SEARCH is automatically enrolled. Other solutions cannot be enrolled. Corresponds to the JSON property solutionTypes

Returns:

  • (Array<String>)


2920
2921
2922
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2920

def solution_types
  @solution_types
end

#starting_schemaGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1Schema

Defines the structure and layout of a type of document data. Corresponds to the JSON property startingSchema



2925
2926
2927
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2925

def starting_schema
  @starting_schema
end

#workspace_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1WorkspaceConfig

Config to store data store type configuration for workspace data Corresponds to the JSON property workspaceConfig



2930
2931
2932
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2930

def workspace_config
  @workspace_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2937
2938
2939
2940
2941
2942
2943
2944
2945
2946
2947
2948
2949
2950
2951
2952
2953
2954
2955
2956
2957
2958
2959
2960
2961
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 2937

def update!(**args)
  @acl_enabled = args[:acl_enabled] if args.key?(:acl_enabled)
  @advanced_site_search_config = args[:advanced_site_search_config] if args.key?(:advanced_site_search_config)
  @billing_estimation = args[:billing_estimation] if args.key?(:billing_estimation)
  @cmek_config = args[:cmek_config] if args.key?(:cmek_config)
  @configurable_billing_approach = args[:configurable_billing_approach] if args.key?(:configurable_billing_approach)
  @configurable_billing_approach_update_time = args[:configurable_billing_approach_update_time] if args.key?(:configurable_billing_approach_update_time)
  @content_config = args[:content_config] if args.key?(:content_config)
  @create_time = args[:create_time] if args.key?(:create_time)
  @default_schema_id = args[:default_schema_id] if args.key?(:default_schema_id)
  @display_name = args[:display_name] if args.key?(:display_name)
  @document_processing_config = args[:document_processing_config] if args.key?(:document_processing_config)
  @federated_search_config = args[:federated_search_config] if args.key?(:federated_search_config)
  @healthcare_fhir_config = args[:healthcare_fhir_config] if args.key?(:healthcare_fhir_config)
  @identity_mapping_store = args[:identity_mapping_store] if args.key?(:identity_mapping_store)
  @industry_vertical = args[:industry_vertical] if args.key?(:industry_vertical)
  @is_infobot_faq_data_store = args[:is_infobot_faq_data_store] if args.key?(:is_infobot_faq_data_store)
  @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name)
  @name = args[:name] if args.key?(:name)
  @natural_language_query_understanding_config = args[:natural_language_query_understanding_config] if args.key?(:natural_language_query_understanding_config)
  @serving_config_data_store = args[:serving_config_data_store] if args.key?(:serving_config_data_store)
  @solution_types = args[:solution_types] if args.key?(:solution_types)
  @starting_schema = args[:starting_schema] if args.key?(:starting_schema)
  @workspace_config = args[:workspace_config] if args.key?(:workspace_config)
end