Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1DataStoreBillingEstimation
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1DataStoreBillingEstimation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Estimation of data size per data store.
Instance Attribute Summary collapse
-
#structured_data_size ⇒ Fixnum
Data size for structured data in terms of bytes.
-
#structured_data_update_time ⇒ String
Last updated timestamp for structured data.
-
#unstructured_data_size ⇒ Fixnum
Data size for unstructured data in terms of bytes.
-
#unstructured_data_update_time ⇒ String
Last updated timestamp for unstructured data.
-
#website_data_size ⇒ Fixnum
Data size for websites in terms of bytes.
-
#website_data_update_time ⇒ String
Last updated timestamp for websites.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1DataStoreBillingEstimation
constructor
A new instance of GoogleCloudDiscoveryengineV1DataStoreBillingEstimation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1DataStoreBillingEstimation
Returns a new instance of GoogleCloudDiscoveryengineV1DataStoreBillingEstimation.
3075 3076 3077 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3075 def initialize(**args) update!(**args) end |
Instance Attribute Details
#structured_data_size ⇒ Fixnum
Data size for structured data in terms of bytes.
Corresponds to the JSON property structuredDataSize
3048 3049 3050 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3048 def structured_data_size @structured_data_size end |
#structured_data_update_time ⇒ String
Last updated timestamp for structured data.
Corresponds to the JSON property structuredDataUpdateTime
3053 3054 3055 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3053 def structured_data_update_time @structured_data_update_time end |
#unstructured_data_size ⇒ Fixnum
Data size for unstructured data in terms of bytes.
Corresponds to the JSON property unstructuredDataSize
3058 3059 3060 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3058 def unstructured_data_size @unstructured_data_size end |
#unstructured_data_update_time ⇒ String
Last updated timestamp for unstructured data.
Corresponds to the JSON property unstructuredDataUpdateTime
3063 3064 3065 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3063 def unstructured_data_update_time @unstructured_data_update_time end |
#website_data_size ⇒ Fixnum
Data size for websites in terms of bytes.
Corresponds to the JSON property websiteDataSize
3068 3069 3070 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3068 def website_data_size @website_data_size end |
#website_data_update_time ⇒ String
Last updated timestamp for websites.
Corresponds to the JSON property websiteDataUpdateTime
3073 3074 3075 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3073 def website_data_update_time @website_data_update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3080 3081 3082 3083 3084 3085 3086 3087 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3080 def update!(**args) @structured_data_size = args[:structured_data_size] if args.key?(:structured_data_size) @structured_data_update_time = args[:structured_data_update_time] if args.key?(:structured_data_update_time) @unstructured_data_size = args[:unstructured_data_size] if args.key?(:unstructured_data_size) @unstructured_data_update_time = args[:unstructured_data_update_time] if args.key?(:unstructured_data_update_time) @website_data_size = args[:website_data_size] if args.key?(:website_data_size) @website_data_update_time = args[:website_data_update_time] if args.key?(:website_data_update_time) end |