Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1DataStoreFederatedSearchConfigAlloyDbConfigAlloyDbConnectionConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Configuration for connecting to AlloyDB.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1DataStoreFederatedSearchConfigAlloyDbConfigAlloyDbConnectionConfig

Returns a new instance of GoogleCloudDiscoveryengineV1DataStoreFederatedSearchConfigAlloyDbConfigAlloyDbConnectionConfig.



3157
3158
3159
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3157

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auth_modeString

Optional. Auth mode. Corresponds to the JSON property authMode

Returns:

  • (String)


3125
3126
3127
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3125

def auth_mode
  @auth_mode
end

#databaseString

Required. The AlloyDB database to connect to. Corresponds to the JSON property database

Returns:

  • (String)


3130
3131
3132
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3130

def database
  @database
end

#enable_psvsBoolean Also known as: enable_psvs?

Optional. If true, enable PSVS for AlloyDB. Corresponds to the JSON property enablePsvs

Returns:

  • (Boolean)


3135
3136
3137
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3135

def enable_psvs
  @enable_psvs
end

#instanceString

Required. The AlloyDB instance to connect to. Corresponds to the JSON property instance

Returns:

  • (String)


3141
3142
3143
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3141

def instance
  @instance
end

#passwordString

Required. Database password. If auth_mode = END_USER_ACCOUNT, it can be unset. In that case, the password will be inferred on the AlloyDB side, based on the authenticated user. Corresponds to the JSON property password

Returns:

  • (String)


3148
3149
3150
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3148

def password
  @password
end

#userString

Required. Database user. If auth_mode = END_USER_ACCOUNT, it can be unset. In that case, the user will be inferred on the AlloyDB side, based on the authenticated user. Corresponds to the JSON property user

Returns:

  • (String)


3155
3156
3157
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3155

def user
  @user
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3162
3163
3164
3165
3166
3167
3168
3169
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3162

def update!(**args)
  @auth_mode = args[:auth_mode] if args.key?(:auth_mode)
  @database = args[:database] if args.key?(:database)
  @enable_psvs = args[:enable_psvs] if args.key?(:enable_psvs)
  @instance = args[:instance] if args.key?(:instance)
  @password = args[:password] if args.key?(:password)
  @user = args[:user] if args.key?(:user)
end