Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1DataStoreFederatedSearchConfigAlloyDbConfigAlloyDbConnectionConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Configuration for connecting to AlloyDB.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1DataStoreFederatedSearchConfigAlloyDbConfigAlloyDbConnectionConfig

Returns a new instance of GoogleCloudDiscoveryengineV1DataStoreFederatedSearchConfigAlloyDbConfigAlloyDbConnectionConfig.



3135
3136
3137
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3135

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auth_modeString

Optional. Auth mode. Corresponds to the JSON property authMode

Returns:

  • (String)


3103
3104
3105
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3103

def auth_mode
  @auth_mode
end

#databaseString

Required. The AlloyDB database to connect to. Corresponds to the JSON property database

Returns:

  • (String)


3108
3109
3110
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3108

def database
  @database
end

#enable_psvsBoolean Also known as: enable_psvs?

Optional. If true, enable PSVS for AlloyDB. Corresponds to the JSON property enablePsvs

Returns:

  • (Boolean)


3113
3114
3115
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3113

def enable_psvs
  @enable_psvs
end

#instanceString

Required. The AlloyDB instance to connect to. Corresponds to the JSON property instance

Returns:

  • (String)


3119
3120
3121
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3119

def instance
  @instance
end

#passwordString

Required. Database password. If auth_mode = END_USER_ACCOUNT, it can be unset. In that case, the password will be inferred on the AlloyDB side, based on the authenticated user. Corresponds to the JSON property password

Returns:

  • (String)


3126
3127
3128
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3126

def password
  @password
end

#userString

Required. Database user. If auth_mode = END_USER_ACCOUNT, it can be unset. In that case, the user will be inferred on the AlloyDB side, based on the authenticated user. Corresponds to the JSON property user

Returns:

  • (String)


3133
3134
3135
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3133

def user
  @user
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3140
3141
3142
3143
3144
3145
3146
3147
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3140

def update!(**args)
  @auth_mode = args[:auth_mode] if args.key?(:auth_mode)
  @database = args[:database] if args.key?(:database)
  @enable_psvs = args[:enable_psvs] if args.key?(:enable_psvs)
  @instance = args[:instance] if args.key?(:instance)
  @password = args[:password] if args.key?(:password)
  @user = args[:user] if args.key?(:user)
end