Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1DestinationConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Defines target endpoints used to connect to third-party sources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1DestinationConfig

Returns a new instance of GoogleCloudDiscoveryengineV1DestinationConfig.



3486
3487
3488
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3486

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destinationsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1DestinationConfigDestination>

Optional. The destinations for the corresponding key. Corresponds to the JSON property destinations



3468
3469
3470
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3468

def destinations
  @destinations
end

#json_paramsString

Additional parameters for this destination config in json string format. Corresponds to the JSON property jsonParams

Returns:

  • (String)


3473
3474
3475
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3473

def json_params
  @json_params
end

#keyString

Optional. Unique destination identifier that is supported by the connector. Corresponds to the JSON property key

Returns:

  • (String)


3478
3479
3480
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3478

def key
  @key
end

#paramsHash<String,Object>

Optional. Additional parameters for this destination config in structured json format. Corresponds to the JSON property params

Returns:

  • (Hash<String,Object>)


3484
3485
3486
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3484

def params
  @params
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3491
3492
3493
3494
3495
3496
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3491

def update!(**args)
  @destinations = args[:destinations] if args.key?(:destinations)
  @json_params = args[:json_params] if args.key?(:json_params)
  @key = args[:key] if args.key?(:key)
  @params = args[:params] if args.key?(:params)
end