Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1DestinationConfig
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1DestinationConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Defines target endpoints used to connect to third-party sources.
Instance Attribute Summary collapse
-
#destinations ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1DestinationConfigDestination>
Optional.
-
#json_params ⇒ String
Additional parameters for this destination config in json string format.
-
#key ⇒ String
Optional.
-
#params ⇒ Hash<String,Object>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1DestinationConfig
constructor
A new instance of GoogleCloudDiscoveryengineV1DestinationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1DestinationConfig
Returns a new instance of GoogleCloudDiscoveryengineV1DestinationConfig.
3474 3475 3476 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3474 def initialize(**args) update!(**args) end |
Instance Attribute Details
#destinations ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1DestinationConfigDestination>
Optional. The destinations for the corresponding key.
Corresponds to the JSON property destinations
3456 3457 3458 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3456 def destinations @destinations end |
#json_params ⇒ String
Additional parameters for this destination config in json string format.
Corresponds to the JSON property jsonParams
3461 3462 3463 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3461 def json_params @json_params end |
#key ⇒ String
Optional. Unique destination identifier that is supported by the connector.
Corresponds to the JSON property key
3466 3467 3468 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3466 def key @key end |
#params ⇒ Hash<String,Object>
Optional. Additional parameters for this destination config in structured json
format.
Corresponds to the JSON property params
3472 3473 3474 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3472 def params @params end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3479 3480 3481 3482 3483 3484 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3479 def update!(**args) @destinations = args[:destinations] if args.key?(:destinations) @json_params = args[:json_params] if args.key?(:json_params) @key = args[:key] if args.key?(:key) @params = args[:params] if args.key?(:params) end |