Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1DestinationConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Defines target endpoints used to connect to third-party sources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1DestinationConfig

Returns a new instance of GoogleCloudDiscoveryengineV1DestinationConfig.



3464
3465
3466
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3464

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destinationsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1DestinationConfigDestination>

Optional. The destinations for the corresponding key. Corresponds to the JSON property destinations



3446
3447
3448
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3446

def destinations
  @destinations
end

#json_paramsString

Additional parameters for this destination config in json string format. Corresponds to the JSON property jsonParams

Returns:

  • (String)


3451
3452
3453
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3451

def json_params
  @json_params
end

#keyString

Optional. Unique destination identifier that is supported by the connector. Corresponds to the JSON property key

Returns:

  • (String)


3456
3457
3458
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3456

def key
  @key
end

#paramsHash<String,Object>

Optional. Additional parameters for this destination config in structured json format. Corresponds to the JSON property params

Returns:

  • (Hash<String,Object>)


3462
3463
3464
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3462

def params
  @params
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3469
3470
3471
3472
3473
3474
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3469

def update!(**args)
  @destinations = args[:destinations] if args.key?(:destinations)
  @json_params = args[:json_params] if args.key?(:json_params)
  @key = args[:key] if args.key?(:key)
  @params = args[:params] if args.key?(:params)
end