Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1Engine
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1Engine
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Metadata that describes the training and serving parameters of an Engine.
Instance Attribute Summary collapse
-
#agent_gateway_setting ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1AgentGatewaySetting
Agent Gateway setting, which may be attached to Gemini Enterprise resources for egress control of Gemini Enterprise agents to agents and tools outside of Gemini Enterprise.
-
#app_type ⇒ String
Optional.
-
#associated_agent_registry ⇒ String
Output only.
-
#chat_engine_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1EngineChatEngineConfig
Configurations for a Chat Engine.
-
#chat_engine_metadata ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1EngineChatEngineMetadata
Additional information of a Chat Engine.
-
#cmek_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1CmekConfig
Configurations used to enable CMEK data encryption with Cloud KMS keys.
-
#common_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1EngineCommonConfig
Common configurations for an Engine.
-
#configurable_billing_approach ⇒ String
Optional.
-
#connector_tenant_info ⇒ Hash<String,String>
Optional.
-
#create_time ⇒ String
Output only.
-
#data_store_ids ⇒ Array<String>
Optional.
-
#disable_analytics ⇒ Boolean
(also: #disable_analytics?)
Optional.
-
#display_name ⇒ String
Required.
-
#features ⇒ Hash<String,String>
Optional.
-
#industry_vertical ⇒ String
Optional.
-
#knowledge_graph_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1EngineKnowledgeGraphConfig
Configuration message for the Knowledge Graph.
-
#marketplace_agent_visibility ⇒ String
Optional.
-
#media_recommendation_engine_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1EngineMediaRecommendationEngineConfig
Additional config specs for a Media Recommendation engine.
-
#model_configs ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Immutable.
-
#observability_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ObservabilityConfig
Observability config for a resource.
-
#procurement_contact_emails ⇒ Array<String>
Optional.
-
#search_engine_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1EngineSearchEngineConfig
Configurations for a Search Engine.
-
#solution_type ⇒ String
Required.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1Engine
constructor
A new instance of GoogleCloudDiscoveryengineV1Engine.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1Engine
Returns a new instance of GoogleCloudDiscoveryengineV1Engine.
4104 4105 4106 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4104 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_gateway_setting ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1AgentGatewaySetting
Agent Gateway setting, which may be attached to Gemini Enterprise resources
for egress control of Gemini Enterprise agents to agents and tools outside of
Gemini Enterprise.
Corresponds to the JSON property agentGatewaySetting
3945 3946 3947 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3945 def agent_gateway_setting @agent_gateway_setting end |
#app_type ⇒ String
Optional. Immutable. This the application type which this engine resource
represents. NOTE: this is a new concept independ of existing industry vertical
or solution type.
Corresponds to the JSON property appType
3952 3953 3954 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3952 def app_type @app_type end |
#associated_agent_registry ⇒ String
Output only. The Agent registry containing the agents, MCP servers and tools
associated with this engine. Derived server-side from the linked Agent Gateway'
s registry.
Corresponds to the JSON property associatedAgentRegistry
3959 3960 3961 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3959 def associated_agent_registry @associated_agent_registry end |
#chat_engine_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1EngineChatEngineConfig
Configurations for a Chat Engine.
Corresponds to the JSON property chatEngineConfig
3964 3965 3966 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3964 def chat_engine_config @chat_engine_config end |
#chat_engine_metadata ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1EngineChatEngineMetadata
Additional information of a Chat Engine. Fields in this message are output
only.
Corresponds to the JSON property chatEngineMetadata
3970 3971 3972 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3970 def @chat_engine_metadata end |
#cmek_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1CmekConfig
Configurations used to enable CMEK data encryption with Cloud KMS keys.
Corresponds to the JSON property cmekConfig
3975 3976 3977 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3975 def cmek_config @cmek_config end |
#common_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1EngineCommonConfig
Common configurations for an Engine.
Corresponds to the JSON property commonConfig
3980 3981 3982 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3980 def common_config @common_config end |
#configurable_billing_approach ⇒ String
Optional. Configuration for configurable billing approach.
Corresponds to the JSON property configurableBillingApproach
3985 3986 3987 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3985 def configurable_billing_approach @configurable_billing_approach end |
#connector_tenant_info ⇒ Hash<String,String>
Optional. Maps a connector ID (e.g., "hybrid-github", "shopify") to tenant-
specific information required for that connector. The structure of the tenant
information string is connector-dependent.
Corresponds to the JSON property connectorTenantInfo
3992 3993 3994 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3992 def connector_tenant_info @connector_tenant_info end |
#create_time ⇒ String
Output only. Timestamp the Recommendation Engine was created at.
Corresponds to the JSON property createTime
3997 3998 3999 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 3997 def create_time @create_time end |
#data_store_ids ⇒ Array<String>
Optional. The data stores associated with this engine. For
SOLUTION_TYPE_SEARCH and SOLUTION_TYPE_RECOMMENDATION type of engines, they
can only associate with at most one data store. If solution_type is
SOLUTION_TYPE_CHAT, multiple DataStores in the same Collection can be
associated here. Note that when used in CreateEngineRequest, one DataStore id
must be provided as the system will use it for necessary initializations.
Corresponds to the JSON property dataStoreIds
4007 4008 4009 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4007 def data_store_ids @data_store_ids end |
#disable_analytics ⇒ Boolean Also known as: disable_analytics?
Optional. Whether to disable analytics for searches performed on this engine.
Corresponds to the JSON property disableAnalytics
4012 4013 4014 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4012 def disable_analytics @disable_analytics end |
#display_name ⇒ String
Required. The display name of the engine. Should be human readable. UTF-8
encoded string with limit of 1024 characters.
Corresponds to the JSON property displayName
4019 4020 4021 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4019 def display_name @display_name end |
#features ⇒ Hash<String,String>
Optional. Feature config for the engine to opt in or opt out of features.
Supported keys: * *: all features, if it's present, all other feature state
settings are ignored. * agent-gallery * no-code-agent-builder * prompt-
gallery * model-selector * notebook-lm * people-search * people-search-
org-chart * bi-directional-audio * feedback * session-sharing *
personalization-memory * personalization-suggested-highlights * mobile-app-
access * disable-agent-sharing * disable-image-generation * disable-
video-generation * disable-onedrive-upload * disable-talk-to-content *
disable-google-drive-upload * disable-welcome-emails * disable-canvas *
canvas-workspace * disable-skills * disable-projects * enable-end-user-
sharing-with-groups * single-agent-orchestration * multi-agent-
orchestration * cross-product-intelligence
Corresponds to the JSON property features
4035 4036 4037 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4035 def features @features end |
#industry_vertical ⇒ String
Optional. The industry vertical that the engine registers. The restriction of
the Engine industry vertical is based on DataStore: Vertical on Engine has to
match vertical of the DataStore linked to the engine.
Corresponds to the JSON property industryVertical
4042 4043 4044 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4042 def industry_vertical @industry_vertical end |
#knowledge_graph_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1EngineKnowledgeGraphConfig
Configuration message for the Knowledge Graph.
Corresponds to the JSON property knowledgeGraphConfig
4047 4048 4049 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4047 def knowledge_graph_config @knowledge_graph_config end |
#marketplace_agent_visibility ⇒ String
Optional. The visibility of marketplace agents in the agent gallery.
Corresponds to the JSON property marketplaceAgentVisibility
4052 4053 4054 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4052 def marketplace_agent_visibility @marketplace_agent_visibility end |
#media_recommendation_engine_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1EngineMediaRecommendationEngineConfig
Additional config specs for a Media Recommendation engine.
Corresponds to the JSON property mediaRecommendationEngineConfig
4057 4058 4059 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4057 def media_recommendation_engine_config @media_recommendation_engine_config end |
#model_configs ⇒ Hash<String,String>
Optional. Maps a model name to its specific configuration for this engine.
This allows admin users to turn on/off individual models. This only stores
models whose states are overridden by the admin. When the state is unspecified,
or model_configs is empty for this model, the system will decide if this
model should be available or not based on the default configuration. For
example, a preview model should be disabled by default if the admin has not
chosen to enable it.
Corresponds to the JSON property modelConfigs
4068 4069 4070 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4068 def model_configs @model_configs end |
#name ⇒ String
Immutable. Identifier. The fully qualified resource name of the engine. This
field must be a UTF-8 encoded string with a length limit of 1024 characters.
Format: projects/project/locations/location/collections/collection/
engines/engine`engine should be 1-63 characters, and valid characters are /
a-z0-9*/. Otherwise, an INVALID_ARGUMENT error is returned.
Corresponds to the JSON propertyname`
4077 4078 4079 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4077 def name @name end |
#observability_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ObservabilityConfig
Observability config for a resource.
Corresponds to the JSON property observabilityConfig
4082 4083 4084 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4082 def observability_config @observability_config end |
#procurement_contact_emails ⇒ Array<String>
Optional. The emails of the procurement contacts.
Corresponds to the JSON property procurementContactEmails
4087 4088 4089 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4087 def procurement_contact_emails @procurement_contact_emails end |
#search_engine_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1EngineSearchEngineConfig
Configurations for a Search Engine.
Corresponds to the JSON property searchEngineConfig
4092 4093 4094 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4092 def search_engine_config @search_engine_config end |
#solution_type ⇒ String
Required. The solutions of the engine.
Corresponds to the JSON property solutionType
4097 4098 4099 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4097 def solution_type @solution_type end |
#update_time ⇒ String
Output only. Timestamp the Recommendation Engine was last updated.
Corresponds to the JSON property updateTime
4102 4103 4104 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4102 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4109 4110 4111 4112 4113 4114 4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4109 def update!(**args) @agent_gateway_setting = args[:agent_gateway_setting] if args.key?(:agent_gateway_setting) @app_type = args[:app_type] if args.key?(:app_type) @associated_agent_registry = args[:associated_agent_registry] if args.key?(:associated_agent_registry) @chat_engine_config = args[:chat_engine_config] if args.key?(:chat_engine_config) @chat_engine_metadata = args[:chat_engine_metadata] if args.key?(:chat_engine_metadata) @cmek_config = args[:cmek_config] if args.key?(:cmek_config) @common_config = args[:common_config] if args.key?(:common_config) @configurable_billing_approach = args[:configurable_billing_approach] if args.key?(:configurable_billing_approach) @connector_tenant_info = args[:connector_tenant_info] if args.key?(:connector_tenant_info) @create_time = args[:create_time] if args.key?(:create_time) @data_store_ids = args[:data_store_ids] if args.key?(:data_store_ids) @disable_analytics = args[:disable_analytics] if args.key?(:disable_analytics) @display_name = args[:display_name] if args.key?(:display_name) @features = args[:features] if args.key?(:features) @industry_vertical = args[:industry_vertical] if args.key?(:industry_vertical) @knowledge_graph_config = args[:knowledge_graph_config] if args.key?(:knowledge_graph_config) @marketplace_agent_visibility = args[:marketplace_agent_visibility] if args.key?(:marketplace_agent_visibility) @media_recommendation_engine_config = args[:media_recommendation_engine_config] if args.key?(:media_recommendation_engine_config) @model_configs = args[:model_configs] if args.key?(:model_configs) @name = args[:name] if args.key?(:name) @observability_config = args[:observability_config] if args.key?(:observability_config) @procurement_contact_emails = args[:procurement_contact_emails] if args.key?(:procurement_contact_emails) @search_engine_config = args[:search_engine_config] if args.key?(:search_engine_config) @solution_type = args[:solution_type] if args.key?(:solution_type) @update_time = args[:update_time] if args.key?(:update_time) end |