Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1EngineChatEngineConfigAgentCreationConfig
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1EngineChatEngineConfigAgentCreationConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Configurations for generating a Dialogflow agent. Note that these configurations are one-time consumed by and passed to Dialogflow service. It means they cannot be retrieved using EngineService.GetEngine or EngineService. ListEngines API after engine creation.
Instance Attribute Summary collapse
-
#business ⇒ String
Name of the company, organization or other entity that the agent represents.
-
#default_language_code ⇒ String
Required.
-
#location ⇒ String
Agent location for Agent creation, supported values: global/us/eu.
-
#time_zone ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1EngineChatEngineConfigAgentCreationConfig
constructor
A new instance of GoogleCloudDiscoveryengineV1EngineChatEngineConfigAgentCreationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1EngineChatEngineConfigAgentCreationConfig
Returns a new instance of GoogleCloudDiscoveryengineV1EngineChatEngineConfigAgentCreationConfig.
4163 4164 4165 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4163 def initialize(**args) update!(**args) end |
Instance Attribute Details
#business ⇒ String
Name of the company, organization or other entity that the agent represents.
Used for knowledge connector LLM prompt and for knowledge search.
Corresponds to the JSON property business
4141 4142 4143 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4141 def business @business end |
#default_language_code ⇒ String
Required. The default language of the agent as a language tag. See Language
Support for a
list of the currently supported language codes.
Corresponds to the JSON property defaultLanguageCode
4148 4149 4150 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4148 def default_language_code @default_language_code end |
#location ⇒ String
Agent location for Agent creation, supported values: global/us/eu. If not
provided, us Engine will create Agent using us-central-1 by default; eu Engine
will create Agent using eu-west-1 by default.
Corresponds to the JSON property location
4155 4156 4157 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4155 def location @location end |
#time_zone ⇒ String
Required. The time zone of the agent from the time zone database, e.g., America/New_York, Europe/Paris.
Corresponds to the JSON property timeZone
4161 4162 4163 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4161 def time_zone @time_zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4168 4169 4170 4171 4172 4173 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4168 def update!(**args) @business = args[:business] if args.key?(:business) @default_language_code = args[:default_language_code] if args.key?(:default_language_code) @location = args[:location] if args.key?(:location) @time_zone = args[:time_zone] if args.key?(:time_zone) end |