Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1EngineCommonConfig
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1EngineCommonConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Common configurations for an Engine.
Instance Attribute Summary collapse
-
#company_name ⇒ String
The name of the company, business or entity that is associated with the engine.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1EngineCommonConfig
constructor
A new instance of GoogleCloudDiscoveryengineV1EngineCommonConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1EngineCommonConfig
Returns a new instance of GoogleCloudDiscoveryengineV1EngineCommonConfig.
4195 4196 4197 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4195 def initialize(**args) update!(**args) end |
Instance Attribute Details
#company_name ⇒ String
The name of the company, business or entity that is associated with the engine.
Setting this may help improve LLM related features.
Corresponds to the JSON property companyName
4193 4194 4195 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4193 def company_name @company_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4200 4201 4202 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4200 def update!(**args) @company_name = args[:company_name] if args.key?(:company_name) end |