Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1EngineMediaRecommendationEngineConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Additional config specs for a Media Recommendation engine.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1EngineMediaRecommendationEngineConfig

Returns a new instance of GoogleCloudDiscoveryengineV1EngineMediaRecommendationEngineConfig.



4320
4321
4322
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4320

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#engine_features_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1EngineMediaRecommendationEngineConfigEngineFeaturesConfig

More feature configs of the selected engine type. Corresponds to the JSON property engineFeaturesConfig



4286
4287
4288
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4286

def engine_features_config
  @engine_features_config
end

#optimization_objectiveString

The optimization objective. e.g., cvr. This field together with optimization_objective describe engine metadata to use to control engine training and serving. Currently supported values: ctr, cvr. If not specified, we choose default based on engine type. Default depends on type of recommendation: recommended-for-you => ctr others-you-may-like => ctr Corresponds to the JSON property optimizationObjective

Returns:

  • (String)


4295
4296
4297
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4295

def optimization_objective
  @optimization_objective
end

#optimization_objective_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1EngineMediaRecommendationEngineConfigOptimizationObjectiveConfig

Custom threshold for cvr optimization_objective. Corresponds to the JSON property optimizationObjectiveConfig



4300
4301
4302
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4300

def optimization_objective_config
  @optimization_objective_config
end

#training_stateString

The training state that the engine is in (e.g. TRAINING or PAUSED). Since part of the cost of running the service is frequency of training - this can be used to determine when to train engine in order to control cost. If not specified: the default value for CreateEngine method is TRAINING. The default value for UpdateEngine method is to keep the state the same as before. Corresponds to the JSON property trainingState

Returns:

  • (String)


4310
4311
4312
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4310

def training_state
  @training_state
end

#typeString

Required. The type of engine. e.g., recommended-for-you. This field together with optimization_objective describe engine metadata to use to control engine training and serving. Currently supported values: recommended-for-you, others-you-may-like, more-like-this, most-popular-items. Corresponds to the JSON property type

Returns:

  • (String)


4318
4319
4320
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4318

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4325
4326
4327
4328
4329
4330
4331
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4325

def update!(**args)
  @engine_features_config = args[:engine_features_config] if args.key?(:engine_features_config)
  @optimization_objective = args[:optimization_objective] if args.key?(:optimization_objective)
  @optimization_objective_config = args[:optimization_objective_config] if args.key?(:optimization_objective_config)
  @training_state = args[:training_state] if args.key?(:training_state)
  @type = args[:type] if args.key?(:type)
end