Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1EngineSearchEngineConfig
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1EngineSearchEngineConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Configurations for a Search Engine.
Instance Attribute Summary collapse
-
#required_subscription_tier ⇒ String
Optional.
-
#search_add_ons ⇒ Array<String>
The add-on that this search engine enables.
-
#search_tier ⇒ String
The search feature tier of this engine.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1EngineSearchEngineConfig
constructor
A new instance of GoogleCloudDiscoveryengineV1EngineSearchEngineConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1EngineSearchEngineConfig
Returns a new instance of GoogleCloudDiscoveryengineV1EngineSearchEngineConfig.
4485 4486 4487 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4485 def initialize(**args) update!(**args) end |
Instance Attribute Details
#required_subscription_tier ⇒ String
Optional. The required subscription tier of this engine. If the required
subscription tier is search, user with higher license tier like assist can
still access the standalone app associated with this engine. Web grounding
feature is only available on the app if it is set as SubscriptionTier.
SUBSCRIPTION_TIER_SEARCH_AND_ASSISTANT.
Corresponds to the JSON property requiredSubscriptionTier
4471 4472 4473 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4471 def required_subscription_tier @required_subscription_tier end |
#search_add_ons ⇒ Array<String>
The add-on that this search engine enables.
Corresponds to the JSON property searchAddOns
4476 4477 4478 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4476 def search_add_ons @search_add_ons end |
#search_tier ⇒ String
The search feature tier of this engine. Different tiers might have different
pricing. To learn more, check the pricing documentation. Defaults to
SearchTier.SEARCH_TIER_STANDARD if not specified.
Corresponds to the JSON property searchTier
4483 4484 4485 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4483 def search_tier @search_tier end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4490 4491 4492 4493 4494 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4490 def update!(**args) @required_subscription_tier = args[:required_subscription_tier] if args.key?(:required_subscription_tier) @search_add_ons = args[:search_add_ons] if args.key?(:search_add_ons) @search_tier = args[:search_tier] if args.key?(:search_tier) end |