Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ImportCompletionSuggestionsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Response of the CompletionService.ImportCompletionSuggestions method. If the long running operation is done, this message is returned by the google. longrunning.Operations.response field if the operation is successful.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1ImportCompletionSuggestionsResponse

Returns a new instance of GoogleCloudDiscoveryengineV1ImportCompletionSuggestionsResponse.



4767
4768
4769
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4767

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ImportErrorConfig

Configuration of destination for Import related errors. Corresponds to the JSON property errorConfig



4760
4761
4762
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4760

def error_config
  @error_config
end

#error_samplesArray<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>

A sample of errors encountered while processing the request. Corresponds to the JSON property errorSamples



4765
4766
4767
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4765

def error_samples
  @error_samples
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4772
4773
4774
4775
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4772

def update!(**args)
  @error_config = args[:error_config] if args.key?(:error_config)
  @error_samples = args[:error_samples] if args.key?(:error_samples)
end