Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ImportCompletionSuggestionsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Response of the CompletionService.ImportCompletionSuggestions method. If the long running operation is done, this message is returned by the google. longrunning.Operations.response field if the operation is successful.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1ImportCompletionSuggestionsResponse

Returns a new instance of GoogleCloudDiscoveryengineV1ImportCompletionSuggestionsResponse.



4712
4713
4714
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4712

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ImportErrorConfig

Configuration of destination for Import related errors. Corresponds to the JSON property errorConfig



4705
4706
4707
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4705

def error_config
  @error_config
end

#error_samplesArray<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>

A sample of errors encountered while processing the request. Corresponds to the JSON property errorSamples



4710
4711
4712
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4710

def error_samples
  @error_samples
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4717
4718
4719
4720
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4717

def update!(**args)
  @error_config = args[:error_config] if args.key?(:error_config)
  @error_samples = args[:error_samples] if args.key?(:error_samples)
end