Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ImportUserEventsResponse
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ImportUserEventsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Response of the ImportUserEventsRequest. If the long running operation was successful, then this message is returned by the google.longrunning.Operations. response field if the operation was successful.
Instance Attribute Summary collapse
-
#error_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ImportErrorConfig
Configuration of destination for Import related errors.
-
#error_samples ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>
A sample of errors encountered while processing the request.
-
#joined_events_count ⇒ Fixnum
Count of user events imported with complete existing Documents.
-
#unjoined_events_count ⇒ Fixnum
Count of user events imported, but with Document information not found in the existing Branch.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1ImportUserEventsResponse
constructor
A new instance of GoogleCloudDiscoveryengineV1ImportUserEventsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1ImportUserEventsResponse
Returns a new instance of GoogleCloudDiscoveryengineV1ImportUserEventsResponse.
5014 5015 5016 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5014 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ImportErrorConfig
Configuration of destination for Import related errors.
Corresponds to the JSON property errorConfig
4996 4997 4998 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4996 def error_config @error_config end |
#error_samples ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>
A sample of errors encountered while processing the request.
Corresponds to the JSON property errorSamples
5001 5002 5003 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5001 def error_samples @error_samples end |
#joined_events_count ⇒ Fixnum
Count of user events imported with complete existing Documents.
Corresponds to the JSON property joinedEventsCount
5006 5007 5008 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5006 def joined_events_count @joined_events_count end |
#unjoined_events_count ⇒ Fixnum
Count of user events imported, but with Document information not found in the
existing Branch.
Corresponds to the JSON property unjoinedEventsCount
5012 5013 5014 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5012 def unjoined_events_count @unjoined_events_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5019 5020 5021 5022 5023 5024 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5019 def update!(**args) @error_config = args[:error_config] if args.key?(:error_config) @error_samples = args[:error_samples] if args.key?(:error_samples) @joined_events_count = args[:joined_events_count] if args.key?(:joined_events_count) @unjoined_events_count = args[:unjoined_events_count] if args.key?(:unjoined_events_count) end |