Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ImportUserEventsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Response of the ImportUserEventsRequest. If the long running operation was successful, then this message is returned by the google.longrunning.Operations. response field if the operation was successful.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1ImportUserEventsResponse

Returns a new instance of GoogleCloudDiscoveryengineV1ImportUserEventsResponse.



4947
4948
4949
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4947

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ImportErrorConfig

Configuration of destination for Import related errors. Corresponds to the JSON property errorConfig



4929
4930
4931
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4929

def error_config
  @error_config
end

#error_samplesArray<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>

A sample of errors encountered while processing the request. Corresponds to the JSON property errorSamples



4934
4935
4936
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4934

def error_samples
  @error_samples
end

#joined_events_countFixnum

Count of user events imported with complete existing Documents. Corresponds to the JSON property joinedEventsCount

Returns:

  • (Fixnum)


4939
4940
4941
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4939

def joined_events_count
  @joined_events_count
end

#unjoined_events_countFixnum

Count of user events imported, but with Document information not found in the existing Branch. Corresponds to the JSON property unjoinedEventsCount

Returns:

  • (Fixnum)


4945
4946
4947
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4945

def unjoined_events_count
  @unjoined_events_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4952
4953
4954
4955
4956
4957
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4952

def update!(**args)
  @error_config = args[:error_config] if args.key?(:error_config)
  @error_samples = args[:error_samples] if args.key?(:error_samples)
  @joined_events_count = args[:joined_events_count] if args.key?(:joined_events_count)
  @unjoined_events_count = args[:unjoined_events_count] if args.key?(:unjoined_events_count)
end