Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1LicenseConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Information about users' licenses.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1LicenseConfig

Returns a new instance of GoogleCloudDiscoveryengineV1LicenseConfig.



5054
5055
5056
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5054

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_renewBoolean Also known as: auto_renew?

Optional. Whether the license config should be auto renewed when it reaches the end date. Corresponds to the JSON property autoRenew

Returns:

  • (Boolean)


4968
4969
4970
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4968

def auto_renew
  @auto_renew
end

#early_terminatedBoolean Also known as: early_terminated?

Output only. Indication of whether the subscription is terminated earlier than the expiration date. This is usually terminated by pipeline once the subscription gets terminated from subsv3. Corresponds to the JSON property earlyTerminated

Returns:

  • (Boolean)


4976
4977
4978
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4976

def early_terminated
  @early_terminated
end

#early_termination_dateGoogle::Apis::DiscoveryengineV1beta::GoogleTypeDate

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property earlyTerminationDate



4989
4990
4991
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4989

def early_termination_date
  @early_termination_date
end

#end_dateGoogle::Apis::DiscoveryengineV1beta::GoogleTypeDate

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property endDate



5001
5002
5003
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5001

def end_date
  @end_date
end

#free_trialBoolean Also known as: free_trial?

Optional. Whether the license config is for free trial. Corresponds to the JSON property freeTrial

Returns:

  • (Boolean)


5006
5007
5008
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5006

def free_trial
  @free_trial
end

#gemini_bundleBoolean Also known as: gemini_bundle?

Output only. Whether the license config is for Gemini bundle. Corresponds to the JSON property geminiBundle

Returns:

  • (Boolean)


5012
5013
5014
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5012

def gemini_bundle
  @gemini_bundle
end

#license_countFixnum

Required. Number of licenses purchased. Corresponds to the JSON property licenseCount

Returns:

  • (Fixnum)


5018
5019
5020
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5018

def license_count
  @license_count
end

#nameString

Immutable. Identifier. The fully qualified resource name of the license config. Format: projects/project/locations/location/licenseConfigs/ license_config` Corresponds to the JSON propertyname`

Returns:

  • (String)


5025
5026
5027
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5025

def name
  @name
end

#start_dateGoogle::Apis::DiscoveryengineV1beta::GoogleTypeDate

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property startDate



5037
5038
5039
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5037

def start_date
  @start_date
end

#stateString

Output only. The state of the license config. Corresponds to the JSON property state

Returns:

  • (String)


5042
5043
5044
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5042

def state
  @state
end

#subscription_termString

Required. Subscription term. Corresponds to the JSON property subscriptionTerm

Returns:

  • (String)


5047
5048
5049
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5047

def subscription_term
  @subscription_term
end

#subscription_tierString

Required. Subscription tier information for the license config. Corresponds to the JSON property subscriptionTier

Returns:

  • (String)


5052
5053
5054
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5052

def subscription_tier
  @subscription_tier
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5059
5060
5061
5062
5063
5064
5065
5066
5067
5068
5069
5070
5071
5072
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5059

def update!(**args)
  @auto_renew = args[:auto_renew] if args.key?(:auto_renew)
  @early_terminated = args[:early_terminated] if args.key?(:early_terminated)
  @early_termination_date = args[:early_termination_date] if args.key?(:early_termination_date)
  @end_date = args[:end_date] if args.key?(:end_date)
  @free_trial = args[:free_trial] if args.key?(:free_trial)
  @gemini_bundle = args[:gemini_bundle] if args.key?(:gemini_bundle)
  @license_count = args[:license_count] if args.key?(:license_count)
  @name = args[:name] if args.key?(:name)
  @start_date = args[:start_date] if args.key?(:start_date)
  @state = args[:state] if args.key?(:state)
  @subscription_term = args[:subscription_term] if args.key?(:subscription_term)
  @subscription_tier = args[:subscription_tier] if args.key?(:subscription_tier)
end