Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1LicenseConfig
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1LicenseConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Information about users' licenses.
Instance Attribute Summary collapse
-
#auto_renew ⇒ Boolean
(also: #auto_renew?)
Optional.
-
#early_terminated ⇒ Boolean
(also: #early_terminated?)
Output only.
-
#early_termination_date ⇒ Google::Apis::DiscoveryengineV1beta::GoogleTypeDate
Represents a whole or partial calendar date, such as a birthday.
-
#end_date ⇒ Google::Apis::DiscoveryengineV1beta::GoogleTypeDate
Represents a whole or partial calendar date, such as a birthday.
-
#free_trial ⇒ Boolean
(also: #free_trial?)
Optional.
-
#gemini_bundle ⇒ Boolean
(also: #gemini_bundle?)
Output only.
-
#license_count ⇒ Fixnum
Required.
-
#name ⇒ String
Immutable.
-
#start_date ⇒ Google::Apis::DiscoveryengineV1beta::GoogleTypeDate
Represents a whole or partial calendar date, such as a birthday.
-
#state ⇒ String
Output only.
-
#subscription_term ⇒ String
Required.
-
#subscription_tier ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1LicenseConfig
constructor
A new instance of GoogleCloudDiscoveryengineV1LicenseConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1LicenseConfig
Returns a new instance of GoogleCloudDiscoveryengineV1LicenseConfig.
5043 5044 5045 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5043 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_renew ⇒ Boolean Also known as: auto_renew?
Optional. Whether the license config should be auto renewed when it reaches
the end date.
Corresponds to the JSON property autoRenew
4957 4958 4959 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4957 def auto_renew @auto_renew end |
#early_terminated ⇒ Boolean Also known as: early_terminated?
Output only. Indication of whether the subscription is terminated earlier than
the expiration date. This is usually terminated by pipeline once the
subscription gets terminated from subsv3.
Corresponds to the JSON property earlyTerminated
4965 4966 4967 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4965 def early_terminated @early_terminated end |
#early_termination_date ⇒ Google::Apis::DiscoveryengineV1beta::GoogleTypeDate
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property earlyTerminationDate
4978 4979 4980 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4978 def early_termination_date @early_termination_date end |
#end_date ⇒ Google::Apis::DiscoveryengineV1beta::GoogleTypeDate
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property endDate
4990 4991 4992 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4990 def end_date @end_date end |
#free_trial ⇒ Boolean Also known as: free_trial?
Optional. Whether the license config is for free trial.
Corresponds to the JSON property freeTrial
4995 4996 4997 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 4995 def free_trial @free_trial end |
#gemini_bundle ⇒ Boolean Also known as: gemini_bundle?
Output only. Whether the license config is for Gemini bundle.
Corresponds to the JSON property geminiBundle
5001 5002 5003 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5001 def gemini_bundle @gemini_bundle end |
#license_count ⇒ Fixnum
Required. Number of licenses purchased.
Corresponds to the JSON property licenseCount
5007 5008 5009 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5007 def license_count @license_count end |
#name ⇒ String
Immutable. Identifier. The fully qualified resource name of the license config.
Format: projects/project/locations/location/licenseConfigs/
license_config`
Corresponds to the JSON propertyname`
5014 5015 5016 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5014 def name @name end |
#start_date ⇒ Google::Apis::DiscoveryengineV1beta::GoogleTypeDate
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property startDate
5026 5027 5028 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5026 def start_date @start_date end |
#state ⇒ String
Output only. The state of the license config.
Corresponds to the JSON property state
5031 5032 5033 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5031 def state @state end |
#subscription_term ⇒ String
Required. Subscription term.
Corresponds to the JSON property subscriptionTerm
5036 5037 5038 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5036 def subscription_term @subscription_term end |
#subscription_tier ⇒ String
Required. Subscription tier information for the license config.
Corresponds to the JSON property subscriptionTier
5041 5042 5043 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5041 def subscription_tier @subscription_tier end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5048 5049 5050 5051 5052 5053 5054 5055 5056 5057 5058 5059 5060 5061 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5048 def update!(**args) @auto_renew = args[:auto_renew] if args.key?(:auto_renew) @early_terminated = args[:early_terminated] if args.key?(:early_terminated) @early_termination_date = args[:early_termination_date] if args.key?(:early_termination_date) @end_date = args[:end_date] if args.key?(:end_date) @free_trial = args[:free_trial] if args.key?(:free_trial) @gemini_bundle = args[:gemini_bundle] if args.key?(:gemini_bundle) @license_count = args[:license_count] if args.key?(:license_count) @name = args[:name] if args.key?(:name) @start_date = args[:start_date] if args.key?(:start_date) @state = args[:state] if args.key?(:state) @subscription_term = args[:subscription_term] if args.key?(:subscription_term) @subscription_tier = args[:subscription_tier] if args.key?(:subscription_tier) end |