Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1Project

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Metadata and configurations for a Google Cloud project in the service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1Project

Returns a new instance of GoogleCloudDiscoveryengineV1Project.



5149
5150
5151
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5149

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#configurable_billing_statusGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ProjectConfigurableBillingStatus

Represents the currently effective configurable billing parameters. These values are derived from the customer's subscription history stored internally and reflect the thresholds actively being used for billing purposes at the time of the GetProject call. This includes the start_time of the subscription and may differ from the values in customer_provided_config due to billing rules (e.g., scale-downs taking effect only at the start of a new month). We also include the update type to indicate the type of update performed on the configurable billing configuration in the UpdateProject operation. Corresponds to the JSON property configurableBillingStatus



5119
5120
5121
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5119

def configurable_billing_status
  @configurable_billing_status
end

#create_timeString

Output only. The timestamp when this project is created. Corresponds to the JSON property createTime

Returns:

  • (String)


5124
5125
5126
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5124

def create_time
  @create_time
end

#customer_provided_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ProjectCustomerProvidedConfig

Customer provided configurations. Corresponds to the JSON property customerProvidedConfig



5129
5130
5131
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5129

def customer_provided_config
  @customer_provided_config
end

#nameString

Output only. Full resource name of the project, for example projects/project . Note that when making requests, project number and project id are both acceptable, but the server will always respond in project number. Corresponds to the JSON property name

Returns:

  • (String)


5136
5137
5138
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5136

def name
  @name
end

#provision_completion_timeString

Output only. The timestamp when this project is successfully provisioned. Empty value means this project is still provisioning and is not ready for use. Corresponds to the JSON property provisionCompletionTime

Returns:

  • (String)


5142
5143
5144
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5142

def provision_completion_time
  @provision_completion_time
end

#service_terms_mapHash<String,Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ProjectServiceTerms>

Output only. A map of terms of services. The key is the id of ServiceTerms. Corresponds to the JSON property serviceTermsMap



5147
5148
5149
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5147

def service_terms_map
  @service_terms_map
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5154
5155
5156
5157
5158
5159
5160
5161
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5154

def update!(**args)
  @configurable_billing_status = args[:configurable_billing_status] if args.key?(:configurable_billing_status)
  @create_time = args[:create_time] if args.key?(:create_time)
  @customer_provided_config = args[:customer_provided_config] if args.key?(:customer_provided_config)
  @name = args[:name] if args.key?(:name)
  @provision_completion_time = args[:provision_completion_time] if args.key?(:provision_completion_time)
  @service_terms_map = args[:service_terms_map] if args.key?(:service_terms_map)
end