Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ProjectConfigurableBillingStatus
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ProjectConfigurableBillingStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Represents the currently effective configurable billing parameters. These
values are derived from the customer's subscription history stored internally
and reflect the thresholds actively being used for billing purposes at the
time of the GetProject call. This includes the start_time of the subscription
and may differ from the values in customer_provided_config due to billing
rules (e.g., scale-downs taking effect only at the start of a new month). We
also include the update type to indicate the type of update performed on the
configurable billing configuration in the UpdateProject operation.
Instance Attribute Summary collapse
-
#agent_search_token_subscription_statuses ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ProjectConfigurableBillingStatusAgentSearchTokenSubscriptionStatus>
Output only.
-
#effective_indexing_core_threshold ⇒ Fixnum
Optional.
-
#effective_search_qpm_threshold ⇒ Fixnum
Optional.
-
#indexing_core_threshold_next_update_time ⇒ String
Output only.
-
#search_qpm_threshold_next_update_time ⇒ String
Output only.
-
#start_time ⇒ String
Optional.
-
#terminate_time ⇒ String
Output only.
-
#update_type ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1ProjectConfigurableBillingStatus
constructor
A new instance of GoogleCloudDiscoveryengineV1ProjectConfigurableBillingStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1ProjectConfigurableBillingStatus
Returns a new instance of GoogleCloudDiscoveryengineV1ProjectConfigurableBillingStatus.
5235 5236 5237 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5235 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_search_token_subscription_statuses ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ProjectConfigurableBillingStatusAgentSearchTokenSubscriptionStatus>
Output only. Per-model Agent Search TPM subscription status.
Corresponds to the JSON property agentSearchTokenSubscriptionStatuses
5186 5187 5188 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5186 def agent_search_token_subscription_statuses @agent_search_token_subscription_statuses end |
#effective_indexing_core_threshold ⇒ Fixnum
Optional. The currently effective Indexing Core threshold. This is the
threshold against which Indexing Core usage is compared for overage
calculations.
Corresponds to the JSON property effectiveIndexingCoreThreshold
5193 5194 5195 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5193 def effective_indexing_core_threshold @effective_indexing_core_threshold end |
#effective_search_qpm_threshold ⇒ Fixnum
Optional. The currently effective Search QPM threshold in queries per minute.
This is the threshold against which QPM usage is compared for overage
calculations.
Corresponds to the JSON property effectiveSearchQpmThreshold
5200 5201 5202 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5200 def effective_search_qpm_threshold @effective_search_qpm_threshold end |
#indexing_core_threshold_next_update_time ⇒ String
Output only. The earliest next update time for the indexing core subscription
threshold. This is based on the next_update_time returned by the underlying
Cloud Billing Subscription V3 API. This field is populated only if an update
indexing core subscription threshold request is succeeded.
Corresponds to the JSON property indexingCoreThresholdNextUpdateTime
5208 5209 5210 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5208 def indexing_core_threshold_next_update_time @indexing_core_threshold_next_update_time end |
#search_qpm_threshold_next_update_time ⇒ String
Output only. The earliest next update time for the search QPM subscription
threshold. This is based on the next_update_time returned by the underlying
Cloud Billing Subscription V3 API. This field is populated only if an update
QPM subscription threshold request is succeeded.
Corresponds to the JSON property searchQpmThresholdNextUpdateTime
5216 5217 5218 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5216 def search_qpm_threshold_next_update_time @search_qpm_threshold_next_update_time end |
#start_time ⇒ String
Optional. The start time of the currently active billing subscription.
Corresponds to the JSON property startTime
5221 5222 5223 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5221 def start_time @start_time end |
#terminate_time ⇒ String
Output only. The latest terminate effective time of search qpm and indexing
core subscriptions.
Corresponds to the JSON property terminateTime
5227 5228 5229 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5227 def terminate_time @terminate_time end |
#update_type ⇒ String
Output only. The type of update performed in this operation. This field is
populated in the response of UpdateProject.
Corresponds to the JSON property updateType
5233 5234 5235 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5233 def update_type @update_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5240 5241 5242 5243 5244 5245 5246 5247 5248 5249 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5240 def update!(**args) @agent_search_token_subscription_statuses = args[:agent_search_token_subscription_statuses] if args.key?(:agent_search_token_subscription_statuses) @effective_indexing_core_threshold = args[:effective_indexing_core_threshold] if args.key?(:effective_indexing_core_threshold) @effective_search_qpm_threshold = args[:effective_search_qpm_threshold] if args.key?(:effective_search_qpm_threshold) @indexing_core_threshold_next_update_time = args[:indexing_core_threshold_next_update_time] if args.key?(:indexing_core_threshold_next_update_time) @search_qpm_threshold_next_update_time = args[:search_qpm_threshold_next_update_time] if args.key?(:search_qpm_threshold_next_update_time) @start_time = args[:start_time] if args.key?(:start_time) @terminate_time = args[:terminate_time] if args.key?(:terminate_time) @update_type = args[:update_type] if args.key?(:update_type) end |