Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1PurgeCompletionSuggestionsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Response message for CompletionService.PurgeCompletionSuggestions method. If the long running operation is successfully done, then this message is returned by the google.longrunning.Operations.response field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1PurgeCompletionSuggestionsResponse

Returns a new instance of GoogleCloudDiscoveryengineV1PurgeCompletionSuggestionsResponse.



5665
5666
5667
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5665

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_samplesArray<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>

A sample of errors encountered while processing the request. Corresponds to the JSON property errorSamples



5657
5658
5659
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5657

def error_samples
  @error_samples
end

#purge_succeededBoolean Also known as: purge_succeeded?

Whether the completion suggestions were successfully purged. Corresponds to the JSON property purgeSucceeded

Returns:

  • (Boolean)


5662
5663
5664
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5662

def purge_succeeded
  @purge_succeeded
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5670
5671
5672
5673
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5670

def update!(**args)
  @error_samples = args[:error_samples] if args.key?(:error_samples)
  @purge_succeeded = args[:purge_succeeded] if args.key?(:purge_succeeded)
end