Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1PurgeDocumentsMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Metadata related to the progress of the PurgeDocuments operation. This will be returned by the google.longrunning.Operation.metadata field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1PurgeDocumentsMetadata

Returns a new instance of GoogleCloudDiscoveryengineV1PurgeDocumentsMetadata.



5617
5618
5619
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5617

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Operation create time. Corresponds to the JSON property createTime

Returns:

  • (String)


5594
5595
5596
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5594

def create_time
  @create_time
end

#failure_countFixnum

Count of entries that encountered errors while processing. Corresponds to the JSON property failureCount

Returns:

  • (Fixnum)


5599
5600
5601
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5599

def failure_count
  @failure_count
end

#ignored_countFixnum

Count of entries that were ignored as entries were not found. Corresponds to the JSON property ignoredCount

Returns:

  • (Fixnum)


5604
5605
5606
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5604

def ignored_count
  @ignored_count
end

#success_countFixnum

Count of entries that were deleted successfully. Corresponds to the JSON property successCount

Returns:

  • (Fixnum)


5609
5610
5611
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5609

def success_count
  @success_count
end

#update_timeString

Operation last update time. If the operation is done, this is also the finish time. Corresponds to the JSON property updateTime

Returns:

  • (String)


5615
5616
5617
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5615

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5622
5623
5624
5625
5626
5627
5628
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5622

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @failure_count = args[:failure_count] if args.key?(:failure_count)
  @ignored_count = args[:ignored_count] if args.key?(:ignored_count)
  @success_count = args[:success_count] if args.key?(:success_count)
  @update_time = args[:update_time] if args.key?(:update_time)
end