Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1PurgeDocumentsMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Metadata related to the progress of the PurgeDocuments operation. This will be returned by the google.longrunning.Operation.metadata field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1PurgeDocumentsMetadata

Returns a new instance of GoogleCloudDiscoveryengineV1PurgeDocumentsMetadata.



5515
5516
5517
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5515

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Operation create time. Corresponds to the JSON property createTime

Returns:

  • (String)


5492
5493
5494
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5492

def create_time
  @create_time
end

#failure_countFixnum

Count of entries that encountered errors while processing. Corresponds to the JSON property failureCount

Returns:

  • (Fixnum)


5497
5498
5499
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5497

def failure_count
  @failure_count
end

#ignored_countFixnum

Count of entries that were ignored as entries were not found. Corresponds to the JSON property ignoredCount

Returns:

  • (Fixnum)


5502
5503
5504
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5502

def ignored_count
  @ignored_count
end

#success_countFixnum

Count of entries that were deleted successfully. Corresponds to the JSON property successCount

Returns:

  • (Fixnum)


5507
5508
5509
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5507

def success_count
  @success_count
end

#update_timeString

Operation last update time. If the operation is done, this is also the finish time. Corresponds to the JSON property updateTime

Returns:

  • (String)


5513
5514
5515
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5513

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5520
5521
5522
5523
5524
5525
5526
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5520

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @failure_count = args[:failure_count] if args.key?(:failure_count)
  @ignored_count = args[:ignored_count] if args.key?(:ignored_count)
  @success_count = args[:success_count] if args.key?(:success_count)
  @update_time = args[:update_time] if args.key?(:update_time)
end