Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1Schema

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Defines the structure and layout of a type of document data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1Schema

Returns a new instance of GoogleCloudDiscoveryengineV1Schema.



5632
5633
5634
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5632

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#json_schemaString

The JSON representation of the schema. Corresponds to the JSON property jsonSchema

Returns:

  • (String)


5617
5618
5619
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5617

def json_schema
  @json_schema
end

#nameString

Immutable. The full resource name of the schema, in the format of projects/ project/locations/location/collections/collection/dataStores/data_store/ schemas/schema`. This field must be a UTF-8 encoded string with a length limit of 1024 characters. Corresponds to the JSON propertyname`

Returns:

  • (String)


5625
5626
5627
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5625

def name
  @name
end

#struct_schemaHash<String,Object>

The structured representation of the schema. Corresponds to the JSON property structSchema

Returns:

  • (Hash<String,Object>)


5630
5631
5632
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5630

def struct_schema
  @struct_schema
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5637
5638
5639
5640
5641
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5637

def update!(**args)
  @json_schema = args[:json_schema] if args.key?(:json_schema)
  @name = args[:name] if args.key?(:name)
  @struct_schema = args[:struct_schema] if args.key?(:struct_schema)
end