Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1SearchLinkPromotion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Promotion proto includes uri and other helping information to display the promotion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1SearchLinkPromotion

Returns a new instance of GoogleCloudDiscoveryengineV1SearchLinkPromotion.



5876
5877
5878
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5876

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Optional. The Promotion description. Maximum length: 200 characters. Corresponds to the JSON property description

Returns:

  • (String)


5844
5845
5846
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5844

def description
  @description
end

#documentString

Optional. The Document the user wants to promote. For site search, leave unset and only populate uri. Can be set along with uri. Corresponds to the JSON property document

Returns:

  • (String)


5850
5851
5852
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5850

def document
  @document
end

#enabledBoolean Also known as: enabled?

Optional. The enabled promotion will be returned for any serving configs associated with the parent of the control this promotion is attached to. This flag is used for basic site search only. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


5857
5858
5859
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5857

def enabled
  @enabled
end

#image_uriString

Optional. The promotion thumbnail image url. Corresponds to the JSON property imageUri

Returns:

  • (String)


5863
5864
5865
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5863

def image_uri
  @image_uri
end

#titleString

Required. The title of the promotion. Maximum length: 160 characters. Corresponds to the JSON property title

Returns:

  • (String)


5868
5869
5870
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5868

def title
  @title
end

#uriString

Optional. The URL for the page the user wants to promote. Must be set for site search. For other verticals, this is optional. Corresponds to the JSON property uri

Returns:

  • (String)


5874
5875
5876
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5874

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5881
5882
5883
5884
5885
5886
5887
5888
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5881

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @document = args[:document] if args.key?(:document)
  @enabled = args[:enabled] if args.key?(:enabled)
  @image_uri = args[:image_uri] if args.key?(:image_uri)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end