Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1SearchLinkPromotion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Promotion proto includes uri and other helping information to display the promotion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1SearchLinkPromotion

Returns a new instance of GoogleCloudDiscoveryengineV1SearchLinkPromotion.



5807
5808
5809
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5807

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Optional. The Promotion description. Maximum length: 200 characters. Corresponds to the JSON property description

Returns:

  • (String)


5775
5776
5777
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5775

def description
  @description
end

#documentString

Optional. The Document the user wants to promote. For site search, leave unset and only populate uri. Can be set along with uri. Corresponds to the JSON property document

Returns:

  • (String)


5781
5782
5783
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5781

def document
  @document
end

#enabledBoolean Also known as: enabled?

Optional. The enabled promotion will be returned for any serving configs associated with the parent of the control this promotion is attached to. This flag is used for basic site search only. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


5788
5789
5790
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5788

def enabled
  @enabled
end

#image_uriString

Optional. The promotion thumbnail image url. Corresponds to the JSON property imageUri

Returns:

  • (String)


5794
5795
5796
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5794

def image_uri
  @image_uri
end

#titleString

Required. The title of the promotion. Maximum length: 160 characters. Corresponds to the JSON property title

Returns:

  • (String)


5799
5800
5801
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5799

def title
  @title
end

#uriString

Optional. The URL for the page the user wants to promote. Must be set for site search. For other verticals, this is optional. Corresponds to the JSON property uri

Returns:

  • (String)


5805
5806
5807
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5805

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5812
5813
5814
5815
5816
5817
5818
5819
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5812

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @document = args[:document] if args.key?(:document)
  @enabled = args[:enabled] if args.key?(:enabled)
  @image_uri = args[:image_uri] if args.key?(:image_uri)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end