Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1SearchLinkPromotion
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1SearchLinkPromotion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Promotion proto includes uri and other helping information to display the promotion.
Instance Attribute Summary collapse
-
#description ⇒ String
Optional.
-
#document ⇒ String
Optional.
-
#enabled ⇒ Boolean
(also: #enabled?)
Optional.
-
#image_uri ⇒ String
Optional.
-
#title ⇒ String
Required.
-
#uri ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1SearchLinkPromotion
constructor
A new instance of GoogleCloudDiscoveryengineV1SearchLinkPromotion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1SearchLinkPromotion
Returns a new instance of GoogleCloudDiscoveryengineV1SearchLinkPromotion.
5684 5685 5686 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5684 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Optional. The Promotion description. Maximum length: 200 characters.
Corresponds to the JSON property description
5652 5653 5654 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5652 def description @description end |
#document ⇒ String
Optional. The Document the user wants to promote. For site search, leave unset
and only populate uri. Can be set along with uri.
Corresponds to the JSON property document
5658 5659 5660 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5658 def document @document end |
#enabled ⇒ Boolean Also known as: enabled?
Optional. The enabled promotion will be returned for any serving configs
associated with the parent of the control this promotion is attached to. This
flag is used for basic site search only.
Corresponds to the JSON property enabled
5665 5666 5667 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5665 def enabled @enabled end |
#image_uri ⇒ String
Optional. The promotion thumbnail image url.
Corresponds to the JSON property imageUri
5671 5672 5673 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5671 def image_uri @image_uri end |
#title ⇒ String
Required. The title of the promotion. Maximum length: 160 characters.
Corresponds to the JSON property title
5676 5677 5678 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5676 def title @title end |
#uri ⇒ String
Optional. The URL for the page the user wants to promote. Must be set for site
search. For other verticals, this is optional.
Corresponds to the JSON property uri
5682 5683 5684 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5682 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5689 5690 5691 5692 5693 5694 5695 5696 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5689 def update!(**args) @description = args[:description] if args.key?(:description) @document = args[:document] if args.key?(:document) @enabled = args[:enabled] if args.key?(:enabled) @image_uri = args[:image_uri] if args.key?(:image_uri) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) end |