Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1SearchRequestContentSearchSpecChunkSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Specifies the chunk spec to be returned from the search response. Only available if the SearchRequest.ContentSearchSpec.search_result_mode is set to CHUNKS

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1SearchRequestContentSearchSpecChunkSpec

Returns a new instance of GoogleCloudDiscoveryengineV1SearchRequestContentSearchSpecChunkSpec.



5865
5866
5867
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5865

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#num_next_chunksFixnum

The number of next chunks to be returned of the current chunk. The maximum allowed value is 3. If not specified, no next chunks will be returned. Corresponds to the JSON property numNextChunks

Returns:

  • (Fixnum)


5857
5858
5859
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5857

def num_next_chunks
  @num_next_chunks
end

#num_previous_chunksFixnum

The number of previous chunks to be returned of the current chunk. The maximum allowed value is 3. If not specified, no previous chunks will be returned. Corresponds to the JSON property numPreviousChunks

Returns:

  • (Fixnum)


5863
5864
5865
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5863

def num_previous_chunks
  @num_previous_chunks
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5870
5871
5872
5873
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5870

def update!(**args)
  @num_next_chunks = args[:num_next_chunks] if args.key?(:num_next_chunks)
  @num_previous_chunks = args[:num_previous_chunks] if args.key?(:num_previous_chunks)
end