Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1SearchRequestContentSearchSpecExtractiveContentSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

A specification for configuring the extractive content in a search response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1SearchRequestContentSearchSpecExtractiveContentSpec

Returns a new instance of GoogleCloudDiscoveryengineV1SearchRequestContentSearchSpecExtractiveContentSpec.



5945
5946
5947
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5945

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_extractive_answer_countFixnum

The maximum number of extractive answers returned in each search result. An extractive answer is a verbatim answer extracted from the original document, which provides a precise and contextually relevant answer to the search query. If the number of matching answers is less than the max_extractive_answer_count, return all of the answers. Otherwise, return the max_extractive_answer_count. At most five answers are returned for each SearchResult. Corresponds to the JSON property maxExtractiveAnswerCount

Returns:

  • (Fixnum)


5910
5911
5912
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5910

def max_extractive_answer_count
  @max_extractive_answer_count
end

#max_extractive_segment_countFixnum

The max number of extractive segments returned in each search result. Only applied if the DataStore is set to DataStore.ContentConfig.CONTENT_REQUIRED or DataStore.solution_types is SOLUTION_TYPE_CHAT. An extractive segment is a text segment extracted from the original document that is relevant to the search query, and, in general, more verbose than an extractive answer. The segment could then be used as input for LLMs to generate summaries and answers. If the number of matching segments is less than max_extractive_segment_count , return all of the segments. Otherwise, return the max_extractive_segment_count. Corresponds to the JSON property maxExtractiveSegmentCount

Returns:

  • (Fixnum)


5923
5924
5925
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5923

def max_extractive_segment_count
  @max_extractive_segment_count
end

#num_next_segmentsFixnum

Return at most num_next_segments segments after each selected segments. Corresponds to the JSON property numNextSegments

Returns:

  • (Fixnum)


5928
5929
5930
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5928

def num_next_segments
  @num_next_segments
end

#num_previous_segmentsFixnum

Specifies whether to also include the adjacent from each selected segments. Return at most num_previous_segments segments before each selected segments. Corresponds to the JSON property numPreviousSegments

Returns:

  • (Fixnum)


5934
5935
5936
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5934

def num_previous_segments
  @num_previous_segments
end

#return_extractive_segment_scoreBoolean Also known as: return_extractive_segment_score?

Specifies whether to return the confidence score from the extractive segments in each search result. This feature is available only for new or allowlisted data stores. To allowlist your data store, contact your Customer Engineer. The default value is false. Corresponds to the JSON property returnExtractiveSegmentScore

Returns:

  • (Boolean)


5942
5943
5944
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5942

def return_extractive_segment_score
  @return_extractive_segment_score
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5950
5951
5952
5953
5954
5955
5956
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 5950

def update!(**args)
  @max_extractive_answer_count = args[:max_extractive_answer_count] if args.key?(:max_extractive_answer_count)
  @max_extractive_segment_count = args[:max_extractive_segment_count] if args.key?(:max_extractive_segment_count)
  @num_next_segments = args[:num_next_segments] if args.key?(:num_next_segments)
  @num_previous_segments = args[:num_previous_segments] if args.key?(:num_previous_segments)
  @return_extractive_segment_score = args[:return_extractive_segment_score] if args.key?(:return_extractive_segment_score)
end