Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1SearchRequestContentSearchSpecSummarySpecModelPromptSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Specification of the prompt to use with the model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1SearchRequestContentSearchSpecSummarySpecModelPromptSpec

Returns a new instance of GoogleCloudDiscoveryengineV1SearchRequestContentSearchSpecSummarySpecModelPromptSpec.



6116
6117
6118
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6116

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#preambleString

Text at the beginning of the prompt that instructs the assistant. Examples are available in the user guide. Corresponds to the JSON property preamble

Returns:

  • (String)


6114
6115
6116
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6114

def preamble
  @preamble
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6121
6122
6123
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6121

def update!(**args)
  @preamble = args[:preamble] if args.key?(:preamble)
end