Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ServingConfig
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ServingConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Configures metadata that is used to generate serving time results (e.g. search results or recommendation predictions). The ServingConfig is passed in the search and predict request and generates results.
Instance Attribute Summary collapse
-
#answer_generation_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1AnswerGenerationSpec
The specification for answer generation.
-
#boost_control_ids ⇒ Array<String>
Boost controls to use in serving path.
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Required.
-
#dissociate_control_ids ⇒ Array<String>
Condition do not associate specifications.
-
#diversity_level ⇒ String
How much diversity to use in recommendation model results e.g.
-
#filter_control_ids ⇒ Array<String>
Filter controls to use in serving path.
-
#generic_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ServingConfigGenericConfig
Specifies the configurations needed for Generic Discovery.Currently we support: *
content_search_spec: configuration for generic content search. -
#ignore_control_ids ⇒ Array<String>
Condition ignore specifications.
-
#media_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ServingConfigMediaConfig
Specifies the configurations needed for Media Discovery.
-
#model_id ⇒ String
The id of the model to use at serving time.
-
#name ⇒ String
Immutable.
-
#oneway_synonyms_control_ids ⇒ Array<String>
Condition oneway synonyms specifications.
-
#promote_control_ids ⇒ Array<String>
Condition promote specifications.
-
#ranking_expression ⇒ String
The ranking expression controls the customized ranking on retrieval documents.
-
#redirect_control_ids ⇒ Array<String>
IDs of the redirect controls.
-
#replacement_control_ids ⇒ Array<String>
Condition replacement specifications.
-
#solution_type ⇒ String
Required.
-
#synonyms_control_ids ⇒ Array<String>
Condition synonyms specifications.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1ServingConfig
constructor
A new instance of GoogleCloudDiscoveryengineV1ServingConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1ServingConfig
Returns a new instance of GoogleCloudDiscoveryengineV1ServingConfig.
6323 6324 6325 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6323 def initialize(**args) update!(**args) end |
Instance Attribute Details
#answer_generation_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1AnswerGenerationSpec
The specification for answer generation.
Corresponds to the JSON property answerGenerationSpec
6171 6172 6173 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6171 def answer_generation_spec @answer_generation_spec end |
#boost_control_ids ⇒ Array<String>
Boost controls to use in serving path. All triggered boost controls will be
applied. Boost controls must be in the same data store as the serving config.
Maximum of 20 boost controls.
Corresponds to the JSON property boostControlIds
6178 6179 6180 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6178 def boost_control_ids @boost_control_ids end |
#create_time ⇒ String
Output only. ServingConfig created timestamp.
Corresponds to the JSON property createTime
6183 6184 6185 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6183 def create_time @create_time end |
#display_name ⇒ String
Required. The human readable serving config display name. Used in Discovery UI.
This field must be a UTF-8 encoded string with a length limit of 128
characters. Otherwise, an INVALID_ARGUMENT error is returned.
Corresponds to the JSON property displayName
6190 6191 6192 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6190 def display_name @display_name end |
#dissociate_control_ids ⇒ Array<String>
Condition do not associate specifications. If multiple do not associate
conditions match, all matching do not associate controls in the list will
execute. Order does not matter. Maximum number of specifications is 100. Can
only be set if SolutionType is SOLUTION_TYPE_SEARCH.
Corresponds to the JSON property dissociateControlIds
6198 6199 6200 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6198 def dissociate_control_ids @dissociate_control_ids end |
#diversity_level ⇒ String
How much diversity to use in recommendation model results e.g. medium-
diversity or high-diversity. Currently supported values: * no-diversity *
low-diversity * medium-diversity * high-diversity * auto-diversity If
not specified, we choose default based on recommendation model type. Default
value: no-diversity. Can only be set if SolutionType is
SOLUTION_TYPE_RECOMMENDATION.
Corresponds to the JSON property diversityLevel
6208 6209 6210 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6208 def diversity_level @diversity_level end |
#filter_control_ids ⇒ Array<String>
Filter controls to use in serving path. All triggered filter controls will be
applied. Filter controls must be in the same data store as the serving config.
Maximum of 20 filter controls.
Corresponds to the JSON property filterControlIds
6215 6216 6217 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6215 def filter_control_ids @filter_control_ids end |
#generic_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ServingConfigGenericConfig
Specifies the configurations needed for Generic Discovery.Currently we support:
content_search_spec: configuration for generic content search. Corresponds to the JSON propertygenericConfig
6221 6222 6223 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6221 def generic_config @generic_config end |
#ignore_control_ids ⇒ Array<String>
Condition ignore specifications. If multiple ignore conditions match, all
matching ignore controls in the list will execute. Order does not matter.
Maximum number of specifications is 100.
Corresponds to the JSON property ignoreControlIds
6228 6229 6230 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6228 def ignore_control_ids @ignore_control_ids end |
#media_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1ServingConfigMediaConfig
Specifies the configurations needed for Media Discovery. Currently we support:
demote_content_watched: Threshold for watched content demotion. Customers can specify if using watched content demotion or use viewed detail page. Using the content watched demotion, customers need to specify the watched minutes or percentage exceeds the threshold, the content will be demoted in the recommendation result. *promote_fresh_content: cutoff days for fresh content promotion. Customers can specify if using content freshness promotion. If the content was published within the cutoff days, the content will be promoted in the recommendation result. Can only be set if SolutionType is SOLUTION_TYPE_RECOMMENDATION. Corresponds to the JSON propertymediaConfig
6242 6243 6244 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6242 def media_config @media_config end |
#model_id ⇒ String
The id of the model to use at serving time. Currently only
RecommendationModels are supported. Can be changed but only to a compatible
model (e.g. others-you-may-like CTR to others-you-may-like CVR). Required when
SolutionType is SOLUTION_TYPE_RECOMMENDATION.
Corresponds to the JSON property modelId
6250 6251 6252 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6250 def model_id @model_id end |
#name ⇒ String
Immutable. Fully qualified name projects/project/locations/location/
collections/collection_id/engines/engine_id/servingConfigs/
serving_config_id`
Corresponds to the JSON propertyname`
6257 6258 6259 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6257 def name @name end |
#oneway_synonyms_control_ids ⇒ Array<String>
Condition oneway synonyms specifications. If multiple oneway synonyms
conditions match, all matching oneway synonyms controls in the list will
execute. Maximum number of specifications is 100. Can only be set if
SolutionType is SOLUTION_TYPE_SEARCH.
Corresponds to the JSON property onewaySynonymsControlIds
6265 6266 6267 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6265 def oneway_synonyms_control_ids @oneway_synonyms_control_ids end |
#promote_control_ids ⇒ Array<String>
Condition promote specifications. Maximum number of specifications is 100.
Corresponds to the JSON property promoteControlIds
6270 6271 6272 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6270 def promote_control_ids @promote_control_ids end |
#ranking_expression ⇒ String
The ranking expression controls the customized ranking on retrieval documents.
To leverage this, document embedding is required. The ranking expression
setting in ServingConfig applies to all search requests served by the serving
config. However, if SearchRequest.ranking_expression is specified, it
overrides the ServingConfig ranking expression. The ranking expression is a
single function or multiple functions that are joined by "+". *
ranking_expression = function, " + ", function; Supported functions: *
double * relevance_score * double * dotProduct(embedding_field_path) Function
variables: * relevance_score: pre-defined keywords, used for measure
relevance between query and document. * embedding_field_path: the document
embedding field used with query embedding vector. * dotProduct: embedding
function between embedding_field_path and query embedding vector. Example
ranking expression: If document has an embedding field doc_embedding, the
ranking expression could be 0.5 * relevance_score + 0.3 * dotProduct(
doc_embedding).
Corresponds to the JSON property rankingExpression
6289 6290 6291 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6289 def ranking_expression @ranking_expression end |
#redirect_control_ids ⇒ Array<String>
IDs of the redirect controls. Only the first triggered redirect action is
applied, even if multiple apply. Maximum number of specifications is 100. Can
only be set if SolutionType is SOLUTION_TYPE_SEARCH.
Corresponds to the JSON property redirectControlIds
6296 6297 6298 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6296 def redirect_control_ids @redirect_control_ids end |
#replacement_control_ids ⇒ Array<String>
Condition replacement specifications. Applied according to the order in the
list. A previously replaced term can not be re-replaced. Maximum number of
specifications is 100. Can only be set if SolutionType is SOLUTION_TYPE_SEARCH.
Corresponds to the JSON property replacementControlIds
6303 6304 6305 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6303 def replacement_control_ids @replacement_control_ids end |
#solution_type ⇒ String
Required. Immutable. Specifies the solution type that a serving config can be
associated with.
Corresponds to the JSON property solutionType
6309 6310 6311 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6309 def solution_type @solution_type end |
#synonyms_control_ids ⇒ Array<String>
Condition synonyms specifications. If multiple synonyms conditions match, all
matching synonyms controls in the list will execute. Maximum number of
specifications is 100. Can only be set if SolutionType is SOLUTION_TYPE_SEARCH.
Corresponds to the JSON property synonymsControlIds
6316 6317 6318 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6316 def synonyms_control_ids @synonyms_control_ids end |
#update_time ⇒ String
Output only. ServingConfig updated timestamp.
Corresponds to the JSON property updateTime
6321 6322 6323 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6321 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 6346 6347 6348 6349 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6328 def update!(**args) @answer_generation_spec = args[:answer_generation_spec] if args.key?(:answer_generation_spec) @boost_control_ids = args[:boost_control_ids] if args.key?(:boost_control_ids) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @dissociate_control_ids = args[:dissociate_control_ids] if args.key?(:dissociate_control_ids) @diversity_level = args[:diversity_level] if args.key?(:diversity_level) @filter_control_ids = args[:filter_control_ids] if args.key?(:filter_control_ids) @generic_config = args[:generic_config] if args.key?(:generic_config) @ignore_control_ids = args[:ignore_control_ids] if args.key?(:ignore_control_ids) @media_config = args[:media_config] if args.key?(:media_config) @model_id = args[:model_id] if args.key?(:model_id) @name = args[:name] if args.key?(:name) @oneway_synonyms_control_ids = args[:oneway_synonyms_control_ids] if args.key?(:oneway_synonyms_control_ids) @promote_control_ids = args[:promote_control_ids] if args.key?(:promote_control_ids) @ranking_expression = args[:ranking_expression] if args.key?(:ranking_expression) @redirect_control_ids = args[:redirect_control_ids] if args.key?(:redirect_control_ids) @replacement_control_ids = args[:replacement_control_ids] if args.key?(:replacement_control_ids) @solution_type = args[:solution_type] if args.key?(:solution_type) @synonyms_control_ids = args[:synonyms_control_ids] if args.key?(:synonyms_control_ids) @update_time = args[:update_time] if args.key?(:update_time) end |