Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1Tenant
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1Tenant
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Tenant information for a connector source. This includes some of the same information stored in the Credential message, but is limited to only what is needed to provide a list of accessible tenants to the user.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Optional display name for the tenant, e.g.
-
#id ⇒ String
The tenant's instance ID.
-
#uri ⇒ String
The URI of the tenant, if applicable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1Tenant
constructor
A new instance of GoogleCloudDiscoveryengineV1Tenant.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1Tenant
Returns a new instance of GoogleCloudDiscoveryengineV1Tenant.
6548 6549 6550 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6548 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Optional display name for the tenant, e.g. "My Slack Team".
Corresponds to the JSON property displayName
6533 6534 6535 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6533 def display_name @display_name end |
#id ⇒ String
The tenant's instance ID. Examples: Jira ("8594f221-9797-5f78-1fa4-
485e198d7cd0"), Slack ("T123456").
Corresponds to the JSON property id
6539 6540 6541 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6539 def id @id end |
#uri ⇒ String
The URI of the tenant, if applicable. For example, the URI of a Jira instance
is https://my-jira-instance.atlassian.net, and a Slack tenant does not have a
URI.
Corresponds to the JSON property uri
6546 6547 6548 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6546 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6553 6554 6555 6556 6557 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6553 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @id = args[:id] if args.key?(:id) @uri = args[:uri] if args.key?(:uri) end |