Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1UserLicense

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

User License information assigned by the admin.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1UserLicense

Returns a new instance of GoogleCloudDiscoveryengineV1UserLicense.



6900
6901
6902
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6900

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. User created timestamp. Corresponds to the JSON property createTime

Returns:

  • (String)


6860
6861
6862
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6860

def create_time
  @create_time
end

#last_login_timeString

Output only. User last logged in time. If the user has not logged in yet, this field will be empty. Corresponds to the JSON property lastLoginTime

Returns:

  • (String)


6866
6867
6868
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6866

def 
  @last_login_time
end

#license_assignment_stateString

Output only. License assignment state of the user. If the user is assigned with a license config, the user login will be assigned with the license; If the user's license assignment state is unassigned or unspecified, no license config will be associated to the user; Corresponds to the JSON property licenseAssignmentState

Returns:

  • (String)


6874
6875
6876
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6874

def license_assignment_state
  @license_assignment_state
end

#license_configString

Optional. The full resource name of the Subscription(LicenseConfig) assigned to the user. Corresponds to the JSON property licenseConfig

Returns:

  • (String)


6880
6881
6882
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6880

def license_config
  @license_config
end

#update_timeString

Output only. User update timestamp. Corresponds to the JSON property updateTime

Returns:

  • (String)


6885
6886
6887
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6885

def update_time
  @update_time
end

#user_principalString

Required. Immutable. The user principal of the User, could be email address or other prinical identifier. This field is immutable. Admin assign licenses based on the user principal. Corresponds to the JSON property userPrincipal

Returns:

  • (String)


6892
6893
6894
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6892

def user_principal
  @user_principal
end

#user_profileString

Optional. The user profile. We user user full name(First name + Last name) as user profile. Corresponds to the JSON property userProfile

Returns:

  • (String)


6898
6899
6900
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6898

def 
  @user_profile
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6905
6906
6907
6908
6909
6910
6911
6912
6913
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6905

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @last_login_time = args[:last_login_time] if args.key?(:last_login_time)
  @license_assignment_state = args[:license_assignment_state] if args.key?(:license_assignment_state)
  @license_config = args[:license_config] if args.key?(:license_config)
  @update_time = args[:update_time] if args.key?(:update_time)
  @user_principal = args[:user_principal] if args.key?(:user_principal)
  @user_profile = args[:user_profile] if args.key?(:user_profile)
end