Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1UserStore
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1UserStore
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Configures metadata that is used for End User entities.
Instance Attribute Summary collapse
-
#default_license_config ⇒ String
Optional.
-
#display_name ⇒ String
The display name of the User Store.
-
#enable_expired_license_auto_update ⇒ Boolean
(also: #enable_expired_license_auto_update?)
Optional.
-
#enable_license_auto_register ⇒ Boolean
(also: #enable_license_auto_register?)
Optional.
-
#name ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1UserStore
constructor
A new instance of GoogleCloudDiscoveryengineV1UserStore.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1UserStore
Returns a new instance of GoogleCloudDiscoveryengineV1UserStore.
6925 6926 6927 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6925 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_license_config ⇒ String
Optional. The default subscription LicenseConfig for the UserStore, if
UserStore.enable_license_auto_register is true, new users will automatically
register under the default subscription. If default LicenseConfig doesn't have
remaining license seats left, new users will not be assigned with license and
will be blocked for Vertex AI Search features. This is used if
license_assignment_tier_rules is not configured.
Corresponds to the JSON property defaultLicenseConfig
6895 6896 6897 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6895 def default_license_config @default_license_config end |
#display_name ⇒ String
The display name of the User Store.
Corresponds to the JSON property displayName
6900 6901 6902 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6900 def display_name @display_name end |
#enable_expired_license_auto_update ⇒ Boolean Also known as: enable_expired_license_auto_update?
Optional. Whether to enable license auto update for users in this User Store.
If true, users with expired licenses will automatically be updated to use the
default license config as long as the default license config has seats left.
Corresponds to the JSON property enableExpiredLicenseAutoUpdate
6907 6908 6909 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6907 def enable_expired_license_auto_update @enable_expired_license_auto_update end |
#enable_license_auto_register ⇒ Boolean Also known as: enable_license_auto_register?
Optional. Whether to enable license auto register for users in this User Store.
If true, new users will automatically register under the default license
config as long as the default license config has seats left.
Corresponds to the JSON property enableLicenseAutoRegister
6915 6916 6917 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6915 def enable_license_auto_register @enable_license_auto_register end |
#name ⇒ String
Immutable. The full resource name of the User Store, in the format of
projects/project/locations/location/userStores/user_store`. This field
must be a UTF-8 encoded string with a length limit of 1024 characters.
Corresponds to the JSON propertyname`
6923 6924 6925 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6923 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6930 6931 6932 6933 6934 6935 6936 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6930 def update!(**args) @default_license_config = args[:default_license_config] if args.key?(:default_license_config) @display_name = args[:display_name] if args.key?(:display_name) @enable_expired_license_auto_update = args[:enable_expired_license_auto_update] if args.key?(:enable_expired_license_auto_update) @enable_license_auto_register = args[:enable_license_auto_register] if args.key?(:enable_license_auto_register) @name = args[:name] if args.key?(:name) end |