Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1WorkspaceConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Config to store data store type configuration for workspace data

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1WorkspaceConfig

Returns a new instance of GoogleCloudDiscoveryengineV1WorkspaceConfig.



7059
7060
7061
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7059

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dasher_customer_idString

Output only. Obfuscated Dasher customer ID. Derived by the server from the project's GCP organization at data store creation time; any value supplied in the request payload is ignored. Corresponds to the JSON property dasherCustomerId

Returns:

  • (String)


7038
7039
7040
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7038

def dasher_customer_id
  @dasher_customer_id
end

#super_admin_email_addressString

Optional. The super admin email address for the workspace that will be used for access token generation. For now we only use it for Native Google Drive connector data ingestion. Corresponds to the JSON property superAdminEmailAddress

Returns:

  • (String)


7045
7046
7047
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7045

def super_admin_email_address
  @super_admin_email_address
end

#super_admin_service_accountString

Optional. The super admin service account for the workspace that will be used for access token generation. For now we only use it for Native Google Drive connector data ingestion. Corresponds to the JSON property superAdminServiceAccount

Returns:

  • (String)


7052
7053
7054
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7052

def 
  @super_admin_service_account
end

#typeString

The Google Workspace data source. Corresponds to the JSON property type

Returns:

  • (String)


7057
7058
7059
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7057

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7064
7065
7066
7067
7068
7069
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7064

def update!(**args)
  @dasher_customer_id = args[:dasher_customer_id] if args.key?(:dasher_customer_id)
  @super_admin_email_address = args[:super_admin_email_address] if args.key?(:super_admin_email_address)
  @super_admin_service_account = args[:super_admin_service_account] if args.key?(:super_admin_service_account)
  @type = args[:type] if args.key?(:type)
end