Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1WorkspaceConfig
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1WorkspaceConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Config to store data store type configuration for workspace data
Instance Attribute Summary collapse
-
#dasher_customer_id ⇒ String
Output only.
-
#super_admin_email_address ⇒ String
Optional.
-
#super_admin_service_account ⇒ String
Optional.
-
#type ⇒ String
The Google Workspace data source.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1WorkspaceConfig
constructor
A new instance of GoogleCloudDiscoveryengineV1WorkspaceConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1WorkspaceConfig
Returns a new instance of GoogleCloudDiscoveryengineV1WorkspaceConfig.
7002 7003 7004 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7002 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dasher_customer_id ⇒ String
Output only. Obfuscated Dasher customer ID. Derived by the server from the
project's GCP organization at data store creation time; any value supplied in
the request payload is ignored.
Corresponds to the JSON property dasherCustomerId
6981 6982 6983 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6981 def dasher_customer_id @dasher_customer_id end |
#super_admin_email_address ⇒ String
Optional. The super admin email address for the workspace that will be used
for access token generation. For now we only use it for Native Google Drive
connector data ingestion.
Corresponds to the JSON property superAdminEmailAddress
6988 6989 6990 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6988 def super_admin_email_address @super_admin_email_address end |
#super_admin_service_account ⇒ String
Optional. The super admin service account for the workspace that will be used
for access token generation. For now we only use it for Native Google Drive
connector data ingestion.
Corresponds to the JSON property superAdminServiceAccount
6995 6996 6997 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 6995 def super_admin_service_account @super_admin_service_account end |
#type ⇒ String
The Google Workspace data source.
Corresponds to the JSON property type
7000 7001 7002 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7000 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7007 7008 7009 7010 7011 7012 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7007 def update!(**args) @dasher_customer_id = args[:dasher_customer_id] if args.key?(:dasher_customer_id) @super_admin_email_address = args[:super_admin_email_address] if args.key?(:super_admin_email_address) @super_admin_service_account = args[:super_admin_service_account] if args.key?(:super_admin_service_account) @type = args[:type] if args.key?(:type) end |