Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaActionConfig
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaActionConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Informations to support actions on the connector.
Instance Attribute Summary collapse
-
#action_params ⇒ Hash<String,Object>
Optional.
-
#create_bap_connection ⇒ Boolean
(also: #create_bap_connection?)
Optional.
-
#is_action_configured ⇒ Boolean
(also: #is_action_configured?)
Output only.
-
#json_action_params ⇒ String
Optional.
-
#service_name ⇒ String
Optional.
-
#use_static_secrets ⇒ Boolean
(also: #use_static_secrets?)
Optional.
-
#user_defined_scopes_mapping ⇒ Hash<String,Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaActionConfigScopeList>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaActionConfig
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaActionConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaActionConfig
Returns a new instance of GoogleCloudDiscoveryengineV1alphaActionConfig.
7147 7148 7149 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7147 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action_params ⇒ Hash<String,Object>
Optional. Action parameters in structured json format.
Corresponds to the JSON property actionParams
7106 7107 7108 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7106 def action_params @action_params end |
#create_bap_connection ⇒ Boolean Also known as: create_bap_connection?
Optional. Whether to create a BAP connection for the connector.
Corresponds to the JSON property createBapConnection
7111 7112 7113 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7111 def create_bap_connection @create_bap_connection end |
#is_action_configured ⇒ Boolean Also known as: is_action_configured?
Output only. The connector contains the necessary parameters and is configured
to support actions.
Corresponds to the JSON property isActionConfigured
7118 7119 7120 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7118 def is_action_configured @is_action_configured end |
#json_action_params ⇒ String
Optional. Action parameters in json string format.
Corresponds to the JSON property jsonActionParams
7124 7125 7126 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7124 def json_action_params @json_action_params end |
#service_name ⇒ String
Optional. The Service Directory resource name (projects//locations//
namespaces//services/) representing a VPC network endpoint used to connect
to the data source's instance_uri, defined in DataConnector.params. Required
when VPC Service Controls are enabled.
Corresponds to the JSON property serviceName
7132 7133 7134 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7132 def service_name @service_name end |
#use_static_secrets ⇒ Boolean Also known as: use_static_secrets?
Optional. Whether to use static secrets for the connector. If true, the
secrets provided in the action_params will be ignored.
Corresponds to the JSON property useStaticSecrets
7138 7139 7140 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7138 def use_static_secrets @use_static_secrets end |
#user_defined_scopes_mapping ⇒ Hash<String,Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaActionConfigScopeList>
Optional. Mapping from operation name to the list of scopes. Only be populated
if there are user specified scopes.
Corresponds to the JSON property userDefinedScopesMapping
7145 7146 7147 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7145 def user_defined_scopes_mapping @user_defined_scopes_mapping end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7152 7153 7154 7155 7156 7157 7158 7159 7160 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7152 def update!(**args) @action_params = args[:action_params] if args.key?(:action_params) @create_bap_connection = args[:create_bap_connection] if args.key?(:create_bap_connection) @is_action_configured = args[:is_action_configured] if args.key?(:is_action_configured) @json_action_params = args[:json_action_params] if args.key?(:json_action_params) @service_name = args[:service_name] if args.key?(:service_name) @use_static_secrets = args[:use_static_secrets] if args.key?(:use_static_secrets) @user_defined_scopes_mapping = args[:user_defined_scopes_mapping] if args.key?(:user_defined_scopes_mapping) end |