Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaActionConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Informations to support actions on the connector.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaActionConfig

Returns a new instance of GoogleCloudDiscoveryengineV1alphaActionConfig.



7057
7058
7059
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7057

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#action_paramsHash<String,Object>

Optional. Action parameters in structured json format. Corresponds to the JSON property actionParams

Returns:

  • (Hash<String,Object>)


7016
7017
7018
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7016

def action_params
  @action_params
end

#create_bap_connectionBoolean Also known as: create_bap_connection?

Optional. Whether to create a BAP connection for the connector. Corresponds to the JSON property createBapConnection

Returns:

  • (Boolean)


7021
7022
7023
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7021

def create_bap_connection
  @create_bap_connection
end

#is_action_configuredBoolean Also known as: is_action_configured?

Output only. The connector contains the necessary parameters and is configured to support actions. Corresponds to the JSON property isActionConfigured

Returns:

  • (Boolean)


7028
7029
7030
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7028

def is_action_configured
  @is_action_configured
end

#json_action_paramsString

Optional. Action parameters in json string format. Corresponds to the JSON property jsonActionParams

Returns:

  • (String)


7034
7035
7036
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7034

def json_action_params
  @json_action_params
end

#service_nameString

Optional. The Service Directory resource name (projects//locations// namespaces//services/) representing a VPC network endpoint used to connect to the data source's instance_uri, defined in DataConnector.params. Required when VPC Service Controls are enabled. Corresponds to the JSON property serviceName

Returns:

  • (String)


7042
7043
7044
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7042

def service_name
  @service_name
end

#use_static_secretsBoolean Also known as: use_static_secrets?

Optional. Whether to use static secrets for the connector. If true, the secrets provided in the action_params will be ignored. Corresponds to the JSON property useStaticSecrets

Returns:

  • (Boolean)


7048
7049
7050
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7048

def use_static_secrets
  @use_static_secrets
end

#user_defined_scopes_mappingHash<String,Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaActionConfigScopeList>

Optional. Mapping from operation name to the list of scopes. Only be populated if there are user specified scopes. Corresponds to the JSON property userDefinedScopesMapping



7055
7056
7057
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7055

def user_defined_scopes_mapping
  @user_defined_scopes_mapping
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7062
7063
7064
7065
7066
7067
7068
7069
7070
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7062

def update!(**args)
  @action_params = args[:action_params] if args.key?(:action_params)
  @create_bap_connection = args[:create_bap_connection] if args.key?(:create_bap_connection)
  @is_action_configured = args[:is_action_configured] if args.key?(:is_action_configured)
  @json_action_params = args[:json_action_params] if args.key?(:json_action_params)
  @service_name = args[:service_name] if args.key?(:service_name)
  @use_static_secrets = args[:use_static_secrets] if args.key?(:use_static_secrets)
  @user_defined_scopes_mapping = args[:user_defined_scopes_mapping] if args.key?(:user_defined_scopes_mapping)
end