Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAddPatientFilterRequest
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAddPatientFilterRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Request for DataStoreService.AddPatientFilter method.
Instance Attribute Summary collapse
-
#data_store ⇒ String
Required.
-
#filter_groups ⇒ Array<String>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAddPatientFilterRequest
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaAddPatientFilterRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAddPatientFilterRequest
Returns a new instance of GoogleCloudDiscoveryengineV1alphaAddPatientFilterRequest.
7020 7021 7022 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7020 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_store ⇒ String
Required. Full resource name of DataStore, such as projects/project/
locations/location/collections/collection_id/dataStores/data_store_id`.
If the caller does not have permission to access the DataStore, regardless of
whether or not it exists, a PERMISSION_DENIED error is returned. If the
requested DataStore does not exist, a NOT_FOUND error is returned. If the
requested DataStore already has a patient filter, an ALREADY_EXISTS error will
be returned.
Corresponds to the JSON propertydataStore`
7003 7004 7005 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7003 def data_store @data_store end |
#filter_groups ⇒ Array<String>
Required. Names of the Group resources to use as a basis for the patient
filter, in format projects/project_id/locations/location_id/datasets/
dataset_id/fhirStores/fhir_store_id/fhir/Group/group_id`. if the caller
does not have permission to access the FHIR store, regardless of whether it
exists, PERMISSION_DENIED error is returned. If the discovery engine service
account does not have permission to access the FHIR store, regardless of
whether or not it exists, a PERMISSION_DENIED error is returned. If the group
is not found at the location, a RESOURCE_NOT_FOUND error will be returned. The
filter group must be a FHIR resource name of type Group, and the filter will
be constructed from the direct members of the group which are Patient
resources.
Corresponds to the JSON propertyfilterGroups`
7018 7019 7020 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7018 def filter_groups @filter_groups end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7025 7026 7027 7028 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7025 def update!(**args) @data_store = args[:data_store] if args.key?(:data_store) @filter_groups = args[:filter_groups] if args.key?(:filter_groups) end |