Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAgentGatewaySetting
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAgentGatewaySetting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Agent Gateway setting, which may be attached to Gemini Enterprise resources for egress control of Gemini Enterprise agents to agents and tools outside of Gemini Enterprise.
Instance Attribute Summary collapse
-
#default_egress_agent_gateway ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAgentGatewaySettingAgentGatewayReference
Reference to an Agent Gateway resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAgentGatewaySetting
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaAgentGatewaySetting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAgentGatewaySetting
Returns a new instance of GoogleCloudDiscoveryengineV1alphaAgentGatewaySetting.
7192 7193 7194 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7192 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_egress_agent_gateway ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAgentGatewaySettingAgentGatewayReference
Reference to an Agent Gateway resource.
Corresponds to the JSON property defaultEgressAgentGateway
7190 7191 7192 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7190 def default_egress_agent_gateway @default_egress_agent_gateway end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7197 7198 7199 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7197 def update!(**args) @default_egress_agent_gateway = args[:default_egress_agent_gateway] if args.key?(:default_egress_agent_gateway) end |