Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAlertPolicyResourceConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

The resource level alert config. Used in: * UserLicense * EngineUserData The AlertPolicyConfig in data connector is of same usage. No easy way to migrate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAlertPolicyResourceConfig

Returns a new instance of GoogleCloudDiscoveryengineV1alphaAlertPolicyResourceConfig.



7179
7180
7181
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7179

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#alert_enrollmentsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAlertPolicyResourceConfigAlertEnrollment>

Optional. The enrollment state of each alert. Corresponds to the JSON property alertEnrollments



7157
7158
7159
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7157

def alert_enrollments
  @alert_enrollments
end

#alert_policyString

Immutable. The fully qualified resource name of the AlertPolicy. Corresponds to the JSON property alertPolicy

Returns:

  • (String)


7162
7163
7164
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7162

def alert_policy
  @alert_policy
end

#contact_detailsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaContactDetails>

Optional. The contact details for each alert policy. Corresponds to the JSON property contactDetails



7167
7168
7169
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7167

def contact_details
  @contact_details
end

#language_codeString

Optional. The language code used for notifications Corresponds to the JSON property languageCode

Returns:

  • (String)


7172
7173
7174
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7172

def language_code
  @language_code
end

#region_codeString

Optional. The region code used of the user that subscribed to the alert policy. Corresponds to the JSON property regionCode

Returns:

  • (String)


7177
7178
7179
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7177

def region_code
  @region_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7184
7185
7186
7187
7188
7189
7190
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7184

def update!(**args)
  @alert_enrollments = args[:alert_enrollments] if args.key?(:alert_enrollments)
  @alert_policy = args[:alert_policy] if args.key?(:alert_policy)
  @contact_details = args[:contact_details] if args.key?(:contact_details)
  @language_code = args[:language_code] if args.key?(:language_code)
  @region_code = args[:region_code] if args.key?(:region_code)
end