Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAlphaEvolveExperiment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

An experiment is a single run of the AlphaEvolve agent, an evolutionary coding agent powered by LLM for algorithm discovery and optimization.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAlphaEvolveExperiment

Returns a new instance of GoogleCloudDiscoveryengineV1alphaAlphaEvolveExperiment.



7544
7545
7546
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7544

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAlphaEvolveExperimentConfig

Configuration of an experiment. Corresponds to the JSON property config



7514
7515
7516
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7514

def config
  @config
end

#create_timeString

Output only. Time when the experiment was created. Corresponds to the JSON property createTime

Returns:

  • (String)


7519
7520
7521
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7519

def create_time
  @create_time
end

#initial_alpha_evolve_programString

Output only. Specifies the name of the seed program used to start the experiment. Corresponds to the JSON property initialAlphaEvolveProgram

Returns:

  • (String)


7525
7526
7527
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7525

def initial_alpha_evolve_program
  @initial_alpha_evolve_program
end

#nameString

Identifier. The full resource name of the experiment. Format: projects/ project/locations/location/collections/collection/engines/engine/ sessions/session/alphaEvolveExperiments/alpha_evolve_experiment` Corresponds to the JSON propertyname`

Returns:

  • (String)


7532
7533
7534
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7532

def name
  @name
end

#stateString

Output only. The state of the experiment. Corresponds to the JSON property state

Returns:

  • (String)


7537
7538
7539
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7537

def state
  @state
end

#statsGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAlphaEvolveExperimentStats

Stats about the experiment. Corresponds to the JSON property stats



7542
7543
7544
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7542

def stats
  @stats
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7549
7550
7551
7552
7553
7554
7555
7556
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7549

def update!(**args)
  @config = args[:config] if args.key?(:config)
  @create_time = args[:create_time] if args.key?(:create_time)
  @initial_alpha_evolve_program = args[:initial_alpha_evolve_program] if args.key?(:initial_alpha_evolve_program)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @stats = args[:stats] if args.key?(:stats)
end