Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAlphaEvolveExperiment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

An experiment is a single run of the AlphaEvolve agent, an evolutionary coding agent powered by LLM for algorithm discovery and optimization.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAlphaEvolveExperiment

Returns a new instance of GoogleCloudDiscoveryengineV1alphaAlphaEvolveExperiment.



7465
7466
7467
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7465

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAlphaEvolveExperimentConfig

Configuration of an experiment. Corresponds to the JSON property config



7435
7436
7437
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7435

def config
  @config
end

#create_timeString

Output only. Time when the experiment was created. Corresponds to the JSON property createTime

Returns:

  • (String)


7440
7441
7442
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7440

def create_time
  @create_time
end

#initial_alpha_evolve_programString

Output only. Specifies the name of the seed program used to start the experiment. Corresponds to the JSON property initialAlphaEvolveProgram

Returns:

  • (String)


7446
7447
7448
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7446

def initial_alpha_evolve_program
  @initial_alpha_evolve_program
end

#nameString

Identifier. The full resource name of the experiment. Format: projects/ project/locations/location/collections/collection/engines/engine/ sessions/session/alphaEvolveExperiments/alpha_evolve_experiment` Corresponds to the JSON propertyname`

Returns:

  • (String)


7453
7454
7455
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7453

def name
  @name
end

#stateString

Output only. The state of the experiment. Corresponds to the JSON property state

Returns:

  • (String)


7458
7459
7460
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7458

def state
  @state
end

#statsGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAlphaEvolveExperimentStats

Stats about the experiment. Corresponds to the JSON property stats



7463
7464
7465
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7463

def stats
  @stats
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7470
7471
7472
7473
7474
7475
7476
7477
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7470

def update!(**args)
  @config = args[:config] if args.key?(:config)
  @create_time = args[:create_time] if args.key?(:create_time)
  @initial_alpha_evolve_program = args[:initial_alpha_evolve_program] if args.key?(:initial_alpha_evolve_program)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @stats = args[:stats] if args.key?(:stats)
end