Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAlphaEvolveExperimentConfigRunSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Run settings for the experiment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAlphaEvolveExperimentConfigRunSettings

Returns a new instance of GoogleCloudDiscoveryengineV1alphaAlphaEvolveExperimentConfigRunSettings.



7761
7762
7763
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7761

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#concurrencyFixnum

Required. Maximum number of programs that can be generated in parallel. Must be positive. Corresponds to the JSON property concurrency

Returns:

  • (Fixnum)


7748
7749
7750
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7748

def concurrency
  @concurrency
end

#max_durationString

Optional. Maximum duration of the experiment. If unset, defaults to 24 hours. Corresponds to the JSON property maxDuration

Returns:

  • (String)


7753
7754
7755
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7753

def max_duration
  @max_duration
end

#max_programsFixnum

Required. Maximum number of programs to generate during the experiment run. The initial program counts towards this limit. Must be greater than 1. Corresponds to the JSON property maxPrograms

Returns:

  • (Fixnum)


7759
7760
7761
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7759

def max_programs
  @max_programs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7766
7767
7768
7769
7770
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7766

def update!(**args)
  @concurrency = args[:concurrency] if args.key?(:concurrency)
  @max_duration = args[:max_duration] if args.key?(:max_duration)
  @max_programs = args[:max_programs] if args.key?(:max_programs)
end