Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAlphaEvolveExperimentConfigRunSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Run settings for the experiment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAlphaEvolveExperimentConfigRunSettings

Returns a new instance of GoogleCloudDiscoveryengineV1alphaAlphaEvolveExperimentConfigRunSettings.



7704
7705
7706
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7704

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#concurrencyFixnum

Required. Maximum number of programs that can be generated in parallel. Must be positive. Corresponds to the JSON property concurrency

Returns:

  • (Fixnum)


7691
7692
7693
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7691

def concurrency
  @concurrency
end

#max_durationString

Optional. Maximum duration of the experiment. If unset, defaults to 24 hours. Corresponds to the JSON property maxDuration

Returns:

  • (String)


7696
7697
7698
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7696

def max_duration
  @max_duration
end

#max_programsFixnum

Required. Maximum number of programs to generate during the experiment run. The initial program counts towards this limit. Must be greater than 1. Corresponds to the JSON property maxPrograms

Returns:

  • (Fixnum)


7702
7703
7704
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7702

def max_programs
  @max_programs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7709
7710
7711
7712
7713
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7709

def update!(**args)
  @concurrency = args[:concurrency] if args.key?(:concurrency)
  @max_duration = args[:max_duration] if args.key?(:max_duration)
  @max_programs = args[:max_programs] if args.key?(:max_programs)
end