Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAlphaEvolveExperimentConfigRunSettings
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAlphaEvolveExperimentConfigRunSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Run settings for the experiment.
Instance Attribute Summary collapse
-
#concurrency ⇒ Fixnum
Required.
-
#max_duration ⇒ String
Optional.
-
#max_programs ⇒ Fixnum
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAlphaEvolveExperimentConfigRunSettings
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaAlphaEvolveExperimentConfigRunSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAlphaEvolveExperimentConfigRunSettings
Returns a new instance of GoogleCloudDiscoveryengineV1alphaAlphaEvolveExperimentConfigRunSettings.
7692 7693 7694 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7692 def initialize(**args) update!(**args) end |
Instance Attribute Details
#concurrency ⇒ Fixnum
Required. Maximum number of programs that can be generated in parallel. Must
be positive.
Corresponds to the JSON property concurrency
7679 7680 7681 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7679 def concurrency @concurrency end |
#max_duration ⇒ String
Optional. Maximum duration of the experiment. If unset, defaults to 24 hours.
Corresponds to the JSON property maxDuration
7684 7685 7686 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7684 def max_duration @max_duration end |
#max_programs ⇒ Fixnum
Required. Maximum number of programs to generate during the experiment run.
The initial program counts towards this limit. Must be greater than 1.
Corresponds to the JSON property maxPrograms
7690 7691 7692 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7690 def max_programs @max_programs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7697 7698 7699 7700 7701 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7697 def update!(**args) @concurrency = args[:concurrency] if args.key?(:concurrency) @max_duration = args[:max_duration] if args.key?(:max_duration) @max_programs = args[:max_programs] if args.key?(:max_programs) end |