Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAlphaEvolveExperimentConfigRunSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Run settings for the experiment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAlphaEvolveExperimentConfigRunSettings

Returns a new instance of GoogleCloudDiscoveryengineV1alphaAlphaEvolveExperimentConfigRunSettings.



7682
7683
7684
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7682

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#concurrencyFixnum

Required. Maximum number of programs that can be generated in parallel. Must be positive. Corresponds to the JSON property concurrency

Returns:

  • (Fixnum)


7669
7670
7671
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7669

def concurrency
  @concurrency
end

#max_durationString

Optional. Maximum duration of the experiment. If unset, defaults to 24 hours. Corresponds to the JSON property maxDuration

Returns:

  • (String)


7674
7675
7676
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7674

def max_duration
  @max_duration
end

#max_programsFixnum

Required. Maximum number of programs to generate during the experiment run. The initial program counts towards this limit. Must be greater than 1. Corresponds to the JSON property maxPrograms

Returns:

  • (Fixnum)


7680
7681
7682
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7680

def max_programs
  @max_programs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7687
7688
7689
7690
7691
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7687

def update!(**args)
  @concurrency = args[:concurrency] if args.key?(:concurrency)
  @max_duration = args[:max_duration] if args.key?(:max_duration)
  @max_programs = args[:max_programs] if args.key?(:max_programs)
end