Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAlphaEvolveExperimentStats

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Stats about the experiment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAlphaEvolveExperimentStats

Returns a new instance of GoogleCloudDiscoveryengineV1alphaAlphaEvolveExperimentStats.



7718
7719
7720
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7718

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#candidates_countFixnum

Output only. Number of candidates generated. Corresponds to the JSON property candidatesCount

Returns:

  • (Fixnum)


7701
7702
7703
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7701

def candidates_count
  @candidates_count
end

#evaluated_candidates_countFixnum

Output only. Number of candidates evaluated. Corresponds to the JSON property evaluatedCandidatesCount

Returns:

  • (Fixnum)


7706
7707
7708
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7706

def evaluated_candidates_count
  @evaluated_candidates_count
end

#input_token_countFixnum

Output only. Number of billed input tokens consumed by the experiment. Corresponds to the JSON property inputTokenCount

Returns:

  • (Fixnum)


7711
7712
7713
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7711

def input_token_count
  @input_token_count
end

#output_token_countFixnum

Output only. Number of billed output tokens consumed by the experiment. Corresponds to the JSON property outputTokenCount

Returns:

  • (Fixnum)


7716
7717
7718
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7716

def output_token_count
  @output_token_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7723
7724
7725
7726
7727
7728
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7723

def update!(**args)
  @candidates_count = args[:candidates_count] if args.key?(:candidates_count)
  @evaluated_candidates_count = args[:evaluated_candidates_count] if args.key?(:evaluated_candidates_count)
  @input_token_count = args[:input_token_count] if args.key?(:input_token_count)
  @output_token_count = args[:output_token_count] if args.key?(:output_token_count)
end