Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAlphaEvolveProgram

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Represents a single program to be used within the context of an AlphaEvolve experiment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAlphaEvolveProgram

Returns a new instance of GoogleCloudDiscoveryengineV1alphaAlphaEvolveProgram.



7778
7779
7780
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7778

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAlphaEvolveProgramContent

A self-contained message containing the content of a program. Can represent a collection of files. Corresponds to the JSON property content



7740
7741
7742
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7740

def content
  @content
end

#create_timeString

Output only. Time when the program was created. Corresponds to the JSON property createTime

Returns:

  • (String)


7745
7746
7747
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7745

def create_time
  @create_time
end

#evaluationGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAlphaEvolveProgramEvaluation

Evaluation results for a program candidate. Corresponds to the JSON property evaluation



7750
7751
7752
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7750

def evaluation
  @evaluation
end

#lock_tokenString

Optional. Lock token for the program. Corresponds to the JSON property lockToken

Returns:

  • (String)


7755
7756
7757
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7755

def lock_token
  @lock_token
end

#nameString

Identifier. Unique identifier for the program. Format: projects/project/ locations/location/collections/collection/engines/engine/sessions/ session/alphaEvolveExperiments/alpha_evolve_experiment/alphaEvolvePrograms/ alpha_evolve_program` Corresponds to the JSON propertyname`

Returns:

  • (String)


7763
7764
7765
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7763

def name
  @name
end

#parent_programsArray<String>

Output only. Optionally specifies which parent programs this program was evolved from. Format: projects/project/locations/location/collections/ collection/engines/engine/sessions/session/alphaEvolveExperiments/ alpha_evolve_experiment/alphaEvolvePrograms/alpha_evolve_program` Corresponds to the JSON propertyparentPrograms`

Returns:

  • (Array<String>)


7771
7772
7773
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7771

def parent_programs
  @parent_programs
end

#stateString

Output only. State of the program. Corresponds to the JSON property state

Returns:

  • (String)


7776
7777
7778
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7776

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7783
7784
7785
7786
7787
7788
7789
7790
7791
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7783

def update!(**args)
  @content = args[:content] if args.key?(:content)
  @create_time = args[:create_time] if args.key?(:create_time)
  @evaluation = args[:evaluation] if args.key?(:evaluation)
  @lock_token = args[:lock_token] if args.key?(:lock_token)
  @name = args[:name] if args.key?(:name)
  @parent_programs = args[:parent_programs] if args.key?(:parent_programs)
  @state = args[:state] if args.key?(:state)
end