Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAlphaEvolveProgramEvaluation
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAlphaEvolveProgramEvaluation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Evaluation results for a program candidate.
Instance Attribute Summary collapse
-
#insights ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAlphaEvolveEvaluationInsights
Evaluation insights for a program.
-
#scores ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAlphaEvolveEvaluationScores
Contains the evaluation scores for the target metrics to optimize.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAlphaEvolveProgramEvaluation
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaAlphaEvolveProgramEvaluation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAlphaEvolveProgramEvaluation
Returns a new instance of GoogleCloudDiscoveryengineV1alphaAlphaEvolveProgramEvaluation.
7834 7835 7836 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7834 def initialize(**args) update!(**args) end |
Instance Attribute Details
#insights ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAlphaEvolveEvaluationInsights
Evaluation insights for a program.
Corresponds to the JSON property insights
7827 7828 7829 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7827 def insights @insights end |
#scores ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAlphaEvolveEvaluationScores
Contains the evaluation scores for the target metrics to optimize.
Corresponds to the JSON property scores
7832 7833 7834 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7832 def scores @scores end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7839 7840 7841 7842 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7839 def update!(**args) @insights = args[:insights] if args.key?(:insights) @scores = args[:scores] if args.key?(:scores) end |