Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAlphaEvolveSourceFile
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAlphaEvolveSourceFile
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
A single source file with its path, content and metadata.
Instance Attribute Summary collapse
-
#content ⇒ String
Required.
-
#description ⇒ String
Optional.
-
#path ⇒ String
Required.
-
#program_language ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAlphaEvolveSourceFile
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaAlphaEvolveSourceFile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAlphaEvolveSourceFile
Returns a new instance of GoogleCloudDiscoveryengineV1alphaAlphaEvolveSourceFile.
7871 7872 7873 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7871 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content ⇒ String
Required. The raw content of the file. This is a string and not bytes, because
it should be ultimately processed by the LLM as text.
Corresponds to the JSON property content
7853 7854 7855 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7853 def content @content end |
#description ⇒ String
Optional. Additional description of the file.
Corresponds to the JSON property description
7858 7859 7860 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7858 def description @description end |
#path ⇒ String
Required. The relative path of the file, including the filename. e.g., "src/
main.py", "utils/helpers.js", "README.md"
Corresponds to the JSON property path
7864 7865 7866 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7864 def path @path end |
#program_language ⇒ String
Optional. The programming language of the file.
Corresponds to the JSON property programLanguage
7869 7870 7871 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7869 def program_language @program_language end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7876 7877 7878 7879 7880 7881 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7876 def update!(**args) @content = args[:content] if args.key?(:content) @description = args[:description] if args.key?(:description) @path = args[:path] if args.key?(:path) @program_language = args[:program_language] if args.key?(:program_language) end |