Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswer

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Defines an answer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAnswer

Returns a new instance of GoogleCloudDiscoveryengineV1alphaAnswer.



7988
7989
7990
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7988

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#answer_skipped_reasonsArray<String>

Additional answer-skipped reasons. This provides the reason for ignored cases. If nothing is skipped, this field is not set. Corresponds to the JSON property answerSkippedReasons

Returns:

  • (Array<String>)


7914
7915
7916
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7914

def answer_skipped_reasons
  @answer_skipped_reasons
end

#answer_textString

The textual answer. Corresponds to the JSON property answerText

Returns:

  • (String)


7919
7920
7921
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7919

def answer_text
  @answer_text
end

#blob_attachmentsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerBlobAttachment>

Output only. List of blob attachments in the answer. Corresponds to the JSON property blobAttachments



7924
7925
7926
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7924

def blob_attachments
  @blob_attachments
end

#citationsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerCitation>

Citations. Corresponds to the JSON property citations



7929
7930
7931
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7929

def citations
  @citations
end

#complete_timeString

Output only. Answer completed timestamp. Corresponds to the JSON property completeTime

Returns:

  • (String)


7934
7935
7936
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7934

def complete_time
  @complete_time
end

#create_timeString

Output only. Answer creation timestamp. Corresponds to the JSON property createTime

Returns:

  • (String)


7939
7940
7941
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7939

def create_time
  @create_time
end

#grounding_scoreFloat

A score in the range of [0, 1] describing how grounded the answer is by the reference chunks. Corresponds to the JSON property groundingScore

Returns:

  • (Float)


7945
7946
7947
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7945

def grounding_score
  @grounding_score
end

#grounding_supportsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerGroundingSupport>

Optional. Grounding supports. Corresponds to the JSON property groundingSupports



7950
7951
7952
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7950

def grounding_supports
  @grounding_supports
end

#nameString

Immutable. Fully qualified name projects/project/locations/global/ collections/collection/engines/engine/sessions/*/answers/* Corresponds to the JSON property name

Returns:

  • (String)


7956
7957
7958
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7956

def name
  @name
end

#query_understanding_infoGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerQueryUnderstandingInfo

Query understanding information. Corresponds to the JSON property queryUnderstandingInfo



7961
7962
7963
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7961

def query_understanding_info
  @query_understanding_info
end

#referencesArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerReference>

References. Corresponds to the JSON property references



7966
7967
7968
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7966

def references
  @references
end

Suggested related questions. Corresponds to the JSON property relatedQuestions

Returns:

  • (Array<String>)


7971
7972
7973
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7971

def related_questions
  @related_questions
end

#safety_ratingsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSafetyRating>

Optional. Safety ratings. Corresponds to the JSON property safetyRatings



7976
7977
7978
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7976

def safety_ratings
  @safety_ratings
end

#stateString

The state of the answer generation. Corresponds to the JSON property state

Returns:

  • (String)


7981
7982
7983
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7981

def state
  @state
end

#stepsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerStep>

Answer generation steps. Corresponds to the JSON property steps



7986
7987
7988
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7986

def steps
  @steps
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7993
7994
7995
7996
7997
7998
7999
8000
8001
8002
8003
8004
8005
8006
8007
8008
8009
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7993

def update!(**args)
  @answer_skipped_reasons = args[:answer_skipped_reasons] if args.key?(:answer_skipped_reasons)
  @answer_text = args[:answer_text] if args.key?(:answer_text)
  @blob_attachments = args[:blob_attachments] if args.key?(:blob_attachments)
  @citations = args[:citations] if args.key?(:citations)
  @complete_time = args[:complete_time] if args.key?(:complete_time)
  @create_time = args[:create_time] if args.key?(:create_time)
  @grounding_score = args[:grounding_score] if args.key?(:grounding_score)
  @grounding_supports = args[:grounding_supports] if args.key?(:grounding_supports)
  @name = args[:name] if args.key?(:name)
  @query_understanding_info = args[:query_understanding_info] if args.key?(:query_understanding_info)
  @references = args[:references] if args.key?(:references)
  @related_questions = args[:related_questions] if args.key?(:related_questions)
  @safety_ratings = args[:safety_ratings] if args.key?(:safety_ratings)
  @state = args[:state] if args.key?(:state)
  @steps = args[:steps] if args.key?(:steps)
end