Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswer

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Defines an answer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAnswer

Returns a new instance of GoogleCloudDiscoveryengineV1alphaAnswer.



7966
7967
7968
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7966

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#answer_skipped_reasonsArray<String>

Additional answer-skipped reasons. This provides the reason for ignored cases. If nothing is skipped, this field is not set. Corresponds to the JSON property answerSkippedReasons

Returns:

  • (Array<String>)


7892
7893
7894
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7892

def answer_skipped_reasons
  @answer_skipped_reasons
end

#answer_textString

The textual answer. Corresponds to the JSON property answerText

Returns:

  • (String)


7897
7898
7899
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7897

def answer_text
  @answer_text
end

#blob_attachmentsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerBlobAttachment>

Output only. List of blob attachments in the answer. Corresponds to the JSON property blobAttachments



7902
7903
7904
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7902

def blob_attachments
  @blob_attachments
end

#citationsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerCitation>

Citations. Corresponds to the JSON property citations



7907
7908
7909
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7907

def citations
  @citations
end

#complete_timeString

Output only. Answer completed timestamp. Corresponds to the JSON property completeTime

Returns:

  • (String)


7912
7913
7914
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7912

def complete_time
  @complete_time
end

#create_timeString

Output only. Answer creation timestamp. Corresponds to the JSON property createTime

Returns:

  • (String)


7917
7918
7919
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7917

def create_time
  @create_time
end

#grounding_scoreFloat

A score in the range of [0, 1] describing how grounded the answer is by the reference chunks. Corresponds to the JSON property groundingScore

Returns:

  • (Float)


7923
7924
7925
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7923

def grounding_score
  @grounding_score
end

#grounding_supportsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerGroundingSupport>

Optional. Grounding supports. Corresponds to the JSON property groundingSupports



7928
7929
7930
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7928

def grounding_supports
  @grounding_supports
end

#nameString

Immutable. Fully qualified name projects/project/locations/global/ collections/collection/engines/engine/sessions/*/answers/* Corresponds to the JSON property name

Returns:

  • (String)


7934
7935
7936
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7934

def name
  @name
end

#query_understanding_infoGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerQueryUnderstandingInfo

Query understanding information. Corresponds to the JSON property queryUnderstandingInfo



7939
7940
7941
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7939

def query_understanding_info
  @query_understanding_info
end

#referencesArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerReference>

References. Corresponds to the JSON property references



7944
7945
7946
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7944

def references
  @references
end

Suggested related questions. Corresponds to the JSON property relatedQuestions

Returns:

  • (Array<String>)


7949
7950
7951
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7949

def related_questions
  @related_questions
end

#safety_ratingsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSafetyRating>

Optional. Safety ratings. Corresponds to the JSON property safetyRatings



7954
7955
7956
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7954

def safety_ratings
  @safety_ratings
end

#stateString

The state of the answer generation. Corresponds to the JSON property state

Returns:

  • (String)


7959
7960
7961
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7959

def state
  @state
end

#stepsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerStep>

Answer generation steps. Corresponds to the JSON property steps



7964
7965
7966
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7964

def steps
  @steps
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7971
7972
7973
7974
7975
7976
7977
7978
7979
7980
7981
7982
7983
7984
7985
7986
7987
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7971

def update!(**args)
  @answer_skipped_reasons = args[:answer_skipped_reasons] if args.key?(:answer_skipped_reasons)
  @answer_text = args[:answer_text] if args.key?(:answer_text)
  @blob_attachments = args[:blob_attachments] if args.key?(:blob_attachments)
  @citations = args[:citations] if args.key?(:citations)
  @complete_time = args[:complete_time] if args.key?(:complete_time)
  @create_time = args[:create_time] if args.key?(:create_time)
  @grounding_score = args[:grounding_score] if args.key?(:grounding_score)
  @grounding_supports = args[:grounding_supports] if args.key?(:grounding_supports)
  @name = args[:name] if args.key?(:name)
  @query_understanding_info = args[:query_understanding_info] if args.key?(:query_understanding_info)
  @references = args[:references] if args.key?(:references)
  @related_questions = args[:related_questions] if args.key?(:related_questions)
  @safety_ratings = args[:safety_ratings] if args.key?(:safety_ratings)
  @state = args[:state] if args.key?(:state)
  @steps = args[:steps] if args.key?(:steps)
end