Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswer

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Defines an answer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAnswer

Returns a new instance of GoogleCloudDiscoveryengineV1alphaAnswer.



7410
7411
7412
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7410

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#answer_skipped_reasonsArray<String>

Additional answer-skipped reasons. This provides the reason for ignored cases. If nothing is skipped, this field is not set. Corresponds to the JSON property answerSkippedReasons

Returns:

  • (Array<String>)


7336
7337
7338
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7336

def answer_skipped_reasons
  @answer_skipped_reasons
end

#answer_textString

The textual answer. Corresponds to the JSON property answerText

Returns:

  • (String)


7341
7342
7343
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7341

def answer_text
  @answer_text
end

#blob_attachmentsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerBlobAttachment>

Output only. List of blob attachments in the answer. Corresponds to the JSON property blobAttachments



7346
7347
7348
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7346

def blob_attachments
  @blob_attachments
end

#citationsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerCitation>

Citations. Corresponds to the JSON property citations



7351
7352
7353
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7351

def citations
  @citations
end

#complete_timeString

Output only. Answer completed timestamp. Corresponds to the JSON property completeTime

Returns:

  • (String)


7356
7357
7358
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7356

def complete_time
  @complete_time
end

#create_timeString

Output only. Answer creation timestamp. Corresponds to the JSON property createTime

Returns:

  • (String)


7361
7362
7363
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7361

def create_time
  @create_time
end

#grounding_scoreFloat

A score in the range of [0, 1] describing how grounded the answer is by the reference chunks. Corresponds to the JSON property groundingScore

Returns:

  • (Float)


7367
7368
7369
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7367

def grounding_score
  @grounding_score
end

#grounding_supportsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerGroundingSupport>

Optional. Grounding supports. Corresponds to the JSON property groundingSupports



7372
7373
7374
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7372

def grounding_supports
  @grounding_supports
end

#nameString

Immutable. Fully qualified name projects/project/locations/global/ collections/collection/engines/engine/sessions/*/answers/* Corresponds to the JSON property name

Returns:

  • (String)


7378
7379
7380
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7378

def name
  @name
end

#query_understanding_infoGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerQueryUnderstandingInfo

Query understanding information. Corresponds to the JSON property queryUnderstandingInfo



7383
7384
7385
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7383

def query_understanding_info
  @query_understanding_info
end

#referencesArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerReference>

References. Corresponds to the JSON property references



7388
7389
7390
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7388

def references
  @references
end

Suggested related questions. Corresponds to the JSON property relatedQuestions

Returns:

  • (Array<String>)


7393
7394
7395
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7393

def related_questions
  @related_questions
end

#safety_ratingsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSafetyRating>

Optional. Safety ratings. Corresponds to the JSON property safetyRatings



7398
7399
7400
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7398

def safety_ratings
  @safety_ratings
end

#stateString

The state of the answer generation. Corresponds to the JSON property state

Returns:

  • (String)


7403
7404
7405
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7403

def state
  @state
end

#stepsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerStep>

Answer generation steps. Corresponds to the JSON property steps



7408
7409
7410
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7408

def steps
  @steps
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7415
7416
7417
7418
7419
7420
7421
7422
7423
7424
7425
7426
7427
7428
7429
7430
7431
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7415

def update!(**args)
  @answer_skipped_reasons = args[:answer_skipped_reasons] if args.key?(:answer_skipped_reasons)
  @answer_text = args[:answer_text] if args.key?(:answer_text)
  @blob_attachments = args[:blob_attachments] if args.key?(:blob_attachments)
  @citations = args[:citations] if args.key?(:citations)
  @complete_time = args[:complete_time] if args.key?(:complete_time)
  @create_time = args[:create_time] if args.key?(:create_time)
  @grounding_score = args[:grounding_score] if args.key?(:grounding_score)
  @grounding_supports = args[:grounding_supports] if args.key?(:grounding_supports)
  @name = args[:name] if args.key?(:name)
  @query_understanding_info = args[:query_understanding_info] if args.key?(:query_understanding_info)
  @references = args[:references] if args.key?(:references)
  @related_questions = args[:related_questions] if args.key?(:related_questions)
  @safety_ratings = args[:safety_ratings] if args.key?(:safety_ratings)
  @state = args[:state] if args.key?(:state)
  @steps = args[:steps] if args.key?(:steps)
end