Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswer
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswer
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Defines an answer.
Instance Attribute Summary collapse
-
#answer_skipped_reasons ⇒ Array<String>
Additional answer-skipped reasons.
-
#answer_text ⇒ String
The textual answer.
-
#blob_attachments ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerBlobAttachment>
Output only.
-
#citations ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerCitation>
Citations.
-
#complete_time ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#grounding_score ⇒ Float
A score in the range of [0, 1] describing how grounded the answer is by the reference chunks.
-
#grounding_supports ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerGroundingSupport>
Optional.
-
#name ⇒ String
Immutable.
-
#query_understanding_info ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerQueryUnderstandingInfo
Query understanding information.
-
#references ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerReference>
References.
-
#related_questions ⇒ Array<String>
Suggested related questions.
-
#safety_ratings ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSafetyRating>
Optional.
-
#state ⇒ String
The state of the answer generation.
-
#steps ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerStep>
Answer generation steps.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAnswer
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaAnswer.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAnswer
Returns a new instance of GoogleCloudDiscoveryengineV1alphaAnswer.
7308 7309 7310 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7308 def initialize(**args) update!(**args) end |
Instance Attribute Details
#answer_skipped_reasons ⇒ Array<String>
Additional answer-skipped reasons. This provides the reason for ignored cases.
If nothing is skipped, this field is not set.
Corresponds to the JSON property answerSkippedReasons
7234 7235 7236 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7234 def answer_skipped_reasons @answer_skipped_reasons end |
#answer_text ⇒ String
The textual answer.
Corresponds to the JSON property answerText
7239 7240 7241 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7239 def answer_text @answer_text end |
#blob_attachments ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerBlobAttachment>
Output only. List of blob attachments in the answer.
Corresponds to the JSON property blobAttachments
7244 7245 7246 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7244 def @blob_attachments end |
#citations ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerCitation>
Citations.
Corresponds to the JSON property citations
7249 7250 7251 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7249 def citations @citations end |
#complete_time ⇒ String
Output only. Answer completed timestamp.
Corresponds to the JSON property completeTime
7254 7255 7256 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7254 def complete_time @complete_time end |
#create_time ⇒ String
Output only. Answer creation timestamp.
Corresponds to the JSON property createTime
7259 7260 7261 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7259 def create_time @create_time end |
#grounding_score ⇒ Float
A score in the range of [0, 1] describing how grounded the answer is by the
reference chunks.
Corresponds to the JSON property groundingScore
7265 7266 7267 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7265 def grounding_score @grounding_score end |
#grounding_supports ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerGroundingSupport>
Optional. Grounding supports.
Corresponds to the JSON property groundingSupports
7270 7271 7272 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7270 def grounding_supports @grounding_supports end |
#name ⇒ String
Immutable. Fully qualified name projects/project/locations/global/
collections/collection/engines/engine/sessions/*/answers/*
Corresponds to the JSON property name
7276 7277 7278 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7276 def name @name end |
#query_understanding_info ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerQueryUnderstandingInfo
Query understanding information.
Corresponds to the JSON property queryUnderstandingInfo
7281 7282 7283 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7281 def query_understanding_info @query_understanding_info end |
#references ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerReference>
References.
Corresponds to the JSON property references
7286 7287 7288 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7286 def references @references end |
#related_questions ⇒ Array<String>
Suggested related questions.
Corresponds to the JSON property relatedQuestions
7291 7292 7293 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7291 def @related_questions end |
#safety_ratings ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSafetyRating>
Optional. Safety ratings.
Corresponds to the JSON property safetyRatings
7296 7297 7298 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7296 def @safety_ratings end |
#state ⇒ String
The state of the answer generation.
Corresponds to the JSON property state
7301 7302 7303 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7301 def state @state end |
#steps ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerStep>
Answer generation steps.
Corresponds to the JSON property steps
7306 7307 7308 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7306 def steps @steps end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7313 7314 7315 7316 7317 7318 7319 7320 7321 7322 7323 7324 7325 7326 7327 7328 7329 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7313 def update!(**args) @answer_skipped_reasons = args[:answer_skipped_reasons] if args.key?(:answer_skipped_reasons) @answer_text = args[:answer_text] if args.key?(:answer_text) @blob_attachments = args[:blob_attachments] if args.key?(:blob_attachments) @citations = args[:citations] if args.key?(:citations) @complete_time = args[:complete_time] if args.key?(:complete_time) @create_time = args[:create_time] if args.key?(:create_time) @grounding_score = args[:grounding_score] if args.key?(:grounding_score) @grounding_supports = args[:grounding_supports] if args.key?(:grounding_supports) @name = args[:name] if args.key?(:name) @query_understanding_info = args[:query_understanding_info] if args.key?(:query_understanding_info) @references = args[:references] if args.key?(:references) @related_questions = args[:related_questions] if args.key?(:related_questions) @safety_ratings = args[:safety_ratings] if args.key?(:safety_ratings) @state = args[:state] if args.key?(:state) @steps = args[:steps] if args.key?(:steps) end |