Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerCitation
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerCitation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Citation info for a segment.
Instance Attribute Summary collapse
-
#end_index ⇒ Fixnum
End of the attributed segment, exclusive.
-
#sources ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerCitationSource>
Citation sources for the attributed segment.
-
#start_index ⇒ Fixnum
Index indicates the start of the segment, measured in bytes (UTF-8 unicode).
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAnswerCitation
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaAnswerCitation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAnswerCitation
Returns a new instance of GoogleCloudDiscoveryengineV1alphaAnswerCitation.
7508 7509 7510 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7508 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_index ⇒ Fixnum
End of the attributed segment, exclusive. Measured in bytes (UTF-8 unicode).
If there are multi-byte characters,such as non-ASCII characters, the index
measurement is longer than the string length.
Corresponds to the JSON property endIndex
7494 7495 7496 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7494 def end_index @end_index end |
#sources ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerCitationSource>
Citation sources for the attributed segment.
Corresponds to the JSON property sources
7499 7500 7501 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7499 def sources @sources end |
#start_index ⇒ Fixnum
Index indicates the start of the segment, measured in bytes (UTF-8 unicode).
If there are multi-byte characters,such as non-ASCII characters, the index
measurement is longer than the string length.
Corresponds to the JSON property startIndex
7506 7507 7508 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7506 def start_index @start_index end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7513 7514 7515 7516 7517 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7513 def update!(**args) @end_index = args[:end_index] if args.key?(:end_index) @sources = args[:sources] if args.key?(:sources) @start_index = args[:start_index] if args.key?(:start_index) end |