Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerCitation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Citation info for a segment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAnswerCitation

Returns a new instance of GoogleCloudDiscoveryengineV1alphaAnswerCitation.



7406
7407
7408
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7406

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_indexFixnum

End of the attributed segment, exclusive. Measured in bytes (UTF-8 unicode). If there are multi-byte characters,such as non-ASCII characters, the index measurement is longer than the string length. Corresponds to the JSON property endIndex

Returns:

  • (Fixnum)


7392
7393
7394
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7392

def end_index
  @end_index
end

#sourcesArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerCitationSource>

Citation sources for the attributed segment. Corresponds to the JSON property sources



7397
7398
7399
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7397

def sources
  @sources
end

#start_indexFixnum

Index indicates the start of the segment, measured in bytes (UTF-8 unicode). If there are multi-byte characters,such as non-ASCII characters, the index measurement is longer than the string length. Corresponds to the JSON property startIndex

Returns:

  • (Fixnum)


7404
7405
7406
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7404

def start_index
  @start_index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7411
7412
7413
7414
7415
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7411

def update!(**args)
  @end_index = args[:end_index] if args.key?(:end_index)
  @sources = args[:sources] if args.key?(:sources)
  @start_index = args[:start_index] if args.key?(:start_index)
end