Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerGroundingSupport

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Grounding support for a claim in answer_text.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAnswerGroundingSupport

Returns a new instance of GoogleCloudDiscoveryengineV1alphaAnswerGroundingSupport.



8141
8142
8143
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8141

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_indexFixnum

Required. End of the claim, exclusive. Corresponds to the JSON property endIndex

Returns:

  • (Fixnum)


8112
8113
8114
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8112

def end_index
  @end_index
end

#grounding_check_requiredBoolean Also known as: grounding_check_required?

Indicates that this claim required grounding check. When the system decided this claim didn't require attribution/grounding check, this field is set to false. In that case, no grounding check was done for the claim and therefore grounding_score, sources is not returned. Corresponds to the JSON property groundingCheckRequired

Returns:

  • (Boolean)


8120
8121
8122
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8120

def grounding_check_required
  @grounding_check_required
end

#grounding_scoreFloat

A score in the range of [0, 1] describing how grounded is a specific claim by the references. Higher value means that the claim is better supported by the reference chunks. Corresponds to the JSON property groundingScore

Returns:

  • (Float)


8128
8129
8130
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8128

def grounding_score
  @grounding_score
end

#sourcesArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerCitationSource>

Optional. Citation sources for the claim. Corresponds to the JSON property sources



8133
8134
8135
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8133

def sources
  @sources
end

#start_indexFixnum

Required. Index indicates the start of the claim, measured in bytes (UTF-8 unicode). Corresponds to the JSON property startIndex

Returns:

  • (Fixnum)


8139
8140
8141
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8139

def start_index
  @start_index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8146
8147
8148
8149
8150
8151
8152
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8146

def update!(**args)
  @end_index = args[:end_index] if args.key?(:end_index)
  @grounding_check_required = args[:grounding_check_required] if args.key?(:grounding_check_required)
  @grounding_score = args[:grounding_score] if args.key?(:grounding_score)
  @sources = args[:sources] if args.key?(:sources)
  @start_index = args[:start_index] if args.key?(:start_index)
end