Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerReferenceChunkInfo
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerReferenceChunkInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Chunk information.
Instance Attribute Summary collapse
-
#blob_attachment_indexes ⇒ Array<Fixnum>
Output only.
-
#chunk ⇒ String
Chunk resource name.
-
#content ⇒ String
Chunk textual content.
-
#document_metadata ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerReferenceChunkInfoDocumentMetadata
Document metadata.
-
#relevance_score ⇒ Float
The relevance of the chunk for a given query.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAnswerReferenceChunkInfo
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaAnswerReferenceChunkInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAnswerReferenceChunkInfo
Returns a new instance of GoogleCloudDiscoveryengineV1alphaAnswerReferenceChunkInfo.
7697 7698 7699 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7697 def initialize(**args) update!(**args) end |
Instance Attribute Details
#blob_attachment_indexes ⇒ Array<Fixnum>
Output only. Stores indexes of blobattachments linked to this chunk.
Corresponds to the JSON property blobAttachmentIndexes
7672 7673 7674 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7672 def @blob_attachment_indexes end |
#chunk ⇒ String
Chunk resource name.
Corresponds to the JSON property chunk
7677 7678 7679 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7677 def chunk @chunk end |
#content ⇒ String
Chunk textual content.
Corresponds to the JSON property content
7682 7683 7684 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7682 def content @content end |
#document_metadata ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerReferenceChunkInfoDocumentMetadata
Document metadata.
Corresponds to the JSON property documentMetadata
7687 7688 7689 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7687 def @document_metadata end |
#relevance_score ⇒ Float
The relevance of the chunk for a given query. Values range from 0.0 (
completely irrelevant) to 1.0 (completely relevant). This value is for
informational purpose only. It may change for the same query and chunk at any
time due to a model retraining or change in implementation.
Corresponds to the JSON property relevanceScore
7695 7696 7697 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7695 def relevance_score @relevance_score end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7702 7703 7704 7705 7706 7707 7708 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7702 def update!(**args) @blob_attachment_indexes = args[:blob_attachment_indexes] if args.key?(:blob_attachment_indexes) @chunk = args[:chunk] if args.key?(:chunk) @content = args[:content] if args.key?(:content) @document_metadata = args[:document_metadata] if args.key?(:document_metadata) @relevance_score = args[:relevance_score] if args.key?(:relevance_score) end |