Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerReferenceChunkInfo
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerReferenceChunkInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Chunk information.
Instance Attribute Summary collapse
-
#blob_attachment_indexes ⇒ Array<Fixnum>
Output only.
-
#chunk ⇒ String
Chunk resource name.
-
#content ⇒ String
Chunk textual content.
-
#document_metadata ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerReferenceChunkInfoDocumentMetadata
Document metadata.
-
#relevance_score ⇒ Float
The relevance of the chunk for a given query.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAnswerReferenceChunkInfo
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaAnswerReferenceChunkInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAnswerReferenceChunkInfo
Returns a new instance of GoogleCloudDiscoveryengineV1alphaAnswerReferenceChunkInfo.
7595 7596 7597 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7595 def initialize(**args) update!(**args) end |
Instance Attribute Details
#blob_attachment_indexes ⇒ Array<Fixnum>
Output only. Stores indexes of blobattachments linked to this chunk.
Corresponds to the JSON property blobAttachmentIndexes
7570 7571 7572 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7570 def @blob_attachment_indexes end |
#chunk ⇒ String
Chunk resource name.
Corresponds to the JSON property chunk
7575 7576 7577 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7575 def chunk @chunk end |
#content ⇒ String
Chunk textual content.
Corresponds to the JSON property content
7580 7581 7582 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7580 def content @content end |
#document_metadata ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerReferenceChunkInfoDocumentMetadata
Document metadata.
Corresponds to the JSON property documentMetadata
7585 7586 7587 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7585 def @document_metadata end |
#relevance_score ⇒ Float
The relevance of the chunk for a given query. Values range from 0.0 (
completely irrelevant) to 1.0 (completely relevant). This value is for
informational purpose only. It may change for the same query and chunk at any
time due to a model retraining or change in implementation.
Corresponds to the JSON property relevanceScore
7593 7594 7595 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7593 def relevance_score @relevance_score end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7600 7601 7602 7603 7604 7605 7606 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7600 def update!(**args) @blob_attachment_indexes = args[:blob_attachment_indexes] if args.key?(:blob_attachment_indexes) @chunk = args[:chunk] if args.key?(:chunk) @content = args[:content] if args.key?(:content) @document_metadata = args[:document_metadata] if args.key?(:document_metadata) @relevance_score = args[:relevance_score] if args.key?(:relevance_score) end |