Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerReferenceUnstructuredDocumentInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Unstructured document information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAnswerReferenceUnstructuredDocumentInfo

Returns a new instance of GoogleCloudDiscoveryengineV1alphaAnswerReferenceUnstructuredDocumentInfo.



8457
8458
8459
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8457

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chunk_contentsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerReferenceUnstructuredDocumentInfoChunkContent>

List of cited chunk contents derived from document content. Corresponds to the JSON property chunkContents



8434
8435
8436
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8434

def chunk_contents
  @chunk_contents
end

#documentString

Document resource name. Corresponds to the JSON property document

Returns:

  • (String)


8439
8440
8441
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8439

def document
  @document
end

#struct_dataHash<String,Object>

The structured JSON metadata for the document. It is populated from the struct data from the Chunk in search result. Corresponds to the JSON property structData

Returns:

  • (Hash<String,Object>)


8445
8446
8447
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8445

def struct_data
  @struct_data
end

#titleString

Title. Corresponds to the JSON property title

Returns:

  • (String)


8450
8451
8452
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8450

def title
  @title
end

#uriString

URI for the document. Corresponds to the JSON property uri

Returns:

  • (String)


8455
8456
8457
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8455

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8462
8463
8464
8465
8466
8467
8468
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8462

def update!(**args)
  @chunk_contents = args[:chunk_contents] if args.key?(:chunk_contents)
  @document = args[:document] if args.key?(:document)
  @struct_data = args[:struct_data] if args.key?(:struct_data)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end