Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerReferenceUnstructuredDocumentInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Unstructured document information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAnswerReferenceUnstructuredDocumentInfo

Returns a new instance of GoogleCloudDiscoveryengineV1alphaAnswerReferenceUnstructuredDocumentInfo.



8378
8379
8380
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8378

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chunk_contentsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerReferenceUnstructuredDocumentInfoChunkContent>

List of cited chunk contents derived from document content. Corresponds to the JSON property chunkContents



8355
8356
8357
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8355

def chunk_contents
  @chunk_contents
end

#documentString

Document resource name. Corresponds to the JSON property document

Returns:

  • (String)


8360
8361
8362
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8360

def document
  @document
end

#struct_dataHash<String,Object>

The structured JSON metadata for the document. It is populated from the struct data from the Chunk in search result. Corresponds to the JSON property structData

Returns:

  • (Hash<String,Object>)


8366
8367
8368
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8366

def struct_data
  @struct_data
end

#titleString

Title. Corresponds to the JSON property title

Returns:

  • (String)


8371
8372
8373
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8371

def title
  @title
end

#uriString

URI for the document. Corresponds to the JSON property uri

Returns:

  • (String)


8376
8377
8378
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8376

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8383
8384
8385
8386
8387
8388
8389
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8383

def update!(**args)
  @chunk_contents = args[:chunk_contents] if args.key?(:chunk_contents)
  @document = args[:document] if args.key?(:document)
  @struct_data = args[:struct_data] if args.key?(:struct_data)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end