Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerReferenceUnstructuredDocumentInfo
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerReferenceUnstructuredDocumentInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Unstructured document information.
Instance Attribute Summary collapse
-
#chunk_contents ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerReferenceUnstructuredDocumentInfoChunkContent>
List of cited chunk contents derived from document content.
-
#document ⇒ String
Document resource name.
-
#struct_data ⇒ Hash<String,Object>
The structured JSON metadata for the document.
-
#title ⇒ String
Title.
-
#uri ⇒ String
URI for the document.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAnswerReferenceUnstructuredDocumentInfo
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaAnswerReferenceUnstructuredDocumentInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAnswerReferenceUnstructuredDocumentInfo
Returns a new instance of GoogleCloudDiscoveryengineV1alphaAnswerReferenceUnstructuredDocumentInfo.
7720 7721 7722 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7720 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chunk_contents ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerReferenceUnstructuredDocumentInfoChunkContent>
List of cited chunk contents derived from document content.
Corresponds to the JSON property chunkContents
7697 7698 7699 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7697 def chunk_contents @chunk_contents end |
#document ⇒ String
Document resource name.
Corresponds to the JSON property document
7702 7703 7704 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7702 def document @document end |
#struct_data ⇒ Hash<String,Object>
The structured JSON metadata for the document. It is populated from the struct
data from the Chunk in search result.
Corresponds to the JSON property structData
7708 7709 7710 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7708 def struct_data @struct_data end |
#title ⇒ String
Title.
Corresponds to the JSON property title
7713 7714 7715 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7713 def title @title end |
#uri ⇒ String
URI for the document.
Corresponds to the JSON property uri
7718 7719 7720 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7718 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7725 7726 7727 7728 7729 7730 7731 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7725 def update!(**args) @chunk_contents = args[:chunk_contents] if args.key?(:chunk_contents) @document = args[:document] if args.key?(:document) @struct_data = args[:struct_data] if args.key?(:struct_data) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) end |