Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerReferenceUnstructuredDocumentInfoChunkContent
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerReferenceUnstructuredDocumentInfoChunkContent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Chunk content.
Instance Attribute Summary collapse
-
#blob_attachment_indexes ⇒ Array<Fixnum>
Output only.
-
#content ⇒ String
Chunk textual content.
-
#page_identifier ⇒ String
Page identifier.
-
#relevance_score ⇒ Float
The relevance of the chunk for a given query.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAnswerReferenceUnstructuredDocumentInfoChunkContent
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaAnswerReferenceUnstructuredDocumentInfoChunkContent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAnswerReferenceUnstructuredDocumentInfoChunkContent
Returns a new instance of GoogleCloudDiscoveryengineV1alphaAnswerReferenceUnstructuredDocumentInfoChunkContent.
7761 7762 7763 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7761 def initialize(**args) update!(**args) end |
Instance Attribute Details
#blob_attachment_indexes ⇒ Array<Fixnum>
Output only. Stores indexes of blobattachments linked to this chunk.
Corresponds to the JSON property blobAttachmentIndexes
7741 7742 7743 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7741 def @blob_attachment_indexes end |
#content ⇒ String
Chunk textual content.
Corresponds to the JSON property content
7746 7747 7748 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7746 def content @content end |
#page_identifier ⇒ String
Page identifier.
Corresponds to the JSON property pageIdentifier
7751 7752 7753 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7751 def page_identifier @page_identifier end |
#relevance_score ⇒ Float
The relevance of the chunk for a given query. Values range from 0.0 (
completely irrelevant) to 1.0 (completely relevant). This value is for
informational purpose only. It may change for the same query and chunk at any
time due to a model retraining or change in implementation.
Corresponds to the JSON property relevanceScore
7759 7760 7761 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7759 def relevance_score @relevance_score end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7766 7767 7768 7769 7770 7771 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7766 def update!(**args) @blob_attachment_indexes = args[:blob_attachment_indexes] if args.key?(:blob_attachment_indexes) @content = args[:content] if args.key?(:content) @page_identifier = args[:page_identifier] if args.key?(:page_identifier) @relevance_score = args[:relevance_score] if args.key?(:relevance_score) end |