Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservation
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Observation.
Instance Attribute Summary collapse
-
#search_results ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservationSearchResult>
Search results observed by the search action, it can be snippets info or chunk info, depending on the citation type set by the user.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservation
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservation
Returns a new instance of GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservation.
8514 8515 8516 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8514 def initialize(**args) update!(**args) end |
Instance Attribute Details
#search_results ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservationSearchResult>
Search results observed by the search action, it can be snippets info or chunk
info, depending on the citation type set by the user.
Corresponds to the JSON property searchResults
8512 8513 8514 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8512 def search_results @search_results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8519 8520 8521 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8519 def update!(**args) @search_results = args[:search_results] if args.key?(:search_results) end |