Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Observation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservation

Returns a new instance of GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservation.



8504
8505
8506
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8504

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#search_resultsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservationSearchResult>

Search results observed by the search action, it can be snippets info or chunk info, depending on the citation type set by the user. Corresponds to the JSON property searchResults



8502
8503
8504
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8502

def search_results
  @search_results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8509
8510
8511
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8509

def update!(**args)
  @search_results = args[:search_results] if args.key?(:search_results)
end