Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservationSearchResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservationSearchResult

Returns a new instance of GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservationSearchResult.



8629
8630
8631
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8629

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chunk_infoArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservationSearchResultChunkInfo>

If citation_type is CHUNK_LEVEL_CITATION and chunk mode is on, populate chunk info. Corresponds to the JSON property chunkInfo



8601
8602
8603
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8601

def chunk_info
  @chunk_info
end

#documentString

Document resource name. Corresponds to the JSON property document

Returns:

  • (String)


8606
8607
8608
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8606

def document
  @document
end

#snippet_infoArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservationSearchResultSnippetInfo>

If citation_type is DOCUMENT_LEVEL_CITATION, populate document level snippets. Corresponds to the JSON property snippetInfo



8611
8612
8613
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8611

def snippet_info
  @snippet_info
end

#struct_dataHash<String,Object>

Data representation. The structured JSON data for the document. It's populated from the struct data from the Document, or the Chunk in search result. Corresponds to the JSON property structData

Returns:

  • (Hash<String,Object>)


8617
8618
8619
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8617

def struct_data
  @struct_data
end

#titleString

Title. Corresponds to the JSON property title

Returns:

  • (String)


8622
8623
8624
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8622

def title
  @title
end

#uriString

URI for the document. Corresponds to the JSON property uri

Returns:

  • (String)


8627
8628
8629
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8627

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8634
8635
8636
8637
8638
8639
8640
8641
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8634

def update!(**args)
  @chunk_info = args[:chunk_info] if args.key?(:chunk_info)
  @document = args[:document] if args.key?(:document)
  @snippet_info = args[:snippet_info] if args.key?(:snippet_info)
  @struct_data = args[:struct_data] if args.key?(:struct_data)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end