Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservationSearchResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservationSearchResult

Returns a new instance of GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservationSearchResult.



8560
8561
8562
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8560

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chunk_infoArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservationSearchResultChunkInfo>

If citation_type is CHUNK_LEVEL_CITATION and chunk mode is on, populate chunk info. Corresponds to the JSON property chunkInfo



8532
8533
8534
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8532

def chunk_info
  @chunk_info
end

#documentString

Document resource name. Corresponds to the JSON property document

Returns:

  • (String)


8537
8538
8539
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8537

def document
  @document
end

#snippet_infoArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservationSearchResultSnippetInfo>

If citation_type is DOCUMENT_LEVEL_CITATION, populate document level snippets. Corresponds to the JSON property snippetInfo



8542
8543
8544
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8542

def snippet_info
  @snippet_info
end

#struct_dataHash<String,Object>

Data representation. The structured JSON data for the document. It's populated from the struct data from the Document, or the Chunk in search result. Corresponds to the JSON property structData

Returns:

  • (Hash<String,Object>)


8548
8549
8550
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8548

def struct_data
  @struct_data
end

#titleString

Title. Corresponds to the JSON property title

Returns:

  • (String)


8553
8554
8555
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8553

def title
  @title
end

#uriString

URI for the document. Corresponds to the JSON property uri

Returns:

  • (String)


8558
8559
8560
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8558

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8565
8566
8567
8568
8569
8570
8571
8572
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8565

def update!(**args)
  @chunk_info = args[:chunk_info] if args.key?(:chunk_info)
  @document = args[:document] if args.key?(:document)
  @snippet_info = args[:snippet_info] if args.key?(:snippet_info)
  @struct_data = args[:struct_data] if args.key?(:struct_data)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end