Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservationSearchResult
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservationSearchResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Instance Attribute Summary collapse
-
#chunk_info ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservationSearchResultChunkInfo>
If citation_type is CHUNK_LEVEL_CITATION and chunk mode is on, populate chunk info.
-
#document ⇒ String
Document resource name.
-
#snippet_info ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservationSearchResultSnippetInfo>
If citation_type is DOCUMENT_LEVEL_CITATION, populate document level snippets.
-
#struct_data ⇒ Hash<String,Object>
Data representation.
-
#title ⇒ String
Title.
-
#uri ⇒ String
URI for the document.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservationSearchResult
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservationSearchResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservationSearchResult
Returns a new instance of GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservationSearchResult.
8550 8551 8552 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8550 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chunk_info ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservationSearchResultChunkInfo>
If citation_type is CHUNK_LEVEL_CITATION and chunk mode is on, populate chunk
info.
Corresponds to the JSON property chunkInfo
8522 8523 8524 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8522 def chunk_info @chunk_info end |
#document ⇒ String
Document resource name.
Corresponds to the JSON property document
8527 8528 8529 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8527 def document @document end |
#snippet_info ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservationSearchResultSnippetInfo>
If citation_type is DOCUMENT_LEVEL_CITATION, populate document level snippets.
Corresponds to the JSON property snippetInfo
8532 8533 8534 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8532 def snippet_info @snippet_info end |
#struct_data ⇒ Hash<String,Object>
Data representation. The structured JSON data for the document. It's populated
from the struct data from the Document, or the Chunk in search result.
Corresponds to the JSON property structData
8538 8539 8540 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8538 def struct_data @struct_data end |
#title ⇒ String
Title.
Corresponds to the JSON property title
8543 8544 8545 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8543 def title @title end |
#uri ⇒ String
URI for the document.
Corresponds to the JSON property uri
8548 8549 8550 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8548 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8555 8556 8557 8558 8559 8560 8561 8562 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8555 def update!(**args) @chunk_info = args[:chunk_info] if args.key?(:chunk_info) @document = args[:document] if args.key?(:document) @snippet_info = args[:snippet_info] if args.key?(:snippet_info) @struct_data = args[:struct_data] if args.key?(:struct_data) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) end |