Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservationSearchResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservationSearchResult

Returns a new instance of GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservationSearchResult.



7994
7995
7996
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7994

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chunk_infoArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservationSearchResultChunkInfo>

If citation_type is CHUNK_LEVEL_CITATION and chunk mode is on, populate chunk info. Corresponds to the JSON property chunkInfo



7966
7967
7968
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7966

def chunk_info
  @chunk_info
end

#documentString

Document resource name. Corresponds to the JSON property document

Returns:

  • (String)


7971
7972
7973
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7971

def document
  @document
end

#snippet_infoArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservationSearchResultSnippetInfo>

If citation_type is DOCUMENT_LEVEL_CITATION, populate document level snippets. Corresponds to the JSON property snippetInfo



7976
7977
7978
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7976

def snippet_info
  @snippet_info
end

#struct_dataHash<String,Object>

Data representation. The structured JSON data for the document. It's populated from the struct data from the Document, or the Chunk in search result. Corresponds to the JSON property structData

Returns:

  • (Hash<String,Object>)


7982
7983
7984
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7982

def struct_data
  @struct_data
end

#titleString

Title. Corresponds to the JSON property title

Returns:

  • (String)


7987
7988
7989
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7987

def title
  @title
end

#uriString

URI for the document. Corresponds to the JSON property uri

Returns:

  • (String)


7992
7993
7994
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7992

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7999
8000
8001
8002
8003
8004
8005
8006
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7999

def update!(**args)
  @chunk_info = args[:chunk_info] if args.key?(:chunk_info)
  @document = args[:document] if args.key?(:document)
  @snippet_info = args[:snippet_info] if args.key?(:snippet_info)
  @struct_data = args[:struct_data] if args.key?(:struct_data)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end