Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservationSearchResult
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservationSearchResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Instance Attribute Summary collapse
-
#chunk_info ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservationSearchResultChunkInfo>
If citation_type is CHUNK_LEVEL_CITATION and chunk mode is on, populate chunk info.
-
#document ⇒ String
Document resource name.
-
#snippet_info ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservationSearchResultSnippetInfo>
If citation_type is DOCUMENT_LEVEL_CITATION, populate document level snippets.
-
#struct_data ⇒ Hash<String,Object>
Data representation.
-
#title ⇒ String
Title.
-
#uri ⇒ String
URI for the document.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservationSearchResult
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservationSearchResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservationSearchResult
Returns a new instance of GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservationSearchResult.
7892 7893 7894 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7892 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chunk_info ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservationSearchResultChunkInfo>
If citation_type is CHUNK_LEVEL_CITATION and chunk mode is on, populate chunk
info.
Corresponds to the JSON property chunkInfo
7864 7865 7866 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7864 def chunk_info @chunk_info end |
#document ⇒ String
Document resource name.
Corresponds to the JSON property document
7869 7870 7871 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7869 def document @document end |
#snippet_info ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAnswerStepActionObservationSearchResultSnippetInfo>
If citation_type is DOCUMENT_LEVEL_CITATION, populate document level snippets.
Corresponds to the JSON property snippetInfo
7874 7875 7876 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7874 def snippet_info @snippet_info end |
#struct_data ⇒ Hash<String,Object>
Data representation. The structured JSON data for the document. It's populated
from the struct data from the Document, or the Chunk in search result.
Corresponds to the JSON property structData
7880 7881 7882 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7880 def struct_data @struct_data end |
#title ⇒ String
Title.
Corresponds to the JSON property title
7885 7886 7887 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7885 def title @title end |
#uri ⇒ String
URI for the document.
Corresponds to the JSON property uri
7890 7891 7892 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7890 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7897 7898 7899 7900 7901 7902 7903 7904 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 7897 def update!(**args) @chunk_info = args[:chunk_info] if args.key?(:chunk_info) @document = args[:document] if args.key?(:document) @snippet_info = args[:snippet_info] if args.key?(:snippet_info) @struct_data = args[:struct_data] if args.key?(:struct_data) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) end |