Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistAnswer

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

AssistAnswer resource, main part of AssistResponse.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAssistAnswer

Returns a new instance of GoogleCloudDiscoveryengineV1alphaAssistAnswer.



8755
8756
8757
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8755

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assist_skipped_reasonsArray<String>

Reasons for not answering the assist call. Corresponds to the JSON property assistSkippedReasons

Returns:

  • (Array<String>)


8729
8730
8731
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8729

def assist_skipped_reasons
  @assist_skipped_reasons
end

#customer_policy_enforcement_resultGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistAnswerCustomerPolicyEnforcementResult

Customer policy enforcement results. Contains the results of the various policy checks, like the banned phrases or the Model Armor checks. Corresponds to the JSON property customerPolicyEnforcementResult



8735
8736
8737
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8735

def customer_policy_enforcement_result
  @customer_policy_enforcement_result
end

#nameString

Immutable. Identifier. Resource name of the AssistAnswer. Format: projects/ project/locations/location/collections/collection/engines/engine/ sessions/session/assistAnswers/assist_answer`This field must be a UTF-8 encoded string with a length limit of 1024 characters. Corresponds to the JSON propertyname`

Returns:

  • (String)


8743
8744
8745
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8743

def name
  @name
end

#repliesArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistAnswerReply>

Replies of the assistant. Corresponds to the JSON property replies



8748
8749
8750
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8748

def replies
  @replies
end

#stateString

State of the answer generation. Corresponds to the JSON property state

Returns:

  • (String)


8753
8754
8755
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8753

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8760
8761
8762
8763
8764
8765
8766
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8760

def update!(**args)
  @assist_skipped_reasons = args[:assist_skipped_reasons] if args.key?(:assist_skipped_reasons)
  @customer_policy_enforcement_result = args[:customer_policy_enforcement_result] if args.key?(:customer_policy_enforcement_result)
  @name = args[:name] if args.key?(:name)
  @replies = args[:replies] if args.key?(:replies)
  @state = args[:state] if args.key?(:state)
end