Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistAnswerCustomerPolicyEnforcementResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Customer policy enforcement results. Contains the results of the various policy checks, like the banned phrases or the Model Armor checks.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAssistAnswerCustomerPolicyEnforcementResult

Returns a new instance of GoogleCloudDiscoveryengineV1alphaAssistAnswerCustomerPolicyEnforcementResult.



8780
8781
8782
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8780

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#policy_resultsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistAnswerCustomerPolicyEnforcementResultPolicyEnforcementResult>

Customer policy enforcement results. Populated only if the assist call was skipped due to a policy violation. It contains results from those filters that blocked the processing of the query. Corresponds to the JSON property policyResults



8772
8773
8774
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8772

def policy_results
  @policy_results
end

#verdictString

Final verdict of the customer policy enforcement. If only one policy blocked the processing, the verdict is BLOCK. Corresponds to the JSON property verdict

Returns:

  • (String)


8778
8779
8780
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8778

def verdict
  @verdict
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8785
8786
8787
8788
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8785

def update!(**args)
  @policy_results = args[:policy_results] if args.key?(:policy_results)
  @verdict = args[:verdict] if args.key?(:verdict)
end