Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistAnswerCustomerPolicyEnforcementResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Customer policy enforcement results. Contains the results of the various policy checks, like the banned phrases or the Model Armor checks.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAssistAnswerCustomerPolicyEnforcementResult

Returns a new instance of GoogleCloudDiscoveryengineV1alphaAssistAnswerCustomerPolicyEnforcementResult.



8730
8731
8732
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8730

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#policy_resultsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistAnswerCustomerPolicyEnforcementResultPolicyEnforcementResult>

Customer policy enforcement results. Populated only if the assist call was skipped due to a policy violation. It contains results from those filters that blocked the processing of the query. Corresponds to the JSON property policyResults



8722
8723
8724
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8722

def policy_results
  @policy_results
end

#verdictString

Final verdict of the customer policy enforcement. If only one policy blocked the processing, the verdict is BLOCK. Corresponds to the JSON property verdict

Returns:

  • (String)


8728
8729
8730
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8728

def verdict
  @verdict
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8735
8736
8737
8738
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8735

def update!(**args)
  @policy_results = args[:policy_results] if args.key?(:policy_results)
  @verdict = args[:verdict] if args.key?(:verdict)
end