Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistAnswerCustomerPolicyEnforcementResult
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistAnswerCustomerPolicyEnforcementResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Customer policy enforcement results. Contains the results of the various policy checks, like the banned phrases or the Model Armor checks.
Instance Attribute Summary collapse
-
#policy_results ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistAnswerCustomerPolicyEnforcementResultPolicyEnforcementResult>
Customer policy enforcement results.
-
#verdict ⇒ String
Final verdict of the customer policy enforcement.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAssistAnswerCustomerPolicyEnforcementResult
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaAssistAnswerCustomerPolicyEnforcementResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAssistAnswerCustomerPolicyEnforcementResult
Returns a new instance of GoogleCloudDiscoveryengineV1alphaAssistAnswerCustomerPolicyEnforcementResult.
8050 8051 8052 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8050 def initialize(**args) update!(**args) end |
Instance Attribute Details
#policy_results ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistAnswerCustomerPolicyEnforcementResultPolicyEnforcementResult>
Customer policy enforcement results. Populated only if the assist call was
skipped due to a policy violation. It contains results from those filters that
blocked the processing of the query.
Corresponds to the JSON property policyResults
8042 8043 8044 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8042 def policy_results @policy_results end |
#verdict ⇒ String
Final verdict of the customer policy enforcement. If only one policy blocked
the processing, the verdict is BLOCK.
Corresponds to the JSON property verdict
8048 8049 8050 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8048 def verdict @verdict end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8055 8056 8057 8058 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8055 def update!(**args) @policy_results = args[:policy_results] if args.key?(:policy_results) @verdict = args[:verdict] if args.key?(:verdict) end |