Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistAnswerCustomerPolicyEnforcementResultBannedPhraseEnforcementResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Customer policy enforcement result for the banned phrase policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAssistAnswerCustomerPolicyEnforcementResultBannedPhraseEnforcementResult

Returns a new instance of GoogleCloudDiscoveryengineV1alphaAssistAnswerCustomerPolicyEnforcementResultBannedPhraseEnforcementResult.



8172
8173
8174
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8172

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#banned_phrasesArray<String>

The banned phrases that were found in the query or the answer. Corresponds to the JSON property bannedPhrases

Returns:

  • (Array<String>)


8170
8171
8172
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8170

def banned_phrases
  @banned_phrases
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8177
8178
8179
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8177

def update!(**args)
  @banned_phrases = args[:banned_phrases] if args.key?(:banned_phrases)
end