Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistAnswerCustomerPolicyEnforcementResultBannedPhraseEnforcementResult
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistAnswerCustomerPolicyEnforcementResultBannedPhraseEnforcementResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Customer policy enforcement result for the banned phrase policy.
Instance Attribute Summary collapse
-
#banned_phrases ⇒ Array<String>
The banned phrases that were found in the query or the answer.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAssistAnswerCustomerPolicyEnforcementResultBannedPhraseEnforcementResult
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaAssistAnswerCustomerPolicyEnforcementResultBannedPhraseEnforcementResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAssistAnswerCustomerPolicyEnforcementResultBannedPhraseEnforcementResult
Returns a new instance of GoogleCloudDiscoveryengineV1alphaAssistAnswerCustomerPolicyEnforcementResultBannedPhraseEnforcementResult.
8070 8071 8072 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8070 def initialize(**args) update!(**args) end |
Instance Attribute Details
#banned_phrases ⇒ Array<String>
The banned phrases that were found in the query or the answer.
Corresponds to the JSON property bannedPhrases
8068 8069 8070 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8068 def banned_phrases @banned_phrases end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8075 8076 8077 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8075 def update!(**args) @banned_phrases = args[:banned_phrases] if args.key?(:banned_phrases) end |