Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistAnswerCustomerPolicyEnforcementResultModelArmorEnforcementResult
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistAnswerCustomerPolicyEnforcementResultModelArmorEnforcementResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Customer policy enforcement result for the Model Armor policy.
Instance Attribute Summary collapse
-
#error ⇒ Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#model_armor_violation ⇒ String
The Model Armor violation that was found.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAssistAnswerCustomerPolicyEnforcementResultModelArmorEnforcementResult
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaAssistAnswerCustomerPolicyEnforcementResultModelArmorEnforcementResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAssistAnswerCustomerPolicyEnforcementResultModelArmorEnforcementResult
Returns a new instance of GoogleCloudDiscoveryengineV1alphaAssistAnswerCustomerPolicyEnforcementResultModelArmorEnforcementResult.
8779 8780 8781 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8779 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error ⇒ Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
8772 8773 8774 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8772 def error @error end |
#model_armor_violation ⇒ String
The Model Armor violation that was found.
Corresponds to the JSON property modelArmorViolation
8777 8778 8779 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8777 def model_armor_violation @model_armor_violation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8784 8785 8786 8787 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8784 def update!(**args) @error = args[:error] if args.key?(:error) @model_armor_violation = args[:model_armor_violation] if args.key?(:model_armor_violation) end |