Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistAnswerReply
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistAnswerReply
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
One part of the multi-part response of the assist call.
Instance Attribute Summary collapse
-
#create_time ⇒ String
The time when the reply was created.
-
#grounded_content ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantGroundedContent
A piece of content and possibly its grounding information.
-
#reply_id ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAssistAnswerReply
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaAssistAnswerReply.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAssistAnswerReply
Returns a new instance of GoogleCloudDiscoveryengineV1alphaAssistAnswerReply.
8160 8161 8162 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8160 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
The time when the reply was created.
Corresponds to the JSON property createTime
8142 8143 8144 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8142 def create_time @create_time end |
#grounded_content ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantGroundedContent
A piece of content and possibly its grounding information. Not all content
needs grounding. Phrases like "Of course, I will gladly search it for you." do
not need grounding.
Corresponds to the JSON property groundedContent
8149 8150 8151 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8149 def grounded_content @grounded_content end |
#reply_id ⇒ String
Output only. When set, uniquely identifies a reply within the AssistAnswer
resource. During an AssistantService.StreamAssist call, multiple Reply
messages with the same ID can occur within the response stream (across
multiple StreamAssistResponse messages). These represent parts of a single
Reply message in the final AssistAnswer resource.
Corresponds to the JSON property replyId
8158 8159 8160 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8158 def reply_id @reply_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8165 8166 8167 8168 8169 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8165 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @grounded_content = args[:grounded_content] if args.key?(:grounded_content) @reply_id = args[:reply_id] if args.key?(:reply_id) end |