Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantContent
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantContent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Multi-modal content.
Instance Attribute Summary collapse
-
#code_execution_result ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantContentCodeExecutionResult
Result of executing ExecutableCode.
-
#executable_code ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantContentExecutableCode
Code generated by the model that is meant to be executed by the model.
-
#file ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantContentFile
A file, e.g., an audio summary.
-
#inline_data ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantContentBlob
Inline blob.
-
#role ⇒ String
The producer of the content.
-
#text ⇒ String
Inline text.
-
#thought ⇒ Boolean
(also: #thought?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAssistantContent
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaAssistantContent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAssistantContent
Returns a new instance of GoogleCloudDiscoveryengineV1alphaAssistantContent.
8870 8871 8872 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8870 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code_execution_result ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantContentCodeExecutionResult
Result of executing ExecutableCode.
Corresponds to the JSON property codeExecutionResult
8837 8838 8839 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8837 def code_execution_result @code_execution_result end |
#executable_code ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantContentExecutableCode
Code generated by the model that is meant to be executed by the model.
Corresponds to the JSON property executableCode
8842 8843 8844 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8842 def executable_code @executable_code end |
#file ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantContentFile
A file, e.g., an audio summary.
Corresponds to the JSON property file
8847 8848 8849 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8847 def file @file end |
#inline_data ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantContentBlob
Inline blob.
Corresponds to the JSON property inlineData
8852 8853 8854 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8852 def inline_data @inline_data end |
#role ⇒ String
The producer of the content. Can be "model" or "user".
Corresponds to the JSON property role
8857 8858 8859 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8857 def role @role end |
#text ⇒ String
Inline text.
Corresponds to the JSON property text
8862 8863 8864 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8862 def text @text end |
#thought ⇒ Boolean Also known as: thought?
Optional. Indicates if the part is thought from the model.
Corresponds to the JSON property thought
8867 8868 8869 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8867 def thought @thought end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8875 8876 8877 8878 8879 8880 8881 8882 8883 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8875 def update!(**args) @code_execution_result = args[:code_execution_result] if args.key?(:code_execution_result) @executable_code = args[:executable_code] if args.key?(:executable_code) @file = args[:file] if args.key?(:file) @inline_data = args[:inline_data] if args.key?(:inline_data) @role = args[:role] if args.key?(:role) @text = args[:text] if args.key?(:text) @thought = args[:thought] if args.key?(:thought) end |