Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantContent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Multi-modal content.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAssistantContent

Returns a new instance of GoogleCloudDiscoveryengineV1alphaAssistantContent.



8314
8315
8316
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8314

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#code_execution_resultGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantContentCodeExecutionResult

Result of executing ExecutableCode. Corresponds to the JSON property codeExecutionResult



8281
8282
8283
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8281

def code_execution_result
  @code_execution_result
end

#executable_codeGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantContentExecutableCode

Code generated by the model that is meant to be executed by the model. Corresponds to the JSON property executableCode



8286
8287
8288
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8286

def executable_code
  @executable_code
end

#fileGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantContentFile

A file, e.g., an audio summary. Corresponds to the JSON property file



8291
8292
8293
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8291

def file
  @file
end

#inline_dataGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantContentBlob

Inline blob. Corresponds to the JSON property inlineData



8296
8297
8298
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8296

def inline_data
  @inline_data
end

#roleString

The producer of the content. Can be "model" or "user". Corresponds to the JSON property role

Returns:

  • (String)


8301
8302
8303
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8301

def role
  @role
end

#textString

Inline text. Corresponds to the JSON property text

Returns:

  • (String)


8306
8307
8308
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8306

def text
  @text
end

#thoughtBoolean Also known as: thought?

Optional. Indicates if the part is thought from the model. Corresponds to the JSON property thought

Returns:

  • (Boolean)


8311
8312
8313
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8311

def thought
  @thought
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8319
8320
8321
8322
8323
8324
8325
8326
8327
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8319

def update!(**args)
  @code_execution_result = args[:code_execution_result] if args.key?(:code_execution_result)
  @executable_code = args[:executable_code] if args.key?(:executable_code)
  @file = args[:file] if args.key?(:file)
  @inline_data = args[:inline_data] if args.key?(:inline_data)
  @role = args[:role] if args.key?(:role)
  @text = args[:text] if args.key?(:text)
  @thought = args[:thought] if args.key?(:thought)
end