Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantContent
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantContent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Multi-modal content.
Instance Attribute Summary collapse
-
#code_execution_result ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantContentCodeExecutionResult
Result of executing ExecutableCode.
-
#executable_code ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantContentExecutableCode
Code generated by the model that is meant to be executed by the model.
-
#file ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantContentFile
A file, e.g., an audio summary.
-
#inline_data ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantContentBlob
Inline blob.
-
#role ⇒ String
The producer of the content.
-
#text ⇒ String
Inline text.
-
#thought ⇒ Boolean
(also: #thought?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAssistantContent
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaAssistantContent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAssistantContent
Returns a new instance of GoogleCloudDiscoveryengineV1alphaAssistantContent.
8212 8213 8214 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8212 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code_execution_result ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantContentCodeExecutionResult
Result of executing ExecutableCode.
Corresponds to the JSON property codeExecutionResult
8179 8180 8181 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8179 def code_execution_result @code_execution_result end |
#executable_code ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantContentExecutableCode
Code generated by the model that is meant to be executed by the model.
Corresponds to the JSON property executableCode
8184 8185 8186 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8184 def executable_code @executable_code end |
#file ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantContentFile
A file, e.g., an audio summary.
Corresponds to the JSON property file
8189 8190 8191 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8189 def file @file end |
#inline_data ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantContentBlob
Inline blob.
Corresponds to the JSON property inlineData
8194 8195 8196 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8194 def inline_data @inline_data end |
#role ⇒ String
The producer of the content. Can be "model" or "user".
Corresponds to the JSON property role
8199 8200 8201 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8199 def role @role end |
#text ⇒ String
Inline text.
Corresponds to the JSON property text
8204 8205 8206 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8204 def text @text end |
#thought ⇒ Boolean Also known as: thought?
Optional. Indicates if the part is thought from the model.
Corresponds to the JSON property thought
8209 8210 8211 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8209 def thought @thought end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8217 8218 8219 8220 8221 8222 8223 8224 8225 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8217 def update!(**args) @code_execution_result = args[:code_execution_result] if args.key?(:code_execution_result) @executable_code = args[:executable_code] if args.key?(:executable_code) @file = args[:file] if args.key?(:file) @inline_data = args[:inline_data] if args.key?(:inline_data) @role = args[:role] if args.key?(:role) @text = args[:text] if args.key?(:text) @thought = args[:thought] if args.key?(:thought) end |