Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantGroundedContent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

A piece of content and possibly its grounding information. Not all content needs grounding. Phrases like "Of course, I will gladly search it for you." do not need grounding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAssistantGroundedContent

Returns a new instance of GoogleCloudDiscoveryengineV1alphaAssistantGroundedContent.



9003
9004
9005
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9003

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#citation_metadataGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaCitationMetadata

A collection of source attributions for a piece of content. Corresponds to the JSON property citationMetadata



8991
8992
8993
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8991

def 
  @citation_metadata
end

#contentGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantContent

Multi-modal content. Corresponds to the JSON property content



8996
8997
8998
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8996

def content
  @content
end

#text_grounding_metadataGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantGroundedContentTextGroundingMetadata

Grounding details for text sources. Corresponds to the JSON property textGroundingMetadata



9001
9002
9003
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9001

def 
  @text_grounding_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9008
9009
9010
9011
9012
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9008

def update!(**args)
  @citation_metadata = args[:citation_metadata] if args.key?(:citation_metadata)
  @content = args[:content] if args.key?(:content)
  @text_grounding_metadata = args[:text_grounding_metadata] if args.key?(:text_grounding_metadata)
end