Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantGroundedContent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

A piece of content and possibly its grounding information. Not all content needs grounding. Phrases like "Of course, I will gladly search it for you." do not need grounding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAssistantGroundedContent

Returns a new instance of GoogleCloudDiscoveryengineV1alphaAssistantGroundedContent.



8447
8448
8449
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8447

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#citation_metadataGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaCitationMetadata

A collection of source attributions for a piece of content. Corresponds to the JSON property citationMetadata



8435
8436
8437
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8435

def 
  @citation_metadata
end

#contentGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantContent

Multi-modal content. Corresponds to the JSON property content



8440
8441
8442
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8440

def content
  @content
end

#text_grounding_metadataGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantGroundedContentTextGroundingMetadata

Grounding details for text sources. Corresponds to the JSON property textGroundingMetadata



8445
8446
8447
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8445

def 
  @text_grounding_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8452
8453
8454
8455
8456
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8452

def update!(**args)
  @citation_metadata = args[:citation_metadata] if args.key?(:citation_metadata)
  @content = args[:content] if args.key?(:content)
  @text_grounding_metadata = args[:text_grounding_metadata] if args.key?(:text_grounding_metadata)
end