Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantGroundedContent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

A piece of content and possibly its grounding information. Not all content needs grounding. Phrases like "Of course, I will gladly search it for you." do not need grounding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAssistantGroundedContent

Returns a new instance of GoogleCloudDiscoveryengineV1alphaAssistantGroundedContent.



8345
8346
8347
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8345

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#citation_metadataGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaCitationMetadata

A collection of source attributions for a piece of content. Corresponds to the JSON property citationMetadata



8333
8334
8335
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8333

def 
  @citation_metadata
end

#contentGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantContent

Multi-modal content. Corresponds to the JSON property content



8338
8339
8340
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8338

def content
  @content
end

#text_grounding_metadataGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantGroundedContentTextGroundingMetadata

Grounding details for text sources. Corresponds to the JSON property textGroundingMetadata



8343
8344
8345
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8343

def 
  @text_grounding_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8350
8351
8352
8353
8354
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8350

def update!(**args)
  @citation_metadata = args[:citation_metadata] if args.key?(:citation_metadata)
  @content = args[:content] if args.key?(:content)
  @text_grounding_metadata = args[:text_grounding_metadata] if args.key?(:text_grounding_metadata)
end