Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Document metadata.
Instance Attribute Summary collapse
-
#document ⇒ String
Document resource name.
-
#domain ⇒ String
Domain name from the document URI.
-
#language ⇒ String
Corresponds to the JSON property
language. -
#mime_type ⇒ String
The mime type of the document.
-
#page_identifier ⇒ String
Page identifier.
-
#title ⇒ String
Title.
-
#uri ⇒ String
URI for the document.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata
Returns a new instance of GoogleCloudDiscoveryengineV1alphaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata.
9199 9200 9201 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9199 def initialize(**args) update!(**args) end |
Instance Attribute Details
#document ⇒ String
Document resource name.
Corresponds to the JSON property document
9163 9164 9165 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9163 def document @document end |
#domain ⇒ String
Domain name from the document URI. Note that the uri field may contain a URL
that redirects to the actual website, in which case this will contain the
domain name of the target site.
Corresponds to the JSON property domain
9170 9171 9172 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9170 def domain @domain end |
#language ⇒ String
Corresponds to the JSON property language
9175 9176 9177 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9175 def language @language end |
#mime_type ⇒ String
The mime type of the document. https://www.iana.org/assignments/media-types/
media-types.xhtml.
Corresponds to the JSON property mimeType
9181 9182 9183 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9181 def mime_type @mime_type end |
#page_identifier ⇒ String
Page identifier.
Corresponds to the JSON property pageIdentifier
9186 9187 9188 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9186 def page_identifier @page_identifier end |
#title ⇒ String
Title.
Corresponds to the JSON property title
9191 9192 9193 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9191 def title @title end |
#uri ⇒ String
URI for the document. It may contain a URL that redirects to the actual
website.
Corresponds to the JSON property uri
9197 9198 9199 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9197 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9204 9205 9206 9207 9208 9209 9210 9211 9212 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9204 def update!(**args) @document = args[:document] if args.key?(:document) @domain = args[:domain] if args.key?(:domain) @language = args[:language] if args.key?(:language) @mime_type = args[:mime_type] if args.key?(:mime_type) @page_identifier = args[:page_identifier] if args.key?(:page_identifier) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) end |