Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Document metadata.
Instance Attribute Summary collapse
-
#document ⇒ String
Document resource name.
-
#domain ⇒ String
Domain name from the document URI.
-
#language ⇒ String
Corresponds to the JSON property
language. -
#mime_type ⇒ String
The mime type of the document.
-
#page_identifier ⇒ String
Page identifier.
-
#title ⇒ String
Title.
-
#uri ⇒ String
URI for the document.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata
Returns a new instance of GoogleCloudDiscoveryengineV1alphaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata.
9120 9121 9122 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9120 def initialize(**args) update!(**args) end |
Instance Attribute Details
#document ⇒ String
Document resource name.
Corresponds to the JSON property document
9084 9085 9086 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9084 def document @document end |
#domain ⇒ String
Domain name from the document URI. Note that the uri field may contain a URL
that redirects to the actual website, in which case this will contain the
domain name of the target site.
Corresponds to the JSON property domain
9091 9092 9093 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9091 def domain @domain end |
#language ⇒ String
Corresponds to the JSON property language
9096 9097 9098 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9096 def language @language end |
#mime_type ⇒ String
The mime type of the document. https://www.iana.org/assignments/media-types/
media-types.xhtml.
Corresponds to the JSON property mimeType
9102 9103 9104 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9102 def mime_type @mime_type end |
#page_identifier ⇒ String
Page identifier.
Corresponds to the JSON property pageIdentifier
9107 9108 9109 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9107 def page_identifier @page_identifier end |
#title ⇒ String
Title.
Corresponds to the JSON property title
9112 9113 9114 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9112 def title @title end |
#uri ⇒ String
URI for the document. It may contain a URL that redirects to the actual
website.
Corresponds to the JSON property uri
9118 9119 9120 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9118 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9125 9126 9127 9128 9129 9130 9131 9132 9133 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9125 def update!(**args) @document = args[:document] if args.key?(:document) @domain = args[:domain] if args.key?(:domain) @language = args[:language] if args.key?(:language) @mime_type = args[:mime_type] if args.key?(:mime_type) @page_identifier = args[:page_identifier] if args.key?(:page_identifier) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) end |