Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Document metadata.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata

Returns a new instance of GoogleCloudDiscoveryengineV1alphaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata.



8564
8565
8566
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8564

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#documentString

Document resource name. Corresponds to the JSON property document

Returns:

  • (String)


8528
8529
8530
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8528

def document
  @document
end

#domainString

Domain name from the document URI. Note that the uri field may contain a URL that redirects to the actual website, in which case this will contain the domain name of the target site. Corresponds to the JSON property domain

Returns:

  • (String)


8535
8536
8537
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8535

def domain
  @domain
end

#languageString

Corresponds to the JSON property language

Returns:

  • (String)


8540
8541
8542
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8540

def language
  @language
end

#mime_typeString

The mime type of the document. https://www.iana.org/assignments/media-types/ media-types.xhtml. Corresponds to the JSON property mimeType

Returns:

  • (String)


8546
8547
8548
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8546

def mime_type
  @mime_type
end

#page_identifierString

Page identifier. Corresponds to the JSON property pageIdentifier

Returns:

  • (String)


8551
8552
8553
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8551

def page_identifier
  @page_identifier
end

#titleString

Title. Corresponds to the JSON property title

Returns:

  • (String)


8556
8557
8558
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8556

def title
  @title
end

#uriString

URI for the document. It may contain a URL that redirects to the actual website. Corresponds to the JSON property uri

Returns:

  • (String)


8562
8563
8564
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8562

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8569
8570
8571
8572
8573
8574
8575
8576
8577
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8569

def update!(**args)
  @document = args[:document] if args.key?(:document)
  @domain = args[:domain] if args.key?(:domain)
  @language = args[:language] if args.key?(:language)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
  @page_identifier = args[:page_identifier] if args.key?(:page_identifier)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end