Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Document metadata.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata

Returns a new instance of GoogleCloudDiscoveryengineV1alphaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata.



8462
8463
8464
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8462

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#documentString

Document resource name. Corresponds to the JSON property document

Returns:

  • (String)


8426
8427
8428
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8426

def document
  @document
end

#domainString

Domain name from the document URI. Note that the uri field may contain a URL that redirects to the actual website, in which case this will contain the domain name of the target site. Corresponds to the JSON property domain

Returns:

  • (String)


8433
8434
8435
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8433

def domain
  @domain
end

#languageString

Corresponds to the JSON property language

Returns:

  • (String)


8438
8439
8440
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8438

def language
  @language
end

#mime_typeString

The mime type of the document. https://www.iana.org/assignments/media-types/ media-types.xhtml. Corresponds to the JSON property mimeType

Returns:

  • (String)


8444
8445
8446
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8444

def mime_type
  @mime_type
end

#page_identifierString

Page identifier. Corresponds to the JSON property pageIdentifier

Returns:

  • (String)


8449
8450
8451
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8449

def page_identifier
  @page_identifier
end

#titleString

Title. Corresponds to the JSON property title

Returns:

  • (String)


8454
8455
8456
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8454

def title
  @title
end

#uriString

URI for the document. It may contain a URL that redirects to the actual website. Corresponds to the JSON property uri

Returns:

  • (String)


8460
8461
8462
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8460

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8467
8468
8469
8470
8471
8472
8473
8474
8475
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8467

def update!(**args)
  @document = args[:document] if args.key?(:document)
  @domain = args[:domain] if args.key?(:domain)
  @language = args[:language] if args.key?(:language)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
  @page_identifier = args[:page_identifier] if args.key?(:page_identifier)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end