Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Document metadata.
Instance Attribute Summary collapse
-
#document ⇒ String
Document resource name.
-
#domain ⇒ String
Domain name from the document URI.
-
#language ⇒ String
Corresponds to the JSON property
language. -
#mime_type ⇒ String
The mime type of the document.
-
#page_identifier ⇒ String
Page identifier.
-
#title ⇒ String
Title.
-
#uri ⇒ String
URI for the document.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata
Returns a new instance of GoogleCloudDiscoveryengineV1alphaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata.
8462 8463 8464 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8462 def initialize(**args) update!(**args) end |
Instance Attribute Details
#document ⇒ String
Document resource name.
Corresponds to the JSON property document
8426 8427 8428 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8426 def document @document end |
#domain ⇒ String
Domain name from the document URI. Note that the uri field may contain a URL
that redirects to the actual website, in which case this will contain the
domain name of the target site.
Corresponds to the JSON property domain
8433 8434 8435 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8433 def domain @domain end |
#language ⇒ String
Corresponds to the JSON property language
8438 8439 8440 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8438 def language @language end |
#mime_type ⇒ String
The mime type of the document. https://www.iana.org/assignments/media-types/
media-types.xhtml.
Corresponds to the JSON property mimeType
8444 8445 8446 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8444 def mime_type @mime_type end |
#page_identifier ⇒ String
Page identifier.
Corresponds to the JSON property pageIdentifier
8449 8450 8451 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8449 def page_identifier @page_identifier end |
#title ⇒ String
Title.
Corresponds to the JSON property title
8454 8455 8456 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8454 def title @title end |
#uri ⇒ String
URI for the document. It may contain a URL that redirects to the actual
website.
Corresponds to the JSON property uri
8460 8461 8462 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8460 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8467 8468 8469 8470 8471 8472 8473 8474 8475 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8467 def update!(**args) @document = args[:document] if args.key?(:document) @domain = args[:domain] if args.key?(:domain) @language = args[:language] if args.key?(:language) @mime_type = args[:mime_type] if args.key?(:mime_type) @page_identifier = args[:page_identifier] if args.key?(:page_identifier) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) end |