Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantGroundedContentTextGroundingMetadataSegment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Grounding information for a segment of the text.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAssistantGroundedContentTextGroundingMetadataSegment

Returns a new instance of GoogleCloudDiscoveryengineV1alphaAssistantGroundedContentTextGroundingMetadataSegment.



8611
8612
8613
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8611

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_indexFixnum

End of the segment, exclusive. Corresponds to the JSON property endIndex

Returns:

  • (Fixnum)


8587
8588
8589
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8587

def end_index
  @end_index
end

#grounding_scoreFloat

Score for the segment. Corresponds to the JSON property groundingScore

Returns:

  • (Float)


8592
8593
8594
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8592

def grounding_score
  @grounding_score
end

#reference_indicesArray<Fixnum>

References for the segment. Corresponds to the JSON property referenceIndices

Returns:

  • (Array<Fixnum>)


8597
8598
8599
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8597

def reference_indices
  @reference_indices
end

#start_indexFixnum

Zero-based index indicating the start of the segment, measured in bytes of a UTF-8 string (i.e. characters encoded on multiple bytes have a length of more than one). Corresponds to the JSON property startIndex

Returns:

  • (Fixnum)


8604
8605
8606
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8604

def start_index
  @start_index
end

#textString

The text segment itself. Corresponds to the JSON property text

Returns:

  • (String)


8609
8610
8611
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8609

def text
  @text
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8616
8617
8618
8619
8620
8621
8622
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8616

def update!(**args)
  @end_index = args[:end_index] if args.key?(:end_index)
  @grounding_score = args[:grounding_score] if args.key?(:grounding_score)
  @reference_indices = args[:reference_indices] if args.key?(:reference_indices)
  @start_index = args[:start_index] if args.key?(:start_index)
  @text = args[:text] if args.key?(:text)
end