Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantGroundedContentTextGroundingMetadataSegment
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAssistantGroundedContentTextGroundingMetadataSegment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Grounding information for a segment of the text.
Instance Attribute Summary collapse
-
#end_index ⇒ Fixnum
End of the segment, exclusive.
-
#grounding_score ⇒ Float
Score for the segment.
-
#reference_indices ⇒ Array<Fixnum>
References for the segment.
-
#start_index ⇒ Fixnum
Zero-based index indicating the start of the segment, measured in bytes of a UTF-8 string (i.e. characters encoded on multiple bytes have a length of more than one).
-
#text ⇒ String
The text segment itself.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAssistantGroundedContentTextGroundingMetadataSegment
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaAssistantGroundedContentTextGroundingMetadataSegment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaAssistantGroundedContentTextGroundingMetadataSegment
Returns a new instance of GoogleCloudDiscoveryengineV1alphaAssistantGroundedContentTextGroundingMetadataSegment.
8509 8510 8511 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8509 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_index ⇒ Fixnum
End of the segment, exclusive.
Corresponds to the JSON property endIndex
8485 8486 8487 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8485 def end_index @end_index end |
#grounding_score ⇒ Float
Score for the segment.
Corresponds to the JSON property groundingScore
8490 8491 8492 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8490 def grounding_score @grounding_score end |
#reference_indices ⇒ Array<Fixnum>
References for the segment.
Corresponds to the JSON property referenceIndices
8495 8496 8497 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8495 def reference_indices @reference_indices end |
#start_index ⇒ Fixnum
Zero-based index indicating the start of the segment, measured in bytes of a
UTF-8 string (i.e. characters encoded on multiple bytes have a length of more
than one).
Corresponds to the JSON property startIndex
8502 8503 8504 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8502 def start_index @start_index end |
#text ⇒ String
The text segment itself.
Corresponds to the JSON property text
8507 8508 8509 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8507 def text @text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8514 8515 8516 8517 8518 8519 8520 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8514 def update!(**args) @end_index = args[:end_index] if args.key?(:end_index) @grounding_score = args[:grounding_score] if args.key?(:grounding_score) @reference_indices = args[:reference_indices] if args.key?(:reference_indices) @start_index = args[:start_index] if args.key?(:start_index) @text = args[:text] if args.key?(:text) end |