Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaBapConfig
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaBapConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
The configuration for the BAP connector.
Instance Attribute Summary collapse
-
#enabled_actions ⇒ Array<String>
Optional.
-
#supported_connector_modes ⇒ Array<String>
Required.
-
#toolspec_override ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaBapConfigToolspecOverride
Customer-facing view of the admin-curated toolspec for a BAP connection.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaBapConfig
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaBapConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaBapConfig
Returns a new instance of GoogleCloudDiscoveryengineV1alphaBapConfig.
8576 8577 8578 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8576 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enabled_actions ⇒ Array<String>
Optional. The actions enabled on the associated BAP connection.
Corresponds to the JSON property enabledActions
8557 8558 8559 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8557 def enabled_actions @enabled_actions end |
#supported_connector_modes ⇒ Array<String>
Required. The supported connector modes for the associated BAP connection.
Corresponds to the JSON property supportedConnectorModes
8562 8563 8564 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8562 def supported_connector_modes @supported_connector_modes end |
#toolspec_override ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaBapConfigToolspecOverride
Customer-facing view of the admin-curated toolspec for a BAP connection. Holds
the (simplified) per-tool definitions surfaced to and editable by the admin in
the Discovery Engine UI. Mirrors the shape of the backend google.cloud.
connectorexecution.v1.ToolspecOverride message, but is intentionally kept as
a separate public type so the Discovery Engine API surface can evolve
independently of the fed-API surface (AIP-215). Handlers convert between the
two via helpers in //cloud/ml/discoveryengine/external_service/v1main/
data_connector_service/lib:bap_custom_tool_util.
Corresponds to the JSON property toolspecOverride
8574 8575 8576 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8574 def toolspec_override @toolspec_override end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8581 8582 8583 8584 8585 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8581 def update!(**args) @enabled_actions = args[:enabled_actions] if args.key?(:enabled_actions) @supported_connector_modes = args[:supported_connector_modes] if args.key?(:supported_connector_modes) @toolspec_override = args[:toolspec_override] if args.key?(:toolspec_override) end |