Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaBatchUpdateUserLicensesMetadata
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaBatchUpdateUserLicensesMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Metadata related to the progress of the UserLicenseService. BatchUpdateUserLicenses operation. This will be returned by the google. longrunning.Operation.metadata field.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Operation create time.
-
#failure_count ⇒ Fixnum
Count of user licenses that failed to be updated.
-
#success_count ⇒ Fixnum
Count of user licenses successfully updated.
-
#update_time ⇒ String
Operation last update time.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaBatchUpdateUserLicensesMetadata
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaBatchUpdateUserLicensesMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaBatchUpdateUserLicensesMetadata
Returns a new instance of GoogleCloudDiscoveryengineV1alphaBatchUpdateUserLicensesMetadata.
8802 8803 8804 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8802 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Operation create time.
Corresponds to the JSON property createTime
8784 8785 8786 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8784 def create_time @create_time end |
#failure_count ⇒ Fixnum
Count of user licenses that failed to be updated.
Corresponds to the JSON property failureCount
8789 8790 8791 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8789 def failure_count @failure_count end |
#success_count ⇒ Fixnum
Count of user licenses successfully updated.
Corresponds to the JSON property successCount
8794 8795 8796 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8794 def success_count @success_count end |
#update_time ⇒ String
Operation last update time. If the operation is done, this is also the finish
time.
Corresponds to the JSON property updateTime
8800 8801 8802 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8800 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8807 8808 8809 8810 8811 8812 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8807 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @failure_count = args[:failure_count] if args.key?(:failure_count) @success_count = args[:success_count] if args.key?(:success_count) @update_time = args[:update_time] if args.key?(:update_time) end |