Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaBatchUpdateUserLicensesResponse
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaBatchUpdateUserLicensesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Response message for UserLicenseService.BatchUpdateUserLicenses method.
Instance Attribute Summary collapse
-
#error_samples ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>
A sample of errors encountered while processing the request.
-
#user_licenses ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaUserLicense>
UserLicenses successfully updated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaBatchUpdateUserLicensesResponse
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaBatchUpdateUserLicensesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaBatchUpdateUserLicensesResponse
Returns a new instance of GoogleCloudDiscoveryengineV1alphaBatchUpdateUserLicensesResponse.
8829 8830 8831 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8829 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_samples ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>
A sample of errors encountered while processing the request.
Corresponds to the JSON property errorSamples
8822 8823 8824 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8822 def error_samples @error_samples end |
#user_licenses ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaUserLicense>
UserLicenses successfully updated.
Corresponds to the JSON property userLicenses
8827 8828 8829 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8827 def user_licenses @user_licenses end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8834 8835 8836 8837 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8834 def update!(**args) @error_samples = args[:error_samples] if args.key?(:error_samples) @user_licenses = args[:user_licenses] if args.key?(:user_licenses) end |