Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaCmekConfig
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaCmekConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Configurations used to enable CMEK data encryption with Cloud KMS keys.
Instance Attribute Summary collapse
-
#is_default ⇒ Boolean
(also: #is_default?)
Output only.
-
#kms_key ⇒ String
Required.
-
#kms_key_version ⇒ String
Output only.
-
#last_rotation_timestamp_micros ⇒ Fixnum
Output only.
-
#name ⇒ String
Required.
-
#notebooklm_state ⇒ String
Output only.
-
#single_region_keys ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSingleRegionKey>
Optional.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaCmekConfig
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaCmekConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaCmekConfig
Returns a new instance of GoogleCloudDiscoveryengineV1alphaCmekConfig.
9618 9619 9620 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9618 def initialize(**args) update!(**args) end |
Instance Attribute Details
#is_default ⇒ Boolean Also known as: is_default?
Output only. The default CmekConfig for the Customer.
Corresponds to the JSON property isDefault
9576 9577 9578 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9576 def is_default @is_default end |
#kms_key ⇒ String
Required. KMS key resource name which will be used to encrypt resources
projects/project/locations/location/keyRings/keyRing/cryptoKeys/keyId`.
Corresponds to the JSON propertykmsKey`
9583 9584 9585 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9583 def kms_key @kms_key end |
#kms_key_version ⇒ String
Output only. KMS key version resource name which will be used to encrypt
resources /cryptoKeyVersions/keyVersion`.
Corresponds to the JSON propertykmsKeyVersion`
9589 9590 9591 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9589 def kms_key_version @kms_key_version end |
#last_rotation_timestamp_micros ⇒ Fixnum
Output only. The timestamp of the last key rotation.
Corresponds to the JSON property lastRotationTimestampMicros
9594 9595 9596 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9594 def @last_rotation_timestamp_micros end |
#name ⇒ String
Required. The name of the CmekConfig of the form projects/project/locations/
location/cmekConfig or projects/project/locations/location/cmekConfigs/
cmek_config`.
Corresponds to the JSON propertyname`
9601 9602 9603 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9601 def name @name end |
#notebooklm_state ⇒ String
Output only. Whether the NotebookLM Corpus is ready to be used.
Corresponds to the JSON property notebooklmState
9606 9607 9608 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9606 def notebooklm_state @notebooklm_state end |
#single_region_keys ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSingleRegionKey>
Optional. Single-regional CMEKs that are required for some VAIS features.
Corresponds to the JSON property singleRegionKeys
9611 9612 9613 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9611 def single_region_keys @single_region_keys end |
#state ⇒ String
Output only. The states of the CmekConfig.
Corresponds to the JSON property state
9616 9617 9618 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9616 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9623 9624 9625 9626 9627 9628 9629 9630 9631 9632 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9623 def update!(**args) @is_default = args[:is_default] if args.key?(:is_default) @kms_key = args[:kms_key] if args.key?(:kms_key) @kms_key_version = args[:kms_key_version] if args.key?(:kms_key_version) @last_rotation_timestamp_micros = args[:last_rotation_timestamp_micros] if args.key?(:last_rotation_timestamp_micros) @name = args[:name] if args.key?(:name) @notebooklm_state = args[:notebooklm_state] if args.key?(:notebooklm_state) @single_region_keys = args[:single_region_keys] if args.key?(:single_region_keys) @state = args[:state] if args.key?(:state) end |