Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaCmekConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Configurations used to enable CMEK data encryption with Cloud KMS keys.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaCmekConfig

Returns a new instance of GoogleCloudDiscoveryengineV1alphaCmekConfig.



8983
8984
8985
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8983

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#is_defaultBoolean Also known as: is_default?

Output only. The default CmekConfig for the Customer. Corresponds to the JSON property isDefault

Returns:

  • (Boolean)


8941
8942
8943
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8941

def is_default
  @is_default
end

#kms_keyString

Required. KMS key resource name which will be used to encrypt resources projects/project/locations/location/keyRings/keyRing/cryptoKeys/keyId`. Corresponds to the JSON propertykmsKey`

Returns:

  • (String)


8948
8949
8950
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8948

def kms_key
  @kms_key
end

#kms_key_versionString

Output only. KMS key version resource name which will be used to encrypt resources /cryptoKeyVersions/keyVersion`. Corresponds to the JSON propertykmsKeyVersion`

Returns:

  • (String)


8954
8955
8956
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8954

def kms_key_version
  @kms_key_version
end

#last_rotation_timestamp_microsFixnum

Output only. The timestamp of the last key rotation. Corresponds to the JSON property lastRotationTimestampMicros

Returns:

  • (Fixnum)


8959
8960
8961
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8959

def last_rotation_timestamp_micros
  @last_rotation_timestamp_micros
end

#nameString

Required. The name of the CmekConfig of the form projects/project/locations/ location/cmekConfig or projects/project/locations/location/cmekConfigs/ cmek_config`. Corresponds to the JSON propertyname`

Returns:

  • (String)


8966
8967
8968
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8966

def name
  @name
end

#notebooklm_stateString

Output only. Whether the NotebookLM Corpus is ready to be used. Corresponds to the JSON property notebooklmState

Returns:

  • (String)


8971
8972
8973
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8971

def notebooklm_state
  @notebooklm_state
end

#single_region_keysArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSingleRegionKey>

Optional. Single-regional CMEKs that are required for some VAIS features. Corresponds to the JSON property singleRegionKeys



8976
8977
8978
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8976

def single_region_keys
  @single_region_keys
end

#stateString

Output only. The states of the CmekConfig. Corresponds to the JSON property state

Returns:

  • (String)


8981
8982
8983
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8981

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8988
8989
8990
8991
8992
8993
8994
8995
8996
8997
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8988

def update!(**args)
  @is_default = args[:is_default] if args.key?(:is_default)
  @kms_key = args[:kms_key] if args.key?(:kms_key)
  @kms_key_version = args[:kms_key_version] if args.key?(:kms_key_version)
  @last_rotation_timestamp_micros = args[:last_rotation_timestamp_micros] if args.key?(:last_rotation_timestamp_micros)
  @name = args[:name] if args.key?(:name)
  @notebooklm_state = args[:notebooklm_state] if args.key?(:notebooklm_state)
  @single_region_keys = args[:single_region_keys] if args.key?(:single_region_keys)
  @state = args[:state] if args.key?(:state)
end