Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaCmekConfig
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaCmekConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Configurations used to enable CMEK data encryption with Cloud KMS keys.
Instance Attribute Summary collapse
-
#is_default ⇒ Boolean
(also: #is_default?)
Output only.
-
#kms_key ⇒ String
Required.
-
#kms_key_version ⇒ String
Output only.
-
#last_rotation_timestamp_micros ⇒ Fixnum
Output only.
-
#name ⇒ String
Required.
-
#notebooklm_state ⇒ String
Output only.
-
#single_region_keys ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSingleRegionKey>
Optional.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaCmekConfig
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaCmekConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaCmekConfig
Returns a new instance of GoogleCloudDiscoveryengineV1alphaCmekConfig.
8983 8984 8985 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8983 def initialize(**args) update!(**args) end |
Instance Attribute Details
#is_default ⇒ Boolean Also known as: is_default?
Output only. The default CmekConfig for the Customer.
Corresponds to the JSON property isDefault
8941 8942 8943 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8941 def is_default @is_default end |
#kms_key ⇒ String
Required. KMS key resource name which will be used to encrypt resources
projects/project/locations/location/keyRings/keyRing/cryptoKeys/keyId`.
Corresponds to the JSON propertykmsKey`
8948 8949 8950 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8948 def kms_key @kms_key end |
#kms_key_version ⇒ String
Output only. KMS key version resource name which will be used to encrypt
resources /cryptoKeyVersions/keyVersion`.
Corresponds to the JSON propertykmsKeyVersion`
8954 8955 8956 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8954 def kms_key_version @kms_key_version end |
#last_rotation_timestamp_micros ⇒ Fixnum
Output only. The timestamp of the last key rotation.
Corresponds to the JSON property lastRotationTimestampMicros
8959 8960 8961 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8959 def @last_rotation_timestamp_micros end |
#name ⇒ String
Required. The name of the CmekConfig of the form projects/project/locations/
location/cmekConfig or projects/project/locations/location/cmekConfigs/
cmek_config`.
Corresponds to the JSON propertyname`
8966 8967 8968 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8966 def name @name end |
#notebooklm_state ⇒ String
Output only. Whether the NotebookLM Corpus is ready to be used.
Corresponds to the JSON property notebooklmState
8971 8972 8973 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8971 def notebooklm_state @notebooklm_state end |
#single_region_keys ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSingleRegionKey>
Optional. Single-regional CMEKs that are required for some VAIS features.
Corresponds to the JSON property singleRegionKeys
8976 8977 8978 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8976 def single_region_keys @single_region_keys end |
#state ⇒ String
Output only. The states of the CmekConfig.
Corresponds to the JSON property state
8981 8982 8983 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8981 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8988 8989 8990 8991 8992 8993 8994 8995 8996 8997 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8988 def update!(**args) @is_default = args[:is_default] if args.key?(:is_default) @kms_key = args[:kms_key] if args.key?(:kms_key) @kms_key_version = args[:kms_key_version] if args.key?(:kms_key_version) @last_rotation_timestamp_micros = args[:last_rotation_timestamp_micros] if args.key?(:last_rotation_timestamp_micros) @name = args[:name] if args.key?(:name) @notebooklm_state = args[:notebooklm_state] if args.key?(:notebooklm_state) @single_region_keys = args[:single_region_keys] if args.key?(:single_region_keys) @state = args[:state] if args.key?(:state) end |