Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaCollection

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Collection is a container for configuring resources and access to a set of DataStores.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaCollection

Returns a new instance of GoogleCloudDiscoveryengineV1alphaCollection.



8931
8932
8933
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8931

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp the Collection was created at. Corresponds to the JSON property createTime

Returns:

  • (String)


8906
8907
8908
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8906

def create_time
  @create_time
end

#data_connectorGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataConnector

Manages the connection to external data sources for all data stores grouped under a Collection. It's a singleton resource of Collection. The initialization is only supported through DataConnectorService. SetUpDataConnector method, which will create a new Collection and initialize its DataConnector. Corresponds to the JSON property dataConnector



8915
8916
8917
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8915

def data_connector
  @data_connector
end

#display_nameString

Required. The Collection display name. This field must be a UTF-8 encoded string with a length limit of 128 characters. Otherwise, an INVALID_ARGUMENT error is returned. Corresponds to the JSON property displayName

Returns:

  • (String)


8922
8923
8924
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8922

def display_name
  @display_name
end

#nameString

Immutable. The full resource name of the Collection. Format: projects/ project/locations/location/collections/collection_id`. This field must be a UTF-8 encoded string with a length limit of 1024 characters. Corresponds to the JSON propertyname`

Returns:

  • (String)


8929
8930
8931
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8929

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8936
8937
8938
8939
8940
8941
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 8936

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_connector = args[:data_connector] if args.key?(:data_connector)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
end