Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaConnectorRun

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

A data sync run of DataConnector. After DataConnector is successfully initialized, data syncs are scheduled at DataConnector.refresh_interval. A ConnectorRun represents a data sync either in the past or onging that the moment. //

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaConnectorRun

Returns a new instance of GoogleCloudDiscoveryengineV1alphaConnectorRun.



9769
9770
9771
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9769

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_timeString

Output only. The time when the connector run ended. Corresponds to the JSON property endTime

Returns:

  • (String)


9722
9723
9724
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9722

def end_time
  @end_time
end

#entity_runsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaConnectorRunEntityRun>

Output only. The details of the entities synced at the ConnectorRun. Each ConnectorRun consists of syncing one or more entities. Corresponds to the JSON property entityRuns



9728
9729
9730
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9728

def entity_runs
  @entity_runs
end

#errorsArray<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>

Contains info about errors incurred during the sync. Only exist if running into an error state. Contains error code and error message. Use with the state field. Corresponds to the JSON property errors



9735
9736
9737
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9735

def errors
  @errors
end

#latest_pause_timeString

Output only. The time when the connector run was most recently paused. Corresponds to the JSON property latestPauseTime

Returns:

  • (String)


9740
9741
9742
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9740

def latest_pause_time
  @latest_pause_time
end

#nameString

Output only. The full resource name of the Connector Run. Format: projects/*/ locations/*/collections/*/dataConnector/connectorRuns/*. The connector_run_id is system-generated. Corresponds to the JSON property name

Returns:

  • (String)


9747
9748
9749
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9747

def name
  @name
end

#start_timeString

Output only. The time when the connector run started. Corresponds to the JSON property startTime

Returns:

  • (String)


9752
9753
9754
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9752

def start_time
  @start_time
end

#stateString

Output only. The state of the sync run. Corresponds to the JSON property state

Returns:

  • (String)


9757
9758
9759
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9757

def state
  @state
end

#state_update_timeString

Timestamp at which the connector run sync state was last updated. Corresponds to the JSON property stateUpdateTime

Returns:

  • (String)


9762
9763
9764
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9762

def state_update_time
  @state_update_time
end

#triggerString

Output only. The trigger for this ConnectorRun. Corresponds to the JSON property trigger

Returns:

  • (String)


9767
9768
9769
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9767

def trigger
  @trigger
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9774
9775
9776
9777
9778
9779
9780
9781
9782
9783
9784
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9774

def update!(**args)
  @end_time = args[:end_time] if args.key?(:end_time)
  @entity_runs = args[:entity_runs] if args.key?(:entity_runs)
  @errors = args[:errors] if args.key?(:errors)
  @latest_pause_time = args[:latest_pause_time] if args.key?(:latest_pause_time)
  @name = args[:name] if args.key?(:name)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @state_update_time = args[:state_update_time] if args.key?(:state_update_time)
  @trigger = args[:trigger] if args.key?(:trigger)
end