Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaConnectorRun
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaConnectorRun
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
A data sync run of DataConnector. After DataConnector is successfully initialized, data syncs are scheduled at DataConnector.refresh_interval. A ConnectorRun represents a data sync either in the past or onging that the moment. //
Instance Attribute Summary collapse
-
#end_time ⇒ String
Output only.
-
#entity_runs ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaConnectorRunEntityRun>
Output only.
-
#errors ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>
Contains info about errors incurred during the sync.
-
#latest_pause_time ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#state_update_time ⇒ String
Timestamp at which the connector run sync state was last updated.
-
#trigger ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaConnectorRun
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaConnectorRun.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaConnectorRun
Returns a new instance of GoogleCloudDiscoveryengineV1alphaConnectorRun.
9757 9758 9759 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9757 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time ⇒ String
Output only. The time when the connector run ended.
Corresponds to the JSON property endTime
9710 9711 9712 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9710 def end_time @end_time end |
#entity_runs ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaConnectorRunEntityRun>
Output only. The details of the entities synced at the ConnectorRun. Each
ConnectorRun consists of syncing one or more entities.
Corresponds to the JSON property entityRuns
9716 9717 9718 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9716 def entity_runs @entity_runs end |
#errors ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>
Contains info about errors incurred during the sync. Only exist if running
into an error state. Contains error code and error message. Use with the
state field.
Corresponds to the JSON property errors
9723 9724 9725 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9723 def errors @errors end |
#latest_pause_time ⇒ String
Output only. The time when the connector run was most recently paused.
Corresponds to the JSON property latestPauseTime
9728 9729 9730 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9728 def latest_pause_time @latest_pause_time end |
#name ⇒ String
Output only. The full resource name of the Connector Run. Format: projects/*/
locations/*/collections/*/dataConnector/connectorRuns/*. The
connector_run_id is system-generated.
Corresponds to the JSON property name
9735 9736 9737 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9735 def name @name end |
#start_time ⇒ String
Output only. The time when the connector run started.
Corresponds to the JSON property startTime
9740 9741 9742 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9740 def start_time @start_time end |
#state ⇒ String
Output only. The state of the sync run.
Corresponds to the JSON property state
9745 9746 9747 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9745 def state @state end |
#state_update_time ⇒ String
Timestamp at which the connector run sync state was last updated.
Corresponds to the JSON property stateUpdateTime
9750 9751 9752 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9750 def state_update_time @state_update_time end |
#trigger ⇒ String
Output only. The trigger for this ConnectorRun.
Corresponds to the JSON property trigger
9755 9756 9757 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9755 def trigger @trigger end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9762 9763 9764 9765 9766 9767 9768 9769 9770 9771 9772 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9762 def update!(**args) @end_time = args[:end_time] if args.key?(:end_time) @entity_runs = args[:entity_runs] if args.key?(:entity_runs) @errors = args[:errors] if args.key?(:errors) @latest_pause_time = args[:latest_pause_time] if args.key?(:latest_pause_time) @name = args[:name] if args.key?(:name) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @state_update_time = args[:state_update_time] if args.key?(:state_update_time) @trigger = args[:trigger] if args.key?(:trigger) end |