Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaConnectorRunEntityRun

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Represents an entity that was synced in this ConnectorRun.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaConnectorRunEntityRun

Returns a new instance of GoogleCloudDiscoveryengineV1alphaConnectorRunEntityRun.



9838
9839
9840
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9838

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deleted_record_countFixnum

Optional. The number of documents deleted. Corresponds to the JSON property deletedRecordCount

Returns:

  • (Fixnum)


9772
9773
9774
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9772

def deleted_record_count
  @deleted_record_count
end

#entity_nameString

The name of the source entity. Corresponds to the JSON property entityName

Returns:

  • (String)


9777
9778
9779
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9777

def entity_name
  @entity_name
end

#error_record_countFixnum

Optional. The total number of documents failed at sync at indexing stage. Corresponds to the JSON property errorRecordCount

Returns:

  • (Fixnum)


9782
9783
9784
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9782

def error_record_count
  @error_record_count
end

#errorsArray<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>

The errors from the entity's sync run. Only exist if running into an error state. Contains error code and error message. Corresponds to the JSON property errors



9788
9789
9790
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9788

def errors
  @errors
end

#extracted_record_countFixnum

Optional. The number of documents extracted from connector source, ready to be ingested to VAIS. Corresponds to the JSON property extractedRecordCount

Returns:

  • (Fixnum)


9794
9795
9796
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9794

def extracted_record_count
  @extracted_record_count
end

#indexed_record_countFixnum

Optional. The number of documents indexed. Corresponds to the JSON property indexedRecordCount

Returns:

  • (Fixnum)


9799
9800
9801
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9799

def indexed_record_count
  @indexed_record_count
end

#progressGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaConnectorRunEntityRunProgress

Represents the progress of a sync run. Corresponds to the JSON property progress



9804
9805
9806
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9804

def progress
  @progress
end

#scheduled_record_countFixnum

Optional. The number of documents scheduled to be crawled/extracted from connector source. This only applies to third party connectors. Corresponds to the JSON property scheduledRecordCount

Returns:

  • (Fixnum)


9810
9811
9812
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9810

def scheduled_record_count
  @scheduled_record_count
end

#source_api_request_countFixnum

Optional. The number of requests sent to 3p API. Corresponds to the JSON property sourceApiRequestCount

Returns:

  • (Fixnum)


9815
9816
9817
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9815

def source_api_request_count
  @source_api_request_count
end

#stateString

The state of the entity's sync run. Corresponds to the JSON property state

Returns:

  • (String)


9820
9821
9822
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9820

def state
  @state
end

#state_update_timeString

Timestamp at which the entity sync state was last updated. Corresponds to the JSON property stateUpdateTime

Returns:

  • (String)


9825
9826
9827
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9825

def state_update_time
  @state_update_time
end

#stats_update_timeString

The timestamp for either extracted_documents_count, indexed_documents_count and error_documents_count was last updated. Corresponds to the JSON property statsUpdateTime

Returns:

  • (String)


9831
9832
9833
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9831

def stats_update_time
  @stats_update_time
end

#sync_typeString

Sync type of this run. Corresponds to the JSON property syncType

Returns:

  • (String)


9836
9837
9838
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9836

def sync_type
  @sync_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9843
9844
9845
9846
9847
9848
9849
9850
9851
9852
9853
9854
9855
9856
9857
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9843

def update!(**args)
  @deleted_record_count = args[:deleted_record_count] if args.key?(:deleted_record_count)
  @entity_name = args[:entity_name] if args.key?(:entity_name)
  @error_record_count = args[:error_record_count] if args.key?(:error_record_count)
  @errors = args[:errors] if args.key?(:errors)
  @extracted_record_count = args[:extracted_record_count] if args.key?(:extracted_record_count)
  @indexed_record_count = args[:indexed_record_count] if args.key?(:indexed_record_count)
  @progress = args[:progress] if args.key?(:progress)
  @scheduled_record_count = args[:scheduled_record_count] if args.key?(:scheduled_record_count)
  @source_api_request_count = args[:source_api_request_count] if args.key?(:source_api_request_count)
  @state = args[:state] if args.key?(:state)
  @state_update_time = args[:state_update_time] if args.key?(:state_update_time)
  @stats_update_time = args[:stats_update_time] if args.key?(:stats_update_time)
  @sync_type = args[:sync_type] if args.key?(:sync_type)
end