Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaConnectorRunEntityRun
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaConnectorRunEntityRun
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Represents an entity that was synced in this ConnectorRun.
Instance Attribute Summary collapse
-
#deleted_record_count ⇒ Fixnum
Optional.
-
#entity_name ⇒ String
The name of the source entity.
-
#error_record_count ⇒ Fixnum
Optional.
-
#errors ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>
The errors from the entity's sync run.
-
#extracted_record_count ⇒ Fixnum
Optional.
-
#indexed_record_count ⇒ Fixnum
Optional.
-
#progress ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaConnectorRunEntityRunProgress
Represents the progress of a sync run.
-
#scheduled_record_count ⇒ Fixnum
Optional.
-
#source_api_request_count ⇒ Fixnum
Optional.
-
#state ⇒ String
The state of the entity's sync run.
-
#state_update_time ⇒ String
Timestamp at which the entity sync state was last updated.
-
#stats_update_time ⇒ String
The timestamp for either extracted_documents_count, indexed_documents_count and error_documents_count was last updated.
-
#sync_type ⇒ String
Sync type of this run.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaConnectorRunEntityRun
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaConnectorRunEntityRun.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaConnectorRunEntityRun
Returns a new instance of GoogleCloudDiscoveryengineV1alphaConnectorRunEntityRun.
9282 9283 9284 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9282 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deleted_record_count ⇒ Fixnum
Optional. The number of documents deleted.
Corresponds to the JSON property deletedRecordCount
9216 9217 9218 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9216 def deleted_record_count @deleted_record_count end |
#entity_name ⇒ String
The name of the source entity.
Corresponds to the JSON property entityName
9221 9222 9223 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9221 def entity_name @entity_name end |
#error_record_count ⇒ Fixnum
Optional. The total number of documents failed at sync at indexing stage.
Corresponds to the JSON property errorRecordCount
9226 9227 9228 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9226 def error_record_count @error_record_count end |
#errors ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>
The errors from the entity's sync run. Only exist if running into an error
state. Contains error code and error message.
Corresponds to the JSON property errors
9232 9233 9234 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9232 def errors @errors end |
#extracted_record_count ⇒ Fixnum
Optional. The number of documents extracted from connector source, ready to be
ingested to VAIS.
Corresponds to the JSON property extractedRecordCount
9238 9239 9240 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9238 def extracted_record_count @extracted_record_count end |
#indexed_record_count ⇒ Fixnum
Optional. The number of documents indexed.
Corresponds to the JSON property indexedRecordCount
9243 9244 9245 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9243 def indexed_record_count @indexed_record_count end |
#progress ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaConnectorRunEntityRunProgress
Represents the progress of a sync run.
Corresponds to the JSON property progress
9248 9249 9250 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9248 def progress @progress end |
#scheduled_record_count ⇒ Fixnum
Optional. The number of documents scheduled to be crawled/extracted from
connector source. This only applies to third party connectors.
Corresponds to the JSON property scheduledRecordCount
9254 9255 9256 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9254 def scheduled_record_count @scheduled_record_count end |
#source_api_request_count ⇒ Fixnum
Optional. The number of requests sent to 3p API.
Corresponds to the JSON property sourceApiRequestCount
9259 9260 9261 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9259 def source_api_request_count @source_api_request_count end |
#state ⇒ String
The state of the entity's sync run.
Corresponds to the JSON property state
9264 9265 9266 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9264 def state @state end |
#state_update_time ⇒ String
Timestamp at which the entity sync state was last updated.
Corresponds to the JSON property stateUpdateTime
9269 9270 9271 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9269 def state_update_time @state_update_time end |
#stats_update_time ⇒ String
The timestamp for either extracted_documents_count, indexed_documents_count
and error_documents_count was last updated.
Corresponds to the JSON property statsUpdateTime
9275 9276 9277 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9275 def stats_update_time @stats_update_time end |
#sync_type ⇒ String
Sync type of this run.
Corresponds to the JSON property syncType
9280 9281 9282 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9280 def sync_type @sync_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9287 9288 9289 9290 9291 9292 9293 9294 9295 9296 9297 9298 9299 9300 9301 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9287 def update!(**args) @deleted_record_count = args[:deleted_record_count] if args.key?(:deleted_record_count) @entity_name = args[:entity_name] if args.key?(:entity_name) @error_record_count = args[:error_record_count] if args.key?(:error_record_count) @errors = args[:errors] if args.key?(:errors) @extracted_record_count = args[:extracted_record_count] if args.key?(:extracted_record_count) @indexed_record_count = args[:indexed_record_count] if args.key?(:indexed_record_count) @progress = args[:progress] if args.key?(:progress) @scheduled_record_count = args[:scheduled_record_count] if args.key?(:scheduled_record_count) @source_api_request_count = args[:source_api_request_count] if args.key?(:source_api_request_count) @state = args[:state] if args.key?(:state) @state_update_time = args[:state_update_time] if args.key?(:state_update_time) @stats_update_time = args[:stats_update_time] if args.key?(:stats_update_time) @sync_type = args[:sync_type] if args.key?(:sync_type) end |