Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaConnectorRunEntityRun
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaConnectorRunEntityRun
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Represents an entity that was synced in this ConnectorRun.
Instance Attribute Summary collapse
-
#deleted_record_count ⇒ Fixnum
Optional.
-
#entity_name ⇒ String
The name of the source entity.
-
#error_record_count ⇒ Fixnum
Optional.
-
#errors ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>
The errors from the entity's sync run.
-
#extracted_record_count ⇒ Fixnum
Optional.
-
#indexed_record_count ⇒ Fixnum
Optional.
-
#progress ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaConnectorRunEntityRunProgress
Represents the progress of a sync run.
-
#scheduled_record_count ⇒ Fixnum
Optional.
-
#source_api_request_count ⇒ Fixnum
Optional.
-
#state ⇒ String
The state of the entity's sync run.
-
#state_update_time ⇒ String
Timestamp at which the entity sync state was last updated.
-
#stats_update_time ⇒ String
The timestamp for either extracted_documents_count, indexed_documents_count and error_documents_count was last updated.
-
#sync_type ⇒ String
Sync type of this run.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaConnectorRunEntityRun
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaConnectorRunEntityRun.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaConnectorRunEntityRun
Returns a new instance of GoogleCloudDiscoveryengineV1alphaConnectorRunEntityRun.
9180 9181 9182 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9180 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deleted_record_count ⇒ Fixnum
Optional. The number of documents deleted.
Corresponds to the JSON property deletedRecordCount
9114 9115 9116 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9114 def deleted_record_count @deleted_record_count end |
#entity_name ⇒ String
The name of the source entity.
Corresponds to the JSON property entityName
9119 9120 9121 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9119 def entity_name @entity_name end |
#error_record_count ⇒ Fixnum
Optional. The total number of documents failed at sync at indexing stage.
Corresponds to the JSON property errorRecordCount
9124 9125 9126 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9124 def error_record_count @error_record_count end |
#errors ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>
The errors from the entity's sync run. Only exist if running into an error
state. Contains error code and error message.
Corresponds to the JSON property errors
9130 9131 9132 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9130 def errors @errors end |
#extracted_record_count ⇒ Fixnum
Optional. The number of documents extracted from connector source, ready to be
ingested to VAIS.
Corresponds to the JSON property extractedRecordCount
9136 9137 9138 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9136 def extracted_record_count @extracted_record_count end |
#indexed_record_count ⇒ Fixnum
Optional. The number of documents indexed.
Corresponds to the JSON property indexedRecordCount
9141 9142 9143 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9141 def indexed_record_count @indexed_record_count end |
#progress ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaConnectorRunEntityRunProgress
Represents the progress of a sync run.
Corresponds to the JSON property progress
9146 9147 9148 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9146 def progress @progress end |
#scheduled_record_count ⇒ Fixnum
Optional. The number of documents scheduled to be crawled/extracted from
connector source. This only applies to third party connectors.
Corresponds to the JSON property scheduledRecordCount
9152 9153 9154 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9152 def scheduled_record_count @scheduled_record_count end |
#source_api_request_count ⇒ Fixnum
Optional. The number of requests sent to 3p API.
Corresponds to the JSON property sourceApiRequestCount
9157 9158 9159 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9157 def source_api_request_count @source_api_request_count end |
#state ⇒ String
The state of the entity's sync run.
Corresponds to the JSON property state
9162 9163 9164 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9162 def state @state end |
#state_update_time ⇒ String
Timestamp at which the entity sync state was last updated.
Corresponds to the JSON property stateUpdateTime
9167 9168 9169 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9167 def state_update_time @state_update_time end |
#stats_update_time ⇒ String
The timestamp for either extracted_documents_count, indexed_documents_count
and error_documents_count was last updated.
Corresponds to the JSON property statsUpdateTime
9173 9174 9175 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9173 def stats_update_time @stats_update_time end |
#sync_type ⇒ String
Sync type of this run.
Corresponds to the JSON property syncType
9178 9179 9180 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9178 def sync_type @sync_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9185 9186 9187 9188 9189 9190 9191 9192 9193 9194 9195 9196 9197 9198 9199 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9185 def update!(**args) @deleted_record_count = args[:deleted_record_count] if args.key?(:deleted_record_count) @entity_name = args[:entity_name] if args.key?(:entity_name) @error_record_count = args[:error_record_count] if args.key?(:error_record_count) @errors = args[:errors] if args.key?(:errors) @extracted_record_count = args[:extracted_record_count] if args.key?(:extracted_record_count) @indexed_record_count = args[:indexed_record_count] if args.key?(:indexed_record_count) @progress = args[:progress] if args.key?(:progress) @scheduled_record_count = args[:scheduled_record_count] if args.key?(:scheduled_record_count) @source_api_request_count = args[:source_api_request_count] if args.key?(:source_api_request_count) @state = args[:state] if args.key?(:state) @state_update_time = args[:state_update_time] if args.key?(:state_update_time) @stats_update_time = args[:stats_update_time] if args.key?(:stats_update_time) @sync_type = args[:sync_type] if args.key?(:sync_type) end |