Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaContactDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

The contact info stored in resource level. If both project level and resource level is populated, the resource level contact info will override the project level contact info.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaContactDetails

Returns a new instance of GoogleCloudDiscoveryengineV1alphaContactDetails.



9913
9914
9915
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9913

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#email_addressString

Optional. The email address of the contact. Corresponds to the JSON property emailAddress

Returns:

  • (String)


9911
9912
9913
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9911

def email_address
  @email_address
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9918
9919
9920
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9918

def update!(**args)
  @email_address = args[:email_address] if args.key?(:email_address)
end