Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaControl
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaControl
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Defines a conditioned behavior to employ during serving. Must be attached to a
ServingConfig to be considered at serving time. Permitted actions dependent on
SolutionType.
Instance Attribute Summary collapse
-
#associated_serving_config_ids ⇒ Array<String>
Output only.
-
#boost_action ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaControlBoostAction
Adjusts order of products in returned list.
-
#conditions ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaCondition>
Determines when the associated action will trigger.
-
#display_name ⇒ String
Required.
-
#filter_action ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaControlFilterAction
Specified which products may be included in results.
-
#name ⇒ String
Immutable.
-
#promote_action ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaControlPromoteAction
Promote certain links based on some trigger queries.
-
#redirect_action ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaControlRedirectAction
Redirects a shopper to the provided URI.
-
#solution_type ⇒ String
Required.
-
#synonyms_action ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaControlSynonymsAction
Creates a set of terms that will act as synonyms of one another.
-
#use_cases ⇒ Array<String>
Specifies the use case for the control.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaControl
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaControl.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaControl
Returns a new instance of GoogleCloudDiscoveryengineV1alphaControl.
10067 10068 10069 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10067 def initialize(**args) update!(**args) end |
Instance Attribute Details
#associated_serving_config_ids ⇒ Array<String>
Output only. List of all ServingConfig IDs this control is attached to. May
take up to 10 minutes to update after changes.
Corresponds to the JSON property associatedServingConfigIds
10002 10003 10004 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10002 def associated_serving_config_ids @associated_serving_config_ids end |
#boost_action ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaControlBoostAction
Adjusts order of products in returned list.
Corresponds to the JSON property boostAction
10007 10008 10009 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10007 def boost_action @boost_action end |
#conditions ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaCondition>
Determines when the associated action will trigger. Omit to always apply the
action. Currently only a single condition may be specified. Otherwise an
INVALID ARGUMENT error is thrown.
Corresponds to the JSON property conditions
10014 10015 10016 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10014 def conditions @conditions end |
#display_name ⇒ String
Required. Human readable name. The identifier used in UI views. Must be UTF-8
encoded string. Length limit is 128 characters. Otherwise an INVALID ARGUMENT
error is thrown.
Corresponds to the JSON property displayName
10021 10022 10023 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10021 def display_name @display_name end |
#filter_action ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaControlFilterAction
Specified which products may be included in results. Uses same filter as boost.
Corresponds to the JSON property filterAction
10026 10027 10028 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10026 def filter_action @filter_action end |
#name ⇒ String
Immutable. Fully qualified name projects/*/locations/global/dataStore/*/
controls/*
Corresponds to the JSON property name
10032 10033 10034 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10032 def name @name end |
#promote_action ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaControlPromoteAction
Promote certain links based on some trigger queries. Example: Promote shoe
store link when searching for shoe keyword. The link can be outside of
associated data store.
Corresponds to the JSON property promoteAction
10039 10040 10041 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10039 def promote_action @promote_action end |
#redirect_action ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaControlRedirectAction
Redirects a shopper to the provided URI.
Corresponds to the JSON property redirectAction
10044 10045 10046 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10044 def redirect_action @redirect_action end |
#solution_type ⇒ String
Required. Immutable. What solution the control belongs to. Must be compatible
with vertical of resource. Otherwise an INVALID ARGUMENT error is thrown.
Corresponds to the JSON property solutionType
10050 10051 10052 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10050 def solution_type @solution_type end |
#synonyms_action ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaControlSynonymsAction
Creates a set of terms that will act as synonyms of one another. Example: "
happy" will also be considered as "glad", "glad" will also be considered as "
happy".
Corresponds to the JSON property synonymsAction
10057 10058 10059 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10057 def synonyms_action @synonyms_action end |
#use_cases ⇒ Array<String>
Specifies the use case for the control. Affects what condition fields can be
set. Only applies to SOLUTION_TYPE_SEARCH. Currently only allow one use case
per control. Must be set when solution_type is SolutionType.
SOLUTION_TYPE_SEARCH.
Corresponds to the JSON property useCases
10065 10066 10067 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10065 def use_cases @use_cases end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10072 10073 10074 10075 10076 10077 10078 10079 10080 10081 10082 10083 10084 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10072 def update!(**args) @associated_serving_config_ids = args[:associated_serving_config_ids] if args.key?(:associated_serving_config_ids) @boost_action = args[:boost_action] if args.key?(:boost_action) @conditions = args[:conditions] if args.key?(:conditions) @display_name = args[:display_name] if args.key?(:display_name) @filter_action = args[:filter_action] if args.key?(:filter_action) @name = args[:name] if args.key?(:name) @promote_action = args[:promote_action] if args.key?(:promote_action) @redirect_action = args[:redirect_action] if args.key?(:redirect_action) @solution_type = args[:solution_type] if args.key?(:solution_type) @synonyms_action = args[:synonyms_action] if args.key?(:synonyms_action) @use_cases = args[:use_cases] if args.key?(:use_cases) end |