Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaControl
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaControl
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Defines a conditioned behavior to employ during serving. Must be attached to a
ServingConfig to be considered at serving time. Permitted actions dependent on
SolutionType.
Instance Attribute Summary collapse
-
#associated_serving_config_ids ⇒ Array<String>
Output only.
-
#boost_action ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaControlBoostAction
Adjusts order of products in returned list.
-
#conditions ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaCondition>
Determines when the associated action will trigger.
-
#display_name ⇒ String
Required.
-
#filter_action ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaControlFilterAction
Specified which products may be included in results.
-
#name ⇒ String
Immutable.
-
#promote_action ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaControlPromoteAction
Promote certain links based on some trigger queries.
-
#redirect_action ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaControlRedirectAction
Redirects a shopper to the provided URI.
-
#solution_type ⇒ String
Required.
-
#synonyms_action ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaControlSynonymsAction
Creates a set of terms that will act as synonyms of one another.
-
#use_cases ⇒ Array<String>
Specifies the use case for the control.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaControl
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaControl.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaControl
Returns a new instance of GoogleCloudDiscoveryengineV1alphaControl.
10010 10011 10012 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10010 def initialize(**args) update!(**args) end |
Instance Attribute Details
#associated_serving_config_ids ⇒ Array<String>
Output only. List of all ServingConfig IDs this control is attached to. May
take up to 10 minutes to update after changes.
Corresponds to the JSON property associatedServingConfigIds
9945 9946 9947 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9945 def associated_serving_config_ids @associated_serving_config_ids end |
#boost_action ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaControlBoostAction
Adjusts order of products in returned list.
Corresponds to the JSON property boostAction
9950 9951 9952 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9950 def boost_action @boost_action end |
#conditions ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaCondition>
Determines when the associated action will trigger. Omit to always apply the
action. Currently only a single condition may be specified. Otherwise an
INVALID ARGUMENT error is thrown.
Corresponds to the JSON property conditions
9957 9958 9959 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9957 def conditions @conditions end |
#display_name ⇒ String
Required. Human readable name. The identifier used in UI views. Must be UTF-8
encoded string. Length limit is 128 characters. Otherwise an INVALID ARGUMENT
error is thrown.
Corresponds to the JSON property displayName
9964 9965 9966 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9964 def display_name @display_name end |
#filter_action ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaControlFilterAction
Specified which products may be included in results. Uses same filter as boost.
Corresponds to the JSON property filterAction
9969 9970 9971 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9969 def filter_action @filter_action end |
#name ⇒ String
Immutable. Fully qualified name projects/*/locations/global/dataStore/*/
controls/*
Corresponds to the JSON property name
9975 9976 9977 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9975 def name @name end |
#promote_action ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaControlPromoteAction
Promote certain links based on some trigger queries. Example: Promote shoe
store link when searching for shoe keyword. The link can be outside of
associated data store.
Corresponds to the JSON property promoteAction
9982 9983 9984 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9982 def promote_action @promote_action end |
#redirect_action ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaControlRedirectAction
Redirects a shopper to the provided URI.
Corresponds to the JSON property redirectAction
9987 9988 9989 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9987 def redirect_action @redirect_action end |
#solution_type ⇒ String
Required. Immutable. What solution the control belongs to. Must be compatible
with vertical of resource. Otherwise an INVALID ARGUMENT error is thrown.
Corresponds to the JSON property solutionType
9993 9994 9995 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9993 def solution_type @solution_type end |
#synonyms_action ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaControlSynonymsAction
Creates a set of terms that will act as synonyms of one another. Example: "
happy" will also be considered as "glad", "glad" will also be considered as "
happy".
Corresponds to the JSON property synonymsAction
10000 10001 10002 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10000 def synonyms_action @synonyms_action end |
#use_cases ⇒ Array<String>
Specifies the use case for the control. Affects what condition fields can be
set. Only applies to SOLUTION_TYPE_SEARCH. Currently only allow one use case
per control. Must be set when solution_type is SolutionType.
SOLUTION_TYPE_SEARCH.
Corresponds to the JSON property useCases
10008 10009 10010 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10008 def use_cases @use_cases end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10015 10016 10017 10018 10019 10020 10021 10022 10023 10024 10025 10026 10027 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10015 def update!(**args) @associated_serving_config_ids = args[:associated_serving_config_ids] if args.key?(:associated_serving_config_ids) @boost_action = args[:boost_action] if args.key?(:boost_action) @conditions = args[:conditions] if args.key?(:conditions) @display_name = args[:display_name] if args.key?(:display_name) @filter_action = args[:filter_action] if args.key?(:filter_action) @name = args[:name] if args.key?(:name) @promote_action = args[:promote_action] if args.key?(:promote_action) @redirect_action = args[:redirect_action] if args.key?(:redirect_action) @solution_type = args[:solution_type] if args.key?(:solution_type) @synonyms_action = args[:synonyms_action] if args.key?(:synonyms_action) @use_cases = args[:use_cases] if args.key?(:use_cases) end |