Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaControl

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Defines a conditioned behavior to employ during serving. Must be attached to a ServingConfig to be considered at serving time. Permitted actions dependent on SolutionType.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaControl

Returns a new instance of GoogleCloudDiscoveryengineV1alphaControl.



9988
9989
9990
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9988

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#associated_serving_config_idsArray<String>

Output only. List of all ServingConfig IDs this control is attached to. May take up to 10 minutes to update after changes. Corresponds to the JSON property associatedServingConfigIds

Returns:

  • (Array<String>)


9923
9924
9925
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9923

def associated_serving_config_ids
  @associated_serving_config_ids
end

#boost_actionGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaControlBoostAction

Adjusts order of products in returned list. Corresponds to the JSON property boostAction



9928
9929
9930
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9928

def boost_action
  @boost_action
end

#conditionsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaCondition>

Determines when the associated action will trigger. Omit to always apply the action. Currently only a single condition may be specified. Otherwise an INVALID ARGUMENT error is thrown. Corresponds to the JSON property conditions



9935
9936
9937
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9935

def conditions
  @conditions
end

#display_nameString

Required. Human readable name. The identifier used in UI views. Must be UTF-8 encoded string. Length limit is 128 characters. Otherwise an INVALID ARGUMENT error is thrown. Corresponds to the JSON property displayName

Returns:

  • (String)


9942
9943
9944
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9942

def display_name
  @display_name
end

#filter_actionGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaControlFilterAction

Specified which products may be included in results. Uses same filter as boost. Corresponds to the JSON property filterAction



9947
9948
9949
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9947

def filter_action
  @filter_action
end

#nameString

Immutable. Fully qualified name projects/*/locations/global/dataStore/*/ controls/* Corresponds to the JSON property name

Returns:

  • (String)


9953
9954
9955
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9953

def name
  @name
end

#promote_actionGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaControlPromoteAction

Promote certain links based on some trigger queries. Example: Promote shoe store link when searching for shoe keyword. The link can be outside of associated data store. Corresponds to the JSON property promoteAction



9960
9961
9962
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9960

def promote_action
  @promote_action
end

#redirect_actionGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaControlRedirectAction

Redirects a shopper to the provided URI. Corresponds to the JSON property redirectAction



9965
9966
9967
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9965

def redirect_action
  @redirect_action
end

#solution_typeString

Required. Immutable. What solution the control belongs to. Must be compatible with vertical of resource. Otherwise an INVALID ARGUMENT error is thrown. Corresponds to the JSON property solutionType

Returns:

  • (String)


9971
9972
9973
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9971

def solution_type
  @solution_type
end

#synonyms_actionGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaControlSynonymsAction

Creates a set of terms that will act as synonyms of one another. Example: " happy" will also be considered as "glad", "glad" will also be considered as " happy". Corresponds to the JSON property synonymsAction



9978
9979
9980
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9978

def synonyms_action
  @synonyms_action
end

#use_casesArray<String>

Specifies the use case for the control. Affects what condition fields can be set. Only applies to SOLUTION_TYPE_SEARCH. Currently only allow one use case per control. Must be set when solution_type is SolutionType. SOLUTION_TYPE_SEARCH. Corresponds to the JSON property useCases

Returns:

  • (Array<String>)


9986
9987
9988
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9986

def use_cases
  @use_cases
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9993
9994
9995
9996
9997
9998
9999
10000
10001
10002
10003
10004
10005
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9993

def update!(**args)
  @associated_serving_config_ids = args[:associated_serving_config_ids] if args.key?(:associated_serving_config_ids)
  @boost_action = args[:boost_action] if args.key?(:boost_action)
  @conditions = args[:conditions] if args.key?(:conditions)
  @display_name = args[:display_name] if args.key?(:display_name)
  @filter_action = args[:filter_action] if args.key?(:filter_action)
  @name = args[:name] if args.key?(:name)
  @promote_action = args[:promote_action] if args.key?(:promote_action)
  @redirect_action = args[:redirect_action] if args.key?(:redirect_action)
  @solution_type = args[:solution_type] if args.key?(:solution_type)
  @synonyms_action = args[:synonyms_action] if args.key?(:synonyms_action)
  @use_cases = args[:use_cases] if args.key?(:use_cases)
end