Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaControl

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Defines a conditioned behavior to employ during serving. Must be attached to a ServingConfig to be considered at serving time. Permitted actions dependent on SolutionType.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaControl

Returns a new instance of GoogleCloudDiscoveryengineV1alphaControl.



9330
9331
9332
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9330

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#associated_serving_config_idsArray<String>

Output only. List of all ServingConfig IDs this control is attached to. May take up to 10 minutes to update after changes. Corresponds to the JSON property associatedServingConfigIds

Returns:

  • (Array<String>)


9265
9266
9267
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9265

def associated_serving_config_ids
  @associated_serving_config_ids
end

#boost_actionGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaControlBoostAction

Adjusts order of products in returned list. Corresponds to the JSON property boostAction



9270
9271
9272
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9270

def boost_action
  @boost_action
end

#conditionsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaCondition>

Determines when the associated action will trigger. Omit to always apply the action. Currently only a single condition may be specified. Otherwise an INVALID ARGUMENT error is thrown. Corresponds to the JSON property conditions



9277
9278
9279
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9277

def conditions
  @conditions
end

#display_nameString

Required. Human readable name. The identifier used in UI views. Must be UTF-8 encoded string. Length limit is 128 characters. Otherwise an INVALID ARGUMENT error is thrown. Corresponds to the JSON property displayName

Returns:

  • (String)


9284
9285
9286
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9284

def display_name
  @display_name
end

#filter_actionGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaControlFilterAction

Specified which products may be included in results. Uses same filter as boost. Corresponds to the JSON property filterAction



9289
9290
9291
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9289

def filter_action
  @filter_action
end

#nameString

Immutable. Fully qualified name projects/*/locations/global/dataStore/*/ controls/* Corresponds to the JSON property name

Returns:

  • (String)


9295
9296
9297
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9295

def name
  @name
end

#promote_actionGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaControlPromoteAction

Promote certain links based on some trigger queries. Example: Promote shoe store link when searching for shoe keyword. The link can be outside of associated data store. Corresponds to the JSON property promoteAction



9302
9303
9304
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9302

def promote_action
  @promote_action
end

#redirect_actionGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaControlRedirectAction

Redirects a shopper to the provided URI. Corresponds to the JSON property redirectAction



9307
9308
9309
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9307

def redirect_action
  @redirect_action
end

#solution_typeString

Required. Immutable. What solution the control belongs to. Must be compatible with vertical of resource. Otherwise an INVALID ARGUMENT error is thrown. Corresponds to the JSON property solutionType

Returns:

  • (String)


9313
9314
9315
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9313

def solution_type
  @solution_type
end

#synonyms_actionGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaControlSynonymsAction

Creates a set of terms that will act as synonyms of one another. Example: " happy" will also be considered as "glad", "glad" will also be considered as " happy". Corresponds to the JSON property synonymsAction



9320
9321
9322
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9320

def synonyms_action
  @synonyms_action
end

#use_casesArray<String>

Specifies the use case for the control. Affects what condition fields can be set. Only applies to SOLUTION_TYPE_SEARCH. Currently only allow one use case per control. Must be set when solution_type is SolutionType. SOLUTION_TYPE_SEARCH. Corresponds to the JSON property useCases

Returns:

  • (Array<String>)


9328
9329
9330
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9328

def use_cases
  @use_cases
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9335
9336
9337
9338
9339
9340
9341
9342
9343
9344
9345
9346
9347
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9335

def update!(**args)
  @associated_serving_config_ids = args[:associated_serving_config_ids] if args.key?(:associated_serving_config_ids)
  @boost_action = args[:boost_action] if args.key?(:boost_action)
  @conditions = args[:conditions] if args.key?(:conditions)
  @display_name = args[:display_name] if args.key?(:display_name)
  @filter_action = args[:filter_action] if args.key?(:filter_action)
  @name = args[:name] if args.key?(:name)
  @promote_action = args[:promote_action] if args.key?(:promote_action)
  @redirect_action = args[:redirect_action] if args.key?(:redirect_action)
  @solution_type = args[:solution_type] if args.key?(:solution_type)
  @synonyms_action = args[:synonyms_action] if args.key?(:synonyms_action)
  @use_cases = args[:use_cases] if args.key?(:use_cases)
end