Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaControlBoostAction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Adjusts order of products in returned list.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaControlBoostAction

Returns a new instance of GoogleCloudDiscoveryengineV1alphaControlBoostAction.



10046
10047
10048
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10046

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#boostFloat

Strength of the boost, which should be in [-1, 1]. Negative boost means demotion. Default is 0.0 (No-op). Corresponds to the JSON property boost

Returns:

  • (Float)


10016
10017
10018
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10016

def boost
  @boost
end

#data_storeString

Required. Specifies which data store's documents can be boosted by this control. Full data store name e.g. projects/123/locations/global/collections/ default_collection/dataStores/default_data_store Corresponds to the JSON property dataStore

Returns:

  • (String)


10023
10024
10025
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10023

def data_store
  @data_store
end

#filterString

Required. Specifies which products to apply the boost to. If no filter is provided all products will be boosted (No-op). Syntax documentation: https:// cloud.google.com/retail/docs/filter-and-order Maximum length is 5000 characters. Otherwise an INVALID ARGUMENT error is thrown. Corresponds to the JSON property filter

Returns:

  • (String)


10031
10032
10033
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10031

def filter
  @filter
end

#fixed_boostFloat

Optional. Strength of the boost, which should be in [-1, 1]. Negative boost means demotion. Default is 0.0 (No-op). Corresponds to the JSON property fixedBoost

Returns:

  • (Float)


10037
10038
10039
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10037

def fixed_boost
  @fixed_boost
end

#interpolation_boost_specGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaControlBoostActionInterpolationBoostSpec

Specification for custom ranking based on customer specified attribute value. It provides more controls for customized ranking than the simple (condition, boost) combination above. Corresponds to the JSON property interpolationBoostSpec



10044
10045
10046
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10044

def interpolation_boost_spec
  @interpolation_boost_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10051
10052
10053
10054
10055
10056
10057
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10051

def update!(**args)
  @boost = args[:boost] if args.key?(:boost)
  @data_store = args[:data_store] if args.key?(:data_store)
  @filter = args[:filter] if args.key?(:filter)
  @fixed_boost = args[:fixed_boost] if args.key?(:fixed_boost)
  @interpolation_boost_spec = args[:interpolation_boost_spec] if args.key?(:interpolation_boost_spec)
end