Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaControlBoostActionInterpolationBoostSpecControlPoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

The control points used to define the curve. The curve defined through these control points can only be monotonically increasing or decreasing(constant values are acceptable).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaControlBoostActionInterpolationBoostSpecControlPoint

Returns a new instance of GoogleCloudDiscoveryengineV1alphaControlBoostActionInterpolationBoostSpecControlPoint.



9469
9470
9471
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9469

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attribute_valueString

Optional. Can be one of: 1. The numerical field value. 2. The duration spec for freshness: The value must be formatted as an XSD dayTimeDuration value ( a restricted subset of an ISO 8601 duration value). The pattern for this is: nDnM]. Corresponds to the JSON property attributeValue

Returns:

  • (String)


9461
9462
9463
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9461

def attribute_value
  @attribute_value
end

#boost_amountFloat

Optional. The value between -1 to 1 by which to boost the score if the attribute_value evaluates to the value specified above. Corresponds to the JSON property boostAmount

Returns:

  • (Float)


9467
9468
9469
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9467

def boost_amount
  @boost_amount
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9474
9475
9476
9477
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 9474

def update!(**args)
  @attribute_value = args[:attribute_value] if args.key?(:attribute_value)
  @boost_amount = args[:boost_amount] if args.key?(:boost_amount)
end