Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataConnector

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Manages the connection to external data sources for all data stores grouped under a Collection. It's a singleton resource of Collection. The initialization is only supported through DataConnectorService. SetUpDataConnector method, which will create a new Collection and initialize its DataConnector.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaDataConnector

Returns a new instance of GoogleCloudDiscoveryengineV1alphaDataConnector.



10749
10750
10751
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10749

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#acl_enabledBoolean Also known as: acl_enabled?

Optional. Whether the connector will be created with an ACL config. Currently this field only affects Cloud Storage and BigQuery connectors. Corresponds to the JSON property aclEnabled

Returns:

  • (Boolean)


10442
10443
10444
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10442

def acl_enabled
  @acl_enabled
end

#action_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaActionConfig

Informations to support actions on the connector. Corresponds to the JSON property actionConfig



10448
10449
10450
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10448

def action_config
  @action_config
end

#action_stateString

Output only. State of the action connector. This reflects whether the action connector is initializing, active or has encountered errors. Corresponds to the JSON property actionState

Returns:

  • (String)


10454
10455
10456
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10454

def action_state
  @action_state
end

#alert_policy_configsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAlertPolicyConfig>

Optional. The connector level alert config. Corresponds to the JSON property alertPolicyConfigs



10459
10460
10461
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10459

def alert_policy_configs
  @alert_policy_configs
end

#auto_run_disabledBoolean Also known as: auto_run_disabled?

Optional. Indicates whether the connector is disabled for auto run. It can be used to pause periodical and real time sync. Update: with the introduction of incremental_sync_disabled, auto_run_disabled is used to pause/disable only full syncs Corresponds to the JSON property autoRunDisabled

Returns:

  • (Boolean)


10467
10468
10469
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10467

def auto_run_disabled
  @auto_run_disabled
end

#bap_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaBapConfig

The configuration for the BAP connector. Corresponds to the JSON property bapConfig



10473
10474
10475
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10473

def bap_config
  @bap_config
end

#blocking_reasonsArray<String>

Output only. User actions that must be completed before the connector can start syncing data. Corresponds to the JSON property blockingReasons

Returns:

  • (Array<String>)


10479
10480
10481
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10479

def blocking_reasons
  @blocking_reasons
end

#cli_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaCliConfig

The configuration for the CLI execution based connectors. Corresponds to the JSON property cliConfig



10484
10485
10486
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10484

def cli_config
  @cli_config
end

#connector_modesArray<String>

Optional. The modes enabled for this connector. Default state is CONNECTOR_MODE_UNSPECIFIED. Corresponds to the JSON property connectorModes

Returns:

  • (Array<String>)


10490
10491
10492
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10490

def connector_modes
  @connector_modes
end

#connector_source_idString

Optional. If set, this value instead of data_source is used to fetch the corresponding connector source. Corresponds to the JSON property connectorSourceId

Returns:

  • (String)


10496
10497
10498
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10496

def connector_source_id
  @connector_source_id
end

#connector_typeString

Output only. The type of connector. Each source can only map to one type. For example, salesforce, confluence and jira have THIRD_PARTY connector type. It is not mutable once set by system. Corresponds to the JSON property connectorType

Returns:

  • (String)


10503
10504
10505
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10503

def connector_type
  @connector_type
end

#create_eua_saasBoolean Also known as: create_eua_saas?

Optional. Whether the END USER AUTHENTICATION connector is created in SaaS. Corresponds to the JSON property createEuaSaas

Returns:

  • (Boolean)


10508
10509
10510
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10508

def create_eua_saas
  @create_eua_saas
end

#create_timeString

Output only. Timestamp the DataConnector was created at. Corresponds to the JSON property createTime

Returns:

  • (String)


10514
10515
10516
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10514

def create_time
  @create_time
end

#data_protection_policyGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataProtectionPolicy

Contains the data protection policy config for a DataStore or a connector. Corresponds to the JSON property dataProtectionPolicy



10519
10520
10521
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10519

def data_protection_policy
  @data_protection_policy
end

#data_sourceString

Required. The identifier for the data source. This is a partial list of supported connectors. Please refer to the documentation for the full list of connectors. Supported first-party connectors include: * gcs * bigquery * gcp_fhir * google_mail * google_drive * google_calendar * google_chat Supported third-party connectors include: Generally available (GA) connectors: * onedrive * outlook * confluence * jira * servicenow * sharepoint Preview connectors: * asana * azure_active_directory * box * canva * confluence_server * custom_connector * docusign * dropbox * dynamics365 * github * gitlab * hubspot * jira_server * linear * native_cloud_identity * notion * okta * pagerduty * peoplesoft * salesforce * shopify * slack * snowflake * teams * trello * workday * zendesk Corresponds to the JSON property dataSource

Returns:

  • (String)


10536
10537
10538
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10536

def data_source
  @data_source
end

#destination_configsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDestinationConfig>

Optional. Any target destinations used to connect to third-party services. Corresponds to the JSON property destinationConfigs



10541
10542
10543
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10541

def destination_configs
  @destination_configs
end

#dynamic_toolsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDynamicTool>

Output only. The dynamic tools fetched for this connector. Corresponds to the JSON property dynamicTools



10546
10547
10548
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10546

def dynamic_tools
  @dynamic_tools
end

#egress_fqdnsArray<String>

Output only. The list of FQDNs of the data connector can egress to. This includes both FQDN derived from the customer provided instance URL and default per connector type FQDNs. Corresponds to the JSON property egressFqdns

Returns:

  • (Array<String>)


10553
10554
10555
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10553

def egress_fqdns
  @egress_fqdns
end

#end_user_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataConnectorEndUserConfig

Any params and credentials used specifically for EUA connectors. Corresponds to the JSON property endUserConfig



10558
10559
10560
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10558

def end_user_config
  @end_user_config
end

#entitiesArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataConnectorSourceEntity>

List of entities from the connected data source to ingest. Corresponds to the JSON property entities



10563
10564
10565
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10563

def entities
  @entities
end

#errorsArray<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>

Output only. The errors from initialization or from the latest connector run. Corresponds to the JSON property errors



10568
10569
10570
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10568

def errors
  @errors
end

#federated_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataConnectorFederatedConfig

Any params and credentials used specifically for hybrid connectors supporting FEDERATED mode. Corresponds to the JSON property federatedConfig



10574
10575
10576
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10574

def federated_config
  @federated_config
end

#hybrid_ingestion_disabledBoolean Also known as: hybrid_ingestion_disabled?

Optional. If the connector is a hybrid connector, determines whether ingestion is enabled and appropriate resources are provisioned during connector creation. If the connector is not a hybrid connector, this field is ignored. Corresponds to the JSON property hybridIngestionDisabled

Returns:

  • (Boolean)


10581
10582
10583
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10581

def hybrid_ingestion_disabled
  @hybrid_ingestion_disabled
end

#identity_refresh_intervalString

The refresh interval to sync the Access Control List information for the documents ingested by this connector. If not set, the access control list will be refreshed at the default interval of 30 minutes. The identity refresh interval can be at least 30 minutes and at most 7 days. Corresponds to the JSON property identityRefreshInterval

Returns:

  • (String)


10590
10591
10592
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10590

def identity_refresh_interval
  @identity_refresh_interval
end

#identity_schedule_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaIdentityScheduleConfig

The configuration for the identity data synchronization runs. Corresponds to the JSON property identityScheduleConfig



10595
10596
10597
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10595

def identity_schedule_config
  @identity_schedule_config
end

#incremental_refresh_intervalString

Optional. The refresh interval specifically for incremental data syncs. If unset, incremental syncs will use the default from env, set to 3hrs. The minimum is 30 minutes and maximum is 7 days. Applicable to only 3P connectors. When the refresh interval is set to the same value as the incremental refresh interval, incremental sync will be disabled. Corresponds to the JSON property incrementalRefreshInterval

Returns:

  • (String)


10604
10605
10606
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10604

def incremental_refresh_interval
  @incremental_refresh_interval
end

#incremental_sync_disabledBoolean Also known as: incremental_sync_disabled?

Optional. Indicates whether incremental syncs are paused for this connector. This is independent of auto_run_disabled. Applicable to only 3P connectors. When the refresh interval is set to the same value as the incremental refresh interval, incremental sync will be disabled, i.e. set to true. Corresponds to the JSON property incrementalSyncDisabled

Returns:

  • (Boolean)


10612
10613
10614
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10612

def incremental_sync_disabled
  @incremental_sync_disabled
end

#json_paramsString

Required data connector parameters in json string format. Corresponds to the JSON property jsonParams

Returns:

  • (String)


10618
10619
10620
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10618

def json_params
  @json_params
end

#kms_key_nameString

Input only. The KMS key to be used to protect the DataStores managed by this connector. Must be set for requests that need to comply with CMEK Org Policy protections. If this field is set and processed successfully, the DataStores created by this connector will be protected by the KMS key. Corresponds to the JSON property kmsKeyName

Returns:

  • (String)


10626
10627
10628
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10626

def kms_key_name
  @kms_key_name
end

#last_sync_timeString

Output only. For periodic connectors only, the last time a data sync was completed. Corresponds to the JSON property lastSyncTime

Returns:

  • (String)


10632
10633
10634
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10632

def last_sync_time
  @last_sync_time
end

#latest_pause_timeString

Output only. The most recent timestamp when this DataConnector was paused, affecting all functionalities such as data synchronization. Pausing a connector has the following effects: - All functionalities, including data synchronization, are halted. - Any ongoing data synchronization job will be canceled. - No future data synchronization runs will be scheduled nor can be triggered. Corresponds to the JSON property latestPauseTime

Returns:

  • (String)


10642
10643
10644
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10642

def latest_pause_time
  @latest_pause_time
end

#nameString

Identifier. The full resource name of the Data Connector. Format: projects/*/ locations/*/collections/*/dataConnector. Corresponds to the JSON property name

Returns:

  • (String)


10648
10649
10650
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10648

def name
  @name
end

#next_sync_timeGoogle::Apis::DiscoveryengineV1beta::GoogleTypeDateTime

Represents civil time (or occasionally physical time). This type can represent a civil time in one of a few possible ways: * When utc_offset is set and time_zone is unset: a civil time on a calendar day with a particular offset from UTC. * When time_zone is set and utc_offset is unset: a civil time on a calendar day in a particular time zone. * When neither time_zone nor utc_offset is set: a civil time on a calendar day in local time. The date is relative to the Proleptic Gregorian Calendar. If year, month, or day are 0, the DateTime is considered not to have a specific year, month, or day respectively. This type may also be used to represent a physical time if all the date and time fields are set and either case of the time_offset oneof is set. Consider using Timestamp message for physical time instead. If your use case also would like to store the user's timezone, that can be done in another field. This type is more flexible than some applications may want. Make sure to document and validate your application's limitations. Corresponds to the JSON property nextSyncTime



10666
10667
10668
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10666

def next_sync_time
  @next_sync_time
end

#oauth_static_ip_addressesArray<String>

Output only. The static IP addresses used by this connector for OAuth APIs (e. g. end user authentication). These are surfaced separately from static_ip_addresses so that customers can apply granular firewall settings for OAuth endpoints. Only populated for connectors that have static IP enabled and are used for actions and/or federated search. Corresponds to the JSON property oauthStaticIpAddresses

Returns:

  • (Array<String>)


10675
10676
10677
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10675

def oauth_static_ip_addresses
  @oauth_static_ip_addresses
end

#paramsHash<String,Object>

Required data connector parameters in structured json format. Corresponds to the JSON property params

Returns:

  • (Hash<String,Object>)


10680
10681
10682
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10680

def params
  @params
end

#private_connectivity_project_idString

Output only. The tenant project ID associated with private connectivity connectors. This project must be allowlisted by in order for the connector to function. Corresponds to the JSON property privateConnectivityProjectId

Returns:

  • (String)


10687
10688
10689
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10687

def private_connectivity_project_id
  @private_connectivity_project_id
end

#realtime_stateString

Output only. real-time sync state Corresponds to the JSON property realtimeState

Returns:

  • (String)


10692
10693
10694
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10692

def realtime_state
  @realtime_state
end

#realtime_sync_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataConnectorRealtimeSyncConfig

The configuration for realtime sync to store additional params for realtime sync. Corresponds to the JSON property realtimeSyncConfig



10698
10699
10700
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10698

def realtime_sync_config
  @realtime_sync_config
end

#refresh_intervalString

Required. The refresh interval for data sync. If duration is set to 0, the data will be synced in real time. The streaming feature is not supported yet. The minimum is 30 minutes and maximum is 7 days. When the refresh interval is set to the same value as the incremental refresh interval, incremental sync will be disabled. Corresponds to the JSON property refreshInterval

Returns:

  • (String)


10707
10708
10709
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10707

def refresh_interval
  @refresh_interval
end

#remove_param_keysArray<String>

Optional. Specifies keys to be removed from the 'params' field. This is only active when 'params' is included in the 'update_mask' in an UpdateDataConnectorRequest. Deletion takes precedence if a key is both in ' remove_param_keys' and present in the 'params' field of the request. Corresponds to the JSON property removeParamKeys

Returns:

  • (Array<String>)


10715
10716
10717
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10715

def remove_param_keys
  @remove_param_keys
end

#stateString

Output only. State of the connector. Corresponds to the JSON property state

Returns:

  • (String)


10720
10721
10722
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10720

def state
  @state
end

#static_ip_addressesArray<String>

Output only. The static IP addresses used by this connector. Corresponds to the JSON property staticIpAddresses

Returns:

  • (Array<String>)


10725
10726
10727
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10725

def static_ip_addresses
  @static_ip_addresses
end

#static_ip_enabledBoolean Also known as: static_ip_enabled?

Optional. Whether customer has enabled static IP addresses for this connector. Corresponds to the JSON property staticIpEnabled

Returns:

  • (Boolean)


10730
10731
10732
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10730

def static_ip_enabled
  @static_ip_enabled
end

#sync_modeString

The data synchronization mode supported by the data connector. Corresponds to the JSON property syncMode

Returns:

  • (String)


10736
10737
10738
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10736

def sync_mode
  @sync_mode
end

#update_timeString

Output only. Timestamp the DataConnector was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


10741
10742
10743
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10741

def update_time
  @update_time
end

#vpcsc_enabledBoolean Also known as: vpcsc_enabled?

Output only. Whether the connector is created with VPC-SC enabled. Corresponds to the JSON property vpcscEnabled

Returns:

  • (Boolean)


10746
10747
10748
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10746

def vpcsc_enabled
  @vpcsc_enabled
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10754
10755
10756
10757
10758
10759
10760
10761
10762
10763
10764
10765
10766
10767
10768
10769
10770
10771
10772
10773
10774
10775
10776
10777
10778
10779
10780
10781
10782
10783
10784
10785
10786
10787
10788
10789
10790
10791
10792
10793
10794
10795
10796
10797
10798
10799
10800
10801
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10754

def update!(**args)
  @acl_enabled = args[:acl_enabled] if args.key?(:acl_enabled)
  @action_config = args[:action_config] if args.key?(:action_config)
  @action_state = args[:action_state] if args.key?(:action_state)
  @alert_policy_configs = args[:alert_policy_configs] if args.key?(:alert_policy_configs)
  @auto_run_disabled = args[:auto_run_disabled] if args.key?(:auto_run_disabled)
  @bap_config = args[:bap_config] if args.key?(:bap_config)
  @blocking_reasons = args[:blocking_reasons] if args.key?(:blocking_reasons)
  @cli_config = args[:cli_config] if args.key?(:cli_config)
  @connector_modes = args[:connector_modes] if args.key?(:connector_modes)
  @connector_source_id = args[:connector_source_id] if args.key?(:connector_source_id)
  @connector_type = args[:connector_type] if args.key?(:connector_type)
  @create_eua_saas = args[:create_eua_saas] if args.key?(:create_eua_saas)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_protection_policy = args[:data_protection_policy] if args.key?(:data_protection_policy)
  @data_source = args[:data_source] if args.key?(:data_source)
  @destination_configs = args[:destination_configs] if args.key?(:destination_configs)
  @dynamic_tools = args[:dynamic_tools] if args.key?(:dynamic_tools)
  @egress_fqdns = args[:egress_fqdns] if args.key?(:egress_fqdns)
  @end_user_config = args[:end_user_config] if args.key?(:end_user_config)
  @entities = args[:entities] if args.key?(:entities)
  @errors = args[:errors] if args.key?(:errors)
  @federated_config = args[:federated_config] if args.key?(:federated_config)
  @hybrid_ingestion_disabled = args[:hybrid_ingestion_disabled] if args.key?(:hybrid_ingestion_disabled)
  @identity_refresh_interval = args[:identity_refresh_interval] if args.key?(:identity_refresh_interval)
  @identity_schedule_config = args[:identity_schedule_config] if args.key?(:identity_schedule_config)
  @incremental_refresh_interval = args[:incremental_refresh_interval] if args.key?(:incremental_refresh_interval)
  @incremental_sync_disabled = args[:incremental_sync_disabled] if args.key?(:incremental_sync_disabled)
  @json_params = args[:json_params] if args.key?(:json_params)
  @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name)
  @last_sync_time = args[:last_sync_time] if args.key?(:last_sync_time)
  @latest_pause_time = args[:latest_pause_time] if args.key?(:latest_pause_time)
  @name = args[:name] if args.key?(:name)
  @next_sync_time = args[:next_sync_time] if args.key?(:next_sync_time)
  @oauth_static_ip_addresses = args[:oauth_static_ip_addresses] if args.key?(:oauth_static_ip_addresses)
  @params = args[:params] if args.key?(:params)
  @private_connectivity_project_id = args[:private_connectivity_project_id] if args.key?(:private_connectivity_project_id)
  @realtime_state = args[:realtime_state] if args.key?(:realtime_state)
  @realtime_sync_config = args[:realtime_sync_config] if args.key?(:realtime_sync_config)
  @refresh_interval = args[:refresh_interval] if args.key?(:refresh_interval)
  @remove_param_keys = args[:remove_param_keys] if args.key?(:remove_param_keys)
  @state = args[:state] if args.key?(:state)
  @static_ip_addresses = args[:static_ip_addresses] if args.key?(:static_ip_addresses)
  @static_ip_enabled = args[:static_ip_enabled] if args.key?(:static_ip_enabled)
  @sync_mode = args[:sync_mode] if args.key?(:sync_mode)
  @update_time = args[:update_time] if args.key?(:update_time)
  @vpcsc_enabled = args[:vpcsc_enabled] if args.key?(:vpcsc_enabled)
end