Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataConnectorConnectorMetadata
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataConnectorConnectorMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
User-facing metadata for the connector, shown on the connector detail page ( title, description, short_description, author, authenticated_account, note).
Instance Attribute Summary collapse
-
#authenticated_account ⇒ String
Optional.
-
#author ⇒ String
Optional.
-
#description ⇒ String
Optional.
-
#note ⇒ String
Optional.
-
#short_description ⇒ String
Optional.
-
#title ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaDataConnectorConnectorMetadata
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaDataConnectorConnectorMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaDataConnectorConnectorMetadata
Returns a new instance of GoogleCloudDiscoveryengineV1alphaDataConnectorConnectorMetadata.
10935 10936 10937 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10935 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authenticated_account ⇒ String
Optional. The end user's account as authenticated to the connector, so the end
user can see which account is connected. May be an email, a username, or any
identifier the connector/third party provides.
Corresponds to the JSON property authenticatedAccount
10903 10904 10905 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10903 def authenticated_account @authenticated_account end |
#author ⇒ String
Optional. The party that authored the connector, e.g. "Google" or a third-
party provider name. Lets end users see who authored a connector (future:
third-party-authored connectors).
Corresponds to the JSON property author
10910 10911 10912 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10910 def @author end |
#description ⇒ String
Optional. Human-readable description of the connector, shown on the connector
detail page. One connector has a single description.
Corresponds to the JSON property description
10916 10917 10918 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10916 def description @description end |
#note ⇒ String
Optional. Free-form, multi-line note about the connector's capabilities or a
custom note that can be set for the connector.
Corresponds to the JSON property note
10922 10923 10924 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10922 def note @note end |
#short_description ⇒ String
Optional. Short, subtitle-length description of the connector (e.g. shown
beneath the connector name in list and detail views).
Corresponds to the JSON property shortDescription
10928 10929 10930 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10928 def short_description @short_description end |
#title ⇒ String
Optional. Display title of the connector.
Corresponds to the JSON property title
10933 10934 10935 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10933 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10940 10941 10942 10943 10944 10945 10946 10947 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10940 def update!(**args) @authenticated_account = args[:authenticated_account] if args.key?(:authenticated_account) @author = args[:author] if args.key?(:author) @description = args[:description] if args.key?(:description) @note = args[:note] if args.key?(:note) @short_description = args[:short_description] if args.key?(:short_description) @title = args[:title] if args.key?(:title) end |