Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataConnectorEndUserConfig
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataConnectorEndUserConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Any params and credentials used specifically for EUA connectors.
Instance Attribute Summary collapse
-
#additional_params ⇒ Hash<String,Object>
Optional.
-
#auth_params ⇒ Hash<String,Object>
Optional.
-
#json_auth_params ⇒ String
Optional.
-
#tenant ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaTenant
Tenant information for a connector source.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaDataConnectorEndUserConfig
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaDataConnectorEndUserConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaDataConnectorEndUserConfig
Returns a new instance of GoogleCloudDiscoveryengineV1alphaDataConnectorEndUserConfig.
10841 10842 10843 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10841 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_params ⇒ Hash<String,Object>
Optional. Any additional parameters needed for EUA.
Corresponds to the JSON property additionalParams
10821 10822 10823 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10821 def additional_params @additional_params end |
#auth_params ⇒ Hash<String,Object>
Optional. Any authentication parameters specific to EUA connectors.
Corresponds to the JSON property authParams
10826 10827 10828 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10826 def auth_params @auth_params end |
#json_auth_params ⇒ String
Optional. Any authentication parameters specific to EUA connectors in json
string format.
Corresponds to the JSON property jsonAuthParams
10832 10833 10834 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10832 def json_auth_params @json_auth_params end |
#tenant ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaTenant
Tenant information for a connector source. This includes some of the same
information stored in the Credential message, but is limited to only what is
needed to provide a list of accessible tenants to the user.
Corresponds to the JSON property tenant
10839 10840 10841 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10839 def tenant @tenant end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10846 10847 10848 10849 10850 10851 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10846 def update!(**args) @additional_params = args[:additional_params] if args.key?(:additional_params) @auth_params = args[:auth_params] if args.key?(:auth_params) @json_auth_params = args[:json_auth_params] if args.key?(:json_auth_params) @tenant = args[:tenant] if args.key?(:tenant) end |