Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataConnectorEndUserConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Any params and credentials used specifically for EUA connectors.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaDataConnectorEndUserConfig

Returns a new instance of GoogleCloudDiscoveryengineV1alphaDataConnectorEndUserConfig.



10831
10832
10833
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10831

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_paramsHash<String,Object>

Optional. Any additional parameters needed for EUA. Corresponds to the JSON property additionalParams

Returns:

  • (Hash<String,Object>)


10811
10812
10813
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10811

def additional_params
  @additional_params
end

#auth_paramsHash<String,Object>

Optional. Any authentication parameters specific to EUA connectors. Corresponds to the JSON property authParams

Returns:

  • (Hash<String,Object>)


10816
10817
10818
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10816

def auth_params
  @auth_params
end

#json_auth_paramsString

Optional. Any authentication parameters specific to EUA connectors in json string format. Corresponds to the JSON property jsonAuthParams

Returns:

  • (String)


10822
10823
10824
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10822

def json_auth_params
  @json_auth_params
end

#tenantGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaTenant

Tenant information for a connector source. This includes some of the same information stored in the Credential message, but is limited to only what is needed to provide a list of accessible tenants to the user. Corresponds to the JSON property tenant



10829
10830
10831
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10829

def tenant
  @tenant
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10836
10837
10838
10839
10840
10841
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10836

def update!(**args)
  @additional_params = args[:additional_params] if args.key?(:additional_params)
  @auth_params = args[:auth_params] if args.key?(:auth_params)
  @json_auth_params = args[:json_auth_params] if args.key?(:json_auth_params)
  @tenant = args[:tenant] if args.key?(:tenant)
end