Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataConnectorRealtimeSyncConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

The configuration for realtime sync to store additional params for realtime sync.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaDataConnectorRealtimeSyncConfig

Returns a new instance of GoogleCloudDiscoveryengineV1alphaDataConnectorRealtimeSyncConfig.



10932
10933
10934
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10932

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#realtime_sync_secretString

Optional. The ID of the Secret Manager secret used for webhook secret. Corresponds to the JSON property realtimeSyncSecret

Returns:

  • (String)


10919
10920
10921
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10919

def realtime_sync_secret
  @realtime_sync_secret
end

#streaming_errorGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataConnectorRealtimeSyncConfigStreamingError

Streaming error details. Corresponds to the JSON property streamingError



10924
10925
10926
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10924

def streaming_error
  @streaming_error
end

#webhook_uriString

Optional. Webhook url for the connector to specify additional params for realtime sync. Corresponds to the JSON property webhookUri

Returns:

  • (String)


10930
10931
10932
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10930

def webhook_uri
  @webhook_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10937
10938
10939
10940
10941
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10937

def update!(**args)
  @realtime_sync_secret = args[:realtime_sync_secret] if args.key?(:realtime_sync_secret)
  @streaming_error = args[:streaming_error] if args.key?(:streaming_error)
  @webhook_uri = args[:webhook_uri] if args.key?(:webhook_uri)
end