Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataConnectorRealtimeSyncConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

The configuration for realtime sync to store additional params for realtime sync.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaDataConnectorRealtimeSyncConfig

Returns a new instance of GoogleCloudDiscoveryengineV1alphaDataConnectorRealtimeSyncConfig.



10898
10899
10900
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10898

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#realtime_sync_secretString

Optional. The ID of the Secret Manager secret used for webhook secret. Corresponds to the JSON property realtimeSyncSecret

Returns:

  • (String)


10885
10886
10887
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10885

def realtime_sync_secret
  @realtime_sync_secret
end

#streaming_errorGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataConnectorRealtimeSyncConfigStreamingError

Streaming error details. Corresponds to the JSON property streamingError



10890
10891
10892
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10890

def streaming_error
  @streaming_error
end

#webhook_uriString

Optional. Webhook url for the connector to specify additional params for realtime sync. Corresponds to the JSON property webhookUri

Returns:

  • (String)


10896
10897
10898
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10896

def webhook_uri
  @webhook_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10903
10904
10905
10906
10907
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10903

def update!(**args)
  @realtime_sync_secret = args[:realtime_sync_secret] if args.key?(:realtime_sync_secret)
  @streaming_error = args[:streaming_error] if args.key?(:streaming_error)
  @webhook_uri = args[:webhook_uri] if args.key?(:webhook_uri)
end