Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataConnectorRealtimeSyncConfigStreamingError
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataConnectorRealtimeSyncConfigStreamingError
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Streaming error details.
Instance Attribute Summary collapse
-
#error ⇒ Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#streaming_error_reason ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaDataConnectorRealtimeSyncConfigStreamingError
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaDataConnectorRealtimeSyncConfigStreamingError.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaDataConnectorRealtimeSyncConfigStreamingError
Returns a new instance of GoogleCloudDiscoveryengineV1alphaDataConnectorRealtimeSyncConfigStreamingError.
11075 11076 11077 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11075 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error ⇒ Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
11068 11069 11070 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11068 def error @error end |
#streaming_error_reason ⇒ String
Optional. Streaming error.
Corresponds to the JSON property streamingErrorReason
11073 11074 11075 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11073 def streaming_error_reason @streaming_error_reason end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11080 11081 11082 11083 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11080 def update!(**args) @error = args[:error] if args.key?(:error) @streaming_error_reason = args[:streaming_error_reason] if args.key?(:streaming_error_reason) end |