Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataConnectorRealtimeSyncConfigStreamingError

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Streaming error details.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaDataConnectorRealtimeSyncConfigStreamingError

Returns a new instance of GoogleCloudDiscoveryengineV1alphaDataConnectorRealtimeSyncConfigStreamingError.



10939
10940
10941
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10939

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::DiscoveryengineV1beta::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



10932
10933
10934
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10932

def error
  @error
end

#streaming_error_reasonString

Optional. Streaming error. Corresponds to the JSON property streamingErrorReason

Returns:

  • (String)


10937
10938
10939
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10937

def streaming_error_reason
  @streaming_error_reason
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10944
10945
10946
10947
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10944

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @streaming_error_reason = args[:streaming_error_reason] if args.key?(:streaming_error_reason)
end