Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataConnectorSourceEntity
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataConnectorSourceEntity
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Represents an entity in the data source. For example, the Account object in
Salesforce.
Instance Attribute Summary collapse
-
#data_store ⇒ String
Output only.
-
#entity_name ⇒ String
The name of the entity.
-
#healthcare_fhir_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaHealthcareFhirConfig
Config to data store for
HEALTHCARE_FHIRvertical. -
#json_params ⇒ String
The parameters for the entity to facilitate data ingestion in json string format.
-
#key_property_mappings ⇒ Hash<String,String>
Attributes for indexing.
-
#params ⇒ Hash<String,Object>
The parameters for the entity to facilitate data ingestion in structured json format.
-
#starting_schema ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSchema
Defines the structure and layout of a type of document data.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaDataConnectorSourceEntity
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaDataConnectorSourceEntity.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaDataConnectorSourceEntity
Returns a new instance of GoogleCloudDiscoveryengineV1alphaDataConnectorSourceEntity.
11123 11124 11125 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11123 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_store ⇒ String
Output only. The full resource name of the associated data store for the
source entity. Format: projects/*/locations/*/collections/*/dataStores/*.
When the connector is initialized by the DataConnectorService.
SetUpDataConnector method, a DataStore is automatically created for each
source entity.
Corresponds to the JSON property dataStore
11083 11084 11085 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11083 def data_store @data_store end |
#entity_name ⇒ String
The name of the entity. Supported values by data source: * Salesforce: Lead,
Opportunity, Contact, Account, Case, Contract, Campaign * Jira:
Issue * Confluence: Content, Space
Corresponds to the JSON property entityName
11090 11091 11092 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11090 def entity_name @entity_name end |
#healthcare_fhir_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaHealthcareFhirConfig
Config to data store for HEALTHCARE_FHIR vertical.
Corresponds to the JSON property healthcareFhirConfig
11095 11096 11097 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11095 def healthcare_fhir_config @healthcare_fhir_config end |
#json_params ⇒ String
The parameters for the entity to facilitate data ingestion in json string
format.
Corresponds to the JSON property jsonParams
11101 11102 11103 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11101 def json_params @json_params end |
#key_property_mappings ⇒ Hash<String,String>
Attributes for indexing. Key: Field name. Value: The key property to map a
field to, such as title, and description. Supported key properties: *
title: The title for data record. This would be displayed on search results. *
description: The description for data record. This would be displayed on
search results.
Corresponds to the JSON property keyPropertyMappings
11110 11111 11112 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11110 def key_property_mappings @key_property_mappings end |
#params ⇒ Hash<String,Object>
The parameters for the entity to facilitate data ingestion in structured json
format.
Corresponds to the JSON property params
11116 11117 11118 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11116 def params @params end |
#starting_schema ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSchema
Defines the structure and layout of a type of document data.
Corresponds to the JSON property startingSchema
11121 11122 11123 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11121 def starting_schema @starting_schema end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11128 11129 11130 11131 11132 11133 11134 11135 11136 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11128 def update!(**args) @data_store = args[:data_store] if args.key?(:data_store) @entity_name = args[:entity_name] if args.key?(:entity_name) @healthcare_fhir_config = args[:healthcare_fhir_config] if args.key?(:healthcare_fhir_config) @json_params = args[:json_params] if args.key?(:json_params) @key_property_mappings = args[:key_property_mappings] if args.key?(:key_property_mappings) @params = args[:params] if args.key?(:params) @starting_schema = args[:starting_schema] if args.key?(:starting_schema) end |