Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataConnectorSourceEntity

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Represents an entity in the data source. For example, the Account object in Salesforce.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaDataConnectorSourceEntity

Returns a new instance of GoogleCloudDiscoveryengineV1alphaDataConnectorSourceEntity.



10992
10993
10994
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10992

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_storeString

Output only. The full resource name of the associated data store for the source entity. Format: projects/*/locations/*/collections/*/dataStores/*. When the connector is initialized by the DataConnectorService. SetUpDataConnector method, a DataStore is automatically created for each source entity. Corresponds to the JSON property dataStore

Returns:

  • (String)


10952
10953
10954
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10952

def data_store
  @data_store
end

#entity_nameString

The name of the entity. Supported values by data source: * Salesforce: Lead, Opportunity, Contact, Account, Case, Contract, Campaign * Jira: Issue * Confluence: Content, Space Corresponds to the JSON property entityName

Returns:

  • (String)


10959
10960
10961
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10959

def entity_name
  @entity_name
end

#healthcare_fhir_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaHealthcareFhirConfig

Config to data store for HEALTHCARE_FHIR vertical. Corresponds to the JSON property healthcareFhirConfig



10964
10965
10966
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10964

def healthcare_fhir_config
  @healthcare_fhir_config
end

#json_paramsString

The parameters for the entity to facilitate data ingestion in json string format. Corresponds to the JSON property jsonParams

Returns:

  • (String)


10970
10971
10972
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10970

def json_params
  @json_params
end

#key_property_mappingsHash<String,String>

Attributes for indexing. Key: Field name. Value: The key property to map a field to, such as title, and description. Supported key properties: * title: The title for data record. This would be displayed on search results. * description: The description for data record. This would be displayed on search results. Corresponds to the JSON property keyPropertyMappings

Returns:

  • (Hash<String,String>)


10979
10980
10981
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10979

def key_property_mappings
  @key_property_mappings
end

#paramsHash<String,Object>

The parameters for the entity to facilitate data ingestion in structured json format. Corresponds to the JSON property params

Returns:

  • (Hash<String,Object>)


10985
10986
10987
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10985

def params
  @params
end

#starting_schemaGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSchema

Defines the structure and layout of a type of document data. Corresponds to the JSON property startingSchema



10990
10991
10992
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10990

def starting_schema
  @starting_schema
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10997
10998
10999
11000
11001
11002
11003
11004
11005
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10997

def update!(**args)
  @data_store = args[:data_store] if args.key?(:data_store)
  @entity_name = args[:entity_name] if args.key?(:entity_name)
  @healthcare_fhir_config = args[:healthcare_fhir_config] if args.key?(:healthcare_fhir_config)
  @json_params = args[:json_params] if args.key?(:json_params)
  @key_property_mappings = args[:key_property_mappings] if args.key?(:key_property_mappings)
  @params = args[:params] if args.key?(:params)
  @starting_schema = args[:starting_schema] if args.key?(:starting_schema)
end