Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataStore

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

DataStore captures global settings and configs at the DataStore level.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaDataStore

Returns a new instance of GoogleCloudDiscoveryengineV1alphaDataStore.



11348
11349
11350
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11348

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#acl_enabledBoolean Also known as: acl_enabled?

Immutable. Whether data in the DataStore has ACL information. If set to true, the source data must have ACL. ACL will be ingested when data is ingested by DocumentService.ImportDocuments methods. When ACL is enabled for the DataStore, Document can't be accessed by calling DocumentService.GetDocument or DocumentService.ListDocuments. Currently ACL is only supported in GENERIC industry vertical with non-PUBLIC_WEBSITE content config. Corresponds to the JSON property aclEnabled

Returns:

  • (Boolean)


11192
11193
11194
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11192

def acl_enabled
  @acl_enabled
end

#advanced_site_search_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAdvancedSiteSearchConfig

Configuration data for advance site search. Corresponds to the JSON property advancedSiteSearchConfig



11198
11199
11200
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11198

def advanced_site_search_config
  @advanced_site_search_config
end

#billing_estimationGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataStoreBillingEstimation

Estimation of data size per data store. Corresponds to the JSON property billingEstimation



11203
11204
11205
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11203

def billing_estimation
  @billing_estimation
end

#cmek_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaCmekConfig

Configurations used to enable CMEK data encryption with Cloud KMS keys. Corresponds to the JSON property cmekConfig



11208
11209
11210
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11208

def cmek_config
  @cmek_config
end

#configurable_billing_approachString

Optional. Configuration for configurable billing approach. See Corresponds to the JSON property configurableBillingApproach

Returns:

  • (String)


11213
11214
11215
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11213

def configurable_billing_approach
  @configurable_billing_approach
end

#configurable_billing_approach_update_timeString

Output only. The timestamp when configurable_billing_approach was last updated. Corresponds to the JSON property configurableBillingApproachUpdateTime

Returns:

  • (String)


11218
11219
11220
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11218

def configurable_billing_approach_update_time
  @configurable_billing_approach_update_time
end

#content_configString

Immutable. The content config of the data store. If this field is unset, the server behavior defaults to ContentConfig.NO_CONTENT. Corresponds to the JSON property contentConfig

Returns:

  • (String)


11224
11225
11226
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11224

def content_config
  @content_config
end

#create_timeString

Output only. Timestamp the DataStore was created at. Corresponds to the JSON property createTime

Returns:

  • (String)


11229
11230
11231
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11229

def create_time
  @create_time
end

#data_protection_policyGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataProtectionPolicy

Contains the data protection policy config for a DataStore or a connector. Corresponds to the JSON property dataProtectionPolicy



11234
11235
11236
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11234

def data_protection_policy
  @data_protection_policy
end

#default_schema_idString

Output only. The id of the default Schema associated to this data store. Corresponds to the JSON property defaultSchemaId

Returns:

  • (String)


11239
11240
11241
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11239

def default_schema_id
  @default_schema_id
end

#display_nameString

Required. The data store display name. This field must be a UTF-8 encoded string with a length limit of 128 characters. Otherwise, an INVALID_ARGUMENT error is returned. Corresponds to the JSON property displayName

Returns:

  • (String)


11246
11247
11248
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11246

def display_name
  @display_name
end

#document_processing_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDocumentProcessingConfig

A singleton resource of DataStore. If it's empty when DataStore is created and DataStore is set to DataStore.ContentConfig.CONTENT_REQUIRED, the default parser will default to digital parser. Corresponds to the JSON property documentProcessingConfig



11253
11254
11255
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11253

def document_processing_config
  @document_processing_config
end

#federated_search_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataStoreFederatedSearchConfig

Stores information for federated search. Corresponds to the JSON property federatedSearchConfig



11258
11259
11260
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11258

def federated_search_config
  @federated_search_config
end

#healthcare_fhir_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaHealthcareFhirConfig

Config to data store for HEALTHCARE_FHIR vertical. Corresponds to the JSON property healthcareFhirConfig



11263
11264
11265
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11263

def healthcare_fhir_config
  @healthcare_fhir_config
end

#icon_uriString

Output only. Provides the icon URI of the data store's connector source, if this is a connector-backed data store. Empty for data stores without an associated connector source. In DataStoreService.ListDataStores and DataStoreService.GetDataStore, this is only populated when DataStoreView. DATA_STORE_VIEW_FULL is requested via ListDataStoresRequest.view or GetDataStoreRequest.view respectively. Corresponds to the JSON property iconUri

Returns:

  • (String)


11273
11274
11275
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11273

def icon_uri
  @icon_uri
end

#identity_mapping_storeString

Immutable. The fully qualified resource name of the associated IdentityMappingStore. This field can only be set for acl_enabled DataStores with THIRD_PARTY or GSUITE IdP. Format: projects/project/locations/ location/identityMappingStores/identity_mapping_store`. Corresponds to the JSON propertyidentityMappingStore`

Returns:

  • (String)


11281
11282
11283
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11281

def identity_mapping_store
  @identity_mapping_store
end

#idp_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaIdpConfig

Identity Provider Config. Corresponds to the JSON property idpConfig



11286
11287
11288
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11286

def idp_config
  @idp_config
end

#industry_verticalString

Immutable. The industry vertical that the data store registers. Corresponds to the JSON property industryVertical

Returns:

  • (String)


11291
11292
11293
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11291

def industry_vertical
  @industry_vertical
end

#is_infobot_faq_data_storeBoolean Also known as: is_infobot_faq_data_store?

Optional. If set, this DataStore is an Infobot FAQ DataStore. Corresponds to the JSON property isInfobotFaqDataStore

Returns:

  • (Boolean)


11296
11297
11298
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11296

def is_infobot_faq_data_store
  @is_infobot_faq_data_store
end

#kms_key_nameString

Input only. The KMS key to be used to protect this DataStore at creation time. Must be set for requests that need to comply with CMEK Org Policy protections. If this field is set and processed successfully, the DataStore will be protected by the KMS key, as indicated in the cmek_config field. Corresponds to the JSON property kmsKeyName

Returns:

  • (String)


11305
11306
11307
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11305

def kms_key_name
  @kms_key_name
end

#language_infoGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaLanguageInfo

Language info for DataStore. Corresponds to the JSON property languageInfo



11310
11311
11312
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11310

def language_info
  @language_info
end

#nameString

Immutable. Identifier. The full resource name of the data store. Format: projects/project/locations/location/collections/collection_id/dataStores/ data_store_id`. This field must be a UTF-8 encoded string with a length limit of 1024 characters. Corresponds to the JSON propertyname`

Returns:

  • (String)


11318
11319
11320
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11318

def name
  @name
end

#natural_language_query_understanding_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaNaturalLanguageQueryUnderstandingConfig

Configuration for Natural Language Query Understanding. Corresponds to the JSON property naturalLanguageQueryUnderstandingConfig



11323
11324
11325
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11323

def natural_language_query_understanding_config
  @natural_language_query_understanding_config
end

#serving_config_data_storeGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataStoreServingConfigDataStore

Stores information regarding the serving configurations at DataStore level. Corresponds to the JSON property servingConfigDataStore



11328
11329
11330
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11328

def serving_config_data_store
  @serving_config_data_store
end

#solution_typesArray<String>

The solutions that the data store enrolls. Available solutions for each industry_vertical: * MEDIA: SOLUTION_TYPE_RECOMMENDATION and SOLUTION_TYPE_SEARCH. * SITE_SEARCH: SOLUTION_TYPE_SEARCH is automatically enrolled. Other solutions cannot be enrolled. Corresponds to the JSON property solutionTypes

Returns:

  • (Array<String>)


11336
11337
11338
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11336

def solution_types
  @solution_types
end

#starting_schemaGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSchema

Defines the structure and layout of a type of document data. Corresponds to the JSON property startingSchema



11341
11342
11343
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11341

def starting_schema
  @starting_schema
end

#workspace_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaWorkspaceConfig

Config to store data store type configuration for workspace data Corresponds to the JSON property workspaceConfig



11346
11347
11348
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11346

def workspace_config
  @workspace_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11353
11354
11355
11356
11357
11358
11359
11360
11361
11362
11363
11364
11365
11366
11367
11368
11369
11370
11371
11372
11373
11374
11375
11376
11377
11378
11379
11380
11381
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11353

def update!(**args)
  @acl_enabled = args[:acl_enabled] if args.key?(:acl_enabled)
  @advanced_site_search_config = args[:advanced_site_search_config] if args.key?(:advanced_site_search_config)
  @billing_estimation = args[:billing_estimation] if args.key?(:billing_estimation)
  @cmek_config = args[:cmek_config] if args.key?(:cmek_config)
  @configurable_billing_approach = args[:configurable_billing_approach] if args.key?(:configurable_billing_approach)
  @configurable_billing_approach_update_time = args[:configurable_billing_approach_update_time] if args.key?(:configurable_billing_approach_update_time)
  @content_config = args[:content_config] if args.key?(:content_config)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_protection_policy = args[:data_protection_policy] if args.key?(:data_protection_policy)
  @default_schema_id = args[:default_schema_id] if args.key?(:default_schema_id)
  @display_name = args[:display_name] if args.key?(:display_name)
  @document_processing_config = args[:document_processing_config] if args.key?(:document_processing_config)
  @federated_search_config = args[:federated_search_config] if args.key?(:federated_search_config)
  @healthcare_fhir_config = args[:healthcare_fhir_config] if args.key?(:healthcare_fhir_config)
  @icon_uri = args[:icon_uri] if args.key?(:icon_uri)
  @identity_mapping_store = args[:identity_mapping_store] if args.key?(:identity_mapping_store)
  @idp_config = args[:idp_config] if args.key?(:idp_config)
  @industry_vertical = args[:industry_vertical] if args.key?(:industry_vertical)
  @is_infobot_faq_data_store = args[:is_infobot_faq_data_store] if args.key?(:is_infobot_faq_data_store)
  @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name)
  @language_info = args[:language_info] if args.key?(:language_info)
  @name = args[:name] if args.key?(:name)
  @natural_language_query_understanding_config = args[:natural_language_query_understanding_config] if args.key?(:natural_language_query_understanding_config)
  @serving_config_data_store = args[:serving_config_data_store] if args.key?(:serving_config_data_store)
  @solution_types = args[:solution_types] if args.key?(:solution_types)
  @starting_schema = args[:starting_schema] if args.key?(:starting_schema)
  @workspace_config = args[:workspace_config] if args.key?(:workspace_config)
end