Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataStore
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataStore
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
DataStore captures global settings and configs at the DataStore level.
Instance Attribute Summary collapse
-
#acl_enabled ⇒ Boolean
(also: #acl_enabled?)
Immutable.
-
#advanced_site_search_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAdvancedSiteSearchConfig
Configuration data for advance site search.
-
#billing_estimation ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataStoreBillingEstimation
Estimation of data size per data store.
-
#cmek_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaCmekConfig
Configurations used to enable CMEK data encryption with Cloud KMS keys.
-
#configurable_billing_approach ⇒ String
Optional.
-
#configurable_billing_approach_update_time ⇒ String
Output only.
-
#content_config ⇒ String
Immutable.
-
#create_time ⇒ String
Output only.
-
#data_protection_policy ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataProtectionPolicy
Contains the data protection policy config for a DataStore or a connector.
-
#default_schema_id ⇒ String
Output only.
-
#display_name ⇒ String
Required.
-
#document_processing_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDocumentProcessingConfig
A singleton resource of DataStore.
-
#federated_search_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataStoreFederatedSearchConfig
Stores information for federated search.
-
#healthcare_fhir_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaHealthcareFhirConfig
Config to data store for
HEALTHCARE_FHIRvertical. -
#identity_mapping_store ⇒ String
Immutable.
-
#idp_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaIdpConfig
Identity Provider Config.
-
#industry_vertical ⇒ String
Immutable.
-
#is_infobot_faq_data_store ⇒ Boolean
(also: #is_infobot_faq_data_store?)
Optional.
-
#kms_key_name ⇒ String
Input only.
-
#language_info ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaLanguageInfo
Language info for DataStore.
-
#name ⇒ String
Immutable.
-
#natural_language_query_understanding_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaNaturalLanguageQueryUnderstandingConfig
Configuration for Natural Language Query Understanding.
-
#serving_config_data_store ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataStoreServingConfigDataStore
Stores information regarding the serving configurations at DataStore level.
-
#solution_types ⇒ Array<String>
The solutions that the data store enrolls.
-
#starting_schema ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSchema
Defines the structure and layout of a type of document data.
-
#workspace_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaWorkspaceConfig
Config to store data store type configuration for workspace data Corresponds to the JSON property
workspaceConfig.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaDataStore
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaDataStore.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaDataStore
Returns a new instance of GoogleCloudDiscoveryengineV1alphaDataStore.
11207 11208 11209 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11207 def initialize(**args) update!(**args) end |
Instance Attribute Details
#acl_enabled ⇒ Boolean Also known as: acl_enabled?
Immutable. Whether data in the DataStore has ACL information. If set to true,
the source data must have ACL. ACL will be ingested when data is ingested by
DocumentService.ImportDocuments methods. When ACL is enabled for the DataStore,
Document can't be accessed by calling DocumentService.GetDocument or
DocumentService.ListDocuments. Currently ACL is only supported in GENERIC
industry vertical with non-PUBLIC_WEBSITE content config.
Corresponds to the JSON property aclEnabled
11061 11062 11063 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11061 def acl_enabled @acl_enabled end |
#advanced_site_search_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAdvancedSiteSearchConfig
Configuration data for advance site search.
Corresponds to the JSON property advancedSiteSearchConfig
11067 11068 11069 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11067 def advanced_site_search_config @advanced_site_search_config end |
#billing_estimation ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataStoreBillingEstimation
Estimation of data size per data store.
Corresponds to the JSON property billingEstimation
11072 11073 11074 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11072 def billing_estimation @billing_estimation end |
#cmek_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaCmekConfig
Configurations used to enable CMEK data encryption with Cloud KMS keys.
Corresponds to the JSON property cmekConfig
11077 11078 11079 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11077 def cmek_config @cmek_config end |
#configurable_billing_approach ⇒ String
Optional. Configuration for configurable billing approach. See
Corresponds to the JSON property configurableBillingApproach
11082 11083 11084 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11082 def configurable_billing_approach @configurable_billing_approach end |
#configurable_billing_approach_update_time ⇒ String
Output only. The timestamp when configurable_billing_approach was last updated.
Corresponds to the JSON property configurableBillingApproachUpdateTime
11087 11088 11089 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11087 def configurable_billing_approach_update_time @configurable_billing_approach_update_time end |
#content_config ⇒ String
Immutable. The content config of the data store. If this field is unset, the
server behavior defaults to ContentConfig.NO_CONTENT.
Corresponds to the JSON property contentConfig
11093 11094 11095 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11093 def content_config @content_config end |
#create_time ⇒ String
Output only. Timestamp the DataStore was created at.
Corresponds to the JSON property createTime
11098 11099 11100 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11098 def create_time @create_time end |
#data_protection_policy ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataProtectionPolicy
Contains the data protection policy config for a DataStore or a connector.
Corresponds to the JSON property dataProtectionPolicy
11103 11104 11105 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11103 def data_protection_policy @data_protection_policy end |
#default_schema_id ⇒ String
Output only. The id of the default Schema associated to this data store.
Corresponds to the JSON property defaultSchemaId
11108 11109 11110 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11108 def default_schema_id @default_schema_id end |
#display_name ⇒ String
Required. The data store display name. This field must be a UTF-8 encoded
string with a length limit of 128 characters. Otherwise, an INVALID_ARGUMENT
error is returned.
Corresponds to the JSON property displayName
11115 11116 11117 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11115 def display_name @display_name end |
#document_processing_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDocumentProcessingConfig
A singleton resource of DataStore. If it's empty when DataStore is created and
DataStore is set to DataStore.ContentConfig.CONTENT_REQUIRED, the default
parser will default to digital parser.
Corresponds to the JSON property documentProcessingConfig
11122 11123 11124 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11122 def document_processing_config @document_processing_config end |
#federated_search_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataStoreFederatedSearchConfig
Stores information for federated search.
Corresponds to the JSON property federatedSearchConfig
11127 11128 11129 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11127 def federated_search_config @federated_search_config end |
#healthcare_fhir_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaHealthcareFhirConfig
Config to data store for HEALTHCARE_FHIR vertical.
Corresponds to the JSON property healthcareFhirConfig
11132 11133 11134 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11132 def healthcare_fhir_config @healthcare_fhir_config end |
#identity_mapping_store ⇒ String
Immutable. The fully qualified resource name of the associated
IdentityMappingStore. This field can only be set for acl_enabled DataStores
with THIRD_PARTY or GSUITE IdP. Format: projects/project/locations/
location/identityMappingStores/identity_mapping_store`.
Corresponds to the JSON propertyidentityMappingStore`
11140 11141 11142 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11140 def identity_mapping_store @identity_mapping_store end |
#idp_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaIdpConfig
Identity Provider Config.
Corresponds to the JSON property idpConfig
11145 11146 11147 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11145 def idp_config @idp_config end |
#industry_vertical ⇒ String
Immutable. The industry vertical that the data store registers.
Corresponds to the JSON property industryVertical
11150 11151 11152 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11150 def industry_vertical @industry_vertical end |
#is_infobot_faq_data_store ⇒ Boolean Also known as: is_infobot_faq_data_store?
Optional. If set, this DataStore is an Infobot FAQ DataStore.
Corresponds to the JSON property isInfobotFaqDataStore
11155 11156 11157 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11155 def is_infobot_faq_data_store @is_infobot_faq_data_store end |
#kms_key_name ⇒ String
Input only. The KMS key to be used to protect this DataStore at creation time.
Must be set for requests that need to comply with CMEK Org Policy protections.
If this field is set and processed successfully, the DataStore will be
protected by the KMS key, as indicated in the cmek_config field.
Corresponds to the JSON property kmsKeyName
11164 11165 11166 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11164 def kms_key_name @kms_key_name end |
#language_info ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaLanguageInfo
Language info for DataStore.
Corresponds to the JSON property languageInfo
11169 11170 11171 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11169 def language_info @language_info end |
#name ⇒ String
Immutable. Identifier. The full resource name of the data store. Format:
projects/project/locations/location/collections/collection_id/dataStores/
data_store_id`. This field must be a UTF-8 encoded string with a length
limit of 1024 characters.
Corresponds to the JSON propertyname`
11177 11178 11179 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11177 def name @name end |
#natural_language_query_understanding_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaNaturalLanguageQueryUnderstandingConfig
Configuration for Natural Language Query Understanding.
Corresponds to the JSON property naturalLanguageQueryUnderstandingConfig
11182 11183 11184 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11182 def natural_language_query_understanding_config @natural_language_query_understanding_config end |
#serving_config_data_store ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataStoreServingConfigDataStore
Stores information regarding the serving configurations at DataStore level.
Corresponds to the JSON property servingConfigDataStore
11187 11188 11189 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11187 def serving_config_data_store @serving_config_data_store end |
#solution_types ⇒ Array<String>
The solutions that the data store enrolls. Available solutions for each
industry_vertical: * MEDIA: SOLUTION_TYPE_RECOMMENDATION and
SOLUTION_TYPE_SEARCH. * SITE_SEARCH: SOLUTION_TYPE_SEARCH is
automatically enrolled. Other solutions cannot be enrolled.
Corresponds to the JSON property solutionTypes
11195 11196 11197 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11195 def solution_types @solution_types end |
#starting_schema ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSchema
Defines the structure and layout of a type of document data.
Corresponds to the JSON property startingSchema
11200 11201 11202 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11200 def starting_schema @starting_schema end |
#workspace_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaWorkspaceConfig
Config to store data store type configuration for workspace data
Corresponds to the JSON property workspaceConfig
11205 11206 11207 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11205 def workspace_config @workspace_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11212 11213 11214 11215 11216 11217 11218 11219 11220 11221 11222 11223 11224 11225 11226 11227 11228 11229 11230 11231 11232 11233 11234 11235 11236 11237 11238 11239 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11212 def update!(**args) @acl_enabled = args[:acl_enabled] if args.key?(:acl_enabled) @advanced_site_search_config = args[:advanced_site_search_config] if args.key?(:advanced_site_search_config) @billing_estimation = args[:billing_estimation] if args.key?(:billing_estimation) @cmek_config = args[:cmek_config] if args.key?(:cmek_config) @configurable_billing_approach = args[:configurable_billing_approach] if args.key?(:configurable_billing_approach) @configurable_billing_approach_update_time = args[:configurable_billing_approach_update_time] if args.key?(:configurable_billing_approach_update_time) @content_config = args[:content_config] if args.key?(:content_config) @create_time = args[:create_time] if args.key?(:create_time) @data_protection_policy = args[:data_protection_policy] if args.key?(:data_protection_policy) @default_schema_id = args[:default_schema_id] if args.key?(:default_schema_id) @display_name = args[:display_name] if args.key?(:display_name) @document_processing_config = args[:document_processing_config] if args.key?(:document_processing_config) @federated_search_config = args[:federated_search_config] if args.key?(:federated_search_config) @healthcare_fhir_config = args[:healthcare_fhir_config] if args.key?(:healthcare_fhir_config) @identity_mapping_store = args[:identity_mapping_store] if args.key?(:identity_mapping_store) @idp_config = args[:idp_config] if args.key?(:idp_config) @industry_vertical = args[:industry_vertical] if args.key?(:industry_vertical) @is_infobot_faq_data_store = args[:is_infobot_faq_data_store] if args.key?(:is_infobot_faq_data_store) @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name) @language_info = args[:language_info] if args.key?(:language_info) @name = args[:name] if args.key?(:name) @natural_language_query_understanding_config = args[:natural_language_query_understanding_config] if args.key?(:natural_language_query_understanding_config) @serving_config_data_store = args[:serving_config_data_store] if args.key?(:serving_config_data_store) @solution_types = args[:solution_types] if args.key?(:solution_types) @starting_schema = args[:starting_schema] if args.key?(:starting_schema) @workspace_config = args[:workspace_config] if args.key?(:workspace_config) end |