Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataStoreBillingEstimation
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataStoreBillingEstimation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Estimation of data size per data store.
Instance Attribute Summary collapse
-
#structured_data_size ⇒ Fixnum
Data size for structured data in terms of bytes.
-
#structured_data_update_time ⇒ String
Last updated timestamp for structured data.
-
#unstructured_data_size ⇒ Fixnum
Data size for unstructured data in terms of bytes.
-
#unstructured_data_update_time ⇒ String
Last updated timestamp for unstructured data.
-
#website_data_size ⇒ Fixnum
Data size for websites in terms of bytes.
-
#website_data_update_time ⇒ String
Last updated timestamp for websites.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaDataStoreBillingEstimation
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaDataStoreBillingEstimation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaDataStoreBillingEstimation
Returns a new instance of GoogleCloudDiscoveryengineV1alphaDataStoreBillingEstimation.
11433 11434 11435 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11433 def initialize(**args) update!(**args) end |
Instance Attribute Details
#structured_data_size ⇒ Fixnum
Data size for structured data in terms of bytes.
Corresponds to the JSON property structuredDataSize
11406 11407 11408 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11406 def structured_data_size @structured_data_size end |
#structured_data_update_time ⇒ String
Last updated timestamp for structured data.
Corresponds to the JSON property structuredDataUpdateTime
11411 11412 11413 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11411 def structured_data_update_time @structured_data_update_time end |
#unstructured_data_size ⇒ Fixnum
Data size for unstructured data in terms of bytes.
Corresponds to the JSON property unstructuredDataSize
11416 11417 11418 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11416 def unstructured_data_size @unstructured_data_size end |
#unstructured_data_update_time ⇒ String
Last updated timestamp for unstructured data.
Corresponds to the JSON property unstructuredDataUpdateTime
11421 11422 11423 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11421 def unstructured_data_update_time @unstructured_data_update_time end |
#website_data_size ⇒ Fixnum
Data size for websites in terms of bytes.
Corresponds to the JSON property websiteDataSize
11426 11427 11428 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11426 def website_data_size @website_data_size end |
#website_data_update_time ⇒ String
Last updated timestamp for websites.
Corresponds to the JSON property websiteDataUpdateTime
11431 11432 11433 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11431 def website_data_update_time @website_data_update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11438 11439 11440 11441 11442 11443 11444 11445 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11438 def update!(**args) @structured_data_size = args[:structured_data_size] if args.key?(:structured_data_size) @structured_data_update_time = args[:structured_data_update_time] if args.key?(:structured_data_update_time) @unstructured_data_size = args[:unstructured_data_size] if args.key?(:unstructured_data_size) @unstructured_data_update_time = args[:unstructured_data_update_time] if args.key?(:unstructured_data_update_time) @website_data_size = args[:website_data_size] if args.key?(:website_data_size) @website_data_update_time = args[:website_data_update_time] if args.key?(:website_data_update_time) end |