Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataStoreBillingEstimation
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataStoreBillingEstimation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Estimation of data size per data store.
Instance Attribute Summary collapse
-
#structured_data_size ⇒ Fixnum
Data size for structured data in terms of bytes.
-
#structured_data_update_time ⇒ String
Last updated timestamp for structured data.
-
#unstructured_data_size ⇒ Fixnum
Data size for unstructured data in terms of bytes.
-
#unstructured_data_update_time ⇒ String
Last updated timestamp for unstructured data.
-
#website_data_size ⇒ Fixnum
Data size for websites in terms of bytes.
-
#website_data_update_time ⇒ String
Last updated timestamp for websites.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaDataStoreBillingEstimation
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaDataStoreBillingEstimation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaDataStoreBillingEstimation
Returns a new instance of GoogleCloudDiscoveryengineV1alphaDataStoreBillingEstimation.
11276 11277 11278 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11276 def initialize(**args) update!(**args) end |
Instance Attribute Details
#structured_data_size ⇒ Fixnum
Data size for structured data in terms of bytes.
Corresponds to the JSON property structuredDataSize
11249 11250 11251 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11249 def structured_data_size @structured_data_size end |
#structured_data_update_time ⇒ String
Last updated timestamp for structured data.
Corresponds to the JSON property structuredDataUpdateTime
11254 11255 11256 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11254 def structured_data_update_time @structured_data_update_time end |
#unstructured_data_size ⇒ Fixnum
Data size for unstructured data in terms of bytes.
Corresponds to the JSON property unstructuredDataSize
11259 11260 11261 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11259 def unstructured_data_size @unstructured_data_size end |
#unstructured_data_update_time ⇒ String
Last updated timestamp for unstructured data.
Corresponds to the JSON property unstructuredDataUpdateTime
11264 11265 11266 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11264 def unstructured_data_update_time @unstructured_data_update_time end |
#website_data_size ⇒ Fixnum
Data size for websites in terms of bytes.
Corresponds to the JSON property websiteDataSize
11269 11270 11271 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11269 def website_data_size @website_data_size end |
#website_data_update_time ⇒ String
Last updated timestamp for websites.
Corresponds to the JSON property websiteDataUpdateTime
11274 11275 11276 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11274 def website_data_update_time @website_data_update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11281 11282 11283 11284 11285 11286 11287 11288 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11281 def update!(**args) @structured_data_size = args[:structured_data_size] if args.key?(:structured_data_size) @structured_data_update_time = args[:structured_data_update_time] if args.key?(:structured_data_update_time) @unstructured_data_size = args[:unstructured_data_size] if args.key?(:unstructured_data_size) @unstructured_data_update_time = args[:unstructured_data_update_time] if args.key?(:unstructured_data_update_time) @website_data_size = args[:website_data_size] if args.key?(:website_data_size) @website_data_update_time = args[:website_data_update_time] if args.key?(:website_data_update_time) end |