Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataStoreBillingEstimation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Estimation of data size per data store.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaDataStoreBillingEstimation

Returns a new instance of GoogleCloudDiscoveryengineV1alphaDataStoreBillingEstimation.



10710
10711
10712
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10710

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#structured_data_sizeFixnum

Data size for structured data in terms of bytes. Corresponds to the JSON property structuredDataSize

Returns:

  • (Fixnum)


10683
10684
10685
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10683

def structured_data_size
  @structured_data_size
end

#structured_data_update_timeString

Last updated timestamp for structured data. Corresponds to the JSON property structuredDataUpdateTime

Returns:

  • (String)


10688
10689
10690
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10688

def structured_data_update_time
  @structured_data_update_time
end

#unstructured_data_sizeFixnum

Data size for unstructured data in terms of bytes. Corresponds to the JSON property unstructuredDataSize

Returns:

  • (Fixnum)


10693
10694
10695
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10693

def unstructured_data_size
  @unstructured_data_size
end

#unstructured_data_update_timeString

Last updated timestamp for unstructured data. Corresponds to the JSON property unstructuredDataUpdateTime

Returns:

  • (String)


10698
10699
10700
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10698

def unstructured_data_update_time
  @unstructured_data_update_time
end

#website_data_sizeFixnum

Data size for websites in terms of bytes. Corresponds to the JSON property websiteDataSize

Returns:

  • (Fixnum)


10703
10704
10705
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10703

def website_data_size
  @website_data_size
end

#website_data_update_timeString

Last updated timestamp for websites. Corresponds to the JSON property websiteDataUpdateTime

Returns:

  • (String)


10708
10709
10710
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10708

def website_data_update_time
  @website_data_update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10715
10716
10717
10718
10719
10720
10721
10722
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10715

def update!(**args)
  @structured_data_size = args[:structured_data_size] if args.key?(:structured_data_size)
  @structured_data_update_time = args[:structured_data_update_time] if args.key?(:structured_data_update_time)
  @unstructured_data_size = args[:unstructured_data_size] if args.key?(:unstructured_data_size)
  @unstructured_data_update_time = args[:unstructured_data_update_time] if args.key?(:unstructured_data_update_time)
  @website_data_size = args[:website_data_size] if args.key?(:website_data_size)
  @website_data_update_time = args[:website_data_update_time] if args.key?(:website_data_update_time)
end