Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataStoreFederatedSearchConfigAlloyDbConfigAlloyDbConnectionConfig
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataStoreFederatedSearchConfigAlloyDbConfigAlloyDbConnectionConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Configuration for connecting to AlloyDB.
Instance Attribute Summary collapse
-
#auth_mode ⇒ String
Optional.
-
#database ⇒ String
Required.
-
#enable_psvs ⇒ Boolean
(also: #enable_psvs?)
Optional.
-
#instance ⇒ String
Required.
-
#password ⇒ String
Required.
-
#user ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaDataStoreFederatedSearchConfigAlloyDbConfigAlloyDbConnectionConfig
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaDataStoreFederatedSearchConfigAlloyDbConfigAlloyDbConnectionConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaDataStoreFederatedSearchConfigAlloyDbConfigAlloyDbConnectionConfig
Returns a new instance of GoogleCloudDiscoveryengineV1alphaDataStoreFederatedSearchConfigAlloyDbConfigAlloyDbConnectionConfig.
11413 11414 11415 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11413 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auth_mode ⇒ String
Optional. Auth mode.
Corresponds to the JSON property authMode
11381 11382 11383 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11381 def auth_mode @auth_mode end |
#database ⇒ String
Required. The AlloyDB database to connect to.
Corresponds to the JSON property database
11386 11387 11388 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11386 def database @database end |
#enable_psvs ⇒ Boolean Also known as: enable_psvs?
Optional. If true, enable PSVS for AlloyDB.
Corresponds to the JSON property enablePsvs
11391 11392 11393 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11391 def enable_psvs @enable_psvs end |
#instance ⇒ String
Required. The AlloyDB instance to connect to.
Corresponds to the JSON property instance
11397 11398 11399 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11397 def instance @instance end |
#password ⇒ String
Required. Database password. If auth_mode = END_USER_ACCOUNT, it can be unset.
In that case, the password will be inferred on the AlloyDB side, based on the
authenticated user.
Corresponds to the JSON property password
11404 11405 11406 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11404 def password @password end |
#user ⇒ String
Required. Database user. If auth_mode = END_USER_ACCOUNT, it can be unset. In
that case, the user will be inferred on the AlloyDB side, based on the
authenticated user.
Corresponds to the JSON property user
11411 11412 11413 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11411 def user @user end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11418 11419 11420 11421 11422 11423 11424 11425 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11418 def update!(**args) @auth_mode = args[:auth_mode] if args.key?(:auth_mode) @database = args[:database] if args.key?(:database) @enable_psvs = args[:enable_psvs] if args.key?(:enable_psvs) @instance = args[:instance] if args.key?(:instance) @password = args[:password] if args.key?(:password) @user = args[:user] if args.key?(:user) end |