Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDataStoreFederatedSearchConfigAlloyDbConfigAlloyDbConnectionConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Configuration for connecting to AlloyDB.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaDataStoreFederatedSearchConfigAlloyDbConfigAlloyDbConnectionConfig

Returns a new instance of GoogleCloudDiscoveryengineV1alphaDataStoreFederatedSearchConfigAlloyDbConfigAlloyDbConnectionConfig.



10745
10746
10747
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10745

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auth_modeString

Optional. Auth mode. Corresponds to the JSON property authMode

Returns:

  • (String)


10713
10714
10715
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10713

def auth_mode
  @auth_mode
end

#databaseString

Required. The AlloyDB database to connect to. Corresponds to the JSON property database

Returns:

  • (String)


10718
10719
10720
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10718

def database
  @database
end

#enable_psvsBoolean Also known as: enable_psvs?

Optional. If true, enable PSVS for AlloyDB. Corresponds to the JSON property enablePsvs

Returns:

  • (Boolean)


10723
10724
10725
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10723

def enable_psvs
  @enable_psvs
end

#instanceString

Required. The AlloyDB instance to connect to. Corresponds to the JSON property instance

Returns:

  • (String)


10729
10730
10731
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10729

def instance
  @instance
end

#passwordString

Required. Database password. If auth_mode = END_USER_ACCOUNT, it can be unset. In that case, the password will be inferred on the AlloyDB side, based on the authenticated user. Corresponds to the JSON property password

Returns:

  • (String)


10736
10737
10738
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10736

def password
  @password
end

#userString

Required. Database user. If auth_mode = END_USER_ACCOUNT, it can be unset. In that case, the user will be inferred on the AlloyDB side, based on the authenticated user. Corresponds to the JSON property user

Returns:

  • (String)


10743
10744
10745
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10743

def user
  @user
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10750
10751
10752
10753
10754
10755
10756
10757
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 10750

def update!(**args)
  @auth_mode = args[:auth_mode] if args.key?(:auth_mode)
  @database = args[:database] if args.key?(:database)
  @enable_psvs = args[:enable_psvs] if args.key?(:enable_psvs)
  @instance = args[:instance] if args.key?(:instance)
  @password = args[:password] if args.key?(:password)
  @user = args[:user] if args.key?(:user)
end