Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDeletePatientFiltersRequest
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDeletePatientFiltersRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Request for DataStoreService.DeletePatientFilters method.
Instance Attribute Summary collapse
-
#data_store ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaDeletePatientFiltersRequest
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaDeletePatientFiltersRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaDeletePatientFiltersRequest
Returns a new instance of GoogleCloudDiscoveryengineV1alphaDeletePatientFiltersRequest.
11048 11049 11050 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11048 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_store ⇒ String
Required. Full resource name of DataStore, such as projects/project/
locations/location/collections/collection_id/dataStores/data_store_id`.
If the caller does not have permission to access the DataStore, regardless of
whether or not it exists, a PERMISSION_DENIED error is returned. If the
requested DataStore does not exist, a NOT_FOUND error is returned. If the
requested DataStore does not have a patient filter, a NOT_FOUND error will be
returned.
Corresponds to the JSON propertydataStore`
11046 11047 11048 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11046 def data_store @data_store end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11053 11054 11055 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11053 def update!(**args) @data_store = args[:data_store] if args.key?(:data_store) end |