Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDeleteUserStoreMetadata
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDeleteUserStoreMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Metadata related to the progress of the UserStoreService.DeleteUserStore operation. This will be returned by the google.longrunning.Operation.metadata field. Delete UserStore will delete all the end users under the user store, return the number of end users successfully deleted or failed to delete in the metadata.
Instance Attribute Summary collapse
-
#failure_count ⇒ Fixnum
The number of end users under the user store that failed to be deleted.
-
#success_count ⇒ Fixnum
The number of end users under the user store that were successfully deleted.
-
#update_time ⇒ String
Operation last update time.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaDeleteUserStoreMetadata
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaDeleteUserStoreMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaDeleteUserStoreMetadata
Returns a new instance of GoogleCloudDiscoveryengineV1alphaDeleteUserStoreMetadata.
11898 11899 11900 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11898 def initialize(**args) update!(**args) end |
Instance Attribute Details
#failure_count ⇒ Fixnum
The number of end users under the user store that failed to be deleted.
Corresponds to the JSON property failureCount
11885 11886 11887 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11885 def failure_count @failure_count end |
#success_count ⇒ Fixnum
The number of end users under the user store that were successfully deleted.
Corresponds to the JSON property successCount
11890 11891 11892 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11890 def success_count @success_count end |
#update_time ⇒ String
Operation last update time. If the operation is done, this is also the finish
time.
Corresponds to the JSON property updateTime
11896 11897 11898 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11896 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11903 11904 11905 11906 11907 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11903 def update!(**args) @failure_count = args[:failure_count] if args.key?(:failure_count) @success_count = args[:success_count] if args.key?(:success_count) @update_time = args[:update_time] if args.key?(:update_time) end |