Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDeleteUserStoreMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Metadata related to the progress of the UserStoreService.DeleteUserStore operation. This will be returned by the google.longrunning.Operation.metadata field. Delete UserStore will delete all the end users under the user store, return the number of end users successfully deleted or failed to delete in the metadata.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaDeleteUserStoreMetadata

Returns a new instance of GoogleCloudDiscoveryengineV1alphaDeleteUserStoreMetadata.



11179
11180
11181
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11179

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#failure_countFixnum

The number of end users under the user store that failed to be deleted. Corresponds to the JSON property failureCount

Returns:

  • (Fixnum)


11172
11173
11174
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11172

def failure_count
  @failure_count
end

#success_countFixnum

The number of end users under the user store that were successfully deleted. Corresponds to the JSON property successCount

Returns:

  • (Fixnum)


11177
11178
11179
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11177

def success_count
  @success_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11184
11185
11186
11187
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11184

def update!(**args)
  @failure_count = args[:failure_count] if args.key?(:failure_count)
  @success_count = args[:success_count] if args.key?(:success_count)
end