Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDestinationConfig
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDestinationConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Defines target endpoints used to connect to third-party sources.
Instance Attribute Summary collapse
-
#destinations ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDestinationConfigDestination>
Optional.
-
#json_params ⇒ String
Additional parameters for this destination config in json string format.
-
#key ⇒ String
Optional.
-
#params ⇒ Hash<String,Object>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaDestinationConfig
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaDestinationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaDestinationConfig
Returns a new instance of GoogleCloudDiscoveryengineV1alphaDestinationConfig.
11935 11936 11937 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11935 def initialize(**args) update!(**args) end |
Instance Attribute Details
#destinations ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDestinationConfigDestination>
Optional. The destinations for the corresponding key.
Corresponds to the JSON property destinations
11917 11918 11919 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11917 def destinations @destinations end |
#json_params ⇒ String
Additional parameters for this destination config in json string format.
Corresponds to the JSON property jsonParams
11922 11923 11924 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11922 def json_params @json_params end |
#key ⇒ String
Optional. Unique destination identifier that is supported by the connector.
Corresponds to the JSON property key
11927 11928 11929 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11927 def key @key end |
#params ⇒ Hash<String,Object>
Optional. Additional parameters for this destination config in structured json
format.
Corresponds to the JSON property params
11933 11934 11935 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11933 def params @params end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11940 11941 11942 11943 11944 11945 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11940 def update!(**args) @destinations = args[:destinations] if args.key?(:destinations) @json_params = args[:json_params] if args.key?(:json_params) @key = args[:key] if args.key?(:key) @params = args[:params] if args.key?(:params) end |