Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDestinationConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Defines target endpoints used to connect to third-party sources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaDestinationConfig

Returns a new instance of GoogleCloudDiscoveryengineV1alphaDestinationConfig.



11911
11912
11913
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11911

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destinationsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDestinationConfigDestination>

Optional. The destinations for the corresponding key. Corresponds to the JSON property destinations



11893
11894
11895
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11893

def destinations
  @destinations
end

#json_paramsString

Additional parameters for this destination config in json string format. Corresponds to the JSON property jsonParams

Returns:

  • (String)


11898
11899
11900
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11898

def json_params
  @json_params
end

#keyString

Optional. Unique destination identifier that is supported by the connector. Corresponds to the JSON property key

Returns:

  • (String)


11903
11904
11905
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11903

def key
  @key
end

#paramsHash<String,Object>

Optional. Additional parameters for this destination config in structured json format. Corresponds to the JSON property params

Returns:

  • (Hash<String,Object>)


11909
11910
11911
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11909

def params
  @params
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11916
11917
11918
11919
11920
11921
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11916

def update!(**args)
  @destinations = args[:destinations] if args.key?(:destinations)
  @json_params = args[:json_params] if args.key?(:json_params)
  @key = args[:key] if args.key?(:key)
  @params = args[:params] if args.key?(:params)
end