Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDestinationConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Defines target endpoints used to connect to third-party sources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaDestinationConfig

Returns a new instance of GoogleCloudDiscoveryengineV1alphaDestinationConfig.



11215
11216
11217
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11215

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destinationsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDestinationConfigDestination>

Optional. The destinations for the corresponding key. Corresponds to the JSON property destinations



11197
11198
11199
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11197

def destinations
  @destinations
end

#json_paramsString

Additional parameters for this destination config in json string format. Corresponds to the JSON property jsonParams

Returns:

  • (String)


11202
11203
11204
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11202

def json_params
  @json_params
end

#keyString

Optional. Unique destination identifier that is supported by the connector. Corresponds to the JSON property key

Returns:

  • (String)


11207
11208
11209
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11207

def key
  @key
end

#paramsHash<String,Object>

Optional. Additional parameters for this destination config in structured json format. Corresponds to the JSON property params

Returns:

  • (Hash<String,Object>)


11213
11214
11215
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11213

def params
  @params
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11220
11221
11222
11223
11224
11225
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11220

def update!(**args)
  @destinations = args[:destinations] if args.key?(:destinations)
  @json_params = args[:json_params] if args.key?(:json_params)
  @key = args[:key] if args.key?(:key)
  @params = args[:params] if args.key?(:params)
end