Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDestinationConfig
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDestinationConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Defines target endpoints used to connect to third-party sources.
Instance Attribute Summary collapse
-
#destinations ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDestinationConfigDestination>
Optional.
-
#json_params ⇒ String
Additional parameters for this destination config in json string format.
-
#key ⇒ String
Optional.
-
#params ⇒ Hash<String,Object>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaDestinationConfig
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaDestinationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaDestinationConfig
Returns a new instance of GoogleCloudDiscoveryengineV1alphaDestinationConfig.
11215 11216 11217 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11215 def initialize(**args) update!(**args) end |
Instance Attribute Details
#destinations ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDestinationConfigDestination>
Optional. The destinations for the corresponding key.
Corresponds to the JSON property destinations
11197 11198 11199 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11197 def destinations @destinations end |
#json_params ⇒ String
Additional parameters for this destination config in json string format.
Corresponds to the JSON property jsonParams
11202 11203 11204 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11202 def json_params @json_params end |
#key ⇒ String
Optional. Unique destination identifier that is supported by the connector.
Corresponds to the JSON property key
11207 11208 11209 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11207 def key @key end |
#params ⇒ Hash<String,Object>
Optional. Additional parameters for this destination config in structured json
format.
Corresponds to the JSON property params
11213 11214 11215 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11213 def params @params end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11220 11221 11222 11223 11224 11225 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11220 def update!(**args) @destinations = args[:destinations] if args.key?(:destinations) @json_params = args[:json_params] if args.key?(:json_params) @key = args[:key] if args.key?(:key) @params = args[:params] if args.key?(:params) end |