Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDocumentProcessingConfigParsingConfigLayoutParsingConfig
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaDocumentProcessingConfigParsingConfigLayoutParsingConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
The layout parsing configurations for documents.
Instance Attribute Summary collapse
-
#enable_get_processed_document ⇒ Boolean
(also: #enable_get_processed_document?)
Optional.
-
#enable_image_annotation ⇒ Boolean
(also: #enable_image_annotation?)
Optional.
-
#enable_llm_layout_parsing ⇒ Boolean
(also: #enable_llm_layout_parsing?)
Optional.
-
#enable_table_annotation ⇒ Boolean
(also: #enable_table_annotation?)
Optional.
-
#exclude_html_classes ⇒ Array<String>
Optional.
-
#exclude_html_elements ⇒ Array<String>
Optional.
-
#exclude_html_ids ⇒ Array<String>
Optional.
-
#structured_content_types ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaDocumentProcessingConfigParsingConfigLayoutParsingConfig
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaDocumentProcessingConfigParsingConfigLayoutParsingConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaDocumentProcessingConfigParsingConfigLayoutParsingConfig
Returns a new instance of GoogleCloudDiscoveryengineV1alphaDocumentProcessingConfigParsingConfigLayoutParsingConfig.
12182 12183 12184 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12182 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable_get_processed_document ⇒ Boolean Also known as: enable_get_processed_document?
Optional. If true, the processed document will be made available for the
GetProcessedDocument API.
Corresponds to the JSON property enableGetProcessedDocument
12138 12139 12140 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12138 def enable_get_processed_document @enable_get_processed_document end |
#enable_image_annotation ⇒ Boolean Also known as: enable_image_annotation?
Optional. If true, the LLM based annotation is added to the image during
parsing.
Corresponds to the JSON property enableImageAnnotation
12145 12146 12147 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12145 def enable_image_annotation @enable_image_annotation end |
#enable_llm_layout_parsing ⇒ Boolean Also known as: enable_llm_layout_parsing?
Optional. If true, the pdf layout will be refined using an LLM.
Corresponds to the JSON property enableLlmLayoutParsing
12151 12152 12153 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12151 def enable_llm_layout_parsing @enable_llm_layout_parsing end |
#enable_table_annotation ⇒ Boolean Also known as: enable_table_annotation?
Optional. If true, the LLM based annotation is added to the table during
parsing.
Corresponds to the JSON property enableTableAnnotation
12158 12159 12160 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12158 def enable_table_annotation @enable_table_annotation end |
#exclude_html_classes ⇒ Array<String>
Optional. List of HTML classes to exclude from the parsed content.
Corresponds to the JSON property excludeHtmlClasses
12164 12165 12166 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12164 def exclude_html_classes @exclude_html_classes end |
#exclude_html_elements ⇒ Array<String>
Optional. List of HTML elements to exclude from the parsed content.
Corresponds to the JSON property excludeHtmlElements
12169 12170 12171 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12169 def exclude_html_elements @exclude_html_elements end |
#exclude_html_ids ⇒ Array<String>
Optional. List of HTML ids to exclude from the parsed content.
Corresponds to the JSON property excludeHtmlIds
12174 12175 12176 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12174 def exclude_html_ids @exclude_html_ids end |
#structured_content_types ⇒ Array<String>
Optional. Contains the required structure types to extract from the document.
Supported values: * shareholder-structure
Corresponds to the JSON property structuredContentTypes
12180 12181 12182 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12180 def structured_content_types @structured_content_types end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12187 12188 12189 12190 12191 12192 12193 12194 12195 12196 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12187 def update!(**args) @enable_get_processed_document = args[:enable_get_processed_document] if args.key?(:enable_get_processed_document) @enable_image_annotation = args[:enable_image_annotation] if args.key?(:enable_image_annotation) @enable_llm_layout_parsing = args[:enable_llm_layout_parsing] if args.key?(:enable_llm_layout_parsing) @enable_table_annotation = args[:enable_table_annotation] if args.key?(:enable_table_annotation) @exclude_html_classes = args[:exclude_html_classes] if args.key?(:exclude_html_classes) @exclude_html_elements = args[:exclude_html_elements] if args.key?(:exclude_html_elements) @exclude_html_ids = args[:exclude_html_ids] if args.key?(:exclude_html_ids) @structured_content_types = args[:structured_content_types] if args.key?(:structured_content_types) end |