Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngine
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngine
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Metadata that describes the training and serving parameters of an Engine.
Instance Attribute Summary collapse
-
#agent_gateway_setting ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAgentGatewaySetting
Agent Gateway setting, which may be attached to Gemini Enterprise resources for egress control of Gemini Enterprise agents to agents and tools outside of Gemini Enterprise.
-
#app_type ⇒ String
Optional.
-
#associated_agent_registry ⇒ String
Output only.
-
#chat_engine_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngineChatEngineConfig
Configurations for a Chat Engine.
-
#chat_engine_metadata ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngineChatEngineMetadata
Additional information of a Chat Engine.
-
#cmek_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaCmekConfig
Configurations used to enable CMEK data encryption with Cloud KMS keys.
-
#common_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngineCommonConfig
Common configurations for an Engine.
-
#configurable_billing_approach ⇒ String
Optional.
-
#connector_tenant_info ⇒ Hash<String,String>
Optional.
-
#create_time ⇒ String
Output only.
-
#data_store_ids ⇒ Array<String>
Optional.
-
#disable_analytics ⇒ Boolean
(also: #disable_analytics?)
Optional.
-
#display_name ⇒ String
Required.
-
#features ⇒ Hash<String,String>
Optional.
-
#industry_vertical ⇒ String
Optional.
-
#knowledge_graph_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngineKnowledgeGraphConfig
Configuration message for the Knowledge Graph.
-
#marketplace_agent_visibility ⇒ String
Optional.
-
#media_recommendation_engine_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngineMediaRecommendationEngineConfig
Additional config specs for a Media Recommendation engine.
-
#model_configs ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Immutable.
-
#observability_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaObservabilityConfig
Observability config for a resource.
-
#procurement_contact_emails ⇒ Array<String>
Optional.
-
#recommendation_metadata ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngineRecommendationMetadata
Additional information of a recommendation engine.
-
#search_engine_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngineSearchEngineConfig
Configurations for a Search Engine.
-
#similar_documents_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngineSimilarDocumentsEngineConfig
Additional config specs for a
similar-itemsengine. -
#solution_type ⇒ String
Required.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaEngine
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaEngine.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaEngine
Returns a new instance of GoogleCloudDiscoveryengineV1alphaEngine.
12606 12607 12608 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12606 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_gateway_setting ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAgentGatewaySetting
Agent Gateway setting, which may be attached to Gemini Enterprise resources
for egress control of Gemini Enterprise agents to agents and tools outside of
Gemini Enterprise.
Corresponds to the JSON property agentGatewaySetting
12436 12437 12438 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12436 def agent_gateway_setting @agent_gateway_setting end |
#app_type ⇒ String
Optional. Immutable. This the application type which this engine resource
represents. NOTE: this is a new concept independ of existing industry vertical
or solution type.
Corresponds to the JSON property appType
12443 12444 12445 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12443 def app_type @app_type end |
#associated_agent_registry ⇒ String
Output only. The Agent registry containing the agents, MCP servers and tools
associated with this engine. Derived server-side from the linked Agent Gateway'
s registry.
Corresponds to the JSON property associatedAgentRegistry
12450 12451 12452 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12450 def associated_agent_registry @associated_agent_registry end |
#chat_engine_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngineChatEngineConfig
Configurations for a Chat Engine.
Corresponds to the JSON property chatEngineConfig
12455 12456 12457 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12455 def chat_engine_config @chat_engine_config end |
#chat_engine_metadata ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngineChatEngineMetadata
Additional information of a Chat Engine. Fields in this message are output
only.
Corresponds to the JSON property chatEngineMetadata
12461 12462 12463 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12461 def @chat_engine_metadata end |
#cmek_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaCmekConfig
Configurations used to enable CMEK data encryption with Cloud KMS keys.
Corresponds to the JSON property cmekConfig
12466 12467 12468 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12466 def cmek_config @cmek_config end |
#common_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngineCommonConfig
Common configurations for an Engine.
Corresponds to the JSON property commonConfig
12471 12472 12473 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12471 def common_config @common_config end |
#configurable_billing_approach ⇒ String
Optional. Configuration for configurable billing approach.
Corresponds to the JSON property configurableBillingApproach
12476 12477 12478 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12476 def configurable_billing_approach @configurable_billing_approach end |
#connector_tenant_info ⇒ Hash<String,String>
Optional. Maps a connector ID (e.g., "hybrid-github", "shopify") to tenant-
specific information required for that connector. The structure of the tenant
information string is connector-dependent.
Corresponds to the JSON property connectorTenantInfo
12483 12484 12485 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12483 def connector_tenant_info @connector_tenant_info end |
#create_time ⇒ String
Output only. Timestamp the Recommendation Engine was created at.
Corresponds to the JSON property createTime
12488 12489 12490 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12488 def create_time @create_time end |
#data_store_ids ⇒ Array<String>
Optional. The data stores associated with this engine. For
SOLUTION_TYPE_SEARCH and SOLUTION_TYPE_RECOMMENDATION type of engines, they
can only associate with at most one data store. If solution_type is
SOLUTION_TYPE_CHAT, multiple DataStores in the same Collection can be
associated here. Note that when used in CreateEngineRequest, one DataStore id
must be provided as the system will use it for necessary initializations.
Corresponds to the JSON property dataStoreIds
12498 12499 12500 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12498 def data_store_ids @data_store_ids end |
#disable_analytics ⇒ Boolean Also known as: disable_analytics?
Optional. Whether to disable analytics for searches performed on this engine.
Corresponds to the JSON property disableAnalytics
12503 12504 12505 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12503 def disable_analytics @disable_analytics end |
#display_name ⇒ String
Required. The display name of the engine. Should be human readable. UTF-8
encoded string with limit of 1024 characters.
Corresponds to the JSON property displayName
12510 12511 12512 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12510 def display_name @display_name end |
#features ⇒ Hash<String,String>
Optional. Feature config for the engine to opt in or opt out of features.
Supported keys: * *: all features, if it's present, all other feature state
settings are ignored. * agent-gallery * no-code-agent-builder * prompt-
gallery * model-selector * notebook-lm * people-search * people-search-
org-chart * bi-directional-audio * feedback * session-sharing *
personalization-memory * personalization-suggested-highlights * mobile-app-
access * disable-agent-sharing * disable-image-generation * disable-
video-generation * disable-onedrive-upload * disable-talk-to-content *
disable-google-drive-upload * disable-welcome-emails * disable-canvas *
canvas-workspace * skills * skill-sharing * skill-sharing-without-admin-
approval * disable-projects * sobi * enable-end-user-sharing-with-groups
single-agent-orchestration*multi-agent-orchestration*cross-product- intelligence*workflow-agents*in-app-notificationsCorresponds to the JSON propertyfeatures
12527 12528 12529 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12527 def features @features end |
#industry_vertical ⇒ String
Optional. The industry vertical that the engine registers. The restriction of
the Engine industry vertical is based on DataStore: Vertical on Engine has to
match vertical of the DataStore linked to the engine.
Corresponds to the JSON property industryVertical
12534 12535 12536 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12534 def industry_vertical @industry_vertical end |
#knowledge_graph_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngineKnowledgeGraphConfig
Configuration message for the Knowledge Graph.
Corresponds to the JSON property knowledgeGraphConfig
12539 12540 12541 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12539 def knowledge_graph_config @knowledge_graph_config end |
#marketplace_agent_visibility ⇒ String
Optional. The visibility of marketplace agents in the agent gallery.
Corresponds to the JSON property marketplaceAgentVisibility
12544 12545 12546 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12544 def marketplace_agent_visibility @marketplace_agent_visibility end |
#media_recommendation_engine_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngineMediaRecommendationEngineConfig
Additional config specs for a Media Recommendation engine.
Corresponds to the JSON property mediaRecommendationEngineConfig
12549 12550 12551 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12549 def media_recommendation_engine_config @media_recommendation_engine_config end |
#model_configs ⇒ Hash<String,String>
Optional. Maps a model name to its specific configuration for this engine.
This allows admin users to turn on/off individual models. This only stores
models whose states are overridden by the admin. When the state is unspecified,
or model_configs is empty for this model, the system will decide if this
model should be available or not based on the default configuration. For
example, a preview model should be disabled by default if the admin has not
chosen to enable it.
Corresponds to the JSON property modelConfigs
12560 12561 12562 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12560 def model_configs @model_configs end |
#name ⇒ String
Immutable. Identifier. The fully qualified resource name of the engine. This
field must be a UTF-8 encoded string with a length limit of 1024 characters.
Format: projects/project/locations/location/collections/collection/
engines/engine`engine should be 1-63 characters, and valid characters are /
a-z0-9*/. Otherwise, an INVALID_ARGUMENT error is returned.
Corresponds to the JSON propertyname`
12569 12570 12571 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12569 def name @name end |
#observability_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaObservabilityConfig
Observability config for a resource.
Corresponds to the JSON property observabilityConfig
12574 12575 12576 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12574 def observability_config @observability_config end |
#procurement_contact_emails ⇒ Array<String>
Optional. The emails of the procurement contacts.
Corresponds to the JSON property procurementContactEmails
12579 12580 12581 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12579 def procurement_contact_emails @procurement_contact_emails end |
#recommendation_metadata ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngineRecommendationMetadata
Additional information of a recommendation engine.
Corresponds to the JSON property recommendationMetadata
12584 12585 12586 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12584 def @recommendation_metadata end |
#search_engine_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngineSearchEngineConfig
Configurations for a Search Engine.
Corresponds to the JSON property searchEngineConfig
12589 12590 12591 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12589 def search_engine_config @search_engine_config end |
#similar_documents_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngineSimilarDocumentsEngineConfig
Additional config specs for a similar-items engine.
Corresponds to the JSON property similarDocumentsConfig
12594 12595 12596 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12594 def similar_documents_config @similar_documents_config end |
#solution_type ⇒ String
Required. The solutions of the engine.
Corresponds to the JSON property solutionType
12599 12600 12601 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12599 def solution_type @solution_type end |
#update_time ⇒ String
Output only. Timestamp the Recommendation Engine was last updated.
Corresponds to the JSON property updateTime
12604 12605 12606 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12604 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12611 12612 12613 12614 12615 12616 12617 12618 12619 12620 12621 12622 12623 12624 12625 12626 12627 12628 12629 12630 12631 12632 12633 12634 12635 12636 12637 12638 12639 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12611 def update!(**args) @agent_gateway_setting = args[:agent_gateway_setting] if args.key?(:agent_gateway_setting) @app_type = args[:app_type] if args.key?(:app_type) @associated_agent_registry = args[:associated_agent_registry] if args.key?(:associated_agent_registry) @chat_engine_config = args[:chat_engine_config] if args.key?(:chat_engine_config) @chat_engine_metadata = args[:chat_engine_metadata] if args.key?(:chat_engine_metadata) @cmek_config = args[:cmek_config] if args.key?(:cmek_config) @common_config = args[:common_config] if args.key?(:common_config) @configurable_billing_approach = args[:configurable_billing_approach] if args.key?(:configurable_billing_approach) @connector_tenant_info = args[:connector_tenant_info] if args.key?(:connector_tenant_info) @create_time = args[:create_time] if args.key?(:create_time) @data_store_ids = args[:data_store_ids] if args.key?(:data_store_ids) @disable_analytics = args[:disable_analytics] if args.key?(:disable_analytics) @display_name = args[:display_name] if args.key?(:display_name) @features = args[:features] if args.key?(:features) @industry_vertical = args[:industry_vertical] if args.key?(:industry_vertical) @knowledge_graph_config = args[:knowledge_graph_config] if args.key?(:knowledge_graph_config) @marketplace_agent_visibility = args[:marketplace_agent_visibility] if args.key?(:marketplace_agent_visibility) @media_recommendation_engine_config = args[:media_recommendation_engine_config] if args.key?(:media_recommendation_engine_config) @model_configs = args[:model_configs] if args.key?(:model_configs) @name = args[:name] if args.key?(:name) @observability_config = args[:observability_config] if args.key?(:observability_config) @procurement_contact_emails = args[:procurement_contact_emails] if args.key?(:procurement_contact_emails) @recommendation_metadata = args[:recommendation_metadata] if args.key?(:recommendation_metadata) @search_engine_config = args[:search_engine_config] if args.key?(:search_engine_config) @similar_documents_config = args[:similar_documents_config] if args.key?(:similar_documents_config) @solution_type = args[:solution_type] if args.key?(:solution_type) @update_time = args[:update_time] if args.key?(:update_time) end |