Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngine

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Metadata that describes the training and serving parameters of an Engine.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaEngine

Returns a new instance of GoogleCloudDiscoveryengineV1alphaEngine.



12484
12485
12486
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12484

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_gateway_settingGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAgentGatewaySetting

Agent Gateway setting, which may be attached to Gemini Enterprise resources for egress control of Gemini Enterprise agents to agents and tools outside of Gemini Enterprise. Corresponds to the JSON property agentGatewaySetting



12315
12316
12317
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12315

def agent_gateway_setting
  @agent_gateway_setting
end

#app_typeString

Optional. Immutable. This the application type which this engine resource represents. NOTE: this is a new concept independ of existing industry vertical or solution type. Corresponds to the JSON property appType

Returns:

  • (String)


12322
12323
12324
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12322

def app_type
  @app_type
end

#associated_agent_registryString

Output only. The Agent registry containing the agents, MCP servers and tools associated with this engine. Derived server-side from the linked Agent Gateway' s registry. Corresponds to the JSON property associatedAgentRegistry

Returns:

  • (String)


12329
12330
12331
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12329

def associated_agent_registry
  @associated_agent_registry
end

#chat_engine_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngineChatEngineConfig

Configurations for a Chat Engine. Corresponds to the JSON property chatEngineConfig



12334
12335
12336
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12334

def chat_engine_config
  @chat_engine_config
end

#chat_engine_metadataGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngineChatEngineMetadata

Additional information of a Chat Engine. Fields in this message are output only. Corresponds to the JSON property chatEngineMetadata



12340
12341
12342
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12340

def 
  @chat_engine_metadata
end

#cmek_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaCmekConfig

Configurations used to enable CMEK data encryption with Cloud KMS keys. Corresponds to the JSON property cmekConfig



12345
12346
12347
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12345

def cmek_config
  @cmek_config
end

#common_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngineCommonConfig

Common configurations for an Engine. Corresponds to the JSON property commonConfig



12350
12351
12352
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12350

def common_config
  @common_config
end

#configurable_billing_approachString

Optional. Configuration for configurable billing approach. Corresponds to the JSON property configurableBillingApproach

Returns:

  • (String)


12355
12356
12357
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12355

def configurable_billing_approach
  @configurable_billing_approach
end

#connector_tenant_infoHash<String,String>

Optional. Maps a connector ID (e.g., "hybrid-github", "shopify") to tenant- specific information required for that connector. The structure of the tenant information string is connector-dependent. Corresponds to the JSON property connectorTenantInfo

Returns:

  • (Hash<String,String>)


12362
12363
12364
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12362

def connector_tenant_info
  @connector_tenant_info
end

#create_timeString

Output only. Timestamp the Recommendation Engine was created at. Corresponds to the JSON property createTime

Returns:

  • (String)


12367
12368
12369
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12367

def create_time
  @create_time
end

#data_store_idsArray<String>

Optional. The data stores associated with this engine. For SOLUTION_TYPE_SEARCH and SOLUTION_TYPE_RECOMMENDATION type of engines, they can only associate with at most one data store. If solution_type is SOLUTION_TYPE_CHAT, multiple DataStores in the same Collection can be associated here. Note that when used in CreateEngineRequest, one DataStore id must be provided as the system will use it for necessary initializations. Corresponds to the JSON property dataStoreIds

Returns:

  • (Array<String>)


12377
12378
12379
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12377

def data_store_ids
  @data_store_ids
end

#disable_analyticsBoolean Also known as: disable_analytics?

Optional. Whether to disable analytics for searches performed on this engine. Corresponds to the JSON property disableAnalytics

Returns:

  • (Boolean)


12382
12383
12384
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12382

def disable_analytics
  @disable_analytics
end

#display_nameString

Required. The display name of the engine. Should be human readable. UTF-8 encoded string with limit of 1024 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


12389
12390
12391
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12389

def display_name
  @display_name
end

#featuresHash<String,String>

Optional. Feature config for the engine to opt in or opt out of features. Supported keys: * *: all features, if it's present, all other feature state settings are ignored. * agent-gallery * no-code-agent-builder * prompt- gallery * model-selector * notebook-lm * people-search * people-search- org-chart * bi-directional-audio * feedback * session-sharing * personalization-memory * personalization-suggested-highlights * mobile-app- access * disable-agent-sharing * disable-image-generation * disable- video-generation * disable-onedrive-upload * disable-talk-to-content * disable-google-drive-upload * disable-welcome-emails * disable-canvas * canvas-workspace * disable-skills * disable-projects * enable-end-user- sharing-with-groups * single-agent-orchestration * multi-agent- orchestration * cross-product-intelligence * deep-research Corresponds to the JSON property features

Returns:

  • (Hash<String,String>)


12405
12406
12407
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12405

def features
  @features
end

#industry_verticalString

Optional. The industry vertical that the engine registers. The restriction of the Engine industry vertical is based on DataStore: Vertical on Engine has to match vertical of the DataStore linked to the engine. Corresponds to the JSON property industryVertical

Returns:

  • (String)


12412
12413
12414
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12412

def industry_vertical
  @industry_vertical
end

#knowledge_graph_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngineKnowledgeGraphConfig

Configuration message for the Knowledge Graph. Corresponds to the JSON property knowledgeGraphConfig



12417
12418
12419
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12417

def knowledge_graph_config
  @knowledge_graph_config
end

#marketplace_agent_visibilityString

Optional. The visibility of marketplace agents in the agent gallery. Corresponds to the JSON property marketplaceAgentVisibility

Returns:

  • (String)


12422
12423
12424
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12422

def marketplace_agent_visibility
  @marketplace_agent_visibility
end

#media_recommendation_engine_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngineMediaRecommendationEngineConfig

Additional config specs for a Media Recommendation engine. Corresponds to the JSON property mediaRecommendationEngineConfig



12427
12428
12429
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12427

def media_recommendation_engine_config
  @media_recommendation_engine_config
end

#model_configsHash<String,String>

Optional. Maps a model name to its specific configuration for this engine. This allows admin users to turn on/off individual models. This only stores models whose states are overridden by the admin. When the state is unspecified, or model_configs is empty for this model, the system will decide if this model should be available or not based on the default configuration. For example, a preview model should be disabled by default if the admin has not chosen to enable it. Corresponds to the JSON property modelConfigs

Returns:

  • (Hash<String,String>)


12438
12439
12440
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12438

def model_configs
  @model_configs
end

#nameString

Immutable. Identifier. The fully qualified resource name of the engine. This field must be a UTF-8 encoded string with a length limit of 1024 characters. Format: projects/project/locations/location/collections/collection/ engines/engine`engine should be 1-63 characters, and valid characters are / a-z0-9*/. Otherwise, an INVALID_ARGUMENT error is returned. Corresponds to the JSON propertyname`

Returns:

  • (String)


12447
12448
12449
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12447

def name
  @name
end

#observability_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaObservabilityConfig

Observability config for a resource. Corresponds to the JSON property observabilityConfig



12452
12453
12454
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12452

def observability_config
  @observability_config
end

#procurement_contact_emailsArray<String>

Optional. The emails of the procurement contacts. Corresponds to the JSON property procurementContactEmails

Returns:

  • (Array<String>)


12457
12458
12459
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12457

def procurement_contact_emails
  @procurement_contact_emails
end

#recommendation_metadataGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngineRecommendationMetadata

Additional information of a recommendation engine. Corresponds to the JSON property recommendationMetadata



12462
12463
12464
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12462

def 
  @recommendation_metadata
end

#search_engine_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngineSearchEngineConfig

Configurations for a Search Engine. Corresponds to the JSON property searchEngineConfig



12467
12468
12469
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12467

def search_engine_config
  @search_engine_config
end

#similar_documents_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngineSimilarDocumentsEngineConfig

Additional config specs for a similar-items engine. Corresponds to the JSON property similarDocumentsConfig



12472
12473
12474
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12472

def similar_documents_config
  @similar_documents_config
end

#solution_typeString

Required. The solutions of the engine. Corresponds to the JSON property solutionType

Returns:

  • (String)


12477
12478
12479
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12477

def solution_type
  @solution_type
end

#update_timeString

Output only. Timestamp the Recommendation Engine was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


12482
12483
12484
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12482

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12489
12490
12491
12492
12493
12494
12495
12496
12497
12498
12499
12500
12501
12502
12503
12504
12505
12506
12507
12508
12509
12510
12511
12512
12513
12514
12515
12516
12517
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12489

def update!(**args)
  @agent_gateway_setting = args[:agent_gateway_setting] if args.key?(:agent_gateway_setting)
  @app_type = args[:app_type] if args.key?(:app_type)
  @associated_agent_registry = args[:associated_agent_registry] if args.key?(:associated_agent_registry)
  @chat_engine_config = args[:chat_engine_config] if args.key?(:chat_engine_config)
  @chat_engine_metadata = args[:chat_engine_metadata] if args.key?(:chat_engine_metadata)
  @cmek_config = args[:cmek_config] if args.key?(:cmek_config)
  @common_config = args[:common_config] if args.key?(:common_config)
  @configurable_billing_approach = args[:configurable_billing_approach] if args.key?(:configurable_billing_approach)
  @connector_tenant_info = args[:connector_tenant_info] if args.key?(:connector_tenant_info)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_store_ids = args[:data_store_ids] if args.key?(:data_store_ids)
  @disable_analytics = args[:disable_analytics] if args.key?(:disable_analytics)
  @display_name = args[:display_name] if args.key?(:display_name)
  @features = args[:features] if args.key?(:features)
  @industry_vertical = args[:industry_vertical] if args.key?(:industry_vertical)
  @knowledge_graph_config = args[:knowledge_graph_config] if args.key?(:knowledge_graph_config)
  @marketplace_agent_visibility = args[:marketplace_agent_visibility] if args.key?(:marketplace_agent_visibility)
  @media_recommendation_engine_config = args[:media_recommendation_engine_config] if args.key?(:media_recommendation_engine_config)
  @model_configs = args[:model_configs] if args.key?(:model_configs)
  @name = args[:name] if args.key?(:name)
  @observability_config = args[:observability_config] if args.key?(:observability_config)
  @procurement_contact_emails = args[:procurement_contact_emails] if args.key?(:procurement_contact_emails)
  @recommendation_metadata = args[:recommendation_metadata] if args.key?(:recommendation_metadata)
  @search_engine_config = args[:search_engine_config] if args.key?(:search_engine_config)
  @similar_documents_config = args[:similar_documents_config] if args.key?(:similar_documents_config)
  @solution_type = args[:solution_type] if args.key?(:solution_type)
  @update_time = args[:update_time] if args.key?(:update_time)
end