Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngineChatEngineConfig
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngineChatEngineConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Configurations for a Chat Engine.
Instance Attribute Summary collapse
-
#agent_creation_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngineChatEngineConfigAgentCreationConfig
Configurations for generating a Dialogflow agent.
-
#allow_cross_region ⇒ Boolean
(also: #allow_cross_region?)
Optional.
-
#dialogflow_agent_to_link ⇒ String
The resource name of an exist Dialogflow agent to link to this Chat Engine.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaEngineChatEngineConfig
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaEngineChatEngineConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaEngineChatEngineConfig
Returns a new instance of GoogleCloudDiscoveryengineV1alphaEngineChatEngineConfig.
12534 12535 12536 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12534 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_creation_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngineChatEngineConfigAgentCreationConfig
Configurations for generating a Dialogflow agent. Note that these
configurations are one-time consumed by and passed to Dialogflow service. It
means they cannot be retrieved using EngineService.GetEngine or EngineService.
ListEngines API after engine creation.
Corresponds to the JSON property agentCreationConfig
12509 12510 12511 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12509 def agent_creation_config @agent_creation_config end |
#allow_cross_region ⇒ Boolean Also known as: allow_cross_region?
Optional. If the flag set to true, we allow the agent and engine are in
different locations, otherwise the agent and engine are required to be in the
same location. The flag is set to false by default. Note that the
allow_cross_region are one-time consumed by and passed to EngineService.
CreateEngine. It means they cannot be retrieved using EngineService.GetEngine
or EngineService.ListEngines API after engine creation.
Corresponds to the JSON property allowCrossRegion
12519 12520 12521 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12519 def allow_cross_region @allow_cross_region end |
#dialogflow_agent_to_link ⇒ String
The resource name of an exist Dialogflow agent to link to this Chat Engine.
Customers can either provide agent_creation_config to create agent or
provide an agent name that links the agent with the Chat engine. Format:
projects//locations//agents/. Note that the dialogflow_agent_to_link are
one-time consumed by and passed to Dialogflow service. It means they cannot be
retrieved using EngineService.GetEngine or EngineService.ListEngines API after
engine creation. Use ChatEngineMetadata.dialogflow_agent for actual agent
association after Engine is created.
Corresponds to the JSON property dialogflowAgentToLink
12532 12533 12534 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12532 def dialogflow_agent_to_link @dialogflow_agent_to_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12539 12540 12541 12542 12543 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12539 def update!(**args) @agent_creation_config = args[:agent_creation_config] if args.key?(:agent_creation_config) @allow_cross_region = args[:allow_cross_region] if args.key?(:allow_cross_region) @dialogflow_agent_to_link = args[:dialogflow_agent_to_link] if args.key?(:dialogflow_agent_to_link) end |