Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngineChatEngineConfigAgentCreationConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Configurations for generating a Dialogflow agent. Note that these configurations are one-time consumed by and passed to Dialogflow service. It means they cannot be retrieved using EngineService.GetEngine or EngineService. ListEngines API after engine creation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaEngineChatEngineConfigAgentCreationConfig

Returns a new instance of GoogleCloudDiscoveryengineV1alphaEngineChatEngineConfigAgentCreationConfig.



12600
12601
12602
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12600

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#businessString

Name of the company, organization or other entity that the agent represents. Used for knowledge connector LLM prompt and for knowledge search. Corresponds to the JSON property business

Returns:

  • (String)


12578
12579
12580
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12578

def business
  @business
end

#default_language_codeString

Required. The default language of the agent as a language tag. See Language Support for a list of the currently supported language codes. Corresponds to the JSON property defaultLanguageCode

Returns:

  • (String)


12585
12586
12587
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12585

def default_language_code
  @default_language_code
end

#locationString

Agent location for Agent creation, supported values: global/us/eu. If not provided, us Engine will create Agent using us-central-1 by default; eu Engine will create Agent using eu-west-1 by default. Corresponds to the JSON property location

Returns:

  • (String)


12592
12593
12594
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12592

def location
  @location
end

#time_zoneString

Required. The time zone of the agent from the time zone database, e.g., America/New_York, Europe/Paris. Corresponds to the JSON property timeZone

Returns:

  • (String)


12598
12599
12600
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12598

def time_zone
  @time_zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12605
12606
12607
12608
12609
12610
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12605

def update!(**args)
  @business = args[:business] if args.key?(:business)
  @default_language_code = args[:default_language_code] if args.key?(:default_language_code)
  @location = args[:location] if args.key?(:location)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
end