Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngineChatEngineConfigAgentCreationConfig
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngineChatEngineConfigAgentCreationConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Configurations for generating a Dialogflow agent. Note that these configurations are one-time consumed by and passed to Dialogflow service. It means they cannot be retrieved using EngineService.GetEngine or EngineService. ListEngines API after engine creation.
Instance Attribute Summary collapse
-
#business ⇒ String
Name of the company, organization or other entity that the agent represents.
-
#default_language_code ⇒ String
Required.
-
#location ⇒ String
Agent location for Agent creation, supported values: global/us/eu.
-
#time_zone ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaEngineChatEngineConfigAgentCreationConfig
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaEngineChatEngineConfigAgentCreationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaEngineChatEngineConfigAgentCreationConfig
Returns a new instance of GoogleCloudDiscoveryengineV1alphaEngineChatEngineConfigAgentCreationConfig.
12006 12007 12008 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12006 def initialize(**args) update!(**args) end |
Instance Attribute Details
#business ⇒ String
Name of the company, organization or other entity that the agent represents.
Used for knowledge connector LLM prompt and for knowledge search.
Corresponds to the JSON property business
11984 11985 11986 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11984 def business @business end |
#default_language_code ⇒ String
Required. The default language of the agent as a language tag. See Language
Support for a
list of the currently supported language codes.
Corresponds to the JSON property defaultLanguageCode
11991 11992 11993 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11991 def default_language_code @default_language_code end |
#location ⇒ String
Agent location for Agent creation, supported values: global/us/eu. If not
provided, us Engine will create Agent using us-central-1 by default; eu Engine
will create Agent using eu-west-1 by default.
Corresponds to the JSON property location
11998 11999 12000 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11998 def location @location end |
#time_zone ⇒ String
Required. The time zone of the agent from the time zone database, e.g., America/New_York, Europe/Paris.
Corresponds to the JSON property timeZone
12004 12005 12006 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12004 def time_zone @time_zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12011 12012 12013 12014 12015 12016 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12011 def update!(**args) @business = args[:business] if args.key?(:business) @default_language_code = args[:default_language_code] if args.key?(:default_language_code) @location = args[:location] if args.key?(:location) @time_zone = args[:time_zone] if args.key?(:time_zone) end |