Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngineCommonConfig
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngineCommonConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Common configurations for an Engine.
Instance Attribute Summary collapse
-
#company_name ⇒ String
The name of the company, business or entity that is associated with the engine.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaEngineCommonConfig
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaEngineCommonConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaEngineCommonConfig
Returns a new instance of GoogleCloudDiscoveryengineV1alphaEngineCommonConfig.
12668 12669 12670 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12668 def initialize(**args) update!(**args) end |
Instance Attribute Details
#company_name ⇒ String
The name of the company, business or entity that is associated with the engine.
Setting this may help improve LLM related features.
Corresponds to the JSON property companyName
12666 12667 12668 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12666 def company_name @company_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12673 12674 12675 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12673 def update!(**args) @company_name = args[:company_name] if args.key?(:company_name) end |