Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngineKnowledgeGraphConfig
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngineKnowledgeGraphConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Configuration message for the Knowledge Graph.
Instance Attribute Summary collapse
-
#cloud_knowledge_graph_types ⇒ Array<String>
Specify entity types to support.
-
#enable_cloud_knowledge_graph ⇒ Boolean
(also: #enable_cloud_knowledge_graph?)
Whether to enable the Cloud Knowledge Graph for the engine.
-
#enable_private_knowledge_graph ⇒ Boolean
(also: #enable_private_knowledge_graph?)
Whether to enable the Private Knowledge Graph for the engine.
-
#feature_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngineKnowledgeGraphConfigFeatureConfig
Feature config for the Knowledge Graph.
-
#private_knowledge_graph_types ⇒ Array<String>
Specify entity types to support.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaEngineKnowledgeGraphConfig
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaEngineKnowledgeGraphConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaEngineKnowledgeGraphConfig
Returns a new instance of GoogleCloudDiscoveryengineV1alphaEngineKnowledgeGraphConfig.
11983 11984 11985 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11983 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cloud_knowledge_graph_types ⇒ Array<String>
Specify entity types to support.
Corresponds to the JSON property cloudKnowledgeGraphTypes
11957 11958 11959 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11957 def cloud_knowledge_graph_types @cloud_knowledge_graph_types end |
#enable_cloud_knowledge_graph ⇒ Boolean Also known as: enable_cloud_knowledge_graph?
Whether to enable the Cloud Knowledge Graph for the engine. Defaults to false
if not specified.
Corresponds to the JSON property enableCloudKnowledgeGraph
11963 11964 11965 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11963 def enable_cloud_knowledge_graph @enable_cloud_knowledge_graph end |
#enable_private_knowledge_graph ⇒ Boolean Also known as: enable_private_knowledge_graph?
Whether to enable the Private Knowledge Graph for the engine. Defaults to
false if not specified.
Corresponds to the JSON property enablePrivateKnowledgeGraph
11970 11971 11972 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11970 def enable_private_knowledge_graph @enable_private_knowledge_graph end |
#feature_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngineKnowledgeGraphConfigFeatureConfig
Feature config for the Knowledge Graph.
Corresponds to the JSON property featureConfig
11976 11977 11978 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11976 def feature_config @feature_config end |
#private_knowledge_graph_types ⇒ Array<String>
Specify entity types to support.
Corresponds to the JSON property privateKnowledgeGraphTypes
11981 11982 11983 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11981 def private_knowledge_graph_types @private_knowledge_graph_types end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11988 11989 11990 11991 11992 11993 11994 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 11988 def update!(**args) @cloud_knowledge_graph_types = args[:cloud_knowledge_graph_types] if args.key?(:cloud_knowledge_graph_types) @enable_cloud_knowledge_graph = args[:enable_cloud_knowledge_graph] if args.key?(:enable_cloud_knowledge_graph) @enable_private_knowledge_graph = args[:enable_private_knowledge_graph] if args.key?(:enable_private_knowledge_graph) @feature_config = args[:feature_config] if args.key?(:feature_config) @private_knowledge_graph_types = args[:private_knowledge_graph_types] if args.key?(:private_knowledge_graph_types) end |