Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngineRecommendationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngineRecommendationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Additional information of a recommendation engine.
Instance Attribute Summary collapse
-
#data_state ⇒ String
Output only.
-
#last_train_time ⇒ String
Output only.
-
#last_tune_time ⇒ String
Output only.
-
#serving_state ⇒ String
Output only.
-
#tuning_operation ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaEngineRecommendationMetadata
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaEngineRecommendationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaEngineRecommendationMetadata
Returns a new instance of GoogleCloudDiscoveryengineV1alphaEngineRecommendationMetadata.
12937 12938 12939 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12937 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_state ⇒ String
Output only. The state of data requirements for this engine: DATA_OK and
DATA_ERROR. Engine cannot be trained if the data is in DATA_ERROR state.
Engine can have DATA_ERROR state even if serving state is ACTIVE: engines
were trained successfully before, but cannot be refreshed because the
underlying engine no longer has sufficient data for training.
Corresponds to the JSON property dataState
12908 12909 12910 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12908 def data_state @data_state end |
#last_train_time ⇒ String
Output only. The timestamp when the latest successful training finished. Only
applicable on Media Recommendation engines.
Corresponds to the JSON property lastTrainTime
12914 12915 12916 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12914 def last_train_time @last_train_time end |
#last_tune_time ⇒ String
Output only. The timestamp when the latest successful tune finished. Only
applicable on Media Recommendation engines.
Corresponds to the JSON property lastTuneTime
12920 12921 12922 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12920 def last_tune_time @last_tune_time end |
#serving_state ⇒ String
Output only. The serving state of the engine: ACTIVE, NOT_ACTIVE.
Corresponds to the JSON property servingState
12925 12926 12927 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12925 def serving_state @serving_state end |
#tuning_operation ⇒ String
Output only. The latest tune operation id associated with the engine. Only
applicable on Media Recommendation engines. If present, this operation id can
be used to determine if there is an ongoing tune for this engine. To check the
operation status, send the GetOperation request with this operation id in the
engine resource format. If no tuning has happened for this engine, the string
is empty.
Corresponds to the JSON property tuningOperation
12935 12936 12937 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12935 def tuning_operation @tuning_operation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12942 12943 12944 12945 12946 12947 12948 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12942 def update!(**args) @data_state = args[:data_state] if args.key?(:data_state) @last_train_time = args[:last_train_time] if args.key?(:last_train_time) @last_tune_time = args[:last_tune_time] if args.key?(:last_tune_time) @serving_state = args[:serving_state] if args.key?(:serving_state) @tuning_operation = args[:tuning_operation] if args.key?(:tuning_operation) end |