Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngineRecommendationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngineRecommendationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Additional information of a recommendation engine.
Instance Attribute Summary collapse
-
#data_state ⇒ String
Output only.
-
#last_train_time ⇒ String
Output only.
-
#last_tune_time ⇒ String
Output only.
-
#serving_state ⇒ String
Output only.
-
#tuning_operation ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaEngineRecommendationMetadata
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaEngineRecommendationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaEngineRecommendationMetadata
Returns a new instance of GoogleCloudDiscoveryengineV1alphaEngineRecommendationMetadata.
12343 12344 12345 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12343 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_state ⇒ String
Output only. The state of data requirements for this engine: DATA_OK and
DATA_ERROR. Engine cannot be trained if the data is in DATA_ERROR state.
Engine can have DATA_ERROR state even if serving state is ACTIVE: engines
were trained successfully before, but cannot be refreshed because the
underlying engine no longer has sufficient data for training.
Corresponds to the JSON property dataState
12314 12315 12316 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12314 def data_state @data_state end |
#last_train_time ⇒ String
Output only. The timestamp when the latest successful training finished. Only
applicable on Media Recommendation engines.
Corresponds to the JSON property lastTrainTime
12320 12321 12322 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12320 def last_train_time @last_train_time end |
#last_tune_time ⇒ String
Output only. The timestamp when the latest successful tune finished. Only
applicable on Media Recommendation engines.
Corresponds to the JSON property lastTuneTime
12326 12327 12328 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12326 def last_tune_time @last_tune_time end |
#serving_state ⇒ String
Output only. The serving state of the engine: ACTIVE, NOT_ACTIVE.
Corresponds to the JSON property servingState
12331 12332 12333 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12331 def serving_state @serving_state end |
#tuning_operation ⇒ String
Output only. The latest tune operation id associated with the engine. Only
applicable on Media Recommendation engines. If present, this operation id can
be used to determine if there is an ongoing tune for this engine. To check the
operation status, send the GetOperation request with this operation id in the
engine resource format. If no tuning has happened for this engine, the string
is empty.
Corresponds to the JSON property tuningOperation
12341 12342 12343 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12341 def tuning_operation @tuning_operation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12348 12349 12350 12351 12352 12353 12354 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12348 def update!(**args) @data_state = args[:data_state] if args.key?(:data_state) @last_train_time = args[:last_train_time] if args.key?(:last_train_time) @last_tune_time = args[:last_tune_time] if args.key?(:last_tune_time) @serving_state = args[:serving_state] if args.key?(:serving_state) @tuning_operation = args[:tuning_operation] if args.key?(:tuning_operation) end |