Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngineSearchEngineConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Configurations for a Search Engine.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaEngineSearchEngineConfig

Returns a new instance of GoogleCloudDiscoveryengineV1alphaEngineSearchEngineConfig.



13000
13001
13002
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13000

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#required_subscription_tierString

Optional. The required subscription tier of this engine. If the required subscription tier is search, user with higher license tier like assist can still access the standalone app associated with this engine. Web grounding feature is only available on the app if it is set as SubscriptionTier. SUBSCRIPTION_TIER_SEARCH_AND_ASSISTANT. Corresponds to the JSON property requiredSubscriptionTier

Returns:

  • (String)


12986
12987
12988
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12986

def required_subscription_tier
  @required_subscription_tier
end

#search_add_onsArray<String>

The add-on that this search engine enables. Corresponds to the JSON property searchAddOns

Returns:

  • (Array<String>)


12991
12992
12993
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12991

def search_add_ons
  @search_add_ons
end

#search_tierString

The search feature tier of this engine. Different tiers might have different pricing. To learn more, check the pricing documentation. Defaults to SearchTier.SEARCH_TIER_STANDARD if not specified. Corresponds to the JSON property searchTier

Returns:

  • (String)


12998
12999
13000
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12998

def search_tier
  @search_tier
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13005
13006
13007
13008
13009
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13005

def update!(**args)
  @required_subscription_tier = args[:required_subscription_tier] if args.key?(:required_subscription_tier)
  @search_add_ons = args[:search_add_ons] if args.key?(:search_add_ons)
  @search_tier = args[:search_tier] if args.key?(:search_tier)
end