Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEngineSearchEngineConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Configurations for a Search Engine.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaEngineSearchEngineConfig

Returns a new instance of GoogleCloudDiscoveryengineV1alphaEngineSearchEngineConfig.



12955
12956
12957
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12955

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#required_subscription_tierString

Optional. The required subscription tier of this engine. If the required subscription tier is search, user with higher license tier like assist can still access the standalone app associated with this engine. Web grounding feature is only available on the app if it is set as SubscriptionTier. SUBSCRIPTION_TIER_SEARCH_AND_ASSISTANT. Corresponds to the JSON property requiredSubscriptionTier

Returns:

  • (String)


12941
12942
12943
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12941

def required_subscription_tier
  @required_subscription_tier
end

#search_add_onsArray<String>

The add-on that this search engine enables. Corresponds to the JSON property searchAddOns

Returns:

  • (Array<String>)


12946
12947
12948
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12946

def search_add_ons
  @search_add_ons
end

#search_tierString

The search feature tier of this engine. Different tiers might have different pricing. To learn more, check the pricing documentation. Defaults to SearchTier.SEARCH_TIER_STANDARD if not specified. Corresponds to the JSON property searchTier

Returns:

  • (String)


12953
12954
12955
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12953

def search_tier
  @search_tier
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12960
12961
12962
12963
12964
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12960

def update!(**args)
  @required_subscription_tier = args[:required_subscription_tier] if args.key?(:required_subscription_tier)
  @search_add_ons = args[:search_add_ons] if args.key?(:search_add_ons)
  @search_tier = args[:search_tier] if args.key?(:search_tier)
end