Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEvaluation
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEvaluation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
An evaluation is a single execution (or run) of an evaluation process. It encapsulates the state of the evaluation and the resulting data.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#error ⇒ Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#error_samples ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>
Output only.
-
#evaluation_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEvaluationEvaluationSpec
Describes the specification of the evaluation.
-
#name ⇒ String
Identifier.
-
#quality_metrics ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaQualityMetrics
Describes the metrics produced by the evaluation.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaEvaluation
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaEvaluation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaEvaluation
Returns a new instance of GoogleCloudDiscoveryengineV1alphaEvaluation.
13124 13125 13126 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13124 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp the Evaluation was created at.
Corresponds to the JSON property createTime
13080 13081 13082 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13080 def create_time @create_time end |
#end_time ⇒ String
Output only. Timestamp the Evaluation was completed at.
Corresponds to the JSON property endTime
13085 13086 13087 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13085 def end_time @end_time end |
#error ⇒ Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
13095 13096 13097 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13095 def error @error end |
#error_samples ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>
Output only. A sample of errors encountered while processing the request.
Corresponds to the JSON property errorSamples
13100 13101 13102 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13100 def error_samples @error_samples end |
#evaluation_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEvaluationEvaluationSpec
Describes the specification of the evaluation.
Corresponds to the JSON property evaluationSpec
13105 13106 13107 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13105 def evaluation_spec @evaluation_spec end |
#name ⇒ String
Identifier. The full resource name of the Evaluation, in the format of
projects/project/locations/location/evaluations/evaluation`. This field
must be a UTF-8 encoded string with a length limit of 1024 characters.
Corresponds to the JSON propertyname`
13112 13113 13114 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13112 def name @name end |
#quality_metrics ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaQualityMetrics
Describes the metrics produced by the evaluation.
Corresponds to the JSON property qualityMetrics
13117 13118 13119 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13117 def quality_metrics @quality_metrics end |
#state ⇒ String
Output only. The state of the evaluation.
Corresponds to the JSON property state
13122 13123 13124 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13122 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13129 13130 13131 13132 13133 13134 13135 13136 13137 13138 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13129 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @error = args[:error] if args.key?(:error) @error_samples = args[:error_samples] if args.key?(:error_samples) @evaluation_spec = args[:evaluation_spec] if args.key?(:evaluation_spec) @name = args[:name] if args.key?(:name) @quality_metrics = args[:quality_metrics] if args.key?(:quality_metrics) @state = args[:state] if args.key?(:state) end |