Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEvaluation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

An evaluation is a single execution (or run) of an evaluation process. It encapsulates the state of the evaluation and the resulting data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaEvaluation

Returns a new instance of GoogleCloudDiscoveryengineV1alphaEvaluation.



12505
12506
12507
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12505

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp the Evaluation was created at. Corresponds to the JSON property createTime

Returns:

  • (String)


12461
12462
12463
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12461

def create_time
  @create_time
end

#end_timeString

Output only. Timestamp the Evaluation was completed at. Corresponds to the JSON property endTime

Returns:

  • (String)


12466
12467
12468
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12466

def end_time
  @end_time
end

#errorGoogle::Apis::DiscoveryengineV1beta::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



12476
12477
12478
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12476

def error
  @error
end

#error_samplesArray<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>

Output only. A sample of errors encountered while processing the request. Corresponds to the JSON property errorSamples



12481
12482
12483
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12481

def error_samples
  @error_samples
end

#evaluation_specGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaEvaluationEvaluationSpec

Describes the specification of the evaluation. Corresponds to the JSON property evaluationSpec



12486
12487
12488
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12486

def evaluation_spec
  @evaluation_spec
end

#nameString

Identifier. The full resource name of the Evaluation, in the format of projects/project/locations/location/evaluations/evaluation`. This field must be a UTF-8 encoded string with a length limit of 1024 characters. Corresponds to the JSON propertyname`

Returns:

  • (String)


12493
12494
12495
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12493

def name
  @name
end

#quality_metricsGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaQualityMetrics

Describes the metrics produced by the evaluation. Corresponds to the JSON property qualityMetrics



12498
12499
12500
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12498

def quality_metrics
  @quality_metrics
end

#stateString

Output only. The state of the evaluation. Corresponds to the JSON property state

Returns:

  • (String)


12503
12504
12505
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12503

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12510
12511
12512
12513
12514
12515
12516
12517
12518
12519
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12510

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @error = args[:error] if args.key?(:error)
  @error_samples = args[:error_samples] if args.key?(:error_samples)
  @evaluation_spec = args[:evaluation_spec] if args.key?(:evaluation_spec)
  @name = args[:name] if args.key?(:name)
  @quality_metrics = args[:quality_metrics] if args.key?(:quality_metrics)
  @state = args[:state] if args.key?(:state)
end