Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaFieldConfig
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaFieldConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Configurations for fields of a schema. For example, configuring a field is indexable, or searchable.
Instance Attribute Summary collapse
-
#advanced_site_search_data_sources ⇒ Array<String>
If this field is set, only the corresponding source will be indexed for this field.
-
#completable_option ⇒ String
If completable_option is COMPLETABLE_ENABLED, field values are directly used and returned as suggestions for Autocomplete in CompletionService.
-
#dynamic_facetable_option ⇒ String
If dynamic_facetable_option is DYNAMIC_FACETABLE_ENABLED, field values are available for dynamic facet.
-
#field_path ⇒ String
Required.
-
#field_type ⇒ String
Output only.
-
#indexable_option ⇒ String
If indexable_option is INDEXABLE_ENABLED, field values are indexed so that it can be filtered or faceted in SearchService.Search.
-
#key_property_type ⇒ String
Output only.
-
#metatag_name ⇒ String
Optional.
-
#recs_filterable_option ⇒ String
If recs_filterable_option is FILTERABLE_ENABLED, field values are filterable by filter expression in RecommendationService.Recommend.
-
#retrievable_option ⇒ String
If retrievable_option is RETRIEVABLE_ENABLED, field values are included in the search results.
-
#schema_org_paths ⇒ Array<String>
Field paths for indexing custom attribute from schema.org data.
-
#searchable_field_importance ⇒ String
Optional.
-
#searchable_option ⇒ String
If searchable_option is SEARCHABLE_ENABLED, field values are searchable by text queries in SearchService.Search.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaFieldConfig
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaFieldConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaFieldConfig
Returns a new instance of GoogleCloudDiscoveryengineV1alphaFieldConfig.
13478 13479 13480 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13478 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advanced_site_search_data_sources ⇒ Array<String>
If this field is set, only the corresponding source will be indexed for this
field. Otherwise, the values from different sources are merged. Assuming a
page with in meta tag, and in page map: if this enum is set to METATAGS,
we will only index ; if this enum is not set, we will merge them and index
.
Corresponds to the JSON property advancedSiteSearchDataSources
13353 13354 13355 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13353 def advanced_site_search_data_sources @advanced_site_search_data_sources end |
#completable_option ⇒ String
If completable_option is COMPLETABLE_ENABLED, field values are directly used
and returned as suggestions for Autocomplete in CompletionService.
CompleteQuery. If completable_option is unset, the server behavior defaults to
COMPLETABLE_DISABLED for fields that support setting completable options,
which are just string fields. For those fields that do not support setting
completable options, the server will skip completable option setting, and
setting completable_option for those fields will throw INVALID_ARGUMENT
error.
Corresponds to the JSON property completableOption
13365 13366 13367 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13365 def completable_option @completable_option end |
#dynamic_facetable_option ⇒ String
If dynamic_facetable_option is DYNAMIC_FACETABLE_ENABLED, field values are
available for dynamic facet. Could only be DYNAMIC_FACETABLE_DISABLED if
FieldConfig.indexable_option is INDEXABLE_DISABLED. Otherwise, an
INVALID_ARGUMENT error will be returned. If dynamic_facetable_option is unset,
the server behavior defaults to DYNAMIC_FACETABLE_DISABLED for fields that
support setting dynamic facetable options. For those fields that do not
support setting dynamic facetable options, such as object and boolean, the
server will skip dynamic facetable option setting, and setting
dynamic_facetable_option for those fields will throw INVALID_ARGUMENT error.
Corresponds to the JSON property dynamicFacetableOption
13378 13379 13380 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13378 def dynamic_facetable_option @dynamic_facetable_option end |
#field_path ⇒ String
Required. Field path of the schema field. For example: title, description,
release_info.release_year.
Corresponds to the JSON property fieldPath
13384 13385 13386 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13384 def field_path @field_path end |
#field_type ⇒ String
Output only. Raw type of the field.
Corresponds to the JSON property fieldType
13389 13390 13391 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13389 def field_type @field_type end |
#indexable_option ⇒ String
If indexable_option is INDEXABLE_ENABLED, field values are indexed so that it
can be filtered or faceted in SearchService.Search. If indexable_option is
unset, the server behavior defaults to INDEXABLE_DISABLED for fields that
support setting indexable options. For those fields that do not support
setting indexable options, such as object and boolean and key properties,
the server will skip indexable_option setting, and setting indexable_option
for those fields will throw INVALID_ARGUMENT error.
Corresponds to the JSON property indexableOption
13400 13401 13402 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13400 def indexable_option @indexable_option end |
#key_property_type ⇒ String
Output only. Type of the key property that this field is mapped to. Empty
string if this is not annotated as mapped to a key property. Example types are
title, description. Full list is defined by keyPropertyMapping in the
schema field annotation. If the schema field has a KeyPropertyMapping
annotation, indexable_option and searchable_option of this field cannot be
modified.
Corresponds to the JSON property keyPropertyType
13410 13411 13412 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13410 def key_property_type @key_property_type end |
#metatag_name ⇒ String
Optional. The metatag name found in the HTML page. If user defines this field,
the value of this metatag name will be used to extract metatag. If the user
does not define this field, the FieldConfig.field_path will be used to extract
metatag.
Corresponds to the JSON property metatagName
13418 13419 13420 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13418 def @metatag_name end |
#recs_filterable_option ⇒ String
If recs_filterable_option is FILTERABLE_ENABLED, field values are filterable
by filter expression in RecommendationService.Recommend. If FILTERABLE_ENABLED
but the field type is numerical, field values are not filterable by text
queries in RecommendationService.Recommend. Only textual fields are supported.
If recs_filterable_option is unset, the default setting is FILTERABLE_DISABLED
for fields that support setting filterable options. When a field set to [
FILTERABLE_DISABLED] is filtered, a warning is generated and an empty result
is returned.
Corresponds to the JSON property recsFilterableOption
13430 13431 13432 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13430 def recs_filterable_option @recs_filterable_option end |
#retrievable_option ⇒ String
If retrievable_option is RETRIEVABLE_ENABLED, field values are included in the
search results. If retrievable_option is unset, the server behavior defaults
to RETRIEVABLE_DISABLED for fields that support setting retrievable options.
For those fields that do not support setting retrievable options, such as
object and boolean, the server will skip retrievable option setting, and
setting retrievable_option for those fields will throw INVALID_ARGUMENT
error.
Corresponds to the JSON property retrievableOption
13441 13442 13443 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13441 def retrievable_option @retrievable_option end |
#schema_org_paths ⇒ Array<String>
Field paths for indexing custom attribute from schema.org data. More details
of schema.org and its defined types can be found at schema.org. It is only used on advanced site search schema. Currently only
support full path from root. The full path to a field is constructed by
concatenating field names, starting from _root, with a period . as the
delimiter. Examples: * Publish date of the root: _root.datePublished * Publish
date of the reviews: _root.review.datePublished
Corresponds to the JSON property schemaOrgPaths
13452 13453 13454 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13452 def schema_org_paths @schema_org_paths end |
#searchable_field_importance ⇒ String
Optional. Specifies the importance of the field when searchable_option is
SEARCHABLE_ENABLED. If searchable_option is SEARCHABLE_DISABLED, this
field is ignored. If searchable_option is SEARCHABLE_ENABLED and this is
SEARCHABLE_FIELD_IMPORTANCE_UNSPECIFIED, it behaves as DEFAULT_IMPORTANCE.
For more information, see Weight searchable fields.
Corresponds to the JSON property searchableFieldImportance
13462 13463 13464 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13462 def searchable_field_importance @searchable_field_importance end |
#searchable_option ⇒ String
If searchable_option is SEARCHABLE_ENABLED, field values are searchable by
text queries in SearchService.Search. If SEARCHABLE_ENABLED but field type is
numerical, field values will not be searchable by text queries in
SearchService.Search, as there are no text values associated to numerical
fields. If searchable_option is unset, the server behavior defaults to
SEARCHABLE_DISABLED for fields that support setting searchable options. Only
string fields that have no key property mapping support setting
searchable_option. For those fields that do not support setting searchable
options, the server will skip searchable option setting, and setting
searchable_option for those fields will throw INVALID_ARGUMENT error.
Corresponds to the JSON property searchableOption
13476 13477 13478 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13476 def searchable_option @searchable_option end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13483 13484 13485 13486 13487 13488 13489 13490 13491 13492 13493 13494 13495 13496 13497 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13483 def update!(**args) @advanced_site_search_data_sources = args[:advanced_site_search_data_sources] if args.key?(:advanced_site_search_data_sources) @completable_option = args[:completable_option] if args.key?(:completable_option) @dynamic_facetable_option = args[:dynamic_facetable_option] if args.key?(:dynamic_facetable_option) @field_path = args[:field_path] if args.key?(:field_path) @field_type = args[:field_type] if args.key?(:field_type) @indexable_option = args[:indexable_option] if args.key?(:indexable_option) @key_property_type = args[:key_property_type] if args.key?(:key_property_type) @metatag_name = args[:metatag_name] if args.key?(:metatag_name) @recs_filterable_option = args[:recs_filterable_option] if args.key?(:recs_filterable_option) @retrievable_option = args[:retrievable_option] if args.key?(:retrievable_option) @schema_org_paths = args[:schema_org_paths] if args.key?(:schema_org_paths) @searchable_field_importance = args[:searchable_field_importance] if args.key?(:searchable_field_importance) @searchable_option = args[:searchable_option] if args.key?(:searchable_option) end |