Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaIdentityScheduleConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

The configuration for the identity data synchronization runs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaIdentityScheduleConfig

Returns a new instance of GoogleCloudDiscoveryengineV1alphaIdentityScheduleConfig.



12814
12815
12816
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12814

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_sync_timeGoogle::Apis::DiscoveryengineV1beta::GoogleTypeDateTime

Represents civil time (or occasionally physical time). This type can represent a civil time in one of a few possible ways: * When utc_offset is set and time_zone is unset: a civil time on a calendar day with a particular offset from UTC. * When time_zone is set and utc_offset is unset: a civil time on a calendar day in a particular time zone. * When neither time_zone nor utc_offset is set: a civil time on a calendar day in local time. The date is relative to the Proleptic Gregorian Calendar. If year, month, or day are 0, the DateTime is considered not to have a specific year, month, or day respectively. This type may also be used to represent a physical time if all the date and time fields are set and either case of the time_offset oneof is set. Consider using Timestamp message for physical time instead. If your use case also would like to store the user's timezone, that can be done in another field. This type is more flexible than some applications may want. Make sure to document and validate your application's limitations. Corresponds to the JSON property nextSyncTime



12804
12805
12806
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12804

def next_sync_time
  @next_sync_time
end

#refresh_intervalString

Optional. The refresh interval to sync the Access Control List information for the documents ingested by this connector. If not set, the access control list will be refreshed at the default interval of 30 minutes. The identity refresh interval can be at least 30 minutes and at most 7 days. Corresponds to the JSON property refreshInterval

Returns:

  • (String)


12812
12813
12814
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12812

def refresh_interval
  @refresh_interval
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12819
12820
12821
12822
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12819

def update!(**args)
  @next_sync_time = args[:next_sync_time] if args.key?(:next_sync_time)
  @refresh_interval = args[:refresh_interval] if args.key?(:refresh_interval)
end