Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaImportCompletionSuggestionsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Response of the CompletionService.ImportCompletionSuggestions method. If the long running operation is done, this message is returned by the google. longrunning.Operations.response field if the operation is successful.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaImportCompletionSuggestionsResponse

Returns a new instance of GoogleCloudDiscoveryengineV1alphaImportCompletionSuggestionsResponse.



13629
13630
13631
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13629

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaImportErrorConfig

Configuration of destination for Import related errors. Corresponds to the JSON property errorConfig



13622
13623
13624
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13622

def error_config
  @error_config
end

#error_samplesArray<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>

A sample of errors encountered while processing the request. Corresponds to the JSON property errorSamples



13627
13628
13629
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13627

def error_samples
  @error_samples
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13634
13635
13636
13637
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13634

def update!(**args)
  @error_config = args[:error_config] if args.key?(:error_config)
  @error_samples = args[:error_samples] if args.key?(:error_samples)
end