Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaImportCompletionSuggestionsResponse
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaImportCompletionSuggestionsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Response of the CompletionService.ImportCompletionSuggestions method. If the long running operation is done, this message is returned by the google. longrunning.Operations.response field if the operation is successful.
Instance Attribute Summary collapse
-
#error_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaImportErrorConfig
Configuration of destination for Import related errors.
-
#error_samples ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>
A sample of errors encountered while processing the request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaImportCompletionSuggestionsResponse
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaImportCompletionSuggestionsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaImportCompletionSuggestionsResponse
Returns a new instance of GoogleCloudDiscoveryengineV1alphaImportCompletionSuggestionsResponse.
12924 12925 12926 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12924 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaImportErrorConfig
Configuration of destination for Import related errors.
Corresponds to the JSON property errorConfig
12917 12918 12919 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12917 def error_config @error_config end |
#error_samples ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>
A sample of errors encountered while processing the request.
Corresponds to the JSON property errorSamples
12922 12923 12924 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12922 def error_samples @error_samples end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12929 12930 12931 12932 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 12929 def update!(**args) @error_config = args[:error_config] if args.key?(:error_config) @error_samples = args[:error_samples] if args.key?(:error_samples) end |