Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaImportDocumentsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Response of the ImportDocumentsRequest. If the long running operation is done, then this message is returned by the google.longrunning.Operations.response field if the operation was successful.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaImportDocumentsResponse

Returns a new instance of GoogleCloudDiscoveryengineV1alphaImportDocumentsResponse.



13680
13681
13682
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13680

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaImportErrorConfig

Configuration of destination for Import related errors. Corresponds to the JSON property errorConfig



13673
13674
13675
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13673

def error_config
  @error_config
end

#error_samplesArray<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>

A sample of errors encountered while processing the request. Corresponds to the JSON property errorSamples



13678
13679
13680
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13678

def error_samples
  @error_samples
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13685
13686
13687
13688
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13685

def update!(**args)
  @error_config = args[:error_config] if args.key?(:error_config)
  @error_samples = args[:error_samples] if args.key?(:error_samples)
end