Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaImportIdentityMappingsResponse
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaImportIdentityMappingsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Response message for IdentityMappingStoreService.ImportIdentityMappings
Instance Attribute Summary collapse
-
#error_samples ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>
A sample of errors encountered while processing the request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaImportIdentityMappingsResponse
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaImportIdentityMappingsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaImportIdentityMappingsResponse
Returns a new instance of GoogleCloudDiscoveryengineV1alphaImportIdentityMappingsResponse.
13037 13038 13039 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13037 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_samples ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>
A sample of errors encountered while processing the request.
Corresponds to the JSON property errorSamples
13035 13036 13037 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13035 def error_samples @error_samples end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13042 13043 13044 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13042 def update!(**args) @error_samples = args[:error_samples] if args.key?(:error_samples) end |