Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaImportSampleQueriesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Response of the SampleQueryService.ImportSampleQueries method. If the long running operation is done, this message is returned by the google.longrunning. Operations.response field if the operation is successful.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaImportSampleQueriesResponse

Returns a new instance of GoogleCloudDiscoveryengineV1alphaImportSampleQueriesResponse.



13218
13219
13220
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13218

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaImportErrorConfig

Configuration of destination for Import related errors. Corresponds to the JSON property errorConfig



13211
13212
13213
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13211

def error_config
  @error_config
end

#error_samplesArray<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>

A sample of errors encountered while processing the request. Corresponds to the JSON property errorSamples



13216
13217
13218
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13216

def error_samples
  @error_samples
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13223
13224
13225
13226
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13223

def update!(**args)
  @error_config = args[:error_config] if args.key?(:error_config)
  @error_samples = args[:error_samples] if args.key?(:error_samples)
end