Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaImportSampleQueriesResponse
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaImportSampleQueriesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Response of the SampleQueryService.ImportSampleQueries method. If the long running operation is done, this message is returned by the google.longrunning. Operations.response field if the operation is successful.
Instance Attribute Summary collapse
-
#error_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaImportErrorConfig
Configuration of destination for Import related errors.
-
#error_samples ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>
A sample of errors encountered while processing the request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaImportSampleQueriesResponse
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaImportSampleQueriesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaImportSampleQueriesResponse
Returns a new instance of GoogleCloudDiscoveryengineV1alphaImportSampleQueriesResponse.
13108 13109 13110 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13108 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaImportErrorConfig
Configuration of destination for Import related errors.
Corresponds to the JSON property errorConfig
13101 13102 13103 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13101 def error_config @error_config end |
#error_samples ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>
A sample of errors encountered while processing the request.
Corresponds to the JSON property errorSamples
13106 13107 13108 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13106 def error_samples @error_samples end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13113 13114 13115 13116 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13113 def update!(**args) @error_config = args[:error_config] if args.key?(:error_config) @error_samples = args[:error_samples] if args.key?(:error_samples) end |