Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaLicenseConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Information about users' licenses.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaLicenseConfig

Returns a new instance of GoogleCloudDiscoveryengineV1alphaLicenseConfig.



14270
14271
14272
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14270

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#alert_policy_resource_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAlertPolicyResourceConfig

The resource level alert config. Used in: * UserLicense * EngineUserData The AlertPolicyConfig in data connector is of same usage. No easy way to migrate. Corresponds to the JSON property alertPolicyResourceConfig



14169
14170
14171
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14169

def alert_policy_resource_config
  @alert_policy_resource_config
end

#auto_renewBoolean Also known as: auto_renew?

Optional. Whether the license config should be auto renewed when it reaches the end date. Corresponds to the JSON property autoRenew

Returns:

  • (Boolean)


14175
14176
14177
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14175

def auto_renew
  @auto_renew
end

#early_terminatedBoolean Also known as: early_terminated?

Output only. Indication of whether the subscription is terminated earlier than the expiration date. This is usually terminated by pipeline once the subscription gets terminated from subsv3. Corresponds to the JSON property earlyTerminated

Returns:

  • (Boolean)


14183
14184
14185
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14183

def early_terminated
  @early_terminated
end

#early_termination_dateGoogle::Apis::DiscoveryengineV1beta::GoogleTypeDate

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property earlyTerminationDate



14196
14197
14198
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14196

def early_termination_date
  @early_termination_date
end

#end_dateGoogle::Apis::DiscoveryengineV1beta::GoogleTypeDate

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property endDate



14208
14209
14210
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14208

def end_date
  @end_date
end

#free_trialBoolean Also known as: free_trial?

Optional. Whether the license config is for free trial. Corresponds to the JSON property freeTrial

Returns:

  • (Boolean)


14213
14214
14215
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14213

def free_trial
  @free_trial
end

#gemini_bundleBoolean Also known as: gemini_bundle?

Output only. Whether the license config is for Gemini bundle. Corresponds to the JSON property geminiBundle

Returns:

  • (Boolean)


14219
14220
14221
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14219

def gemini_bundle
  @gemini_bundle
end

#last_user_update_timeString

Optional. Timestamp of the most recent user-initiated update (seat count change or subscription term change). Unlike update_time, this field is only stamped when a customer explicitly updates the license (e.g. via the UI), and is not touched by system-driven writes (subscription pipeline, BALC propagation, etc.). Corresponds to the JSON property lastUserUpdateTime

Returns:

  • (String)


14229
14230
14231
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14229

def last_user_update_time
  @last_user_update_time
end

#license_countFixnum

Required. Number of licenses purchased. Corresponds to the JSON property licenseCount

Returns:

  • (Fixnum)


14234
14235
14236
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14234

def license_count
  @license_count
end

#nameString

Immutable. Identifier. The fully qualified resource name of the license config. Format: projects/project/locations/location/licenseConfigs/ license_config` Corresponds to the JSON propertyname`

Returns:

  • (String)


14241
14242
14243
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14241

def name
  @name
end

#start_dateGoogle::Apis::DiscoveryengineV1beta::GoogleTypeDate

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property startDate



14253
14254
14255
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14253

def start_date
  @start_date
end

#stateString

Output only. The state of the license config. Corresponds to the JSON property state

Returns:

  • (String)


14258
14259
14260
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14258

def state
  @state
end

#subscription_termString

Required. Subscription term. Corresponds to the JSON property subscriptionTerm

Returns:

  • (String)


14263
14264
14265
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14263

def subscription_term
  @subscription_term
end

#subscription_tierString

Required. Subscription tier information for the license config. Corresponds to the JSON property subscriptionTier

Returns:

  • (String)


14268
14269
14270
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14268

def subscription_tier
  @subscription_tier
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14275
14276
14277
14278
14279
14280
14281
14282
14283
14284
14285
14286
14287
14288
14289
14290
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14275

def update!(**args)
  @alert_policy_resource_config = args[:alert_policy_resource_config] if args.key?(:alert_policy_resource_config)
  @auto_renew = args[:auto_renew] if args.key?(:auto_renew)
  @early_terminated = args[:early_terminated] if args.key?(:early_terminated)
  @early_termination_date = args[:early_termination_date] if args.key?(:early_termination_date)
  @end_date = args[:end_date] if args.key?(:end_date)
  @free_trial = args[:free_trial] if args.key?(:free_trial)
  @gemini_bundle = args[:gemini_bundle] if args.key?(:gemini_bundle)
  @last_user_update_time = args[:last_user_update_time] if args.key?(:last_user_update_time)
  @license_count = args[:license_count] if args.key?(:license_count)
  @name = args[:name] if args.key?(:name)
  @start_date = args[:start_date] if args.key?(:start_date)
  @state = args[:state] if args.key?(:state)
  @subscription_term = args[:subscription_term] if args.key?(:subscription_term)
  @subscription_tier = args[:subscription_tier] if args.key?(:subscription_tier)
end