Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaLicenseConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Information about users' licenses.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaLicenseConfig

Returns a new instance of GoogleCloudDiscoveryengineV1alphaLicenseConfig.



13434
13435
13436
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13434

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#alert_policy_resource_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaAlertPolicyResourceConfig

The resource level alert config. Used in: * UserLicense * EngineUserData The AlertPolicyConfig in data connector is of same usage. No easy way to migrate. Corresponds to the JSON property alertPolicyResourceConfig



13342
13343
13344
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13342

def alert_policy_resource_config
  @alert_policy_resource_config
end

#auto_renewBoolean Also known as: auto_renew?

Optional. Whether the license config should be auto renewed when it reaches the end date. Corresponds to the JSON property autoRenew

Returns:

  • (Boolean)


13348
13349
13350
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13348

def auto_renew
  @auto_renew
end

#early_terminatedBoolean Also known as: early_terminated?

Output only. Indication of whether the subscription is terminated earlier than the expiration date. This is usually terminated by pipeline once the subscription gets terminated from subsv3. Corresponds to the JSON property earlyTerminated

Returns:

  • (Boolean)


13356
13357
13358
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13356

def early_terminated
  @early_terminated
end

#early_termination_dateGoogle::Apis::DiscoveryengineV1beta::GoogleTypeDate

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property earlyTerminationDate



13369
13370
13371
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13369

def early_termination_date
  @early_termination_date
end

#end_dateGoogle::Apis::DiscoveryengineV1beta::GoogleTypeDate

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property endDate



13381
13382
13383
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13381

def end_date
  @end_date
end

#free_trialBoolean Also known as: free_trial?

Optional. Whether the license config is for free trial. Corresponds to the JSON property freeTrial

Returns:

  • (Boolean)


13386
13387
13388
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13386

def free_trial
  @free_trial
end

#gemini_bundleBoolean Also known as: gemini_bundle?

Output only. Whether the license config is for Gemini bundle. Corresponds to the JSON property geminiBundle

Returns:

  • (Boolean)


13392
13393
13394
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13392

def gemini_bundle
  @gemini_bundle
end

#license_countFixnum

Required. Number of licenses purchased. Corresponds to the JSON property licenseCount

Returns:

  • (Fixnum)


13398
13399
13400
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13398

def license_count
  @license_count
end

#nameString

Immutable. Identifier. The fully qualified resource name of the license config. Format: projects/project/locations/location/licenseConfigs/ license_config` Corresponds to the JSON propertyname`

Returns:

  • (String)


13405
13406
13407
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13405

def name
  @name
end

#start_dateGoogle::Apis::DiscoveryengineV1beta::GoogleTypeDate

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property startDate



13417
13418
13419
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13417

def start_date
  @start_date
end

#stateString

Output only. The state of the license config. Corresponds to the JSON property state

Returns:

  • (String)


13422
13423
13424
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13422

def state
  @state
end

#subscription_termString

Required. Subscription term. Corresponds to the JSON property subscriptionTerm

Returns:

  • (String)


13427
13428
13429
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13427

def subscription_term
  @subscription_term
end

#subscription_tierString

Required. Subscription tier information for the license config. Corresponds to the JSON property subscriptionTier

Returns:

  • (String)


13432
13433
13434
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13432

def subscription_tier
  @subscription_tier
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13439
13440
13441
13442
13443
13444
13445
13446
13447
13448
13449
13450
13451
13452
13453
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13439

def update!(**args)
  @alert_policy_resource_config = args[:alert_policy_resource_config] if args.key?(:alert_policy_resource_config)
  @auto_renew = args[:auto_renew] if args.key?(:auto_renew)
  @early_terminated = args[:early_terminated] if args.key?(:early_terminated)
  @early_termination_date = args[:early_termination_date] if args.key?(:early_termination_date)
  @end_date = args[:end_date] if args.key?(:end_date)
  @free_trial = args[:free_trial] if args.key?(:free_trial)
  @gemini_bundle = args[:gemini_bundle] if args.key?(:gemini_bundle)
  @license_count = args[:license_count] if args.key?(:license_count)
  @name = args[:name] if args.key?(:name)
  @start_date = args[:start_date] if args.key?(:start_date)
  @state = args[:state] if args.key?(:state)
  @subscription_term = args[:subscription_term] if args.key?(:subscription_term)
  @subscription_tier = args[:subscription_tier] if args.key?(:subscription_tier)
end