Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaListSessionsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Request for ListSessions method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaListSessionsRequest

Returns a new instance of GoogleCloudDiscoveryengineV1alphaListSessionsRequest.



13499
13500
13501
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13499

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#filterString

A comma-separated list of fields to filter by, in EBNF grammar. The supported fields are: * user_pseudo_id * state * display_name * starred * is_pinned * labels * create_time * update_time * collaborative_project Examples: * user_pseudo_id = some_id * display_name = "some_name" * starred = true * is_pinned=true AND (NOT labels:hidden) * create_time > " 1970-01-01T12:00:00Z" * collaborative_project = "projects/123/locations/ global/collections/default_collection/engines/" "default_engine/ collaborative_projects/cp1" Corresponds to the JSON property filter

Returns:

  • (String)


13470
13471
13472
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13470

def filter
  @filter
end

#order_byString

A comma-separated list of fields to order by, sorted in ascending order. Use " desc" after a field name for descending. Supported fields: * update_time * create_time * session_name * is_pinned * display_name Example: * update_time desc * create_time * is_pinned desc,update_time desc: list sessions by is_pinned first, then by update_time. Corresponds to the JSON property orderBy

Returns:

  • (String)


13479
13480
13481
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13479

def order_by
  @order_by
end

#page_sizeFixnum

Maximum number of results to return. If unspecified, defaults to 50. Max allowed value is 1000. Corresponds to the JSON property pageSize

Returns:

  • (Fixnum)


13485
13486
13487
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13485

def page_size
  @page_size
end

#page_tokenString

A page token, received from a previous ListSessions call. Provide this to retrieve the subsequent page. Corresponds to the JSON property pageToken

Returns:

  • (String)


13491
13492
13493
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13491

def page_token
  @page_token
end

#parentString

Required. The data store resource name. Format: projects/project/locations/ location/collections/collection/dataStores/data_store_id` Corresponds to the JSON propertyparent`

Returns:

  • (String)


13497
13498
13499
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13497

def parent
  @parent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13504
13505
13506
13507
13508
13509
13510
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13504

def update!(**args)
  @filter = args[:filter] if args.key?(:filter)
  @order_by = args[:order_by] if args.key?(:order_by)
  @page_size = args[:page_size] if args.key?(:page_size)
  @page_token = args[:page_token] if args.key?(:page_token)
  @parent = args[:parent] if args.key?(:parent)
end