Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaPatientFilterOperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Metadata related to the progress of the various patient filter operations. This will be returned by the google.longrunning.Operation.metadata field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaPatientFilterOperationMetadata

Returns a new instance of GoogleCloudDiscoveryengineV1alphaPatientFilterOperationMetadata.



14527
14528
14529
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14527

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Operation create time. Corresponds to the JSON property createTime

Returns:

  • (String)


14509
14510
14511
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14509

def create_time
  @create_time
end

#filters_added_countFixnum

The number of patient IDs added to the patient filter. Corresponds to the JSON property filtersAddedCount

Returns:

  • (Fixnum)


14514
14515
14516
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14514

def filters_added_count
  @filters_added_count
end

#filters_removed_countFixnum

The number of patient IDs removed from the patient filter. Corresponds to the JSON property filtersRemovedCount

Returns:

  • (Fixnum)


14519
14520
14521
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14519

def filters_removed_count
  @filters_removed_count
end

#update_timeString

Operation last update time. If the operation is done, this is also the finish time. Corresponds to the JSON property updateTime

Returns:

  • (String)


14525
14526
14527
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14525

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14532
14533
14534
14535
14536
14537
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14532

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @filters_added_count = args[:filters_added_count] if args.key?(:filters_added_count)
  @filters_removed_count = args[:filters_removed_count] if args.key?(:filters_removed_count)
  @update_time = args[:update_time] if args.key?(:update_time)
end