Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaPatientFilterOperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaPatientFilterOperationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Metadata related to the progress of the various patient filter operations. This will be returned by the google.longrunning.Operation.metadata field.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Operation create time.
-
#filters_added_count ⇒ Fixnum
The number of patient IDs added to the patient filter.
-
#filters_removed_count ⇒ Fixnum
The number of patient IDs removed from the patient filter.
-
#update_time ⇒ String
Operation last update time.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaPatientFilterOperationMetadata
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaPatientFilterOperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaPatientFilterOperationMetadata
Returns a new instance of GoogleCloudDiscoveryengineV1alphaPatientFilterOperationMetadata.
13690 13691 13692 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13690 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Operation create time.
Corresponds to the JSON property createTime
13672 13673 13674 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13672 def create_time @create_time end |
#filters_added_count ⇒ Fixnum
The number of patient IDs added to the patient filter.
Corresponds to the JSON property filtersAddedCount
13677 13678 13679 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13677 def filters_added_count @filters_added_count end |
#filters_removed_count ⇒ Fixnum
The number of patient IDs removed from the patient filter.
Corresponds to the JSON property filtersRemovedCount
13682 13683 13684 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13682 def filters_removed_count @filters_removed_count end |
#update_time ⇒ String
Operation last update time. If the operation is done, this is also the finish
time.
Corresponds to the JSON property updateTime
13688 13689 13690 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13688 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13695 13696 13697 13698 13699 13700 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13695 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @filters_added_count = args[:filters_added_count] if args.key?(:filters_added_count) @filters_removed_count = args[:filters_removed_count] if args.key?(:filters_removed_count) @update_time = args[:update_time] if args.key?(:update_time) end |