Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaProject
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaProject
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Metadata and configurations for a Google Cloud project in the service.
Instance Attribute Summary collapse
-
#configurable_billing_status ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaProjectConfigurableBillingStatus
Represents the currently effective configurable billing parameters.
-
#create_time ⇒ String
Output only.
-
#customer_provided_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaProjectCustomerProvidedConfig
Customer provided configurations.
-
#name ⇒ String
Output only.
-
#provision_completion_time ⇒ String
Output only.
-
#service_terms_map ⇒ Hash<String,Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaProjectServiceTerms>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaProject
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaProject.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaProject
Returns a new instance of GoogleCloudDiscoveryengineV1alphaProject.
14598 14599 14600 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14598 def initialize(**args) update!(**args) end |
Instance Attribute Details
#configurable_billing_status ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaProjectConfigurableBillingStatus
Represents the currently effective configurable billing parameters. These
values are derived from the customer's subscription history stored internally
and reflect the thresholds actively being used for billing purposes at the
time of the GetProject call. This includes the start_time of the subscription
and may differ from the values in customer_provided_config due to billing
rules (e.g., scale-downs taking effect only at the start of a new month). We
also include the update type to indicate the type of update performed on the
configurable billing configuration in the UpdateProject operation.
Corresponds to the JSON property configurableBillingStatus
14568 14569 14570 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14568 def configurable_billing_status @configurable_billing_status end |
#create_time ⇒ String
Output only. The timestamp when this project is created.
Corresponds to the JSON property createTime
14573 14574 14575 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14573 def create_time @create_time end |
#customer_provided_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaProjectCustomerProvidedConfig
Customer provided configurations.
Corresponds to the JSON property customerProvidedConfig
14578 14579 14580 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14578 def customer_provided_config @customer_provided_config end |
#name ⇒ String
Output only. Full resource name of the project, for example projects/project
. Note that when making requests, project number and project id are both
acceptable, but the server will always respond in project number.
Corresponds to the JSON property name
14585 14586 14587 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14585 def name @name end |
#provision_completion_time ⇒ String
Output only. The timestamp when this project is successfully provisioned.
Empty value means this project is still provisioning and is not ready for use.
Corresponds to the JSON property provisionCompletionTime
14591 14592 14593 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14591 def provision_completion_time @provision_completion_time end |
#service_terms_map ⇒ Hash<String,Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaProjectServiceTerms>
Output only. A map of terms of services. The key is the id of ServiceTerms.
Corresponds to the JSON property serviceTermsMap
14596 14597 14598 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14596 def service_terms_map @service_terms_map end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14603 14604 14605 14606 14607 14608 14609 14610 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14603 def update!(**args) @configurable_billing_status = args[:configurable_billing_status] if args.key?(:configurable_billing_status) @create_time = args[:create_time] if args.key?(:create_time) @customer_provided_config = args[:customer_provided_config] if args.key?(:customer_provided_config) @name = args[:name] if args.key?(:name) @provision_completion_time = args[:provision_completion_time] if args.key?(:provision_completion_time) @service_terms_map = args[:service_terms_map] if args.key?(:service_terms_map) end |