Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaProjectConfigurableBillingStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Represents the currently effective configurable billing parameters. These values are derived from the customer's subscription history stored internally and reflect the thresholds actively being used for billing purposes at the time of the GetProject call. This includes the start_time of the subscription and may differ from the values in customer_provided_config due to billing rules (e.g., scale-downs taking effect only at the start of a new month). We also include the update type to indicate the type of update performed on the configurable billing configuration in the UpdateProject operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaProjectConfigurableBillingStatus

Returns a new instance of GoogleCloudDiscoveryengineV1alphaProjectConfigurableBillingStatus.



14676
14677
14678
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14676

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_search_token_subscription_statusesArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaProjectConfigurableBillingStatusAgentSearchTokenSubscriptionStatus>

Output only. Per-model Agent Search TPM subscription status. Corresponds to the JSON property agentSearchTokenSubscriptionStatuses



14627
14628
14629
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14627

def agent_search_token_subscription_statuses
  @agent_search_token_subscription_statuses
end

#effective_indexing_core_thresholdFixnum

Optional. The currently effective Indexing Core threshold. This is the threshold against which Indexing Core usage is compared for overage calculations. Corresponds to the JSON property effectiveIndexingCoreThreshold

Returns:

  • (Fixnum)


14634
14635
14636
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14634

def effective_indexing_core_threshold
  @effective_indexing_core_threshold
end

#effective_search_qpm_thresholdFixnum

Optional. The currently effective Search QPM threshold in queries per minute. This is the threshold against which QPM usage is compared for overage calculations. Corresponds to the JSON property effectiveSearchQpmThreshold

Returns:

  • (Fixnum)


14641
14642
14643
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14641

def effective_search_qpm_threshold
  @effective_search_qpm_threshold
end

#indexing_core_threshold_next_update_timeString

Output only. The earliest next update time for the indexing core subscription threshold. This is based on the next_update_time returned by the underlying Cloud Billing Subscription V3 API. This field is populated only if an update indexing core subscription threshold request is succeeded. Corresponds to the JSON property indexingCoreThresholdNextUpdateTime

Returns:

  • (String)


14649
14650
14651
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14649

def indexing_core_threshold_next_update_time
  @indexing_core_threshold_next_update_time
end

#search_qpm_threshold_next_update_timeString

Output only. The earliest next update time for the search QPM subscription threshold. This is based on the next_update_time returned by the underlying Cloud Billing Subscription V3 API. This field is populated only if an update QPM subscription threshold request is succeeded. Corresponds to the JSON property searchQpmThresholdNextUpdateTime

Returns:

  • (String)


14657
14658
14659
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14657

def search_qpm_threshold_next_update_time
  @search_qpm_threshold_next_update_time
end

#start_timeString

Optional. The start time of the currently active billing subscription. Corresponds to the JSON property startTime

Returns:

  • (String)


14662
14663
14664
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14662

def start_time
  @start_time
end

#terminate_timeString

Output only. The latest terminate effective time of search qpm and indexing core subscriptions. Corresponds to the JSON property terminateTime

Returns:

  • (String)


14668
14669
14670
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14668

def terminate_time
  @terminate_time
end

#update_typeString

Output only. The type of update performed in this operation. This field is populated in the response of UpdateProject. Corresponds to the JSON property updateType

Returns:

  • (String)


14674
14675
14676
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14674

def update_type
  @update_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14681
14682
14683
14684
14685
14686
14687
14688
14689
14690
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14681

def update!(**args)
  @agent_search_token_subscription_statuses = args[:agent_search_token_subscription_statuses] if args.key?(:agent_search_token_subscription_statuses)
  @effective_indexing_core_threshold = args[:effective_indexing_core_threshold] if args.key?(:effective_indexing_core_threshold)
  @effective_search_qpm_threshold = args[:effective_search_qpm_threshold] if args.key?(:effective_search_qpm_threshold)
  @indexing_core_threshold_next_update_time = args[:indexing_core_threshold_next_update_time] if args.key?(:indexing_core_threshold_next_update_time)
  @search_qpm_threshold_next_update_time = args[:search_qpm_threshold_next_update_time] if args.key?(:search_qpm_threshold_next_update_time)
  @start_time = args[:start_time] if args.key?(:start_time)
  @terminate_time = args[:terminate_time] if args.key?(:terminate_time)
  @update_type = args[:update_type] if args.key?(:update_type)
end