Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaProjectConfigurableBillingStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Represents the currently effective configurable billing parameters. These values are derived from the customer's subscription history stored internally and reflect the thresholds actively being used for billing purposes at the time of the GetProject call. This includes the start_time of the subscription and may differ from the values in customer_provided_config due to billing rules (e.g., scale-downs taking effect only at the start of a new month). We also include the update type to indicate the type of update performed on the configurable billing configuration in the UpdateProject operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaProjectConfigurableBillingStatus

Returns a new instance of GoogleCloudDiscoveryengineV1alphaProjectConfigurableBillingStatus.



13820
13821
13822
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13820

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#effective_indexing_core_thresholdFixnum

Optional. The currently effective Indexing Core threshold. This is the threshold against which Indexing Core usage is compared for overage calculations. Corresponds to the JSON property effectiveIndexingCoreThreshold

Returns:

  • (Fixnum)


13778
13779
13780
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13778

def effective_indexing_core_threshold
  @effective_indexing_core_threshold
end

#effective_search_qpm_thresholdFixnum

Optional. The currently effective Search QPM threshold in queries per minute. This is the threshold against which QPM usage is compared for overage calculations. Corresponds to the JSON property effectiveSearchQpmThreshold

Returns:

  • (Fixnum)


13785
13786
13787
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13785

def effective_search_qpm_threshold
  @effective_search_qpm_threshold
end

#indexing_core_threshold_next_update_timeString

Output only. The earliest next update time for the indexing core subscription threshold. This is based on the next_update_time returned by the underlying Cloud Billing Subscription V3 API. This field is populated only if an update indexing core subscription threshold request is succeeded. Corresponds to the JSON property indexingCoreThresholdNextUpdateTime

Returns:

  • (String)


13793
13794
13795
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13793

def indexing_core_threshold_next_update_time
  @indexing_core_threshold_next_update_time
end

#search_qpm_threshold_next_update_timeString

Output only. The earliest next update time for the search QPM subscription threshold. This is based on the next_update_time returned by the underlying Cloud Billing Subscription V3 API. This field is populated only if an update QPM subscription threshold request is succeeded. Corresponds to the JSON property searchQpmThresholdNextUpdateTime

Returns:

  • (String)


13801
13802
13803
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13801

def search_qpm_threshold_next_update_time
  @search_qpm_threshold_next_update_time
end

#start_timeString

Optional. The start time of the currently active billing subscription. Corresponds to the JSON property startTime

Returns:

  • (String)


13806
13807
13808
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13806

def start_time
  @start_time
end

#terminate_timeString

Output only. The latest terminate effective time of search qpm and indexing core subscriptions. Corresponds to the JSON property terminateTime

Returns:

  • (String)


13812
13813
13814
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13812

def terminate_time
  @terminate_time
end

#update_typeString

Output only. The type of update performed in this operation. This field is populated in the response of UpdateProject. Corresponds to the JSON property updateType

Returns:

  • (String)


13818
13819
13820
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13818

def update_type
  @update_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13825
13826
13827
13828
13829
13830
13831
13832
13833
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13825

def update!(**args)
  @effective_indexing_core_threshold = args[:effective_indexing_core_threshold] if args.key?(:effective_indexing_core_threshold)
  @effective_search_qpm_threshold = args[:effective_search_qpm_threshold] if args.key?(:effective_search_qpm_threshold)
  @indexing_core_threshold_next_update_time = args[:indexing_core_threshold_next_update_time] if args.key?(:indexing_core_threshold_next_update_time)
  @search_qpm_threshold_next_update_time = args[:search_qpm_threshold_next_update_time] if args.key?(:search_qpm_threshold_next_update_time)
  @start_time = args[:start_time] if args.key?(:start_time)
  @terminate_time = args[:terminate_time] if args.key?(:terminate_time)
  @update_type = args[:update_type] if args.key?(:update_type)
end