Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaProjectCustomerProvidedConfigNotebooklmConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Configuration for NotebookLM.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaProjectCustomerProvidedConfigNotebooklmConfig

Returns a new instance of GoogleCloudDiscoveryengineV1alphaProjectCustomerProvidedConfigNotebooklmConfig.



14086
14087
14088
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14086

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_protection_policyGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaProjectCustomerProvidedConfigNotebooklmConfigDataProtectionPolicy

Data protection policy config for NotebookLM. Corresponds to the JSON property dataProtectionPolicy



14066
14067
14068
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14066

def data_protection_policy
  @data_protection_policy
end

#model_armor_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaProjectCustomerProvidedConfigNotebooklmConfigModelArmorConfig

Configuration for customer defined Model Armor templates to be used for sanitizing user prompts and LLM responses. Corresponds to the JSON property modelArmorConfig



14072
14073
14074
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14072

def model_armor_config
  @model_armor_config
end

#observability_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaObservabilityConfig

Observability config for a resource. Corresponds to the JSON property observabilityConfig



14077
14078
14079
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14077

def observability_config
  @observability_config
end

#opt_out_notebook_sharingBoolean Also known as: opt_out_notebook_sharing?

Optional. Whether to disable the notebook sharing feature for the project. Default to false if not specified. Corresponds to the JSON property optOutNotebookSharing

Returns:

  • (Boolean)


14083
14084
14085
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14083

def opt_out_notebook_sharing
  @opt_out_notebook_sharing
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14091
14092
14093
14094
14095
14096
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14091

def update!(**args)
  @data_protection_policy = args[:data_protection_policy] if args.key?(:data_protection_policy)
  @model_armor_config = args[:model_armor_config] if args.key?(:model_armor_config)
  @observability_config = args[:observability_config] if args.key?(:observability_config)
  @opt_out_notebook_sharing = args[:opt_out_notebook_sharing] if args.key?(:opt_out_notebook_sharing)
end