Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaProjectCustomerProvidedConfigNotebooklmConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Configuration for NotebookLM.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaProjectCustomerProvidedConfigNotebooklmConfig

Returns a new instance of GoogleCloudDiscoveryengineV1alphaProjectCustomerProvidedConfigNotebooklmConfig.



13882
13883
13884
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13882

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_protection_policyGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaProjectCustomerProvidedConfigNotebooklmConfigDataProtectionPolicy

Data protection policy config for NotebookLM. Corresponds to the JSON property dataProtectionPolicy



13862
13863
13864
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13862

def data_protection_policy
  @data_protection_policy
end

#model_armor_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaProjectCustomerProvidedConfigNotebooklmConfigModelArmorConfig

Configuration for customer defined Model Armor templates to be used for sanitizing user prompts and LLM responses. Corresponds to the JSON property modelArmorConfig



13868
13869
13870
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13868

def model_armor_config
  @model_armor_config
end

#observability_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaObservabilityConfig

Observability config for a resource. Corresponds to the JSON property observabilityConfig



13873
13874
13875
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13873

def observability_config
  @observability_config
end

#opt_out_notebook_sharingBoolean Also known as: opt_out_notebook_sharing?

Optional. Whether to disable the notebook sharing feature for the project. Default to false if not specified. Corresponds to the JSON property optOutNotebookSharing

Returns:

  • (Boolean)


13879
13880
13881
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13879

def opt_out_notebook_sharing
  @opt_out_notebook_sharing
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13887
13888
13889
13890
13891
13892
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 13887

def update!(**args)
  @data_protection_policy = args[:data_protection_policy] if args.key?(:data_protection_policy)
  @model_armor_config = args[:model_armor_config] if args.key?(:model_armor_config)
  @observability_config = args[:observability_config] if args.key?(:observability_config)
  @opt_out_notebook_sharing = args[:opt_out_notebook_sharing] if args.key?(:opt_out_notebook_sharing)
end