Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaPurgeCompletionSuggestionsResponse
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaPurgeCompletionSuggestionsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Response message for CompletionService.PurgeCompletionSuggestions method. If the long running operation is successfully done, then this message is returned by the google.longrunning.Operations.response field.
Instance Attribute Summary collapse
-
#error_samples ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>
A sample of errors encountered while processing the request.
-
#purge_succeeded ⇒ Boolean
(also: #purge_succeeded?)
Whether the completion suggestions were successfully purged.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaPurgeCompletionSuggestionsResponse
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaPurgeCompletionSuggestionsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaPurgeCompletionSuggestionsResponse
Returns a new instance of GoogleCloudDiscoveryengineV1alphaPurgeCompletionSuggestionsResponse.
15018 15019 15020 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15018 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_samples ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>
A sample of errors encountered while processing the request.
Corresponds to the JSON property errorSamples
15010 15011 15012 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15010 def error_samples @error_samples end |
#purge_succeeded ⇒ Boolean Also known as: purge_succeeded?
Whether the completion suggestions were successfully purged.
Corresponds to the JSON property purgeSucceeded
15015 15016 15017 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15015 def purge_succeeded @purge_succeeded end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15023 15024 15025 15026 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15023 def update!(**args) @error_samples = args[:error_samples] if args.key?(:error_samples) @purge_succeeded = args[:purge_succeeded] if args.key?(:purge_succeeded) end |