Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaPurgeDocumentsMetadata
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaPurgeDocumentsMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Metadata related to the progress of the PurgeDocuments operation. This will be returned by the google.longrunning.Operation.metadata field.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Operation create time.
-
#failure_count ⇒ Fixnum
Count of entries that encountered errors while processing.
-
#ignored_count ⇒ Fixnum
Count of entries that were ignored as entries were not found.
-
#success_count ⇒ Fixnum
Count of entries that were deleted successfully.
-
#update_time ⇒ String
Operation last update time.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaPurgeDocumentsMetadata
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaPurgeDocumentsMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaPurgeDocumentsMetadata
Returns a new instance of GoogleCloudDiscoveryengineV1alphaPurgeDocumentsMetadata.
14922 14923 14924 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14922 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Operation create time.
Corresponds to the JSON property createTime
14899 14900 14901 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14899 def create_time @create_time end |
#failure_count ⇒ Fixnum
Count of entries that encountered errors while processing.
Corresponds to the JSON property failureCount
14904 14905 14906 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14904 def failure_count @failure_count end |
#ignored_count ⇒ Fixnum
Count of entries that were ignored as entries were not found.
Corresponds to the JSON property ignoredCount
14909 14910 14911 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14909 def ignored_count @ignored_count end |
#success_count ⇒ Fixnum
Count of entries that were deleted successfully.
Corresponds to the JSON property successCount
14914 14915 14916 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14914 def success_count @success_count end |
#update_time ⇒ String
Operation last update time. If the operation is done, this is also the finish
time.
Corresponds to the JSON property updateTime
14920 14921 14922 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14920 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14927 14928 14929 14930 14931 14932 14933 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14927 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @failure_count = args[:failure_count] if args.key?(:failure_count) @ignored_count = args[:ignored_count] if args.key?(:ignored_count) @success_count = args[:success_count] if args.key?(:success_count) @update_time = args[:update_time] if args.key?(:update_time) end |