Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaPurgeUserEventsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Response of the PurgeUserEventsRequest. If the long running operation is successfully done, then this message is returned by the google.longrunning. Operations.response field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaPurgeUserEventsResponse

Returns a new instance of GoogleCloudDiscoveryengineV1alphaPurgeUserEventsResponse.



15036
15037
15038
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15036

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#purge_countFixnum

The total count of events purged as a result of the operation. Corresponds to the JSON property purgeCount

Returns:

  • (Fixnum)


15034
15035
15036
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15034

def purge_count
  @purge_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15041
15042
15043
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15041

def update!(**args)
  @purge_count = args[:purge_count] if args.key?(:purge_count)
end