Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaQueryPart

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Represents a part or the whole of a content, used to represent a query. A query can be made up of multiple parts.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaQueryPart

Returns a new instance of GoogleCloudDiscoveryengineV1alphaQueryPart.



15201
15202
15203
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15201

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#document_referenceGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaQueryPartDocumentReference

Represents a document reference. Corresponds to the JSON property documentReference



15171
15172
15173
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15171

def document_reference
  @document_reference
end

#drive_document_referenceGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaQueryPartDriveDocumentReference

Represents a Google Drive document reference. Corresponds to the JSON property driveDocumentReference



15176
15177
15178
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15176

def drive_document_reference
  @drive_document_reference
end

#mime_typeString

Optional. The IANA standard MIME type of the data. See https://www.iana.org/ assignments/media-types/media-types.xhtml. This field is optional. If not set, the default assumed MIME type is "text/plain" for the "data" field. Corresponds to the JSON property mimeType

Returns:

  • (String)


15183
15184
15185
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15183

def mime_type
  @mime_type
end

#person_referenceGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaQueryPartPersonReference

Represents a person reference. Corresponds to the JSON property personReference



15188
15189
15190
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15188

def person_reference
  @person_reference
end

#textString

Text content. Corresponds to the JSON property text

Returns:

  • (String)


15193
15194
15195
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15193

def text
  @text
end

#ui_json_payloadString

This field is expected to be a ui message in JSON format. As of Q1 2026, ui_json_payload is only supported for A2UI messages. Corresponds to the JSON property uiJsonPayload

Returns:

  • (String)


15199
15200
15201
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15199

def ui_json_payload
  @ui_json_payload
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15206
15207
15208
15209
15210
15211
15212
15213
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15206

def update!(**args)
  @document_reference = args[:document_reference] if args.key?(:document_reference)
  @drive_document_reference = args[:drive_document_reference] if args.key?(:drive_document_reference)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
  @person_reference = args[:person_reference] if args.key?(:person_reference)
  @text = args[:text] if args.key?(:text)
  @ui_json_payload = args[:ui_json_payload] if args.key?(:ui_json_payload)
end