Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaQueryPart

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Represents a part or the whole of a content, used to represent a query. A query can be made up of multiple parts.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaQueryPart

Returns a new instance of GoogleCloudDiscoveryengineV1alphaQueryPart.



14423
14424
14425
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14423

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#document_referenceGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaQueryPartDocumentReference

Represents a document reference. Corresponds to the JSON property documentReference



14393
14394
14395
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14393

def document_reference
  @document_reference
end

#drive_document_referenceGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaQueryPartDriveDocumentReference

Represents a Google Drive document reference. Corresponds to the JSON property driveDocumentReference



14398
14399
14400
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14398

def drive_document_reference
  @drive_document_reference
end

#mime_typeString

Optional. The IANA standard MIME type of the data. See https://www.iana.org/ assignments/media-types/media-types.xhtml. This field is optional. If not set, the default assumed MIME type is "text/plain" for the "data" field. Corresponds to the JSON property mimeType

Returns:

  • (String)


14405
14406
14407
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14405

def mime_type
  @mime_type
end

#person_referenceGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaQueryPartPersonReference

Represents a person reference. Corresponds to the JSON property personReference



14410
14411
14412
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14410

def person_reference
  @person_reference
end

#textString

Text content. Corresponds to the JSON property text

Returns:

  • (String)


14415
14416
14417
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14415

def text
  @text
end

#ui_json_payloadString

This field is expected to be a ui message in JSON format. As of Q1 2026, ui_json_payload is only supported for A2UI messages. Corresponds to the JSON property uiJsonPayload

Returns:

  • (String)


14421
14422
14423
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14421

def ui_json_payload
  @ui_json_payload
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14428
14429
14430
14431
14432
14433
14434
14435
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14428

def update!(**args)
  @document_reference = args[:document_reference] if args.key?(:document_reference)
  @drive_document_reference = args[:drive_document_reference] if args.key?(:drive_document_reference)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
  @person_reference = args[:person_reference] if args.key?(:person_reference)
  @text = args[:text] if args.key?(:text)
  @ui_json_payload = args[:ui_json_payload] if args.key?(:ui_json_payload)
end