Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaRecrawlUrisMetadata
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaRecrawlUrisMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Metadata related to the progress of the SiteSearchEngineService.RecrawlUris operation. This will be returned by the google.longrunning.Operation.metadata field.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Operation create time.
-
#invalid_uris ⇒ Array<String>
Unique URIs in the request that have invalid format.
-
#invalid_uris_count ⇒ Fixnum
Total number of unique URIs in the request that have invalid format.
-
#noindex_uris ⇒ Array<String>
URIs that have no index meta tag.
-
#noindex_uris_count ⇒ Fixnum
Total number of URIs that have no index meta tag.
-
#pending_count ⇒ Fixnum
Total number of URIs that have yet to be crawled.
-
#quota_exceeded_count ⇒ Fixnum
Total number of URIs that were rejected due to insufficient indexing resources.
-
#success_count ⇒ Fixnum
Total number of URIs that have been crawled so far.
-
#update_time ⇒ String
Operation last update time.
-
#uris_not_matching_target_sites ⇒ Array<String>
Unique URIs in the request that don't match any TargetSite in the DataStore, only match TargetSites that haven't been fully indexed, or match a TargetSite with type EXCLUDE.
-
#uris_not_matching_target_sites_count ⇒ Fixnum
Total number of URIs that don't match any TargetSites.
-
#valid_uris_count ⇒ Fixnum
Total number of unique URIs in the request that are not in invalid_uris.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaRecrawlUrisMetadata
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaRecrawlUrisMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaRecrawlUrisMetadata
Returns a new instance of GoogleCloudDiscoveryengineV1alphaRecrawlUrisMetadata.
15600 15601 15602 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15600 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Operation create time.
Corresponds to the JSON property createTime
15540 15541 15542 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15540 def create_time @create_time end |
#invalid_uris ⇒ Array<String>
Unique URIs in the request that have invalid format. Sample limited to 1000.
Corresponds to the JSON property invalidUris
15545 15546 15547 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15545 def invalid_uris @invalid_uris end |
#invalid_uris_count ⇒ Fixnum
Total number of unique URIs in the request that have invalid format.
Corresponds to the JSON property invalidUrisCount
15550 15551 15552 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15550 def invalid_uris_count @invalid_uris_count end |
#noindex_uris ⇒ Array<String>
URIs that have no index meta tag. Sample limited to 1000.
Corresponds to the JSON property noindexUris
15555 15556 15557 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15555 def noindex_uris @noindex_uris end |
#noindex_uris_count ⇒ Fixnum
Total number of URIs that have no index meta tag.
Corresponds to the JSON property noindexUrisCount
15560 15561 15562 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15560 def noindex_uris_count @noindex_uris_count end |
#pending_count ⇒ Fixnum
Total number of URIs that have yet to be crawled.
Corresponds to the JSON property pendingCount
15565 15566 15567 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15565 def pending_count @pending_count end |
#quota_exceeded_count ⇒ Fixnum
Total number of URIs that were rejected due to insufficient indexing resources.
Corresponds to the JSON property quotaExceededCount
15570 15571 15572 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15570 def quota_exceeded_count @quota_exceeded_count end |
#success_count ⇒ Fixnum
Total number of URIs that have been crawled so far.
Corresponds to the JSON property successCount
15575 15576 15577 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15575 def success_count @success_count end |
#update_time ⇒ String
Operation last update time. If the operation is done, this is also the finish
time.
Corresponds to the JSON property updateTime
15581 15582 15583 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15581 def update_time @update_time end |
#uris_not_matching_target_sites ⇒ Array<String>
Unique URIs in the request that don't match any TargetSite in the DataStore,
only match TargetSites that haven't been fully indexed, or match a TargetSite
with type EXCLUDE. Sample limited to 1000.
Corresponds to the JSON property urisNotMatchingTargetSites
15588 15589 15590 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15588 def uris_not_matching_target_sites @uris_not_matching_target_sites end |
#uris_not_matching_target_sites_count ⇒ Fixnum
Total number of URIs that don't match any TargetSites.
Corresponds to the JSON property urisNotMatchingTargetSitesCount
15593 15594 15595 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15593 def uris_not_matching_target_sites_count @uris_not_matching_target_sites_count end |
#valid_uris_count ⇒ Fixnum
Total number of unique URIs in the request that are not in invalid_uris.
Corresponds to the JSON property validUrisCount
15598 15599 15600 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15598 def valid_uris_count @valid_uris_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15605 15606 15607 15608 15609 15610 15611 15612 15613 15614 15615 15616 15617 15618 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15605 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @invalid_uris = args[:invalid_uris] if args.key?(:invalid_uris) @invalid_uris_count = args[:invalid_uris_count] if args.key?(:invalid_uris_count) @noindex_uris = args[:noindex_uris] if args.key?(:noindex_uris) @noindex_uris_count = args[:noindex_uris_count] if args.key?(:noindex_uris_count) @pending_count = args[:pending_count] if args.key?(:pending_count) @quota_exceeded_count = args[:quota_exceeded_count] if args.key?(:quota_exceeded_count) @success_count = args[:success_count] if args.key?(:success_count) @update_time = args[:update_time] if args.key?(:update_time) @uris_not_matching_target_sites = args[:uris_not_matching_target_sites] if args.key?(:uris_not_matching_target_sites) @uris_not_matching_target_sites_count = args[:uris_not_matching_target_sites_count] if args.key?(:uris_not_matching_target_sites_count) @valid_uris_count = args[:valid_uris_count] if args.key?(:valid_uris_count) end |