Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaRecrawlUrisMetadata
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaRecrawlUrisMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Metadata related to the progress of the SiteSearchEngineService.RecrawlUris operation. This will be returned by the google.longrunning.Operation.metadata field.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Operation create time.
-
#invalid_uris ⇒ Array<String>
Unique URIs in the request that have invalid format.
-
#invalid_uris_count ⇒ Fixnum
Total number of unique URIs in the request that have invalid format.
-
#noindex_uris ⇒ Array<String>
URIs that have no index meta tag.
-
#noindex_uris_count ⇒ Fixnum
Total number of URIs that have no index meta tag.
-
#pending_count ⇒ Fixnum
Total number of URIs that have yet to be crawled.
-
#quota_exceeded_count ⇒ Fixnum
Total number of URIs that were rejected due to insufficient indexing resources.
-
#success_count ⇒ Fixnum
Total number of URIs that have been crawled so far.
-
#update_time ⇒ String
Operation last update time.
-
#uris_not_matching_target_sites ⇒ Array<String>
Unique URIs in the request that don't match any TargetSite in the DataStore, only match TargetSites that haven't been fully indexed, or match a TargetSite with type EXCLUDE.
-
#uris_not_matching_target_sites_count ⇒ Fixnum
Total number of URIs that don't match any TargetSites.
-
#valid_uris_count ⇒ Fixnum
Total number of unique URIs in the request that are not in invalid_uris.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaRecrawlUrisMetadata
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaRecrawlUrisMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaRecrawlUrisMetadata
Returns a new instance of GoogleCloudDiscoveryengineV1alphaRecrawlUrisMetadata.
15500 15501 15502 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15500 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Operation create time.
Corresponds to the JSON property createTime
15440 15441 15442 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15440 def create_time @create_time end |
#invalid_uris ⇒ Array<String>
Unique URIs in the request that have invalid format. Sample limited to 1000.
Corresponds to the JSON property invalidUris
15445 15446 15447 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15445 def invalid_uris @invalid_uris end |
#invalid_uris_count ⇒ Fixnum
Total number of unique URIs in the request that have invalid format.
Corresponds to the JSON property invalidUrisCount
15450 15451 15452 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15450 def invalid_uris_count @invalid_uris_count end |
#noindex_uris ⇒ Array<String>
URIs that have no index meta tag. Sample limited to 1000.
Corresponds to the JSON property noindexUris
15455 15456 15457 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15455 def noindex_uris @noindex_uris end |
#noindex_uris_count ⇒ Fixnum
Total number of URIs that have no index meta tag.
Corresponds to the JSON property noindexUrisCount
15460 15461 15462 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15460 def noindex_uris_count @noindex_uris_count end |
#pending_count ⇒ Fixnum
Total number of URIs that have yet to be crawled.
Corresponds to the JSON property pendingCount
15465 15466 15467 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15465 def pending_count @pending_count end |
#quota_exceeded_count ⇒ Fixnum
Total number of URIs that were rejected due to insufficient indexing resources.
Corresponds to the JSON property quotaExceededCount
15470 15471 15472 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15470 def quota_exceeded_count @quota_exceeded_count end |
#success_count ⇒ Fixnum
Total number of URIs that have been crawled so far.
Corresponds to the JSON property successCount
15475 15476 15477 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15475 def success_count @success_count end |
#update_time ⇒ String
Operation last update time. If the operation is done, this is also the finish
time.
Corresponds to the JSON property updateTime
15481 15482 15483 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15481 def update_time @update_time end |
#uris_not_matching_target_sites ⇒ Array<String>
Unique URIs in the request that don't match any TargetSite in the DataStore,
only match TargetSites that haven't been fully indexed, or match a TargetSite
with type EXCLUDE. Sample limited to 1000.
Corresponds to the JSON property urisNotMatchingTargetSites
15488 15489 15490 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15488 def uris_not_matching_target_sites @uris_not_matching_target_sites end |
#uris_not_matching_target_sites_count ⇒ Fixnum
Total number of URIs that don't match any TargetSites.
Corresponds to the JSON property urisNotMatchingTargetSitesCount
15493 15494 15495 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15493 def uris_not_matching_target_sites_count @uris_not_matching_target_sites_count end |
#valid_uris_count ⇒ Fixnum
Total number of unique URIs in the request that are not in invalid_uris.
Corresponds to the JSON property validUrisCount
15498 15499 15500 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15498 def valid_uris_count @valid_uris_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15505 15506 15507 15508 15509 15510 15511 15512 15513 15514 15515 15516 15517 15518 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15505 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @invalid_uris = args[:invalid_uris] if args.key?(:invalid_uris) @invalid_uris_count = args[:invalid_uris_count] if args.key?(:invalid_uris_count) @noindex_uris = args[:noindex_uris] if args.key?(:noindex_uris) @noindex_uris_count = args[:noindex_uris_count] if args.key?(:noindex_uris_count) @pending_count = args[:pending_count] if args.key?(:pending_count) @quota_exceeded_count = args[:quota_exceeded_count] if args.key?(:quota_exceeded_count) @success_count = args[:success_count] if args.key?(:success_count) @update_time = args[:update_time] if args.key?(:update_time) @uris_not_matching_target_sites = args[:uris_not_matching_target_sites] if args.key?(:uris_not_matching_target_sites) @uris_not_matching_target_sites_count = args[:uris_not_matching_target_sites_count] if args.key?(:uris_not_matching_target_sites_count) @valid_uris_count = args[:valid_uris_count] if args.key?(:valid_uris_count) end |