Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaRecrawlUrisMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Metadata related to the progress of the SiteSearchEngineService.RecrawlUris operation. This will be returned by the google.longrunning.Operation.metadata field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaRecrawlUrisMetadata

Returns a new instance of GoogleCloudDiscoveryengineV1alphaRecrawlUrisMetadata.



14667
14668
14669
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14667

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Operation create time. Corresponds to the JSON property createTime

Returns:

  • (String)


14607
14608
14609
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14607

def create_time
  @create_time
end

#invalid_urisArray<String>

Unique URIs in the request that have invalid format. Sample limited to 1000. Corresponds to the JSON property invalidUris

Returns:

  • (Array<String>)


14612
14613
14614
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14612

def invalid_uris
  @invalid_uris
end

#invalid_uris_countFixnum

Total number of unique URIs in the request that have invalid format. Corresponds to the JSON property invalidUrisCount

Returns:

  • (Fixnum)


14617
14618
14619
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14617

def invalid_uris_count
  @invalid_uris_count
end

#noindex_urisArray<String>

URIs that have no index meta tag. Sample limited to 1000. Corresponds to the JSON property noindexUris

Returns:

  • (Array<String>)


14622
14623
14624
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14622

def noindex_uris
  @noindex_uris
end

#noindex_uris_countFixnum

Total number of URIs that have no index meta tag. Corresponds to the JSON property noindexUrisCount

Returns:

  • (Fixnum)


14627
14628
14629
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14627

def noindex_uris_count
  @noindex_uris_count
end

#pending_countFixnum

Total number of URIs that have yet to be crawled. Corresponds to the JSON property pendingCount

Returns:

  • (Fixnum)


14632
14633
14634
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14632

def pending_count
  @pending_count
end

#quota_exceeded_countFixnum

Total number of URIs that were rejected due to insufficient indexing resources. Corresponds to the JSON property quotaExceededCount

Returns:

  • (Fixnum)


14637
14638
14639
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14637

def quota_exceeded_count
  @quota_exceeded_count
end

#success_countFixnum

Total number of URIs that have been crawled so far. Corresponds to the JSON property successCount

Returns:

  • (Fixnum)


14642
14643
14644
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14642

def success_count
  @success_count
end

#update_timeString

Operation last update time. If the operation is done, this is also the finish time. Corresponds to the JSON property updateTime

Returns:

  • (String)


14648
14649
14650
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14648

def update_time
  @update_time
end

#uris_not_matching_target_sitesArray<String>

Unique URIs in the request that don't match any TargetSite in the DataStore, only match TargetSites that haven't been fully indexed, or match a TargetSite with type EXCLUDE. Sample limited to 1000. Corresponds to the JSON property urisNotMatchingTargetSites

Returns:

  • (Array<String>)


14655
14656
14657
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14655

def uris_not_matching_target_sites
  @uris_not_matching_target_sites
end

#uris_not_matching_target_sites_countFixnum

Total number of URIs that don't match any TargetSites. Corresponds to the JSON property urisNotMatchingTargetSitesCount

Returns:

  • (Fixnum)


14660
14661
14662
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14660

def uris_not_matching_target_sites_count
  @uris_not_matching_target_sites_count
end

#valid_uris_countFixnum

Total number of unique URIs in the request that are not in invalid_uris. Corresponds to the JSON property validUrisCount

Returns:

  • (Fixnum)


14665
14666
14667
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14665

def valid_uris_count
  @valid_uris_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14672
14673
14674
14675
14676
14677
14678
14679
14680
14681
14682
14683
14684
14685
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14672

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @invalid_uris = args[:invalid_uris] if args.key?(:invalid_uris)
  @invalid_uris_count = args[:invalid_uris_count] if args.key?(:invalid_uris_count)
  @noindex_uris = args[:noindex_uris] if args.key?(:noindex_uris)
  @noindex_uris_count = args[:noindex_uris_count] if args.key?(:noindex_uris_count)
  @pending_count = args[:pending_count] if args.key?(:pending_count)
  @quota_exceeded_count = args[:quota_exceeded_count] if args.key?(:quota_exceeded_count)
  @success_count = args[:success_count] if args.key?(:success_count)
  @update_time = args[:update_time] if args.key?(:update_time)
  @uris_not_matching_target_sites = args[:uris_not_matching_target_sites] if args.key?(:uris_not_matching_target_sites)
  @uris_not_matching_target_sites_count = args[:uris_not_matching_target_sites_count] if args.key?(:uris_not_matching_target_sites_count)
  @valid_uris_count = args[:valid_uris_count] if args.key?(:valid_uris_count)
end