Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaRemoveDedicatedCrawlRateResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Response message for CrawlRateManagementService.RemoveDedicatedCrawlRate method. It simply returns the state of the response, and an error message if the state is FAILED.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaRemoveDedicatedCrawlRateResponse

Returns a new instance of GoogleCloudDiscoveryengineV1alphaRemoveDedicatedCrawlRateResponse.



15018
15019
15020
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15018

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::DiscoveryengineV1beta::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



15011
15012
15013
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15011

def error
  @error
end

#stateString

Output only. The state of the response. Corresponds to the JSON property state

Returns:

  • (String)


15016
15017
15018
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15016

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15023
15024
15025
15026
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15023

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @state = args[:state] if args.key?(:state)
end