Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaRemovePatientFilterRequest
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaRemovePatientFilterRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Request for DataStoreService.RemovePatientFilter method.
Instance Attribute Summary collapse
-
#data_store ⇒ String
Required.
-
#filter_groups ⇒ Array<String>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaRemovePatientFilterRequest
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaRemovePatientFilterRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaRemovePatientFilterRequest
Returns a new instance of GoogleCloudDiscoveryengineV1alphaRemovePatientFilterRequest.
15688 15689 15690 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15688 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_store ⇒ String
Required. Full resource name of DataStore, such as projects/project/
locations/location/collections/collection_id/dataStores/data_store_id`.
If the caller does not have permission to access the DataStore, regardless of
whether or not it exists, a PERMISSION_DENIED error is returned. If the
requested DataStore does not exist, a NOT_FOUND error is returned. If the
requested DataStore does not have a patient filter, a NOT_FOUND error will be
returned
Corresponds to the JSON propertydataStore`
15671 15672 15673 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15671 def data_store @data_store end |
#filter_groups ⇒ Array<String>
Required. Names of the Group resources to use as a basis for the list of
patients to remove from the patient filter, in format projects/project_id/
locations/location_id/datasets/dataset_id/fhirStores/fhir_store_id/fhir/
Group/group_id`. if the caller does not have permission to access the FHIR
store, regardless of whether it exists, PERMISSION_DENIED error is returned.
If the discovery engine service account does not have permission to access the
FHIR store, regardless of whether or not it exists, a PERMISSION_DENIED error
is returned. If the group is not found at the location, a RESOURCE_NOT_FOUND
error will be returned. The filter group must be a FHIR resource name of type
Group, and the list of IDs to remove will be constructed from the direct
members of the group which are Patient resources.
Corresponds to the JSON propertyfilterGroups`
15686 15687 15688 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15686 def filter_groups @filter_groups end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15693 15694 15695 15696 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15693 def update!(**args) @data_store = args[:data_store] if args.key?(:data_store) @filter_groups = args[:filter_groups] if args.key?(:filter_groups) end |