Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaRemovePatientFilterRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Request for DataStoreService.RemovePatientFilter method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaRemovePatientFilterRequest

Returns a new instance of GoogleCloudDiscoveryengineV1alphaRemovePatientFilterRequest.



14855
14856
14857
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14855

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_storeString

Required. Full resource name of DataStore, such as projects/project/ locations/location/collections/collection_id/dataStores/data_store_id`. If the caller does not have permission to access the DataStore, regardless of whether or not it exists, a PERMISSION_DENIED error is returned. If the requested DataStore does not exist, a NOT_FOUND error is returned. If the requested DataStore does not have a patient filter, a NOT_FOUND error will be returned Corresponds to the JSON propertydataStore`

Returns:

  • (String)


14838
14839
14840
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14838

def data_store
  @data_store
end

#filter_groupsArray<String>

Required. Names of the Group resources to use as a basis for the list of patients to remove from the patient filter, in format projects/project_id/ locations/location_id/datasets/dataset_id/fhirStores/fhir_store_id/fhir/ Group/group_id`. if the caller does not have permission to access the FHIR store, regardless of whether it exists, PERMISSION_DENIED error is returned. If the discovery engine service account does not have permission to access the FHIR store, regardless of whether or not it exists, a PERMISSION_DENIED error is returned. If the group is not found at the location, a RESOURCE_NOT_FOUND error will be returned. The filter group must be a FHIR resource name of type Group, and the list of IDs to remove will be constructed from the direct members of the group which are Patient resources. Corresponds to the JSON propertyfilterGroups`

Returns:

  • (Array<String>)


14853
14854
14855
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14853

def filter_groups
  @filter_groups
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14860
14861
14862
14863
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14860

def update!(**args)
  @data_store = args[:data_store] if args.key?(:data_store)
  @filter_groups = args[:filter_groups] if args.key?(:filter_groups)
end