Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSchema

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Defines the structure and layout of a type of document data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaSchema

Returns a new instance of GoogleCloudDiscoveryengineV1alphaSchema.



14985
14986
14987
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14985

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#field_configsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaFieldConfig>

Output only. Configurations for fields of the schema. Corresponds to the JSON property fieldConfigs



14965
14966
14967
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14965

def field_configs
  @field_configs
end

#json_schemaString

The JSON representation of the schema. Corresponds to the JSON property jsonSchema

Returns:

  • (String)


14970
14971
14972
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14970

def json_schema
  @json_schema
end

#nameString

Immutable. The full resource name of the schema, in the format of projects/ project/locations/location/collections/collection/dataStores/data_store/ schemas/schema`. This field must be a UTF-8 encoded string with a length limit of 1024 characters. Corresponds to the JSON propertyname`

Returns:

  • (String)


14978
14979
14980
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14978

def name
  @name
end

#struct_schemaHash<String,Object>

The structured representation of the schema. Corresponds to the JSON property structSchema

Returns:

  • (Hash<String,Object>)


14983
14984
14985
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14983

def struct_schema
  @struct_schema
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14990
14991
14992
14993
14994
14995
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 14990

def update!(**args)
  @field_configs = args[:field_configs] if args.key?(:field_configs)
  @json_schema = args[:json_schema] if args.key?(:json_schema)
  @name = args[:name] if args.key?(:name)
  @struct_schema = args[:struct_schema] if args.key?(:struct_schema)
end