Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchLinkPromotion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Promotion proto includes uri and other helping information to display the promotion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaSearchLinkPromotion

Returns a new instance of GoogleCloudDiscoveryengineV1alphaSearchLinkPromotion.



15996
15997
15998
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15996

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Optional. The Promotion description. Maximum length: 200 characters. Corresponds to the JSON property description

Returns:

  • (String)


15964
15965
15966
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15964

def description
  @description
end

#documentString

Optional. The Document the user wants to promote. For site search, leave unset and only populate uri. Can be set along with uri. Corresponds to the JSON property document

Returns:

  • (String)


15970
15971
15972
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15970

def document
  @document
end

#enabledBoolean Also known as: enabled?

Optional. The enabled promotion will be returned for any serving configs associated with the parent of the control this promotion is attached to. This flag is used for basic site search only. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


15977
15978
15979
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15977

def enabled
  @enabled
end

#image_uriString

Optional. The promotion thumbnail image url. Corresponds to the JSON property imageUri

Returns:

  • (String)


15983
15984
15985
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15983

def image_uri
  @image_uri
end

#titleString

Required. The title of the promotion. Maximum length: 160 characters. Corresponds to the JSON property title

Returns:

  • (String)


15988
15989
15990
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15988

def title
  @title
end

#uriString

Optional. The URL for the page the user wants to promote. Must be set for site search. For other verticals, this is optional. Corresponds to the JSON property uri

Returns:

  • (String)


15994
15995
15996
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15994

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16001
16002
16003
16004
16005
16006
16007
16008
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16001

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @document = args[:document] if args.key?(:document)
  @enabled = args[:enabled] if args.key?(:enabled)
  @image_uri = args[:image_uri] if args.key?(:image_uri)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end