Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchLinkPromotion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Promotion proto includes uri and other helping information to display the promotion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaSearchLinkPromotion

Returns a new instance of GoogleCloudDiscoveryengineV1alphaSearchLinkPromotion.



16010
16011
16012
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16010

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Optional. The Promotion description. Maximum length: 200 characters. Corresponds to the JSON property description

Returns:

  • (String)


15978
15979
15980
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15978

def description
  @description
end

#documentString

Optional. The Document the user wants to promote. For site search, leave unset and only populate uri. Can be set along with uri. Corresponds to the JSON property document

Returns:

  • (String)


15984
15985
15986
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15984

def document
  @document
end

#enabledBoolean Also known as: enabled?

Optional. The enabled promotion will be returned for any serving configs associated with the parent of the control this promotion is attached to. This flag is used for basic site search only. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


15991
15992
15993
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15991

def enabled
  @enabled
end

#image_uriString

Optional. The promotion thumbnail image url. Corresponds to the JSON property imageUri

Returns:

  • (String)


15997
15998
15999
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15997

def image_uri
  @image_uri
end

#titleString

Required. The title of the promotion. Maximum length: 160 characters. Corresponds to the JSON property title

Returns:

  • (String)


16002
16003
16004
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16002

def title
  @title
end

#uriString

Optional. The URL for the page the user wants to promote. Must be set for site search. For other verticals, this is optional. Corresponds to the JSON property uri

Returns:

  • (String)


16008
16009
16010
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16008

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16015
16016
16017
16018
16019
16020
16021
16022
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16015

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @document = args[:document] if args.key?(:document)
  @enabled = args[:enabled] if args.key?(:enabled)
  @image_uri = args[:image_uri] if args.key?(:image_uri)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end