Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchLinkPromotion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Promotion proto includes uri and other helping information to display the promotion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaSearchLinkPromotion

Returns a new instance of GoogleCloudDiscoveryengineV1alphaSearchLinkPromotion.



15896
15897
15898
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15896

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Optional. The Promotion description. Maximum length: 200 characters. Corresponds to the JSON property description

Returns:

  • (String)


15864
15865
15866
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15864

def description
  @description
end

#documentString

Optional. The Document the user wants to promote. For site search, leave unset and only populate uri. Can be set along with uri. Corresponds to the JSON property document

Returns:

  • (String)


15870
15871
15872
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15870

def document
  @document
end

#enabledBoolean Also known as: enabled?

Optional. The enabled promotion will be returned for any serving configs associated with the parent of the control this promotion is attached to. This flag is used for basic site search only. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


15877
15878
15879
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15877

def enabled
  @enabled
end

#image_uriString

Optional. The promotion thumbnail image url. Corresponds to the JSON property imageUri

Returns:

  • (String)


15883
15884
15885
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15883

def image_uri
  @image_uri
end

#titleString

Required. The title of the promotion. Maximum length: 160 characters. Corresponds to the JSON property title

Returns:

  • (String)


15888
15889
15890
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15888

def title
  @title
end

#uriString

Optional. The URL for the page the user wants to promote. Must be set for site search. For other verticals, this is optional. Corresponds to the JSON property uri

Returns:

  • (String)


15894
15895
15896
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15894

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15901
15902
15903
15904
15905
15906
15907
15908
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15901

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @document = args[:document] if args.key?(:document)
  @enabled = args[:enabled] if args.key?(:enabled)
  @image_uri = args[:image_uri] if args.key?(:image_uri)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end