Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequest
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Request message for SearchService.Search method.
Instance Attribute Summary collapse
-
#boost_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestBoostSpec
Boost specification to boost certain documents.
-
#branch ⇒ String
The branch resource name, such as
projects/*/locations/global/collections/ default_collection/dataStores/default_data_store/branches/0. -
#canonical_filter ⇒ String
The default filter that is applied when a user performs a search without checking any filters on the search page.
-
#content_search_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestContentSearchSpec
A specification for configuring the behavior of content search.
-
#crowding_specs ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestCrowdingSpec>
Optional.
-
#custom_fine_tuning_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaCustomFineTuningSpec
Defines custom fine tuning spec.
-
#custom_ranking_params ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestCustomRankingParams
Configuration parameters for the Custom Ranking feature.
-
#data_store_specs ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestDataStoreSpec>
Specifications that define the specific DataStores to be searched, along with configurations for those data stores.
-
#display_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestDisplaySpec
Specifies features for display, like match highlighting.
-
#embedding_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestEmbeddingSpec
The specification that uses customized query embedding vector to do semantic document retrieval.
-
#entity ⇒ String
Optional.
-
#facet_specs ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestFacetSpec>
Facet specifications for faceted search.
-
#filter ⇒ String
The filter syntax consists of an expression language for constructing a predicate from one or more fields of the documents being filtered.
-
#image_query ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestImageQuery
Specifies the image query input.
-
#language_code ⇒ String
The BCP-47 language code, such as "en-US" or "sr-Latn".
-
#natural_language_query_understanding_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestNaturalLanguageQueryUnderstandingSpec
Specification to enable natural language understanding capabilities for search requests.
-
#num_results_per_data_store ⇒ Fixnum
Optional.
-
#offset ⇒ Fixnum
A 0-indexed integer that specifies the current offset (that is, starting result location, amongst the Documents deemed by the API as relevant) in search results.
-
#one_box_page_size ⇒ Fixnum
The maximum number of results to return for OneBox.
-
#order_by ⇒ String
The order in which documents are returned.
-
#page_categories ⇒ Array<String>
Optional.
-
#page_size ⇒ Fixnum
Maximum number of Documents to return.
-
#page_token ⇒ String
A page token received from a previous SearchService.Search call.
-
#params ⇒ Hash<String,Object>
Additional search parameters.
-
#personalization_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestPersonalizationSpec
The specification for personalization.
-
#query ⇒ String
Raw search query.
-
#query_expansion_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestQueryExpansionSpec
Specification to determine under which conditions query expansion should occur.
-
#ranking_expression ⇒ String
Optional.
-
#ranking_expression_backend ⇒ String
Optional.
-
#region_code ⇒ String
The Unicode country/region code (CLDR) of a location, such as "US" and "419".
-
#relevance_filter_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestRelevanceFilterSpec
Relevance filtering specification.
-
#relevance_score_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestRelevanceScoreSpec
The specification for returning the document relevance score.
-
#relevance_threshold ⇒ String
The global relevance threshold of the search results.
-
#safe_search ⇒ Boolean
(also: #safe_search?)
Whether to turn on safe search.
-
#search_addon_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestSearchAddonSpec
SearchAddonSpec is used to disable add-ons for search as per new repricing model.
-
#search_as_you_type_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestSearchAsYouTypeSpec
Specification for search as you type in search requests.
-
#serving_config ⇒ String
Required.
-
#session ⇒ String
The session resource name.
-
#session_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestSessionSpec
Session specification.
-
#spell_correction_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestSpellCorrectionSpec
The specification for query spell correction.
-
#use_latest_data ⇒ Boolean
(also: #use_latest_data?)
Uses the Engine, ServingConfig and Control freshly read from the database.
-
#user_info ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaUserInfo
Information of an end user.
-
#user_labels ⇒ Hash<String,String>
The user labels applied to a resource must meet the following requirements: * Each resource can have multiple labels, up to a maximum of 64.
-
#user_pseudo_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaSearchRequest
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaSearchRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaSearchRequest
Returns a new instance of GoogleCloudDiscoveryengineV1alphaSearchRequest.
16315 16316 16317 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16315 def initialize(**args) update!(**args) end |
Instance Attribute Details
#boost_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestBoostSpec
Boost specification to boost certain documents.
Corresponds to the JSON property boostSpec
15918 15919 15920 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15918 def boost_spec @boost_spec end |
#branch ⇒ String
The branch resource name, such as projects/*/locations/global/collections/
default_collection/dataStores/default_data_store/branches/0. Use
default_branch as the branch ID or leave this field empty, to search
documents under the default branch.
Corresponds to the JSON property branch
15926 15927 15928 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15926 def branch @branch end |
#canonical_filter ⇒ String
The default filter that is applied when a user performs a search without
checking any filters on the search page. The filter applied to every search
request when quality improvement such as query expansion is needed. In the
case a query does not have a sufficient amount of results this filter will be
used to determine whether or not to enable the query expansion flow. The
original filter will still be used for the query expanded search. This field
is strongly recommended to achieve high search quality. For more information
about filter syntax, see SearchRequest.filter.
Corresponds to the JSON property canonicalFilter
15938 15939 15940 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15938 def canonical_filter @canonical_filter end |
#content_search_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestContentSearchSpec
A specification for configuring the behavior of content search.
Corresponds to the JSON property contentSearchSpec
15943 15944 15945 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15943 def content_search_spec @content_search_spec end |
#crowding_specs ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestCrowdingSpec>
Optional. Crowding specifications for improving result diversity. If multiple
CrowdingSpecs are specified, crowding will be evaluated on each unique
combination of the field values, and max_count will be the maximum value of
max_count across all CrowdingSpecs. For example, if the first CrowdingSpec
has field = "color" and max_count = 3, and the second CrowdingSpec has
field = "size" and max_count = 2, then after 3 documents that share the
same color AND size have been returned, subsequent ones should be removed or
demoted.
Corresponds to the JSON property crowdingSpecs
15955 15956 15957 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15955 def crowding_specs @crowding_specs end |
#custom_fine_tuning_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaCustomFineTuningSpec
Defines custom fine tuning spec.
Corresponds to the JSON property customFineTuningSpec
15960 15961 15962 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15960 def custom_fine_tuning_spec @custom_fine_tuning_spec end |
#custom_ranking_params ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestCustomRankingParams
Configuration parameters for the Custom Ranking feature.
Corresponds to the JSON property customRankingParams
15965 15966 15967 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15965 def custom_ranking_params @custom_ranking_params end |
#data_store_specs ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestDataStoreSpec>
Specifications that define the specific DataStores to be searched, along with
configurations for those data stores. This is only considered for Engines with
multiple data stores. For engines with a single data store, the specs directly
under SearchRequest should be used.
Corresponds to the JSON property dataStoreSpecs
15973 15974 15975 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15973 def data_store_specs @data_store_specs end |
#display_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestDisplaySpec
Specifies features for display, like match highlighting.
Corresponds to the JSON property displaySpec
15978 15979 15980 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15978 def display_spec @display_spec end |
#embedding_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestEmbeddingSpec
The specification that uses customized query embedding vector to do semantic
document retrieval.
Corresponds to the JSON property embeddingSpec
15984 15985 15986 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15984 def @embedding_spec end |
#entity ⇒ String
Optional. The entity for customers that may run multiple different entities,
domains, sites or regions, for example, "Google US", "Google Ads", "Waymo", "
google.com", "youtube.com", etc. If this is set, it should be exactly matched
with UserEvent.entity to get search results boosted by entity.
Corresponds to the JSON property entity
15992 15993 15994 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15992 def entity @entity end |
#facet_specs ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestFacetSpec>
Facet specifications for faceted search. If empty, no facets are returned. A
maximum of 100 values are allowed. Otherwise, an INVALID_ARGUMENT error is
returned.
Corresponds to the JSON property facetSpecs
15999 16000 16001 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15999 def facet_specs @facet_specs end |
#filter ⇒ String
The filter syntax consists of an expression language for constructing a
predicate from one or more fields of the documents being filtered. Filter
expression is case-sensitive. If this field is unrecognizable, an
INVALID_ARGUMENT is returned. Filtering in Vertex AI Search is done by
mapping the LHS filter key to a key property defined in the Vertex AI Search
backend -- this mapping is defined by the customer in their schema. For
example a media customer might have a field 'name' in their schema. In this
case the filter would look like this: filter --> name:'ANY("king kong")' For
more information about filtering including syntax and filter operators, see
Filter
Corresponds to the JSON property filter
16014 16015 16016 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16014 def filter @filter end |
#image_query ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestImageQuery
Specifies the image query input.
Corresponds to the JSON property imageQuery
16019 16020 16021 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16019 def image_query @image_query end |
#language_code ⇒ String
The BCP-47 language code, such as "en-US" or "sr-Latn". For more information,
see Standard fields.
This field helps to better interpret the query. If a value isn't specified,
the query language code is automatically detected, which may not be accurate.
Corresponds to the JSON property languageCode
16027 16028 16029 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16027 def language_code @language_code end |
#natural_language_query_understanding_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestNaturalLanguageQueryUnderstandingSpec
Specification to enable natural language understanding capabilities for search
requests.
Corresponds to the JSON property naturalLanguageQueryUnderstandingSpec
16033 16034 16035 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16033 def natural_language_query_understanding_spec @natural_language_query_understanding_spec end |
#num_results_per_data_store ⇒ Fixnum
Optional. The maximum number of results to retrieve from each data store. If
not specified, it will use the SearchRequest.DataStoreSpec.num_results if
provided, otherwise there is no limit.
Corresponds to the JSON property numResultsPerDataStore
16040 16041 16042 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16040 def num_results_per_data_store @num_results_per_data_store end |
#offset ⇒ Fixnum
A 0-indexed integer that specifies the current offset (that is, starting
result location, amongst the Documents deemed by the API as relevant) in
search results. This field is only considered if page_token is unset. If this
field is negative, an INVALID_ARGUMENT is returned. A large offset may be
capped to a reasonable threshold.
Corresponds to the JSON property offset
16049 16050 16051 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16049 def offset @offset end |
#one_box_page_size ⇒ Fixnum
The maximum number of results to return for OneBox. This applies to each
OneBox type individually. Default number is 10.
Corresponds to the JSON property oneBoxPageSize
16055 16056 16057 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16055 def one_box_page_size @one_box_page_size end |
#order_by ⇒ String
The order in which documents are returned. Documents can be ordered by a field
in an Document object. Leave it unset if ordered by relevance. order_by
expression is case-sensitive. For more information on ordering the website
search results, see Order web search results. For more information
on ordering the healthcare search results, see Order healthcare search
results. If this field is unrecognizable, an INVALID_ARGUMENT is returned.
Corresponds to the JSON property orderBy
16067 16068 16069 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16067 def order_by @order_by end |
#page_categories ⇒ Array<String>
Optional. The categories associated with a category page. Must be set for
category navigation queries to achieve good search quality. The format should
be the same as PageInfo.page_category. This field is the equivalent of the
query for browse (navigation) queries. It's used by the browse model when the
query is empty. If the field is empty, it will not be used by the browse model.
If the field contains more than one element, only the first element will be
used. To represent full path of a category, use '>' character to separate
different hierarchies. If '>' is part of the category name, replace it with
other character(s). For example, Graphics Cards > RTX>4090 > Founders Edition
where "RTX > 4090" represents one level, can be rewritten as Graphics Cards >
RTX_4090 > Founders Edition
Corresponds to the JSON property pageCategories
16082 16083 16084 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16082 def page_categories @page_categories end |
#page_size ⇒ Fixnum
Maximum number of Documents to return. The maximum allowed value depends on the data type. Values above the maximum value are coerced to the maximum value.
- Websites with basic indexing: Default
10, Maximum25. * Websites with advanced indexing: Default25, Maximum50. * Other: Default50, Maximum100. If this field is negative, anINVALID_ARGUMENTis returned. Corresponds to the JSON propertypageSize
16091 16092 16093 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16091 def page_size @page_size end |
#page_token ⇒ String
A page token received from a previous SearchService.Search call. Provide this
to retrieve the subsequent page. When paginating, all other parameters
provided to SearchService.Search must match the call that provided the page
token. Otherwise, an INVALID_ARGUMENT error is returned.
Corresponds to the JSON property pageToken
16099 16100 16101 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16099 def page_token @page_token end |
#params ⇒ Hash<String,Object>
Additional search parameters. For public website search only, supported values
are: * user_country_code: string. Default empty. If set to non-empty,
results are restricted or boosted based on the location provided. For example,
user_country_code: "au" For available codes see Country Codes *
search_type: double. Default empty. Enables non-webpage searching depending
on the value. The only valid non-default value is 1, which enables image
searching. For example, search_type: 1
Corresponds to the JSON property params
16111 16112 16113 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16111 def params @params end |
#personalization_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestPersonalizationSpec
The specification for personalization.
Corresponds to the JSON property personalizationSpec
16116 16117 16118 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16116 def personalization_spec @personalization_spec end |
#query ⇒ String
Raw search query.
Corresponds to the JSON property query
16121 16122 16123 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16121 def query @query end |
#query_expansion_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestQueryExpansionSpec
Specification to determine under which conditions query expansion should occur.
Corresponds to the JSON property queryExpansionSpec
16126 16127 16128 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16126 def query_expansion_spec @query_expansion_spec end |
#ranking_expression ⇒ String
Optional. The ranking expression controls the customized ranking on retrieval
documents. This overrides ServingConfig.ranking_expression. The syntax and
supported features depend on the ranking_expression_backend value. If
ranking_expression_backend is not provided, it defaults to RANK_BY_EMBEDDING
. If ranking_expression_backend is not provided or set to RANK_BY_EMBEDDING,
it should be a single function or multiple functions that are joined by "+". *
ranking_expression = function, " + ", function; Supported functions: *
double * relevance_score * double * dotProduct(embedding_field_path) Function
variables: * relevance_score: pre-defined keywords, used for measure
relevance between query and document. * embedding_field_path: the document
embedding field used with query embedding vector. * dotProduct: embedding
function between embedding_field_path and query embedding vector. Example
ranking expression: If document has an embedding field doc_embedding, the
ranking expression could be 0.5 * relevance_score + 0.3 * dotProduct(
doc_embedding). If ranking_expression_backend is set to RANK_BY_FORMULA,
the following expression types (and combinations of those chained using + or *
operators) are supported: * double * signal * log(signal) * exp(signal)
rr(signal, double > 0)-- reciprocal rank transformation with second argument being a denominator constant. *is_nan(signal)-- returns 0 if signal is NaN, 1 otherwise. *fill_nan(signal1, signal2 | double)-- if signal1 is NaN, returns signal2 | double, else returns signal1. Here are a few examples of ranking formulas that use the supported ranking expression types: -0.2 * semantic_similarity_score + 0.8 * log(keyword_similarity_score)-- mostly rank by the logarithm ofkeyword_similarity_scorewith slightsemantic_smilarity_scoreadjustment. -0.2 * exp(fill_nan( semantic_similarity_score, 0)) + 0.3 * is_nan(keyword_similarity_score)-- rank by the exponent ofsemantic_similarity_scorefilling the value with 0 if it's NaN, also add constant 0.3 adjustment to the final score ifsemantic_similarity_scoreis NaN. -0.2 * rr(semantic_similarity_score, 16) + 0.8 * rr(keyword_similarity_score, 16)-- mostly rank by the reciprocal rank ofkeyword_similarity_scorewith slight adjustment of reciprocal rank ofsemantic_smilarity_score. The following signals are supported: *semantic_similarity_score: semantic similarity adjustment that is calculated using the embeddings generated by a proprietary Google model. This score determines how semantically similar a search query is to a document. *keyword_similarity_score: keyword match adjustment uses the Best Match 25 ( BM25) ranking function. This score is calculated using a probabilistic model to estimate the probability that a document is relevant to a given query. *relevance_score: semantic relevance adjustment that uses a proprietary Google model to determine the meaning and intent behind a user's query in context with the content in the documents. *pctr_rank: predicted conversion rate adjustment as a rank use predicted Click-through rate (pCTR) to gauge the relevance and attractiveness of a search result from a user's perspective. A higher pCTR suggests that the result is more likely to satisfy the user's query and intent, making it a valuable signal for ranking. *freshness_rank: freshness adjustment as a rank *document_age: The time in hours elapsed since the document was last updated, a floating-point number (e.g., 0.25 means 15 minutes). *topicality_rank: topicality adjustment as a rank. Uses proprietary Google model to determine the keyword-based overlap between the query and the document. *base_rank: the default rank of the result *media_actor_match: whether the media actor matches the query *media_director_match: whether the media director matches the query *media_genre_match: whether the media genre matches the query *media_language_match: whether the media language matches the query *media_title_match: whether the media title matches the query *media_prefix_similarity_rank: prefix similarity rank for media results *media_semantic_similarity_rank: semantic similarity rank for media results Corresponds to the JSON propertyrankingExpression
16187 16188 16189 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16187 def ranking_expression @ranking_expression end |
#ranking_expression_backend ⇒ String
Optional. The backend to use for the ranking expression evaluation.
Corresponds to the JSON property rankingExpressionBackend
16192 16193 16194 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16192 def ranking_expression_backend @ranking_expression_backend end |
#region_code ⇒ String
The Unicode country/region code (CLDR) of a location, such as "US" and "419".
For more information, see Standard fields. If set, then results will be boosted based on the
region_code provided.
Corresponds to the JSON property regionCode
16200 16201 16202 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16200 def region_code @region_code end |
#relevance_filter_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestRelevanceFilterSpec
Relevance filtering specification.
Corresponds to the JSON property relevanceFilterSpec
16205 16206 16207 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16205 def relevance_filter_spec @relevance_filter_spec end |
#relevance_score_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestRelevanceScoreSpec
The specification for returning the document relevance score.
Corresponds to the JSON property relevanceScoreSpec
16210 16211 16212 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16210 def relevance_score_spec @relevance_score_spec end |
#relevance_threshold ⇒ String
The global relevance threshold of the search results. Defaults to Google
defined threshold, leveraging a balance of precision and recall to deliver
both highly accurate results and comprehensive coverage of relevant
information. If more granular relevance filtering is required, use the
relevance_filter_spec instead. This feature is not supported for healthcare
search.
Corresponds to the JSON property relevanceThreshold
16220 16221 16222 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16220 def relevance_threshold @relevance_threshold end |
#safe_search ⇒ Boolean Also known as: safe_search?
Whether to turn on safe search. This is only supported for website search.
Corresponds to the JSON property safeSearch
16225 16226 16227 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16225 def safe_search @safe_search end |
#search_addon_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestSearchAddonSpec
SearchAddonSpec is used to disable add-ons for search as per new repricing
model. By default if the SearchAddonSpec is not specified, we consider that
the customer wants to enable them wherever applicable.
Corresponds to the JSON property searchAddonSpec
16233 16234 16235 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16233 def search_addon_spec @search_addon_spec end |
#search_as_you_type_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestSearchAsYouTypeSpec
Specification for search as you type in search requests.
Corresponds to the JSON property searchAsYouTypeSpec
16238 16239 16240 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16238 def search_as_you_type_spec @search_as_you_type_spec end |
#serving_config ⇒ String
Required. The resource name of the Search serving config, such as projects/*/
locations/global/collections/default_collection/engines/*/servingConfigs/
default_serving_config, or projects/*/locations/global/collections/
default_collection/dataStores/default_data_store/servingConfigs/
default_serving_config. This field is used to identify the serving
configuration name, set of models used to make the search.
Corresponds to the JSON property servingConfig
16248 16249 16250 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16248 def serving_config @serving_config end |
#session ⇒ String
The session resource name. Optional. Session allows users to do multi-turn /
search API calls or coordination between /search API calls and /answer API
calls. Example #1 (multi-turn /search API calls): Call /search API with the
session ID generated in the first call. Here, the previous search query gets
considered in query standing. I.e., if the first query is "How did Alphabet do
in 2022?" and the current query is "How about 2023?", the current query will
be interpreted as "How did Alphabet do in 2023?". Example #2 (coordination
between /search API calls and /answer API calls): Call /answer API with the
session ID generated in the first call. Here, the answer generation happens in
the context of the search results from the first search call.
Corresponds to the JSON property session
16262 16263 16264 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16262 def session @session end |
#session_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestSessionSpec
Session specification.
Corresponds to the JSON property sessionSpec
16267 16268 16269 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16267 def session_spec @session_spec end |
#spell_correction_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestSpellCorrectionSpec
The specification for query spell correction.
Corresponds to the JSON property spellCorrectionSpec
16272 16273 16274 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16272 def spell_correction_spec @spell_correction_spec end |
#use_latest_data ⇒ Boolean Also known as: use_latest_data?
Uses the Engine, ServingConfig and Control freshly read from the database.
Note: this skips config cache and introduces dependency on databases, which
could significantly increase the API latency. It should only be used for
testing, but not serving end users.
Corresponds to the JSON property useLatestData
16280 16281 16282 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16280 def use_latest_data @use_latest_data end |
#user_info ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaUserInfo
Information of an end user.
Corresponds to the JSON property userInfo
16286 16287 16288 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16286 def user_info @user_info end |
#user_labels ⇒ Hash<String,String>
The user labels applied to a resource must meet the following requirements: *
Each resource can have multiple labels, up to a maximum of 64. * Each label
must be a key-value pair. * Keys have a minimum length of 1 character and a
maximum length of 63 characters and cannot be empty. Values can be empty and
have a maximum length of 63 characters. * Keys and values can contain only
lowercase letters, numeric characters, underscores, and dashes. All characters
must use UTF-8 encoding, and international characters are allowed. * The key
portion of a label must be unique. However, you can use the same key with
multiple resources. * Keys must start with a lowercase letter or international
character. See Google Cloud Document for more details.
Corresponds to the JSON property userLabels
16301 16302 16303 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16301 def user_labels @user_labels end |
#user_pseudo_id ⇒ String
Optional. A unique identifier for tracking visitors. For example, this could
be implemented with an HTTP cookie, which should be able to uniquely identify
a visitor on a single device. This unique identifier should not change if the
visitor logs in or out of the website. This field should NOT have a fixed
value such as unknown_visitor. This should be the same identifier as
UserEvent.user_pseudo_id and CompleteQueryRequest.user_pseudo_id The field
must be a UTF-8 encoded string with a length limit of 128 characters.
Otherwise, an INVALID_ARGUMENT error is returned.
Corresponds to the JSON property userPseudoId
16313 16314 16315 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16313 def user_pseudo_id @user_pseudo_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16320 16321 16322 16323 16324 16325 16326 16327 16328 16329 16330 16331 16332 16333 16334 16335 16336 16337 16338 16339 16340 16341 16342 16343 16344 16345 16346 16347 16348 16349 16350 16351 16352 16353 16354 16355 16356 16357 16358 16359 16360 16361 16362 16363 16364 16365 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16320 def update!(**args) @boost_spec = args[:boost_spec] if args.key?(:boost_spec) @branch = args[:branch] if args.key?(:branch) @canonical_filter = args[:canonical_filter] if args.key?(:canonical_filter) @content_search_spec = args[:content_search_spec] if args.key?(:content_search_spec) @crowding_specs = args[:crowding_specs] if args.key?(:crowding_specs) @custom_fine_tuning_spec = args[:custom_fine_tuning_spec] if args.key?(:custom_fine_tuning_spec) @custom_ranking_params = args[:custom_ranking_params] if args.key?(:custom_ranking_params) @data_store_specs = args[:data_store_specs] if args.key?(:data_store_specs) @display_spec = args[:display_spec] if args.key?(:display_spec) @embedding_spec = args[:embedding_spec] if args.key?(:embedding_spec) @entity = args[:entity] if args.key?(:entity) @facet_specs = args[:facet_specs] if args.key?(:facet_specs) @filter = args[:filter] if args.key?(:filter) @image_query = args[:image_query] if args.key?(:image_query) @language_code = args[:language_code] if args.key?(:language_code) @natural_language_query_understanding_spec = args[:natural_language_query_understanding_spec] if args.key?(:natural_language_query_understanding_spec) @num_results_per_data_store = args[:num_results_per_data_store] if args.key?(:num_results_per_data_store) @offset = args[:offset] if args.key?(:offset) @one_box_page_size = args[:one_box_page_size] if args.key?(:one_box_page_size) @order_by = args[:order_by] if args.key?(:order_by) @page_categories = args[:page_categories] if args.key?(:page_categories) @page_size = args[:page_size] if args.key?(:page_size) @page_token = args[:page_token] if args.key?(:page_token) @params = args[:params] if args.key?(:params) @personalization_spec = args[:personalization_spec] if args.key?(:personalization_spec) @query = args[:query] if args.key?(:query) @query_expansion_spec = args[:query_expansion_spec] if args.key?(:query_expansion_spec) @ranking_expression = args[:ranking_expression] if args.key?(:ranking_expression) @ranking_expression_backend = args[:ranking_expression_backend] if args.key?(:ranking_expression_backend) @region_code = args[:region_code] if args.key?(:region_code) @relevance_filter_spec = args[:relevance_filter_spec] if args.key?(:relevance_filter_spec) @relevance_score_spec = args[:relevance_score_spec] if args.key?(:relevance_score_spec) @relevance_threshold = args[:relevance_threshold] if args.key?(:relevance_threshold) @safe_search = args[:safe_search] if args.key?(:safe_search) @search_addon_spec = args[:search_addon_spec] if args.key?(:search_addon_spec) @search_as_you_type_spec = args[:search_as_you_type_spec] if args.key?(:search_as_you_type_spec) @serving_config = args[:serving_config] if args.key?(:serving_config) @session = args[:session] if args.key?(:session) @session_spec = args[:session_spec] if args.key?(:session_spec) @spell_correction_spec = args[:spell_correction_spec] if args.key?(:spell_correction_spec) @use_latest_data = args[:use_latest_data] if args.key?(:use_latest_data) @user_info = args[:user_info] if args.key?(:user_info) @user_labels = args[:user_labels] if args.key?(:user_labels) @user_pseudo_id = args[:user_pseudo_id] if args.key?(:user_pseudo_id) end |