Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestContentSearchSpec
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestContentSearchSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
A specification for configuring the behavior of content search.
Instance Attribute Summary collapse
-
#chunk_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestContentSearchSpecChunkSpec
Specifies the chunk spec to be returned from the search response.
-
#extractive_content_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestContentSearchSpecExtractiveContentSpec
A specification for configuring the extractive content in a search response.
-
#search_result_mode ⇒ String
Specifies the search result mode.
-
#snippet_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestContentSearchSpecSnippetSpec
A specification for configuring snippets in a search response.
-
#summary_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestContentSearchSpecSummarySpec
A specification for configuring a summary returned in a search response.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaSearchRequestContentSearchSpec
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaSearchRequestContentSearchSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaSearchRequestContentSearchSpec
Returns a new instance of GoogleCloudDiscoveryengineV1alphaSearchRequestContentSearchSpec.
15690 15691 15692 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15690 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chunk_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestContentSearchSpecChunkSpec
Specifies the chunk spec to be returned from the search response. Only
available if the SearchRequest.ContentSearchSpec.search_result_mode is set to
CHUNKS
Corresponds to the JSON property chunkSpec
15667 15668 15669 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15667 def chunk_spec @chunk_spec end |
#extractive_content_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestContentSearchSpecExtractiveContentSpec
A specification for configuring the extractive content in a search response.
Corresponds to the JSON property extractiveContentSpec
15672 15673 15674 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15672 def extractive_content_spec @extractive_content_spec end |
#search_result_mode ⇒ String
Specifies the search result mode. If unspecified, the search result mode
defaults to DOCUMENTS.
Corresponds to the JSON property searchResultMode
15678 15679 15680 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15678 def search_result_mode @search_result_mode end |
#snippet_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestContentSearchSpecSnippetSpec
A specification for configuring snippets in a search response.
Corresponds to the JSON property snippetSpec
15683 15684 15685 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15683 def snippet_spec @snippet_spec end |
#summary_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestContentSearchSpecSummarySpec
A specification for configuring a summary returned in a search response.
Corresponds to the JSON property summarySpec
15688 15689 15690 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15688 def summary_spec @summary_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15695 15696 15697 15698 15699 15700 15701 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15695 def update!(**args) @chunk_spec = args[:chunk_spec] if args.key?(:chunk_spec) @extractive_content_spec = args[:extractive_content_spec] if args.key?(:extractive_content_spec) @search_result_mode = args[:search_result_mode] if args.key?(:search_result_mode) @snippet_spec = args[:snippet_spec] if args.key?(:snippet_spec) @summary_spec = args[:summary_spec] if args.key?(:summary_spec) end |