Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestContentSearchSpecChunkSpec
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestContentSearchSpecChunkSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Specifies the chunk spec to be returned from the search response. Only available if the SearchRequest.ContentSearchSpec.search_result_mode is set to CHUNKS
Instance Attribute Summary collapse
-
#num_next_chunks ⇒ Fixnum
The number of next chunks to be returned of the current chunk.
-
#num_previous_chunks ⇒ Fixnum
The number of previous chunks to be returned of the current chunk.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaSearchRequestContentSearchSpecChunkSpec
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaSearchRequestContentSearchSpecChunkSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaSearchRequestContentSearchSpecChunkSpec
Returns a new instance of GoogleCloudDiscoveryengineV1alphaSearchRequestContentSearchSpecChunkSpec.
15722 15723 15724 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15722 def initialize(**args) update!(**args) end |
Instance Attribute Details
#num_next_chunks ⇒ Fixnum
The number of next chunks to be returned of the current chunk. The maximum
allowed value is 3. If not specified, no next chunks will be returned.
Corresponds to the JSON property numNextChunks
15714 15715 15716 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15714 def num_next_chunks @num_next_chunks end |
#num_previous_chunks ⇒ Fixnum
The number of previous chunks to be returned of the current chunk. The maximum
allowed value is 3. If not specified, no previous chunks will be returned.
Corresponds to the JSON property numPreviousChunks
15720 15721 15722 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15720 def num_previous_chunks @num_previous_chunks end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15727 15728 15729 15730 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15727 def update!(**args) @num_next_chunks = args[:num_next_chunks] if args.key?(:num_next_chunks) @num_previous_chunks = args[:num_previous_chunks] if args.key?(:num_previous_chunks) end |