Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestContentSearchSpecExtractiveContentSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

A specification for configuring the extractive content in a search response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaSearchRequestContentSearchSpecExtractiveContentSpec

Returns a new instance of GoogleCloudDiscoveryengineV1alphaSearchRequestContentSearchSpecExtractiveContentSpec.



15781
15782
15783
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15781

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_extractive_answer_countFixnum

The maximum number of extractive answers returned in each search result. An extractive answer is a verbatim answer extracted from the original document, which provides a precise and contextually relevant answer to the search query. If the number of matching answers is less than the max_extractive_answer_count, return all of the answers. Otherwise, return the max_extractive_answer_count. At most five answers are returned for each SearchResult. Corresponds to the JSON property maxExtractiveAnswerCount

Returns:

  • (Fixnum)


15746
15747
15748
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15746

def max_extractive_answer_count
  @max_extractive_answer_count
end

#max_extractive_segment_countFixnum

The max number of extractive segments returned in each search result. Only applied if the DataStore is set to DataStore.ContentConfig.CONTENT_REQUIRED or DataStore.solution_types is SOLUTION_TYPE_CHAT. An extractive segment is a text segment extracted from the original document that is relevant to the search query, and, in general, more verbose than an extractive answer. The segment could then be used as input for LLMs to generate summaries and answers. If the number of matching segments is less than max_extractive_segment_count , return all of the segments. Otherwise, return the max_extractive_segment_count. Corresponds to the JSON property maxExtractiveSegmentCount

Returns:

  • (Fixnum)


15759
15760
15761
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15759

def max_extractive_segment_count
  @max_extractive_segment_count
end

#num_next_segmentsFixnum

Return at most num_next_segments segments after each selected segments. Corresponds to the JSON property numNextSegments

Returns:

  • (Fixnum)


15764
15765
15766
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15764

def num_next_segments
  @num_next_segments
end

#num_previous_segmentsFixnum

Specifies whether to also include the adjacent from each selected segments. Return at most num_previous_segments segments before each selected segments. Corresponds to the JSON property numPreviousSegments

Returns:

  • (Fixnum)


15770
15771
15772
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15770

def num_previous_segments
  @num_previous_segments
end

#return_extractive_segment_scoreBoolean Also known as: return_extractive_segment_score?

Specifies whether to return the confidence score from the extractive segments in each search result. This feature is available only for new or allowlisted data stores. To allowlist your data store, contact your Customer Engineer. The default value is false. Corresponds to the JSON property returnExtractiveSegmentScore

Returns:

  • (Boolean)


15778
15779
15780
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15778

def return_extractive_segment_score
  @return_extractive_segment_score
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15786
15787
15788
15789
15790
15791
15792
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 15786

def update!(**args)
  @max_extractive_answer_count = args[:max_extractive_answer_count] if args.key?(:max_extractive_answer_count)
  @max_extractive_segment_count = args[:max_extractive_segment_count] if args.key?(:max_extractive_segment_count)
  @num_next_segments = args[:num_next_segments] if args.key?(:num_next_segments)
  @num_previous_segments = args[:num_previous_segments] if args.key?(:num_previous_segments)
  @return_extractive_segment_score = args[:return_extractive_segment_score] if args.key?(:return_extractive_segment_score)
end