Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestCrowdingSpec
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestCrowdingSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Specification for crowding. Crowding improves the diversity of search results by limiting the number of results that share the same field value. For example, crowding on the color field with a max_count of 3 and mode DROP_CROWDED_RESULTS will return at most 3 results with the same color across all pages.
Instance Attribute Summary collapse
-
#field ⇒ String
The field to use for crowding.
-
#max_count ⇒ Fixnum
The maximum number of documents to keep per value of the field.
-
#mode ⇒ String
Mode to use for documents that are crowded away.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaSearchRequestCrowdingSpec
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaSearchRequestCrowdingSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaSearchRequestCrowdingSpec
Returns a new instance of GoogleCloudDiscoveryengineV1alphaSearchRequestCrowdingSpec.
16855 16856 16857 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16855 def initialize(**args) update!(**args) end |
Instance Attribute Details
#field ⇒ String
The field to use for crowding. Documents can be crowded by a field in the
Document object. Crowding field is case sensitive.
Corresponds to the JSON property field
16840 16841 16842 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16840 def field @field end |
#max_count ⇒ Fixnum
The maximum number of documents to keep per value of the field. Once there are
at least max_count previous results which contain the same value for the given
field (according to the order specified in order_by), later results with the
same value are "crowded away". If not specified, the default value is 1.
Corresponds to the JSON property maxCount
16848 16849 16850 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16848 def max_count @max_count end |
#mode ⇒ String
Mode to use for documents that are crowded away.
Corresponds to the JSON property mode
16853 16854 16855 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16853 def mode @mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16860 16861 16862 16863 16864 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16860 def update!(**args) @field = args[:field] if args.key?(:field) @max_count = args[:max_count] if args.key?(:max_count) @mode = args[:mode] if args.key?(:mode) end |