Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestDataStoreSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

A struct to define data stores to filter on in a search call and configurations for those data stores. Otherwise, an INVALID_ARGUMENT error is returned.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaSearchRequestDataStoreSpec

Returns a new instance of GoogleCloudDiscoveryengineV1alphaSearchRequestDataStoreSpec.



17099
17100
17101
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17099

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#boost_specGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestBoostSpec

Boost specification to boost certain documents. Corresponds to the JSON property boostSpec



17066
17067
17068
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17066

def boost_spec
  @boost_spec
end

#custom_search_operatorsString

Optional. Custom search operators which if specified will be used to filter results from workspace data stores. For more information on custom search operators, see SearchOperators. Corresponds to the JSON property customSearchOperators

Returns:

  • (String)


17074
17075
17076
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17074

def custom_search_operators
  @custom_search_operators
end

#data_storeString

Required. Full resource name of DataStore, such as projects/project/ locations/location/collections/collection_id/dataStores/data_store_id`. The path must include the project number, project id is not supported for this field. Corresponds to the JSON propertydataStore`

Returns:

  • (String)


17082
17083
17084
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17082

def data_store
  @data_store
end

#filterString

Optional. Filter specification to filter documents in the data store specified by data_store field. For more information on filtering, see Filtering Corresponds to the JSON property filter

Returns:

  • (String)


17089
17090
17091
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17089

def filter
  @filter
end

#num_resultsFixnum

Optional. The maximum number of results to retrieve from this data store. If not specified, it will use the SearchRequest.num_results_per_data_store if provided, otherwise there is no limit. If both this field and SearchRequest. num_results_per_data_store are specified, this field will be used. Corresponds to the JSON property numResults

Returns:

  • (Fixnum)


17097
17098
17099
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17097

def num_results
  @num_results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17104
17105
17106
17107
17108
17109
17110
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17104

def update!(**args)
  @boost_spec = args[:boost_spec] if args.key?(:boost_spec)
  @custom_search_operators = args[:custom_search_operators] if args.key?(:custom_search_operators)
  @data_store = args[:data_store] if args.key?(:data_store)
  @filter = args[:filter] if args.key?(:filter)
  @num_results = args[:num_results] if args.key?(:num_results)
end