Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestFacetSpecFacetKey
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestFacetSpecFacetKey
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Specifies how a facet is computed.
Instance Attribute Summary collapse
-
#case_insensitive ⇒ Boolean
(also: #case_insensitive?)
True to make facet keys case insensitive when getting faceting values with prefixes or contains; false otherwise.
-
#contains ⇒ Array<String>
Only get facet values that contain the given strings.
-
#intervals ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaInterval>
Set only if values should be bucketed into intervals.
-
#key ⇒ String
Required.
-
#order_by ⇒ String
The order in which documents are returned.
-
#prefixes ⇒ Array<String>
Only get facet values that start with the given string prefix.
-
#restricted_values ⇒ Array<String>
Only get facet for the given restricted values.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaSearchRequestFacetSpecFacetKey
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaSearchRequestFacetSpecFacetKey.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaSearchRequestFacetSpecFacetKey
Returns a new instance of GoogleCloudDiscoveryengineV1alphaSearchRequestFacetSpecFacetKey.
17297 17298 17299 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17297 def initialize(**args) update!(**args) end |
Instance Attribute Details
#case_insensitive ⇒ Boolean Also known as: case_insensitive?
True to make facet keys case insensitive when getting faceting values with
prefixes or contains; false otherwise.
Corresponds to the JSON property caseInsensitive
17245 17246 17247 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17245 def case_insensitive @case_insensitive end |
#contains ⇒ Array<String>
Only get facet values that contain the given strings. For example, suppose "
category" has three values "Action > 2022", "Action > 2021" and "Sci-Fi > 2022"
. If set "contains" to "2022", the "category" facet only contains "Action >
2022" and "Sci-Fi > 2022". Only supported on textual fields. Maximum is 10.
Corresponds to the JSON property contains
17254 17255 17256 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17254 def contains @contains end |
#intervals ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaInterval>
Set only if values should be bucketed into intervals. Must be set for facets
with numerical values. Must not be set for facet with text values. Maximum
number of intervals is 30.
Corresponds to the JSON property intervals
17261 17262 17263 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17261 def intervals @intervals end |
#key ⇒ String
Required. Supported textual and numerical facet keys in Document object, over
which the facet values are computed. Facet key is case-sensitive.
Corresponds to the JSON property key
17267 17268 17269 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17267 def key @key end |
#order_by ⇒ String
The order in which documents are returned. Allowed values are: * "count desc",
which means order by SearchResponse.Facet.values.count descending. * "value
desc", which means order by SearchResponse.Facet.values.value descending. Only
applies to textual facets. If not set, textual values are sorted in natural
order; numerical intervals
are sorted in the order given by FacetSpec.FacetKey.intervals.
Corresponds to the JSON property orderBy
17277 17278 17279 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17277 def order_by @order_by end |
#prefixes ⇒ Array<String>
Only get facet values that start with the given string prefix. For example,
suppose "category" has three values "Action > 2022", "Action > 2021" and "Sci-
Fi > 2022". If set "prefixes" to "Action", the "category" facet only contains "
Action > 2022" and "Action > 2021". Only supported on textual fields. Maximum
is 10.
Corresponds to the JSON property prefixes
17286 17287 17288 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17286 def prefixes @prefixes end |
#restricted_values ⇒ Array<String>
Only get facet for the given restricted values. Only supported on textual
fields. For example, suppose "category" has three values "Action > 2022", "
Action > 2021" and "Sci-Fi > 2022". If set "restricted_values" to "Action >
2022", the "category" facet only contains "Action > 2022". Only supported on
textual fields. Maximum is 10.
Corresponds to the JSON property restrictedValues
17295 17296 17297 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17295 def restricted_values @restricted_values end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17302 17303 17304 17305 17306 17307 17308 17309 17310 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17302 def update!(**args) @case_insensitive = args[:case_insensitive] if args.key?(:case_insensitive) @contains = args[:contains] if args.key?(:contains) @intervals = args[:intervals] if args.key?(:intervals) @key = args[:key] if args.key?(:key) @order_by = args[:order_by] if args.key?(:order_by) @prefixes = args[:prefixes] if args.key?(:prefixes) @restricted_values = args[:restricted_values] if args.key?(:restricted_values) end |