Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestFacetSpecFacetKey
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestFacetSpecFacetKey
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Specifies how a facet is computed.
Instance Attribute Summary collapse
-
#case_insensitive ⇒ Boolean
(also: #case_insensitive?)
True to make facet keys case insensitive when getting faceting values with prefixes or contains; false otherwise.
-
#contains ⇒ Array<String>
Only get facet values that contain the given strings.
-
#intervals ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaInterval>
Set only if values should be bucketed into intervals.
-
#key ⇒ String
Required.
-
#order_by ⇒ String
The order in which documents are returned.
-
#prefixes ⇒ Array<String>
Only get facet values that start with the given string prefix.
-
#restricted_values ⇒ Array<String>
Only get facet for the given restricted values.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaSearchRequestFacetSpecFacetKey
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaSearchRequestFacetSpecFacetKey.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaSearchRequestFacetSpecFacetKey
Returns a new instance of GoogleCloudDiscoveryengineV1alphaSearchRequestFacetSpecFacetKey.
16339 16340 16341 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16339 def initialize(**args) update!(**args) end |
Instance Attribute Details
#case_insensitive ⇒ Boolean Also known as: case_insensitive?
True to make facet keys case insensitive when getting faceting values with
prefixes or contains; false otherwise.
Corresponds to the JSON property caseInsensitive
16287 16288 16289 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16287 def case_insensitive @case_insensitive end |
#contains ⇒ Array<String>
Only get facet values that contain the given strings. For example, suppose "
category" has three values "Action > 2022", "Action > 2021" and "Sci-Fi > 2022"
. If set "contains" to "2022", the "category" facet only contains "Action >
2022" and "Sci-Fi > 2022". Only supported on textual fields. Maximum is 10.
Corresponds to the JSON property contains
16296 16297 16298 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16296 def contains @contains end |
#intervals ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaInterval>
Set only if values should be bucketed into intervals. Must be set for facets
with numerical values. Must not be set for facet with text values. Maximum
number of intervals is 30.
Corresponds to the JSON property intervals
16303 16304 16305 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16303 def intervals @intervals end |
#key ⇒ String
Required. Supported textual and numerical facet keys in Document object, over
which the facet values are computed. Facet key is case-sensitive.
Corresponds to the JSON property key
16309 16310 16311 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16309 def key @key end |
#order_by ⇒ String
The order in which documents are returned. Allowed values are: * "count desc",
which means order by SearchResponse.Facet.values.count descending. * "value
desc", which means order by SearchResponse.Facet.values.value descending. Only
applies to textual facets. If not set, textual values are sorted in natural
order; numerical intervals
are sorted in the order given by FacetSpec.FacetKey.intervals.
Corresponds to the JSON property orderBy
16319 16320 16321 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16319 def order_by @order_by end |
#prefixes ⇒ Array<String>
Only get facet values that start with the given string prefix. For example,
suppose "category" has three values "Action > 2022", "Action > 2021" and "Sci-
Fi > 2022". If set "prefixes" to "Action", the "category" facet only contains "
Action > 2022" and "Action > 2021". Only supported on textual fields. Maximum
is 10.
Corresponds to the JSON property prefixes
16328 16329 16330 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16328 def prefixes @prefixes end |
#restricted_values ⇒ Array<String>
Only get facet for the given restricted values. Only supported on textual
fields. For example, suppose "category" has three values "Action > 2022", "
Action > 2021" and "Sci-Fi > 2022". If set "restricted_values" to "Action >
2022", the "category" facet only contains "Action > 2022". Only supported on
textual fields. Maximum is 10.
Corresponds to the JSON property restrictedValues
16337 16338 16339 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16337 def restricted_values @restricted_values end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16344 16345 16346 16347 16348 16349 16350 16351 16352 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16344 def update!(**args) @case_insensitive = args[:case_insensitive] if args.key?(:case_insensitive) @contains = args[:contains] if args.key?(:contains) @intervals = args[:intervals] if args.key?(:intervals) @key = args[:key] if args.key?(:key) @order_by = args[:order_by] if args.key?(:order_by) @prefixes = args[:prefixes] if args.key?(:prefixes) @restricted_values = args[:restricted_values] if args.key?(:restricted_values) end |