Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestNaturalLanguageQueryUnderstandingSpec
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestNaturalLanguageQueryUnderstandingSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Specification to enable natural language understanding capabilities for search requests.
Instance Attribute Summary collapse
-
#allowed_field_names ⇒ Array<String>
Optional.
-
#extracted_filter_behavior ⇒ String
Optional.
-
#filter_extraction_condition ⇒ String
The condition under which filter extraction should occur.
-
#geo_search_query_detection_field_names ⇒ Array<String>
Field names used for location-based filtering, where geolocation filters are detected in natural language search queries.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaSearchRequestNaturalLanguageQueryUnderstandingSpec
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaSearchRequestNaturalLanguageQueryUnderstandingSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaSearchRequestNaturalLanguageQueryUnderstandingSpec
Returns a new instance of GoogleCloudDiscoveryengineV1alphaSearchRequestNaturalLanguageQueryUnderstandingSpec.
17372 17373 17374 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17372 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowed_field_names ⇒ Array<String>
Optional. Allowlist of fields that can be used for natural language filter
extraction. By default, if this is unspecified, all indexable fields are
eligible for natural language filter extraction (but are not guaranteed to be
used). If any fields are specified in allowed_field_names, only the fields
that are both marked as indexable in the schema and specified in the allowlist
will be eligible for natural language filter extraction. Note: for multi-
datastore search, this is not yet supported, and will be ignored.
Corresponds to the JSON property allowedFieldNames
17346 17347 17348 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17346 def allowed_field_names @allowed_field_names end |
#extracted_filter_behavior ⇒ String
Optional. Controls behavior of how extracted filters are applied to the search.
The default behavior depends on the request. For single datastore structured
search, the default is HARD_FILTER. For multi-datastore search, the default
behavior is SOFT_BOOST. Location-based filters are always applied as hard
filters, and the SOFT_BOOST setting will not affect them. This field is only
used if SearchRequest.NaturalLanguageQueryUnderstandingSpec.
FilterExtractionCondition is set to FilterExtractionCondition.ENABLED.
Corresponds to the JSON property extractedFilterBehavior
17357 17358 17359 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17357 def extracted_filter_behavior @extracted_filter_behavior end |
#filter_extraction_condition ⇒ String
The condition under which filter extraction should occur. Server behavior
defaults to DISABLED.
Corresponds to the JSON property filterExtractionCondition
17363 17364 17365 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17363 def filter_extraction_condition @filter_extraction_condition end |
#geo_search_query_detection_field_names ⇒ Array<String>
Field names used for location-based filtering, where geolocation filters are
detected in natural language search queries. Only valid when the
FilterExtractionCondition is set to ENABLED.
Corresponds to the JSON property geoSearchQueryDetectionFieldNames
17370 17371 17372 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17370 def geo_search_query_detection_field_names @geo_search_query_detection_field_names end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17377 17378 17379 17380 17381 17382 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17377 def update!(**args) @allowed_field_names = args[:allowed_field_names] if args.key?(:allowed_field_names) @extracted_filter_behavior = args[:extracted_filter_behavior] if args.key?(:extracted_filter_behavior) @filter_extraction_condition = args[:filter_extraction_condition] if args.key?(:filter_extraction_condition) @geo_search_query_detection_field_names = args[:geo_search_query_detection_field_names] if args.key?(:geo_search_query_detection_field_names) end |