Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestNaturalLanguageQueryUnderstandingSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Specification to enable natural language understanding capabilities for search requests.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaSearchRequestNaturalLanguageQueryUnderstandingSpec

Returns a new instance of GoogleCloudDiscoveryengineV1alphaSearchRequestNaturalLanguageQueryUnderstandingSpec.



17217
17218
17219
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17217

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowed_field_namesArray<String>

Optional. Allowlist of fields that can be used for natural language filter extraction. By default, if this is unspecified, all indexable fields are eligible for natural language filter extraction (but are not guaranteed to be used). If any fields are specified in allowed_field_names, only the fields that are both marked as indexable in the schema and specified in the allowlist will be eligible for natural language filter extraction. Note: for multi- datastore search, this is not yet supported, and will be ignored. Corresponds to the JSON property allowedFieldNames

Returns:

  • (Array<String>)


17191
17192
17193
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17191

def allowed_field_names
  @allowed_field_names
end

#extracted_filter_behaviorString

Optional. Controls behavior of how extracted filters are applied to the search. The default behavior depends on the request. For single datastore structured search, the default is HARD_FILTER. For multi-datastore search, the default behavior is SOFT_BOOST. Location-based filters are always applied as hard filters, and the SOFT_BOOST setting will not affect them. This field is only used if SearchRequest.NaturalLanguageQueryUnderstandingSpec. FilterExtractionCondition is set to FilterExtractionCondition.ENABLED. Corresponds to the JSON property extractedFilterBehavior

Returns:

  • (String)


17202
17203
17204
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17202

def extracted_filter_behavior
  @extracted_filter_behavior
end

#filter_extraction_conditionString

The condition under which filter extraction should occur. Server behavior defaults to DISABLED. Corresponds to the JSON property filterExtractionCondition

Returns:

  • (String)


17208
17209
17210
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17208

def filter_extraction_condition
  @filter_extraction_condition
end

#geo_search_query_detection_field_namesArray<String>

Field names used for location-based filtering, where geolocation filters are detected in natural language search queries. Only valid when the FilterExtractionCondition is set to ENABLED. Corresponds to the JSON property geoSearchQueryDetectionFieldNames

Returns:

  • (Array<String>)


17215
17216
17217
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17215

def geo_search_query_detection_field_names
  @geo_search_query_detection_field_names
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17222
17223
17224
17225
17226
17227
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17222

def update!(**args)
  @allowed_field_names = args[:allowed_field_names] if args.key?(:allowed_field_names)
  @extracted_filter_behavior = args[:extracted_filter_behavior] if args.key?(:extracted_filter_behavior)
  @filter_extraction_condition = args[:filter_extraction_condition] if args.key?(:filter_extraction_condition)
  @geo_search_query_detection_field_names = args[:geo_search_query_detection_field_names] if args.key?(:geo_search_query_detection_field_names)
end