Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestQueryExpansionSpec
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestQueryExpansionSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Specification to determine under which conditions query expansion should occur.
Instance Attribute Summary collapse
-
#condition ⇒ String
The condition under which query expansion should occur.
-
#pin_unexpanded_results ⇒ Boolean
(also: #pin_unexpanded_results?)
Whether to pin unexpanded results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaSearchRequestQueryExpansionSpec
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaSearchRequestQueryExpansionSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaSearchRequestQueryExpansionSpec
Returns a new instance of GoogleCloudDiscoveryengineV1alphaSearchRequestQueryExpansionSpec.
17436 17437 17438 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17436 def initialize(**args) update!(**args) end |
Instance Attribute Details
#condition ⇒ String
The condition under which query expansion should occur. Default to Condition.
DISABLED.
Corresponds to the JSON property condition
17426 17427 17428 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17426 def condition @condition end |
#pin_unexpanded_results ⇒ Boolean Also known as: pin_unexpanded_results?
Whether to pin unexpanded results. If this field is set to true, unexpanded
products are always at the top of the search results, followed by the expanded
results.
Corresponds to the JSON property pinUnexpandedResults
17433 17434 17435 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17433 def @pin_unexpanded_results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17441 17442 17443 17444 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17441 def update!(**args) @condition = args[:condition] if args.key?(:condition) @pin_unexpanded_results = args[:pin_unexpanded_results] if args.key?(:pin_unexpanded_results) end |