Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestQueryExpansionSpec
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestQueryExpansionSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Specification to determine under which conditions query expansion should occur.
Instance Attribute Summary collapse
-
#condition ⇒ String
The condition under which query expansion should occur.
-
#pin_unexpanded_results ⇒ Boolean
(also: #pin_unexpanded_results?)
Whether to pin unexpanded results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaSearchRequestQueryExpansionSpec
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaSearchRequestQueryExpansionSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaSearchRequestQueryExpansionSpec
Returns a new instance of GoogleCloudDiscoveryengineV1alphaSearchRequestQueryExpansionSpec.
16464 16465 16466 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16464 def initialize(**args) update!(**args) end |
Instance Attribute Details
#condition ⇒ String
The condition under which query expansion should occur. Default to Condition.
DISABLED.
Corresponds to the JSON property condition
16454 16455 16456 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16454 def condition @condition end |
#pin_unexpanded_results ⇒ Boolean Also known as: pin_unexpanded_results?
Whether to pin unexpanded results. If this field is set to true, unexpanded
products are always at the top of the search results, followed by the expanded
results.
Corresponds to the JSON property pinUnexpandedResults
16461 16462 16463 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16461 def @pin_unexpanded_results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16469 16470 16471 16472 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 16469 def update!(**args) @condition = args[:condition] if args.key?(:condition) @pin_unexpanded_results = args[:pin_unexpanded_results] if args.key?(:pin_unexpanded_results) end |