Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestRelevanceScoreSpec
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSearchRequestRelevanceScoreSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
The specification for returning the document relevance score.
Instance Attribute Summary collapse
-
#return_relevance_score ⇒ Boolean
(also: #return_relevance_score?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaSearchRequestRelevanceScoreSpec
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaSearchRequestRelevanceScoreSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaSearchRequestRelevanceScoreSpec
Returns a new instance of GoogleCloudDiscoveryengineV1alphaSearchRequestRelevanceScoreSpec.
17339 17340 17341 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17339 def initialize(**args) update!(**args) end |
Instance Attribute Details
#return_relevance_score ⇒ Boolean Also known as: return_relevance_score?
Optional. Whether to return the relevance score for search results. The higher
the score, the more relevant the document is to the query.
Corresponds to the JSON property returnRelevanceScore
17336 17337 17338 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17336 def return_relevance_score @return_relevance_score end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17344 17345 17346 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17344 def update!(**args) @return_relevance_score = args[:return_relevance_score] if args.key?(:return_relevance_score) end |