Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSession
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSession
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
External session proto definition.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Optional.
-
#end_time ⇒ String
Output only.
-
#is_pinned ⇒ Boolean
(also: #is_pinned?)
Optional.
-
#labels ⇒ Array<String>
Optional.
-
#name ⇒ String
Immutable.
-
#pending_async_assist_operation_id ⇒ String
Output only.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
The state of the session.
-
#turns ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSessionTurn>
Turns.
-
#user_pseudo_id ⇒ String
A unique identifier for tracking users.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaSession
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaSession.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaSession
Returns a new instance of GoogleCloudDiscoveryengineV1alphaSession.
17691 17692 17693 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17691 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Optional. The display name of the session. This field is used to identify the
session in the UI. By default, the display name is the first turn query text
in the session.
Corresponds to the JSON property displayName
17638 17639 17640 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17638 def display_name @display_name end |
#end_time ⇒ String
Output only. The time the session finished.
Corresponds to the JSON property endTime
17643 17644 17645 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17643 def end_time @end_time end |
#is_pinned ⇒ Boolean Also known as: is_pinned?
Optional. Whether the session is pinned, pinned session will be displayed on
the top of the session list.
Corresponds to the JSON property isPinned
17649 17650 17651 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17649 def is_pinned @is_pinned end |
#labels ⇒ Array<String>
Optional. The labels for the session. Can be set as filter in
ListSessionsRequest.
Corresponds to the JSON property labels
17656 17657 17658 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17656 def labels @labels end |
#name ⇒ String
Immutable. Fully qualified name projects/project/locations/global/
collections/collection/engines/engine/sessions/*
Corresponds to the JSON property name
17662 17663 17664 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17662 def name @name end |
#pending_async_assist_operation_id ⇒ String
Output only. Full resource name of an in-progress AsyncAssist operation for
this session, e.g. projects/*/locations/*/collections/*/engines/*/sessions/*/
operations/*. Set when the operation starts and cleared when it finishes.
Corresponds to the JSON property pendingAsyncAssistOperationId
17669 17670 17671 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17669 def pending_async_assist_operation_id @pending_async_assist_operation_id end |
#start_time ⇒ String
Output only. The time the session started.
Corresponds to the JSON property startTime
17674 17675 17676 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17674 def start_time @start_time end |
#state ⇒ String
The state of the session.
Corresponds to the JSON property state
17679 17680 17681 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17679 def state @state end |
#turns ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSessionTurn>
Turns.
Corresponds to the JSON property turns
17684 17685 17686 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17684 def turns @turns end |
#user_pseudo_id ⇒ String
A unique identifier for tracking users.
Corresponds to the JSON property userPseudoId
17689 17690 17691 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17689 def user_pseudo_id @user_pseudo_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17696 17697 17698 17699 17700 17701 17702 17703 17704 17705 17706 17707 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17696 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @end_time = args[:end_time] if args.key?(:end_time) @is_pinned = args[:is_pinned] if args.key?(:is_pinned) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @pending_async_assist_operation_id = args[:pending_async_assist_operation_id] if args.key?(:pending_async_assist_operation_id) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @turns = args[:turns] if args.key?(:turns) @user_pseudo_id = args[:user_pseudo_id] if args.key?(:user_pseudo_id) end |