Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSession

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

External session proto definition.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaSession

Returns a new instance of GoogleCloudDiscoveryengineV1alphaSession.



17683
17684
17685
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17683

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Optional. The display name of the session. This field is used to identify the session in the UI. By default, the display name is the first turn query text in the session. Corresponds to the JSON property displayName

Returns:

  • (String)


17630
17631
17632
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17630

def display_name
  @display_name
end

#end_timeString

Output only. The time the session finished. Corresponds to the JSON property endTime

Returns:

  • (String)


17635
17636
17637
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17635

def end_time
  @end_time
end

#is_pinnedBoolean Also known as: is_pinned?

Optional. Whether the session is pinned, pinned session will be displayed on the top of the session list. Corresponds to the JSON property isPinned

Returns:

  • (Boolean)


17641
17642
17643
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17641

def is_pinned
  @is_pinned
end

#labelsArray<String>

Optional. The labels for the session. Can be set as filter in ListSessionsRequest. Corresponds to the JSON property labels

Returns:

  • (Array<String>)


17648
17649
17650
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17648

def labels
  @labels
end

#nameString

Immutable. Fully qualified name projects/project/locations/global/ collections/collection/engines/engine/sessions/* Corresponds to the JSON property name

Returns:

  • (String)


17654
17655
17656
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17654

def name
  @name
end

#pending_async_assist_operation_idString

Output only. Full resource name of an in-progress AsyncAssist operation for this session, e.g. projects/*/locations/*/collections/*/engines/*/sessions/*/ operations/*. Set when the operation starts and cleared when it finishes. Corresponds to the JSON property pendingAsyncAssistOperationId

Returns:

  • (String)


17661
17662
17663
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17661

def pending_async_assist_operation_id
  @pending_async_assist_operation_id
end

#start_timeString

Output only. The time the session started. Corresponds to the JSON property startTime

Returns:

  • (String)


17666
17667
17668
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17666

def start_time
  @start_time
end

#stateString

The state of the session. Corresponds to the JSON property state

Returns:

  • (String)


17671
17672
17673
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17671

def state
  @state
end

#turnsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSessionTurn>

Turns. Corresponds to the JSON property turns



17676
17677
17678
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17676

def turns
  @turns
end

#user_pseudo_idString

A unique identifier for tracking users. Corresponds to the JSON property userPseudoId

Returns:

  • (String)


17681
17682
17683
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17681

def user_pseudo_id
  @user_pseudo_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17688
17689
17690
17691
17692
17693
17694
17695
17696
17697
17698
17699
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17688

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @end_time = args[:end_time] if args.key?(:end_time)
  @is_pinned = args[:is_pinned] if args.key?(:is_pinned)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @pending_async_assist_operation_id = args[:pending_async_assist_operation_id] if args.key?(:pending_async_assist_operation_id)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @turns = args[:turns] if args.key?(:turns)
  @user_pseudo_id = args[:user_pseudo_id] if args.key?(:user_pseudo_id)
end