Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaTargetSite

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

A target site for the SiteSearchEngine.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaTargetSite

Returns a new instance of GoogleCloudDiscoveryengineV1alphaTargetSite.



17904
17905
17906
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17904

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#exact_matchBoolean Also known as: exact_match?

Immutable. If set to false, a uri_pattern is generated to include all pages whose address contains the provided_uri_pattern. If set to true, an uri_pattern is generated to try to be an exact match of the provided_uri_pattern or just the specific page if the provided_uri_pattern is a specific one. provided_uri_pattern is always normalized to generate the URI pattern to be used by the search engine. Corresponds to the JSON property exactMatch

Returns:

  • (Boolean)


17851
17852
17853
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17851

def exact_match
  @exact_match
end

#failure_reasonGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaTargetSiteFailureReason

Site search indexing failure reasons. Corresponds to the JSON property failureReason



17857
17858
17859
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17857

def failure_reason
  @failure_reason
end

#generated_uri_patternString

Output only. This is system-generated based on the provided_uri_pattern. Corresponds to the JSON property generatedUriPattern

Returns:

  • (String)


17862
17863
17864
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17862

def generated_uri_pattern
  @generated_uri_pattern
end

#indexing_statusString

Output only. Indexing status. Corresponds to the JSON property indexingStatus

Returns:

  • (String)


17867
17868
17869
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17867

def indexing_status
  @indexing_status
end

#nameString

Output only. The fully qualified resource name of the target site. projects/ project/locations/location/collections/collection/dataStores/data_store/ siteSearchEngine/targetSites/target_site`Thetarget_site_idis system- generated. Corresponds to the JSON propertyname`

Returns:

  • (String)


17875
17876
17877
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17875

def name
  @name
end

#provided_uri_patternString

Required. Input only. The user provided URI pattern from which the generated_uri_pattern is generated. Corresponds to the JSON property providedUriPattern

Returns:

  • (String)


17881
17882
17883
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17881

def provided_uri_pattern
  @provided_uri_pattern
end

#root_domain_uriString

Output only. Root domain of the provided_uri_pattern. Corresponds to the JSON property rootDomainUri

Returns:

  • (String)


17886
17887
17888
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17886

def root_domain_uri
  @root_domain_uri
end

#site_verification_infoGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSiteVerificationInfo

Verification information for target sites in advanced site search. Corresponds to the JSON property siteVerificationInfo



17891
17892
17893
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17891

def site_verification_info
  @site_verification_info
end

#typeString

The type of the target site, e.g., whether the site is to be included or excluded. Corresponds to the JSON property type

Returns:

  • (String)


17897
17898
17899
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17897

def type
  @type
end

#update_timeString

Output only. The target site's last updated time. Corresponds to the JSON property updateTime

Returns:

  • (String)


17902
17903
17904
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17902

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17909
17910
17911
17912
17913
17914
17915
17916
17917
17918
17919
17920
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17909

def update!(**args)
  @exact_match = args[:exact_match] if args.key?(:exact_match)
  @failure_reason = args[:failure_reason] if args.key?(:failure_reason)
  @generated_uri_pattern = args[:generated_uri_pattern] if args.key?(:generated_uri_pattern)
  @indexing_status = args[:indexing_status] if args.key?(:indexing_status)
  @name = args[:name] if args.key?(:name)
  @provided_uri_pattern = args[:provided_uri_pattern] if args.key?(:provided_uri_pattern)
  @root_domain_uri = args[:root_domain_uri] if args.key?(:root_domain_uri)
  @site_verification_info = args[:site_verification_info] if args.key?(:site_verification_info)
  @type = args[:type] if args.key?(:type)
  @update_time = args[:update_time] if args.key?(:update_time)
end