Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaTenant

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Tenant information for a connector source. This includes some of the same information stored in the Credential message, but is limited to only what is needed to provide a list of accessible tenants to the user.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaTenant

Returns a new instance of GoogleCloudDiscoveryengineV1alphaTenant.



17341
17342
17343
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17341

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Optional display name for the tenant, e.g. "My Slack Team". Corresponds to the JSON property displayName

Returns:

  • (String)


17326
17327
17328
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17326

def display_name
  @display_name
end

#idString

The tenant's instance ID. Examples: Jira ("8594f221-9797-5f78-1fa4- 485e198d7cd0"), Slack ("T123456"). Corresponds to the JSON property id

Returns:

  • (String)


17332
17333
17334
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17332

def id
  @id
end

#uriString

The URI of the tenant, if applicable. For example, the URI of a Jira instance is https://my-jira-instance.atlassian.net, and a Slack tenant does not have a URI. Corresponds to the JSON property uri

Returns:

  • (String)


17339
17340
17341
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17339

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17346
17347
17348
17349
17350
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17346

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @id = args[:id] if args.key?(:id)
  @uri = args[:uri] if args.key?(:uri)
end