Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaTenant

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Tenant information for a connector source. This includes some of the same information stored in the Credential message, but is limited to only what is needed to provide a list of accessible tenants to the user.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaTenant

Returns a new instance of GoogleCloudDiscoveryengineV1alphaTenant.



17137
17138
17139
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17137

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Optional display name for the tenant, e.g. "My Slack Team". Corresponds to the JSON property displayName

Returns:

  • (String)


17122
17123
17124
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17122

def display_name
  @display_name
end

#idString

The tenant's instance ID. Examples: Jira ("8594f221-9797-5f78-1fa4- 485e198d7cd0"), Slack ("T123456"). Corresponds to the JSON property id

Returns:

  • (String)


17128
17129
17130
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17128

def id
  @id
end

#uriString

The URI of the tenant, if applicable. For example, the URI of a Jira instance is https://my-jira-instance.atlassian.net, and a Slack tenant does not have a URI. Corresponds to the JSON property uri

Returns:

  • (String)


17135
17136
17137
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17135

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17142
17143
17144
17145
17146
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17142

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @id = args[:id] if args.key?(:id)
  @uri = args[:uri] if args.key?(:uri)
end