Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaUpdateSessionRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Request for UpdateSession method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaUpdateSessionRequest

Returns a new instance of GoogleCloudDiscoveryengineV1alphaUpdateSessionRequest.



17561
17562
17563
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17561

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#sessionGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaSession

External session proto definition. Corresponds to the JSON property session



17552
17553
17554
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17552

def session
  @session
end

#update_maskString

Indicates which fields in the provided Session to update. The following are NOT supported: * Session.name If not set or empty, all supported fields are updated. Corresponds to the JSON property updateMask

Returns:

  • (String)


17559
17560
17561
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17559

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17566
17567
17568
17569
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17566

def update!(**args)
  @session = args[:session] if args.key?(:session)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end