Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaUserInfo
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaUserInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Information of an end user.
Instance Attribute Summary collapse
-
#precise_location ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaUserInfoPreciseLocation
Precise location info with multiple representation options.
-
#time_zone ⇒ String
Optional.
-
#user_agent ⇒ String
User agent as included in the HTTP header.
-
#user_id ⇒ String
Highly recommended for logged-in users.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaUserInfo
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaUserInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaUserInfo
Returns a new instance of GoogleCloudDiscoveryengineV1alphaUserInfo.
18282 18283 18284 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18282 def initialize(**args) update!(**args) end |
Instance Attribute Details
#precise_location ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaUserInfoPreciseLocation
Precise location info with multiple representation options. Currently only
latitude and longitude point is supported.
Corresponds to the JSON property preciseLocation
18253 18254 18255 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18253 def precise_location @precise_location end |
#time_zone ⇒ String
Optional. IANA time zone, e.g. Europe/Budapest.
Corresponds to the JSON property timeZone
18258 18259 18260 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18258 def time_zone @time_zone end |
#user_agent ⇒ String
User agent as included in the HTTP header. The field must be a UTF-8 encoded
string with a length limit of 1,000 characters. Otherwise, an
INVALID_ARGUMENT error is returned. This should not be set when using the
client side event reporting with GTM or JavaScript tag in UserEventService.
CollectUserEvent or if UserEvent.direct_user_request is set.
Corresponds to the JSON property userAgent
18267 18268 18269 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18267 def user_agent @user_agent end |
#user_id ⇒ String
Highly recommended for logged-in users. Unique identifier for logged-in user,
such as a user name. Don't set for anonymous users. Always use a hashed value
for this ID. Don't set the field to the same fixed ID for different users.
This mixes the event history of those users together, which results in
degraded model quality. The field must be a UTF-8 encoded string with a length
limit of 128 characters. Otherwise, an INVALID_ARGUMENT error is returned.
Represents an opaque ID to the Search API. The Search API doesn't interpret
the value in any way. This field is used to associate events with a user
across sessions if the events are being uploaded.
Corresponds to the JSON property userId
18280 18281 18282 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18280 def user_id @user_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18287 18288 18289 18290 18291 18292 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18287 def update!(**args) @precise_location = args[:precise_location] if args.key?(:precise_location) @time_zone = args[:time_zone] if args.key?(:time_zone) @user_agent = args[:user_agent] if args.key?(:user_agent) @user_id = args[:user_id] if args.key?(:user_id) end |