Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaUserInfoPreciseLocation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Precise location info with multiple representation options. Currently only latitude and longitude point is supported.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaUserInfoPreciseLocation

Returns a new instance of GoogleCloudDiscoveryengineV1alphaUserInfoPreciseLocation.



17465
17466
17467
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17465

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addressString

Optional. Location represented by a natural language address. Will later be geocoded and converted to either a point or a polygon. Corresponds to the JSON property address

Returns:

  • (String)


17455
17456
17457
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17455

def address
  @address
end

#pointGoogle::Apis::DiscoveryengineV1beta::GoogleTypeLatLng

An object that represents a latitude/longitude pair. This is expressed as a pair of doubles to represent degrees latitude and degrees longitude. Unless specified otherwise, this object must conform to the WGS84 standard. Values must be within normalized ranges. Corresponds to the JSON property point



17463
17464
17465
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17463

def point
  @point
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17470
17471
17472
17473
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17470

def update!(**args)
  @address = args[:address] if args.key?(:address)
  @point = args[:point] if args.key?(:point)
end