Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaUserLicense
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaUserLicense
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
User License information assigned by the admin.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#last_login_time ⇒ String
Output only.
-
#license_assignment_state ⇒ String
Output only.
-
#license_config ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
-
#user_principal ⇒ String
Required.
-
#user_profile ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaUserLicense
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaUserLicense.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaUserLicense
Returns a new instance of GoogleCloudDiscoveryengineV1alphaUserLicense.
18427 18428 18429 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18427 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. User created timestamp.
Corresponds to the JSON property createTime
18387 18388 18389 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18387 def create_time @create_time end |
#last_login_time ⇒ String
Output only. User last logged in time. If the user has not logged in yet, this
field will be empty.
Corresponds to the JSON property lastLoginTime
18393 18394 18395 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18393 def last_login_time @last_login_time end |
#license_assignment_state ⇒ String
Output only. License assignment state of the user. If the user is assigned
with a license config, the user login will be assigned with the license; If
the user's license assignment state is unassigned or unspecified, no license
config will be associated to the user;
Corresponds to the JSON property licenseAssignmentState
18401 18402 18403 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18401 def license_assignment_state @license_assignment_state end |
#license_config ⇒ String
Optional. The full resource name of the Subscription(LicenseConfig) assigned
to the user.
Corresponds to the JSON property licenseConfig
18407 18408 18409 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18407 def license_config @license_config end |
#update_time ⇒ String
Output only. User update timestamp.
Corresponds to the JSON property updateTime
18412 18413 18414 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18412 def update_time @update_time end |
#user_principal ⇒ String
Required. Immutable. The user principal of the User, could be email address or
other prinical identifier. This field is immutable. Admin assign licenses
based on the user principal.
Corresponds to the JSON property userPrincipal
18419 18420 18421 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18419 def user_principal @user_principal end |
#user_profile ⇒ String
Optional. The user profile. We user user full name(First name + Last name) as
user profile.
Corresponds to the JSON property userProfile
18425 18426 18427 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18425 def user_profile @user_profile end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18432 18433 18434 18435 18436 18437 18438 18439 18440 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18432 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @last_login_time = args[:last_login_time] if args.key?(:last_login_time) @license_assignment_state = args[:license_assignment_state] if args.key?(:license_assignment_state) @license_config = args[:license_config] if args.key?(:license_config) @update_time = args[:update_time] if args.key?(:update_time) @user_principal = args[:user_principal] if args.key?(:user_principal) @user_profile = args[:user_profile] if args.key?(:user_profile) end |