Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaWorkspaceConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Config to store data store type configuration for workspace data

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaWorkspaceConfig

Returns a new instance of GoogleCloudDiscoveryengineV1alphaWorkspaceConfig.



18473
18474
18475
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18473

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dasher_customer_idString

Output only. Obfuscated Dasher customer ID. Derived by the server from the project's GCP organization at data store creation time; any value supplied in the request payload is ignored. Corresponds to the JSON property dasherCustomerId

Returns:

  • (String)


18452
18453
18454
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18452

def dasher_customer_id
  @dasher_customer_id
end

#super_admin_email_addressString

Optional. The super admin email address for the workspace that will be used for access token generation. For now we only use it for Native Google Drive connector data ingestion. Corresponds to the JSON property superAdminEmailAddress

Returns:

  • (String)


18459
18460
18461
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18459

def super_admin_email_address
  @super_admin_email_address
end

#super_admin_service_accountString

Optional. The super admin service account for the workspace that will be used for access token generation. For now we only use it for Native Google Drive connector data ingestion. Corresponds to the JSON property superAdminServiceAccount

Returns:

  • (String)


18466
18467
18468
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18466

def 
  @super_admin_service_account
end

#typeString

The Google Workspace data source. Corresponds to the JSON property type

Returns:

  • (String)


18471
18472
18473
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18471

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18478
18479
18480
18481
18482
18483
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18478

def update!(**args)
  @dasher_customer_id = args[:dasher_customer_id] if args.key?(:dasher_customer_id)
  @super_admin_email_address = args[:super_admin_email_address] if args.key?(:super_admin_email_address)
  @super_admin_service_account = args[:super_admin_service_account] if args.key?(:super_admin_service_account)
  @type = args[:type] if args.key?(:type)
end