Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaWorkspaceConfig
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1alphaWorkspaceConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Config to store data store type configuration for workspace data
Instance Attribute Summary collapse
-
#dasher_customer_id ⇒ String
Output only.
-
#super_admin_email_address ⇒ String
Optional.
-
#super_admin_service_account ⇒ String
Optional.
-
#type ⇒ String
The Google Workspace data source.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaWorkspaceConfig
constructor
A new instance of GoogleCloudDiscoveryengineV1alphaWorkspaceConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1alphaWorkspaceConfig
Returns a new instance of GoogleCloudDiscoveryengineV1alphaWorkspaceConfig.
17773 17774 17775 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17773 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dasher_customer_id ⇒ String
Output only. Obfuscated Dasher customer ID. Derived by the server from the
project's GCP organization at data store creation time; any value supplied in
the request payload is ignored.
Corresponds to the JSON property dasherCustomerId
17752 17753 17754 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17752 def dasher_customer_id @dasher_customer_id end |
#super_admin_email_address ⇒ String
Optional. The super admin email address for the workspace that will be used
for access token generation. For now we only use it for Native Google Drive
connector data ingestion.
Corresponds to the JSON property superAdminEmailAddress
17759 17760 17761 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17759 def super_admin_email_address @super_admin_email_address end |
#super_admin_service_account ⇒ String
Optional. The super admin service account for the workspace that will be used
for access token generation. For now we only use it for Native Google Drive
connector data ingestion.
Corresponds to the JSON property superAdminServiceAccount
17766 17767 17768 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17766 def super_admin_service_account @super_admin_service_account end |
#type ⇒ String
The Google Workspace data source.
Corresponds to the JSON property type
17771 17772 17773 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17771 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17778 17779 17780 17781 17782 17783 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17778 def update!(**args) @dasher_customer_id = args[:dasher_customer_id] if args.key?(:dasher_customer_id) @super_admin_email_address = args[:super_admin_email_address] if args.key?(:super_admin_email_address) @super_admin_service_account = args[:super_admin_service_account] if args.key?(:super_admin_service_account) @type = args[:type] if args.key?(:type) end |