Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Request message for CompletionService.AdvancedCompleteQuery method. .

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryRequest

Returns a new instance of GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryRequest.



18563
18564
18565
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18563

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#boost_specGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryRequestBoostSpec

Specification to boost suggestions based on the condition of the suggestion. Corresponds to the JSON property boostSpec



18496
18497
18498
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18496

def boost_spec
  @boost_spec
end

#experiment_idsArray<String>

Optional. Experiment ids for this request. Corresponds to the JSON property experimentIds

Returns:

  • (Array<String>)


18501
18502
18503
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18501

def experiment_ids
  @experiment_ids
end

#include_tail_suggestionsBoolean Also known as: include_tail_suggestions?

Indicates if tail suggestions should be returned if there are no suggestions that match the full query. Even if set to true, if there are suggestions that match the full query, those are returned and no tail suggestions are returned. Corresponds to the JSON property includeTailSuggestions

Returns:

  • (Boolean)


18508
18509
18510
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18508

def include_tail_suggestions
  @include_tail_suggestions
end

#queryString

Required. The typeahead input used to fetch suggestions. Maximum length is 128 characters. The query can not be empty for most of the suggestion types. If it is empty, an INVALID_ARGUMENT error is returned. The exception is when the suggestion_types contains only the type RECENT_SEARCH, the query can be an empty string. The is called "zero prefix" feature, which returns user's recently searched queries given the empty query. Corresponds to the JSON property query

Returns:

  • (String)


18519
18520
18521
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18519

def query
  @query
end

#query_modelString

Specifies the autocomplete query model, which only applies to the QUERY SuggestionType. This overrides any model specified in the Configuration > Autocomplete section of the Cloud console. Currently supported values: * document - Using suggestions generated from user-imported documents. * search-history - Using suggestions generated from the past history of SearchService.Search API calls. Do not use it when there is no traffic for Search API. * user-event - Using suggestions generated from user-imported search events. * document-completable - Using suggestions taken directly from user-imported document fields marked as completable. Default values: * document is the default model for regular dataStores. * search-history is the default model for site search dataStores. Corresponds to the JSON property queryModel

Returns:

  • (String)


18534
18535
18536
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18534

def query_model
  @query_model
end

#suggestion_type_specsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryRequestSuggestionTypeSpec>

Optional. Specification of each suggestion type. Corresponds to the JSON property suggestionTypeSpecs



18539
18540
18541
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18539

def suggestion_type_specs
  @suggestion_type_specs
end

#suggestion_typesArray<String>

Optional. Suggestion types to return. If empty or unspecified, query suggestions are returned. Only one suggestion type is supported at the moment. Corresponds to the JSON property suggestionTypes

Returns:

  • (Array<String>)


18545
18546
18547
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18545

def suggestion_types
  @suggestion_types
end

#user_infoGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaUserInfo

Information of an end user. Corresponds to the JSON property userInfo



18550
18551
18552
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18550

def 
  @user_info
end

#user_pseudo_idString

Optional. A unique identifier for tracking visitors. For example, this could be implemented with an HTTP cookie, which should be able to uniquely identify a visitor on a single device. This unique identifier should not change if the visitor logs in or out of the website. This field should NOT have a fixed value such as unknown_visitor. This should be the same identifier as UserEvent.user_pseudo_id and SearchRequest.user_pseudo_id. The field must be a UTF-8 encoded string with a length limit of 128 Corresponds to the JSON property userPseudoId

Returns:

  • (String)


18561
18562
18563
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18561

def user_pseudo_id
  @user_pseudo_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18568
18569
18570
18571
18572
18573
18574
18575
18576
18577
18578
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18568

def update!(**args)
  @boost_spec = args[:boost_spec] if args.key?(:boost_spec)
  @experiment_ids = args[:experiment_ids] if args.key?(:experiment_ids)
  @include_tail_suggestions = args[:include_tail_suggestions] if args.key?(:include_tail_suggestions)
  @query = args[:query] if args.key?(:query)
  @query_model = args[:query_model] if args.key?(:query_model)
  @suggestion_type_specs = args[:suggestion_type_specs] if args.key?(:suggestion_type_specs)
  @suggestion_types = args[:suggestion_types] if args.key?(:suggestion_types)
  @user_info = args[:user_info] if args.key?(:user_info)
  @user_pseudo_id = args[:user_pseudo_id] if args.key?(:user_pseudo_id)
end