Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryRequestBoostSpecConditionBoostSpec
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryRequestBoostSpecConditionBoostSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Boost applies to suggestions which match a condition.
Instance Attribute Summary collapse
-
#boost ⇒ Float
Strength of the boost, which should be in [-1, 1].
-
#condition ⇒ String
An expression which specifies a boost condition.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryRequestBoostSpecConditionBoostSpec
constructor
A new instance of GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryRequestBoostSpecConditionBoostSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryRequestBoostSpecConditionBoostSpec
Returns a new instance of GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryRequestBoostSpecConditionBoostSpec.
18748 18749 18750 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18748 def initialize(**args) update!(**args) end |
Instance Attribute Details
#boost ⇒ Float
Strength of the boost, which should be in [-1, 1]. Negative boost means
demotion. Default is 0.0. Setting to 1.0 gives the suggestions a big promotion.
However, it does not necessarily mean that the top result will be a boosted
suggestion. Setting to -1.0 gives the suggestions a big demotion. However,
other suggestions that are relevant might still be shown. Setting to 0.0 means
no boost applied. The boosting condition is ignored.
Corresponds to the JSON property boost
18737 18738 18739 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18737 def boost @boost end |
#condition ⇒ String
An expression which specifies a boost condition. The syntax is the same as
filter expression syntax. Currently, the only
supported condition is a list of BCP-47 lang codes. Example: * To boost
suggestions in languages en or fr: (lang_code: ANY("en", "fr"))
Corresponds to the JSON property condition
18746 18747 18748 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18746 def condition @condition end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18753 18754 18755 18756 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18753 def update!(**args) @boost = args[:boost] if args.key?(:boost) @condition = args[:condition] if args.key?(:condition) end |