Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Response message for CompletionService.AdvancedCompleteQuery method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponse

Returns a new instance of GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponse.



18667
18668
18669
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18667

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#content_suggestionsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponseContentSuggestion>

Results of the matched content suggestions. The result list is ordered and the first result is the top suggestion. Corresponds to the JSON property contentSuggestions



18639
18640
18641
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18639

def content_suggestions
  @content_suggestions
end

#people_suggestionsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponsePersonSuggestion>

Results of the matched people suggestions. The result list is ordered and the first result is the top suggestion. Corresponds to the JSON property peopleSuggestions



18645
18646
18647
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18645

def people_suggestions
  @people_suggestions
end

#query_suggestionsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponseQuerySuggestion>

Results of the matched query suggestions. The result list is ordered and the first result is a top suggestion. Corresponds to the JSON property querySuggestions



18651
18652
18653
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18651

def query_suggestions
  @query_suggestions
end

#recent_search_suggestionsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponseRecentSearchSuggestion>

Results of the matched "recent search" suggestions. The result list is ordered and the first result is the top suggestion. Corresponds to the JSON property recentSearchSuggestions



18657
18658
18659
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18657

def recent_search_suggestions
  @recent_search_suggestions
end

#tail_match_triggeredBoolean Also known as: tail_match_triggered?

True if the returned suggestions are all tail suggestions. For tail matching to be triggered, include_tail_suggestions in the request must be true and there must be no suggestions that match the full query. Corresponds to the JSON property tailMatchTriggered

Returns:

  • (Boolean)


18664
18665
18666
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18664

def tail_match_triggered
  @tail_match_triggered
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18672
18673
18674
18675
18676
18677
18678
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18672

def update!(**args)
  @content_suggestions = args[:content_suggestions] if args.key?(:content_suggestions)
  @people_suggestions = args[:people_suggestions] if args.key?(:people_suggestions)
  @query_suggestions = args[:query_suggestions] if args.key?(:query_suggestions)
  @recent_search_suggestions = args[:recent_search_suggestions] if args.key?(:recent_search_suggestions)
  @tail_match_triggered = args[:tail_match_triggered] if args.key?(:tail_match_triggered)
end