Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponse
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Response message for CompletionService.AdvancedCompleteQuery method.
Instance Attribute Summary collapse
-
#content_suggestions ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponseContentSuggestion>
Results of the matched content suggestions.
-
#people_suggestions ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponsePersonSuggestion>
Results of the matched people suggestions.
-
#query_suggestions ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponseQuerySuggestion>
Results of the matched query suggestions.
-
#recent_search_suggestions ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponseRecentSearchSuggestion>
Results of the matched "recent search" suggestions.
-
#tail_match_triggered ⇒ Boolean
(also: #tail_match_triggered?)
True if the returned suggestions are all tail suggestions.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponse
constructor
A new instance of GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponse
Returns a new instance of GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponse.
18022 18023 18024 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18022 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content_suggestions ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponseContentSuggestion>
Results of the matched content suggestions. The result list is ordered and the
first result is the top suggestion.
Corresponds to the JSON property contentSuggestions
17994 17995 17996 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17994 def content_suggestions @content_suggestions end |
#people_suggestions ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponsePersonSuggestion>
Results of the matched people suggestions. The result list is ordered and the
first result is the top suggestion.
Corresponds to the JSON property peopleSuggestions
18000 18001 18002 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18000 def people_suggestions @people_suggestions end |
#query_suggestions ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponseQuerySuggestion>
Results of the matched query suggestions. The result list is ordered and the
first result is a top suggestion.
Corresponds to the JSON property querySuggestions
18006 18007 18008 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18006 def query_suggestions @query_suggestions end |
#recent_search_suggestions ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponseRecentSearchSuggestion>
Results of the matched "recent search" suggestions. The result list is ordered
and the first result is the top suggestion.
Corresponds to the JSON property recentSearchSuggestions
18012 18013 18014 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18012 def recent_search_suggestions @recent_search_suggestions end |
#tail_match_triggered ⇒ Boolean Also known as: tail_match_triggered?
True if the returned suggestions are all tail suggestions. For tail matching
to be triggered, include_tail_suggestions in the request must be true and
there must be no suggestions that match the full query.
Corresponds to the JSON property tailMatchTriggered
18019 18020 18021 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18019 def tail_match_triggered @tail_match_triggered end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18027 18028 18029 18030 18031 18032 18033 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18027 def update!(**args) @content_suggestions = args[:content_suggestions] if args.key?(:content_suggestions) @people_suggestions = args[:people_suggestions] if args.key?(:people_suggestions) @query_suggestions = args[:query_suggestions] if args.key?(:query_suggestions) @recent_search_suggestions = args[:recent_search_suggestions] if args.key?(:recent_search_suggestions) @tail_match_triggered = args[:tail_match_triggered] if args.key?(:tail_match_triggered) end |