Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponseContentSuggestion
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponseContentSuggestion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Suggestions as content.
Instance Attribute Summary collapse
-
#content_type ⇒ String
The type of the content suggestion.
-
#data_store ⇒ String
The name of the dataStore that this suggestion belongs to.
-
#destination_uri ⇒ String
The destination uri of the content suggestion.
-
#document ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocument
Document captures all raw metadata information of items to be recommended or searched.
-
#icon_uri ⇒ String
The icon uri of the content suggestion.
-
#score ⇒ Float
The score of each suggestion.
-
#suggestion ⇒ String
The suggestion for the query.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponseContentSuggestion
constructor
A new instance of GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponseContentSuggestion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponseContentSuggestion
Returns a new instance of GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponseContentSuggestion.
18752 18753 18754 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18752 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content_type ⇒ String
The type of the content suggestion.
Corresponds to the JSON property contentType
18719 18720 18721 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18719 def content_type @content_type end |
#data_store ⇒ String
The name of the dataStore that this suggestion belongs to.
Corresponds to the JSON property dataStore
18724 18725 18726 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18724 def data_store @data_store end |
#destination_uri ⇒ String
The destination uri of the content suggestion.
Corresponds to the JSON property destinationUri
18729 18730 18731 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18729 def destination_uri @destination_uri end |
#document ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocument
Document captures all raw metadata information of items to be recommended or
searched.
Corresponds to the JSON property document
18735 18736 18737 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18735 def document @document end |
#icon_uri ⇒ String
The icon uri of the content suggestion.
Corresponds to the JSON property iconUri
18740 18741 18742 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18740 def icon_uri @icon_uri end |
#score ⇒ Float
The score of each suggestion. The score is in the range of [0, 1].
Corresponds to the JSON property score
18745 18746 18747 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18745 def score @score end |
#suggestion ⇒ String
The suggestion for the query.
Corresponds to the JSON property suggestion
18750 18751 18752 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18750 def suggestion @suggestion end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18757 18758 18759 18760 18761 18762 18763 18764 18765 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18757 def update!(**args) @content_type = args[:content_type] if args.key?(:content_type) @data_store = args[:data_store] if args.key?(:data_store) @destination_uri = args[:destination_uri] if args.key?(:destination_uri) @document = args[:document] if args.key?(:document) @icon_uri = args[:icon_uri] if args.key?(:icon_uri) @score = args[:score] if args.key?(:score) @suggestion = args[:suggestion] if args.key?(:suggestion) end |