Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponseContentSuggestion
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponseContentSuggestion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Suggestions as content.
Instance Attribute Summary collapse
-
#content_type ⇒ String
The type of the content suggestion.
-
#data_store ⇒ String
The name of the dataStore that this suggestion belongs to.
-
#destination_uri ⇒ String
The destination uri of the content suggestion.
-
#document ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocument
Document captures all raw metadata information of items to be recommended or searched.
-
#icon_uri ⇒ String
The icon uri of the content suggestion.
-
#score ⇒ Float
The score of each suggestion.
-
#suggestion ⇒ String
The suggestion for the query.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponseContentSuggestion
constructor
A new instance of GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponseContentSuggestion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponseContentSuggestion
Returns a new instance of GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponseContentSuggestion.
18076 18077 18078 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18076 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content_type ⇒ String
The type of the content suggestion.
Corresponds to the JSON property contentType
18043 18044 18045 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18043 def content_type @content_type end |
#data_store ⇒ String
The name of the dataStore that this suggestion belongs to.
Corresponds to the JSON property dataStore
18048 18049 18050 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18048 def data_store @data_store end |
#destination_uri ⇒ String
The destination uri of the content suggestion.
Corresponds to the JSON property destinationUri
18053 18054 18055 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18053 def destination_uri @destination_uri end |
#document ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocument
Document captures all raw metadata information of items to be recommended or
searched.
Corresponds to the JSON property document
18059 18060 18061 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18059 def document @document end |
#icon_uri ⇒ String
The icon uri of the content suggestion.
Corresponds to the JSON property iconUri
18064 18065 18066 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18064 def icon_uri @icon_uri end |
#score ⇒ Float
The score of each suggestion. The score is in the range of [0, 1].
Corresponds to the JSON property score
18069 18070 18071 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18069 def score @score end |
#suggestion ⇒ String
The suggestion for the query.
Corresponds to the JSON property suggestion
18074 18075 18076 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18074 def suggestion @suggestion end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18081 18082 18083 18084 18085 18086 18087 18088 18089 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18081 def update!(**args) @content_type = args[:content_type] if args.key?(:content_type) @data_store = args[:data_store] if args.key?(:data_store) @destination_uri = args[:destination_uri] if args.key?(:destination_uri) @document = args[:document] if args.key?(:document) @icon_uri = args[:icon_uri] if args.key?(:icon_uri) @score = args[:score] if args.key?(:score) @suggestion = args[:suggestion] if args.key?(:suggestion) end |