Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponseContentSuggestion
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponseContentSuggestion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Suggestions as content.
Instance Attribute Summary collapse
-
#content_type ⇒ String
The type of the content suggestion.
-
#data_store ⇒ String
The name of the dataStore that this suggestion belongs to.
-
#destination_uri ⇒ String
The destination uri of the content suggestion.
-
#document ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocument
Document captures all raw metadata information of items to be recommended or searched.
-
#icon_uri ⇒ String
The icon uri of the content suggestion.
-
#score ⇒ Float
The score of each suggestion.
-
#suggestion ⇒ String
The suggestion for the query.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponseContentSuggestion
constructor
A new instance of GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponseContentSuggestion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponseContentSuggestion
Returns a new instance of GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponseContentSuggestion.
17872 17873 17874 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17872 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content_type ⇒ String
The type of the content suggestion.
Corresponds to the JSON property contentType
17839 17840 17841 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17839 def content_type @content_type end |
#data_store ⇒ String
The name of the dataStore that this suggestion belongs to.
Corresponds to the JSON property dataStore
17844 17845 17846 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17844 def data_store @data_store end |
#destination_uri ⇒ String
The destination uri of the content suggestion.
Corresponds to the JSON property destinationUri
17849 17850 17851 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17849 def destination_uri @destination_uri end |
#document ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocument
Document captures all raw metadata information of items to be recommended or
searched.
Corresponds to the JSON property document
17855 17856 17857 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17855 def document @document end |
#icon_uri ⇒ String
The icon uri of the content suggestion.
Corresponds to the JSON property iconUri
17860 17861 17862 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17860 def icon_uri @icon_uri end |
#score ⇒ Float
The score of each suggestion. The score is in the range of [0, 1].
Corresponds to the JSON property score
17865 17866 17867 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17865 def score @score end |
#suggestion ⇒ String
The suggestion for the query.
Corresponds to the JSON property suggestion
17870 17871 17872 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17870 def suggestion @suggestion end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17877 17878 17879 17880 17881 17882 17883 17884 17885 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17877 def update!(**args) @content_type = args[:content_type] if args.key?(:content_type) @data_store = args[:data_store] if args.key?(:data_store) @destination_uri = args[:destination_uri] if args.key?(:destination_uri) @document = args[:document] if args.key?(:document) @icon_uri = args[:icon_uri] if args.key?(:icon_uri) @score = args[:score] if args.key?(:score) @suggestion = args[:suggestion] if args.key?(:suggestion) end |