Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponsePersonSuggestion
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponsePersonSuggestion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Suggestions as people.
Instance Attribute Summary collapse
-
#data_store ⇒ String
The name of the dataStore that this suggestion belongs to.
-
#destination_uri ⇒ String
The destination uri of the person suggestion.
-
#display_photo_uri ⇒ String
The photo uri of the person suggestion.
-
#document ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocument
Document captures all raw metadata information of items to be recommended or searched.
-
#person_type ⇒ String
The type of the person.
-
#score ⇒ Float
The score of each suggestion.
-
#suggestion ⇒ String
The suggestion for the query.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponsePersonSuggestion
constructor
A new instance of GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponsePersonSuggestion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponsePersonSuggestion
Returns a new instance of GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponsePersonSuggestion.
18777 18778 18779 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18777 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_store ⇒ String
The name of the dataStore that this suggestion belongs to.
Corresponds to the JSON property dataStore
18744 18745 18746 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18744 def data_store @data_store end |
#destination_uri ⇒ String
The destination uri of the person suggestion.
Corresponds to the JSON property destinationUri
18749 18750 18751 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18749 def destination_uri @destination_uri end |
#display_photo_uri ⇒ String
The photo uri of the person suggestion.
Corresponds to the JSON property displayPhotoUri
18754 18755 18756 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18754 def display_photo_uri @display_photo_uri end |
#document ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocument
Document captures all raw metadata information of items to be recommended or
searched.
Corresponds to the JSON property document
18760 18761 18762 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18760 def document @document end |
#person_type ⇒ String
The type of the person.
Corresponds to the JSON property personType
18765 18766 18767 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18765 def person_type @person_type end |
#score ⇒ Float
The score of each suggestion. The score is in the range of [0, 1].
Corresponds to the JSON property score
18770 18771 18772 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18770 def score @score end |
#suggestion ⇒ String
The suggestion for the query.
Corresponds to the JSON property suggestion
18775 18776 18777 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18775 def suggestion @suggestion end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18782 18783 18784 18785 18786 18787 18788 18789 18790 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18782 def update!(**args) @data_store = args[:data_store] if args.key?(:data_store) @destination_uri = args[:destination_uri] if args.key?(:destination_uri) @display_photo_uri = args[:display_photo_uri] if args.key?(:display_photo_uri) @document = args[:document] if args.key?(:document) @person_type = args[:person_type] if args.key?(:person_type) @score = args[:score] if args.key?(:score) @suggestion = args[:suggestion] if args.key?(:suggestion) end |