Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponsePersonSuggestion
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponsePersonSuggestion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Suggestions as people.
Instance Attribute Summary collapse
-
#data_store ⇒ String
The name of the dataStore that this suggestion belongs to.
-
#destination_uri ⇒ String
The destination uri of the person suggestion.
-
#display_photo_uri ⇒ String
The photo uri of the person suggestion.
-
#document ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocument
Document captures all raw metadata information of items to be recommended or searched.
-
#person_type ⇒ String
The type of the person.
-
#score ⇒ Float
The score of each suggestion.
-
#suggestion ⇒ String
The suggestion for the query.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponsePersonSuggestion
constructor
A new instance of GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponsePersonSuggestion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponsePersonSuggestion
Returns a new instance of GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponsePersonSuggestion.
17928 17929 17930 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17928 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_store ⇒ String
The name of the dataStore that this suggestion belongs to.
Corresponds to the JSON property dataStore
17895 17896 17897 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17895 def data_store @data_store end |
#destination_uri ⇒ String
The destination uri of the person suggestion.
Corresponds to the JSON property destinationUri
17900 17901 17902 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17900 def destination_uri @destination_uri end |
#display_photo_uri ⇒ String
The photo uri of the person suggestion.
Corresponds to the JSON property displayPhotoUri
17905 17906 17907 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17905 def display_photo_uri @display_photo_uri end |
#document ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocument
Document captures all raw metadata information of items to be recommended or
searched.
Corresponds to the JSON property document
17911 17912 17913 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17911 def document @document end |
#person_type ⇒ String
The type of the person.
Corresponds to the JSON property personType
17916 17917 17918 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17916 def person_type @person_type end |
#score ⇒ Float
The score of each suggestion. The score is in the range of [0, 1].
Corresponds to the JSON property score
17921 17922 17923 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17921 def score @score end |
#suggestion ⇒ String
The suggestion for the query.
Corresponds to the JSON property suggestion
17926 17927 17928 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17926 def suggestion @suggestion end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17933 17934 17935 17936 17937 17938 17939 17940 17941 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17933 def update!(**args) @data_store = args[:data_store] if args.key?(:data_store) @destination_uri = args[:destination_uri] if args.key?(:destination_uri) @display_photo_uri = args[:display_photo_uri] if args.key?(:display_photo_uri) @document = args[:document] if args.key?(:document) @person_type = args[:person_type] if args.key?(:person_type) @score = args[:score] if args.key?(:score) @suggestion = args[:suggestion] if args.key?(:suggestion) end |