Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponseQuerySuggestion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Suggestions as search queries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponseQuerySuggestion

Returns a new instance of GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponseQuerySuggestion.



18819
18820
18821
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18819

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#completable_field_pathsArray<String>

The unique document field paths that serve as the source of this suggestion if it was generated from completable fields. This field is only populated for the document-completable model. Corresponds to the JSON property completableFieldPaths

Returns:

  • (Array<String>)


18802
18803
18804
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18802

def completable_field_paths
  @completable_field_paths
end

#data_storeArray<String>

The name of the dataStore that this suggestion belongs to. Corresponds to the JSON property dataStore

Returns:

  • (Array<String>)


18807
18808
18809
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18807

def data_store
  @data_store
end

#scoreFloat

The score of each suggestion. The score is in the range of [0, 1]. Corresponds to the JSON property score

Returns:

  • (Float)


18812
18813
18814
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18812

def score
  @score
end

#suggestionString

The suggestion for the query. Corresponds to the JSON property suggestion

Returns:

  • (String)


18817
18818
18819
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18817

def suggestion
  @suggestion
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18824
18825
18826
18827
18828
18829
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18824

def update!(**args)
  @completable_field_paths = args[:completable_field_paths] if args.key?(:completable_field_paths)
  @data_store = args[:data_store] if args.key?(:data_store)
  @score = args[:score] if args.key?(:score)
  @suggestion = args[:suggestion] if args.key?(:suggestion)
end