Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponseQuerySuggestion
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponseQuerySuggestion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Suggestions as search queries.
Instance Attribute Summary collapse
-
#completable_field_paths ⇒ Array<String>
The unique document field paths that serve as the source of this suggestion if it was generated from completable fields.
-
#data_store ⇒ Array<String>
The name of the dataStore that this suggestion belongs to.
-
#score ⇒ Float
The score of each suggestion.
-
#suggestion ⇒ String
The suggestion for the query.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponseQuerySuggestion
constructor
A new instance of GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponseQuerySuggestion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponseQuerySuggestion
Returns a new instance of GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponseQuerySuggestion.
18174 18175 18176 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18174 def initialize(**args) update!(**args) end |
Instance Attribute Details
#completable_field_paths ⇒ Array<String>
The unique document field paths that serve as the source of this suggestion if
it was generated from completable fields. This field is only populated for the
document-completable model.
Corresponds to the JSON property completableFieldPaths
18157 18158 18159 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18157 def completable_field_paths @completable_field_paths end |
#data_store ⇒ Array<String>
The name of the dataStore that this suggestion belongs to.
Corresponds to the JSON property dataStore
18162 18163 18164 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18162 def data_store @data_store end |
#score ⇒ Float
The score of each suggestion. The score is in the range of [0, 1].
Corresponds to the JSON property score
18167 18168 18169 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18167 def score @score end |
#suggestion ⇒ String
The suggestion for the query.
Corresponds to the JSON property suggestion
18172 18173 18174 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18172 def suggestion @suggestion end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18179 18180 18181 18182 18183 18184 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18179 def update!(**args) @completable_field_paths = args[:completable_field_paths] if args.key?(:completable_field_paths) @data_store = args[:data_store] if args.key?(:data_store) @score = args[:score] if args.key?(:score) @suggestion = args[:suggestion] if args.key?(:suggestion) end |