Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponseQuerySuggestion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Suggestions as search queries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponseQuerySuggestion

Returns a new instance of GoogleCloudDiscoveryengineV1betaAdvancedCompleteQueryResponseQuerySuggestion.



17970
17971
17972
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17970

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#completable_field_pathsArray<String>

The unique document field paths that serve as the source of this suggestion if it was generated from completable fields. This field is only populated for the document-completable model. Corresponds to the JSON property completableFieldPaths

Returns:

  • (Array<String>)


17953
17954
17955
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17953

def completable_field_paths
  @completable_field_paths
end

#data_storeArray<String>

The name of the dataStore that this suggestion belongs to. Corresponds to the JSON property dataStore

Returns:

  • (Array<String>)


17958
17959
17960
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17958

def data_store
  @data_store
end

#scoreFloat

The score of each suggestion. The score is in the range of [0, 1]. Corresponds to the JSON property score

Returns:

  • (Float)


17963
17964
17965
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17963

def score
  @score
end

#suggestionString

The suggestion for the query. Corresponds to the JSON property suggestion

Returns:

  • (String)


17968
17969
17970
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17968

def suggestion
  @suggestion
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17975
17976
17977
17978
17979
17980
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 17975

def update!(**args)
  @completable_field_paths = args[:completable_field_paths] if args.key?(:completable_field_paths)
  @data_store = args[:data_store] if args.key?(:data_store)
  @score = args[:score] if args.key?(:score)
  @suggestion = args[:suggestion] if args.key?(:suggestion)
end