Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAlloyDbSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

AlloyDB source import data from.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAlloyDbSource

Returns a new instance of GoogleCloudDiscoveryengineV1betaAlloyDbSource.



19029
19030
19031
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19029

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Required. The AlloyDB cluster to copy the data from with a length limit of 256 characters. Corresponds to the JSON property clusterId

Returns:

  • (String)


18994
18995
18996
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18994

def cluster_id
  @cluster_id
end

#database_idString

Required. The AlloyDB database to copy the data from with a length limit of 256 characters. Corresponds to the JSON property databaseId

Returns:

  • (String)


19000
19001
19002
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19000

def database_id
  @database_id
end

#gcs_staging_dirString

Intermediate Cloud Storage directory used for the import with a length limit of 2,000 characters. Can be specified if one wants to have the AlloyDB export to a specific Cloud Storage directory. Ensure that the AlloyDB service account has the necessary Cloud Storage Admin permissions to access the specified Cloud Storage directory. Corresponds to the JSON property gcsStagingDir

Returns:

  • (String)


19009
19010
19011
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19009

def gcs_staging_dir
  @gcs_staging_dir
end

#location_idString

Required. The AlloyDB location to copy the data from with a length limit of 256 characters. Corresponds to the JSON property locationId

Returns:

  • (String)


19015
19016
19017
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19015

def location_id
  @location_id
end

#project_idString

The project ID that contains the AlloyDB source. Has a length limit of 128 characters. If not specified, inherits the project ID from the parent request. Corresponds to the JSON property projectId

Returns:

  • (String)


19021
19022
19023
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19021

def project_id
  @project_id
end

#table_idString

Required. The AlloyDB table to copy the data from with a length limit of 256 characters. Corresponds to the JSON property tableId

Returns:

  • (String)


19027
19028
19029
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19027

def table_id
  @table_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19034
19035
19036
19037
19038
19039
19040
19041
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19034

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @database_id = args[:database_id] if args.key?(:database_id)
  @gcs_staging_dir = args[:gcs_staging_dir] if args.key?(:gcs_staging_dir)
  @location_id = args[:location_id] if args.key?(:location_id)
  @project_id = args[:project_id] if args.key?(:project_id)
  @table_id = args[:table_id] if args.key?(:table_id)
end