Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAlloyDbSource
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAlloyDbSource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
AlloyDB source import data from.
Instance Attribute Summary collapse
-
#cluster_id ⇒ String
Required.
-
#database_id ⇒ String
Required.
-
#gcs_staging_dir ⇒ String
Intermediate Cloud Storage directory used for the import with a length limit of 2,000 characters.
-
#location_id ⇒ String
Required.
-
#project_id ⇒ String
The project ID that contains the AlloyDB source.
-
#table_id ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAlloyDbSource
constructor
A new instance of GoogleCloudDiscoveryengineV1betaAlloyDbSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAlloyDbSource
Returns a new instance of GoogleCloudDiscoveryengineV1betaAlloyDbSource.
19005 19006 19007 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19005 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_id ⇒ String
Required. The AlloyDB cluster to copy the data from with a length limit of 256
characters.
Corresponds to the JSON property clusterId
18970 18971 18972 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18970 def cluster_id @cluster_id end |
#database_id ⇒ String
Required. The AlloyDB database to copy the data from with a length limit of
256 characters.
Corresponds to the JSON property databaseId
18976 18977 18978 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18976 def database_id @database_id end |
#gcs_staging_dir ⇒ String
Intermediate Cloud Storage directory used for the import with a length limit
of 2,000 characters. Can be specified if one wants to have the AlloyDB export
to a specific Cloud Storage directory. Ensure that the AlloyDB service account
has the necessary Cloud Storage Admin permissions to access the specified
Cloud Storage directory.
Corresponds to the JSON property gcsStagingDir
18985 18986 18987 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18985 def gcs_staging_dir @gcs_staging_dir end |
#location_id ⇒ String
Required. The AlloyDB location to copy the data from with a length limit of
256 characters.
Corresponds to the JSON property locationId
18991 18992 18993 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18991 def location_id @location_id end |
#project_id ⇒ String
The project ID that contains the AlloyDB source. Has a length limit of 128
characters. If not specified, inherits the project ID from the parent request.
Corresponds to the JSON property projectId
18997 18998 18999 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18997 def project_id @project_id end |
#table_id ⇒ String
Required. The AlloyDB table to copy the data from with a length limit of 256
characters.
Corresponds to the JSON property tableId
19003 19004 19005 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19003 def table_id @table_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19010 19011 19012 19013 19014 19015 19016 19017 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19010 def update!(**args) @cluster_id = args[:cluster_id] if args.key?(:cluster_id) @database_id = args[:database_id] if args.key?(:database_id) @gcs_staging_dir = args[:gcs_staging_dir] if args.key?(:gcs_staging_dir) @location_id = args[:location_id] if args.key?(:location_id) @project_id = args[:project_id] if args.key?(:project_id) @table_id = args[:table_id] if args.key?(:table_id) end |