Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAlloyDbSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

AlloyDB source import data from.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAlloyDbSource

Returns a new instance of GoogleCloudDiscoveryengineV1betaAlloyDbSource.



18329
18330
18331
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18329

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Required. The AlloyDB cluster to copy the data from with a length limit of 256 characters. Corresponds to the JSON property clusterId

Returns:

  • (String)


18294
18295
18296
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18294

def cluster_id
  @cluster_id
end

#database_idString

Required. The AlloyDB database to copy the data from with a length limit of 256 characters. Corresponds to the JSON property databaseId

Returns:

  • (String)


18300
18301
18302
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18300

def database_id
  @database_id
end

#gcs_staging_dirString

Intermediate Cloud Storage directory used for the import with a length limit of 2,000 characters. Can be specified if one wants to have the AlloyDB export to a specific Cloud Storage directory. Ensure that the AlloyDB service account has the necessary Cloud Storage Admin permissions to access the specified Cloud Storage directory. Corresponds to the JSON property gcsStagingDir

Returns:

  • (String)


18309
18310
18311
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18309

def gcs_staging_dir
  @gcs_staging_dir
end

#location_idString

Required. The AlloyDB location to copy the data from with a length limit of 256 characters. Corresponds to the JSON property locationId

Returns:

  • (String)


18315
18316
18317
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18315

def location_id
  @location_id
end

#project_idString

The project ID that contains the AlloyDB source. Has a length limit of 128 characters. If not specified, inherits the project ID from the parent request. Corresponds to the JSON property projectId

Returns:

  • (String)


18321
18322
18323
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18321

def project_id
  @project_id
end

#table_idString

Required. The AlloyDB table to copy the data from with a length limit of 256 characters. Corresponds to the JSON property tableId

Returns:

  • (String)


18327
18328
18329
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18327

def table_id
  @table_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18334
18335
18336
18337
18338
18339
18340
18341
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18334

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @database_id = args[:database_id] if args.key?(:database_id)
  @gcs_staging_dir = args[:gcs_staging_dir] if args.key?(:gcs_staging_dir)
  @location_id = args[:location_id] if args.key?(:location_id)
  @project_id = args[:project_id] if args.key?(:project_id)
  @table_id = args[:table_id] if args.key?(:table_id)
end