Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAlloyDbSource
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAlloyDbSource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
AlloyDB source import data from.
Instance Attribute Summary collapse
-
#cluster_id ⇒ String
Required.
-
#database_id ⇒ String
Required.
-
#gcs_staging_dir ⇒ String
Intermediate Cloud Storage directory used for the import with a length limit of 2,000 characters.
-
#location_id ⇒ String
Required.
-
#project_id ⇒ String
The project ID that contains the AlloyDB source.
-
#table_id ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAlloyDbSource
constructor
A new instance of GoogleCloudDiscoveryengineV1betaAlloyDbSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAlloyDbSource
Returns a new instance of GoogleCloudDiscoveryengineV1betaAlloyDbSource.
18125 18126 18127 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18125 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_id ⇒ String
Required. The AlloyDB cluster to copy the data from with a length limit of 256
characters.
Corresponds to the JSON property clusterId
18090 18091 18092 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18090 def cluster_id @cluster_id end |
#database_id ⇒ String
Required. The AlloyDB database to copy the data from with a length limit of
256 characters.
Corresponds to the JSON property databaseId
18096 18097 18098 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18096 def database_id @database_id end |
#gcs_staging_dir ⇒ String
Intermediate Cloud Storage directory used for the import with a length limit
of 2,000 characters. Can be specified if one wants to have the AlloyDB export
to a specific Cloud Storage directory. Ensure that the AlloyDB service account
has the necessary Cloud Storage Admin permissions to access the specified
Cloud Storage directory.
Corresponds to the JSON property gcsStagingDir
18105 18106 18107 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18105 def gcs_staging_dir @gcs_staging_dir end |
#location_id ⇒ String
Required. The AlloyDB location to copy the data from with a length limit of
256 characters.
Corresponds to the JSON property locationId
18111 18112 18113 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18111 def location_id @location_id end |
#project_id ⇒ String
The project ID that contains the AlloyDB source. Has a length limit of 128
characters. If not specified, inherits the project ID from the parent request.
Corresponds to the JSON property projectId
18117 18118 18119 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18117 def project_id @project_id end |
#table_id ⇒ String
Required. The AlloyDB table to copy the data from with a length limit of 256
characters.
Corresponds to the JSON property tableId
18123 18124 18125 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18123 def table_id @table_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18130 18131 18132 18133 18134 18135 18136 18137 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18130 def update!(**args) @cluster_id = args[:cluster_id] if args.key?(:cluster_id) @database_id = args[:database_id] if args.key?(:database_id) @gcs_staging_dir = args[:gcs_staging_dir] if args.key?(:gcs_staging_dir) @location_id = args[:location_id] if args.key?(:location_id) @project_id = args[:project_id] if args.key?(:project_id) @table_id = args[:table_id] if args.key?(:table_id) end |