Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswer

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Defines an answer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswer

Returns a new instance of GoogleCloudDiscoveryengineV1betaAnswer.



19238
19239
19240
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19238

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#answer_skipped_reasonsArray<String>

Additional answer-skipped reasons. This provides the reason for ignored cases. If nothing is skipped, this field is not set. Corresponds to the JSON property answerSkippedReasons

Returns:

  • (Array<String>)


19164
19165
19166
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19164

def answer_skipped_reasons
  @answer_skipped_reasons
end

#answer_textString

The textual answer. Corresponds to the JSON property answerText

Returns:

  • (String)


19169
19170
19171
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19169

def answer_text
  @answer_text
end

#blob_attachmentsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerBlobAttachment>

Output only. List of blob attachments in the answer. Corresponds to the JSON property blobAttachments



19174
19175
19176
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19174

def blob_attachments
  @blob_attachments
end

#citationsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerCitation>

Citations. Corresponds to the JSON property citations



19179
19180
19181
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19179

def citations
  @citations
end

#complete_timeString

Output only. Answer completed timestamp. Corresponds to the JSON property completeTime

Returns:

  • (String)


19184
19185
19186
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19184

def complete_time
  @complete_time
end

#create_timeString

Output only. Answer creation timestamp. Corresponds to the JSON property createTime

Returns:

  • (String)


19189
19190
19191
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19189

def create_time
  @create_time
end

#grounding_scoreFloat

A score in the range of [0, 1] describing how grounded the answer is by the reference chunks. Corresponds to the JSON property groundingScore

Returns:

  • (Float)


19195
19196
19197
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19195

def grounding_score
  @grounding_score
end

#grounding_supportsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerGroundingSupport>

Optional. Grounding supports. Corresponds to the JSON property groundingSupports



19200
19201
19202
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19200

def grounding_supports
  @grounding_supports
end

#nameString

Immutable. Fully qualified name projects/project/locations/global/ collections/collection/engines/engine/sessions/*/answers/* Corresponds to the JSON property name

Returns:

  • (String)


19206
19207
19208
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19206

def name
  @name
end

#query_understanding_infoGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryUnderstandingInfo

Query understanding information. Corresponds to the JSON property queryUnderstandingInfo



19211
19212
19213
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19211

def query_understanding_info
  @query_understanding_info
end

#referencesArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerReference>

References. Corresponds to the JSON property references



19216
19217
19218
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19216

def references
  @references
end

Suggested related questions. Corresponds to the JSON property relatedQuestions

Returns:

  • (Array<String>)


19221
19222
19223
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19221

def related_questions
  @related_questions
end

#safety_ratingsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSafetyRating>

Optional. Safety ratings. Corresponds to the JSON property safetyRatings



19226
19227
19228
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19226

def safety_ratings
  @safety_ratings
end

#stateString

The state of the answer generation. Corresponds to the JSON property state

Returns:

  • (String)


19231
19232
19233
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19231

def state
  @state
end

#stepsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerStep>

Answer generation steps. Corresponds to the JSON property steps



19236
19237
19238
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19236

def steps
  @steps
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19243
19244
19245
19246
19247
19248
19249
19250
19251
19252
19253
19254
19255
19256
19257
19258
19259
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19243

def update!(**args)
  @answer_skipped_reasons = args[:answer_skipped_reasons] if args.key?(:answer_skipped_reasons)
  @answer_text = args[:answer_text] if args.key?(:answer_text)
  @blob_attachments = args[:blob_attachments] if args.key?(:blob_attachments)
  @citations = args[:citations] if args.key?(:citations)
  @complete_time = args[:complete_time] if args.key?(:complete_time)
  @create_time = args[:create_time] if args.key?(:create_time)
  @grounding_score = args[:grounding_score] if args.key?(:grounding_score)
  @grounding_supports = args[:grounding_supports] if args.key?(:grounding_supports)
  @name = args[:name] if args.key?(:name)
  @query_understanding_info = args[:query_understanding_info] if args.key?(:query_understanding_info)
  @references = args[:references] if args.key?(:references)
  @related_questions = args[:related_questions] if args.key?(:related_questions)
  @safety_ratings = args[:safety_ratings] if args.key?(:safety_ratings)
  @state = args[:state] if args.key?(:state)
  @steps = args[:steps] if args.key?(:steps)
end