Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswer

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Defines an answer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswer

Returns a new instance of GoogleCloudDiscoveryengineV1betaAnswer.



19126
19127
19128
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19126

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#answer_skipped_reasonsArray<String>

Additional answer-skipped reasons. This provides the reason for ignored cases. If nothing is skipped, this field is not set. Corresponds to the JSON property answerSkippedReasons

Returns:

  • (Array<String>)


19052
19053
19054
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19052

def answer_skipped_reasons
  @answer_skipped_reasons
end

#answer_textString

The textual answer. Corresponds to the JSON property answerText

Returns:

  • (String)


19057
19058
19059
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19057

def answer_text
  @answer_text
end

#blob_attachmentsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerBlobAttachment>

Output only. List of blob attachments in the answer. Corresponds to the JSON property blobAttachments



19062
19063
19064
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19062

def blob_attachments
  @blob_attachments
end

#citationsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerCitation>

Citations. Corresponds to the JSON property citations



19067
19068
19069
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19067

def citations
  @citations
end

#complete_timeString

Output only. Answer completed timestamp. Corresponds to the JSON property completeTime

Returns:

  • (String)


19072
19073
19074
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19072

def complete_time
  @complete_time
end

#create_timeString

Output only. Answer creation timestamp. Corresponds to the JSON property createTime

Returns:

  • (String)


19077
19078
19079
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19077

def create_time
  @create_time
end

#grounding_scoreFloat

A score in the range of [0, 1] describing how grounded the answer is by the reference chunks. Corresponds to the JSON property groundingScore

Returns:

  • (Float)


19083
19084
19085
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19083

def grounding_score
  @grounding_score
end

#grounding_supportsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerGroundingSupport>

Optional. Grounding supports. Corresponds to the JSON property groundingSupports



19088
19089
19090
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19088

def grounding_supports
  @grounding_supports
end

#nameString

Immutable. Fully qualified name projects/project/locations/global/ collections/collection/engines/engine/sessions/*/answers/* Corresponds to the JSON property name

Returns:

  • (String)


19094
19095
19096
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19094

def name
  @name
end

#query_understanding_infoGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryUnderstandingInfo

Query understanding information. Corresponds to the JSON property queryUnderstandingInfo



19099
19100
19101
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19099

def query_understanding_info
  @query_understanding_info
end

#referencesArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerReference>

References. Corresponds to the JSON property references



19104
19105
19106
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19104

def references
  @references
end

Suggested related questions. Corresponds to the JSON property relatedQuestions

Returns:

  • (Array<String>)


19109
19110
19111
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19109

def related_questions
  @related_questions
end

#safety_ratingsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSafetyRating>

Optional. Safety ratings. Corresponds to the JSON property safetyRatings



19114
19115
19116
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19114

def safety_ratings
  @safety_ratings
end

#stateString

The state of the answer generation. Corresponds to the JSON property state

Returns:

  • (String)


19119
19120
19121
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19119

def state
  @state
end

#stepsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerStep>

Answer generation steps. Corresponds to the JSON property steps



19124
19125
19126
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19124

def steps
  @steps
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19131
19132
19133
19134
19135
19136
19137
19138
19139
19140
19141
19142
19143
19144
19145
19146
19147
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19131

def update!(**args)
  @answer_skipped_reasons = args[:answer_skipped_reasons] if args.key?(:answer_skipped_reasons)
  @answer_text = args[:answer_text] if args.key?(:answer_text)
  @blob_attachments = args[:blob_attachments] if args.key?(:blob_attachments)
  @citations = args[:citations] if args.key?(:citations)
  @complete_time = args[:complete_time] if args.key?(:complete_time)
  @create_time = args[:create_time] if args.key?(:create_time)
  @grounding_score = args[:grounding_score] if args.key?(:grounding_score)
  @grounding_supports = args[:grounding_supports] if args.key?(:grounding_supports)
  @name = args[:name] if args.key?(:name)
  @query_understanding_info = args[:query_understanding_info] if args.key?(:query_understanding_info)
  @references = args[:references] if args.key?(:references)
  @related_questions = args[:related_questions] if args.key?(:related_questions)
  @safety_ratings = args[:safety_ratings] if args.key?(:safety_ratings)
  @state = args[:state] if args.key?(:state)
  @steps = args[:steps] if args.key?(:steps)
end