Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswer

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Defines an answer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswer

Returns a new instance of GoogleCloudDiscoveryengineV1betaAnswer.



19102
19103
19104
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19102

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#answer_skipped_reasonsArray<String>

Additional answer-skipped reasons. This provides the reason for ignored cases. If nothing is skipped, this field is not set. Corresponds to the JSON property answerSkippedReasons

Returns:

  • (Array<String>)


19028
19029
19030
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19028

def answer_skipped_reasons
  @answer_skipped_reasons
end

#answer_textString

The textual answer. Corresponds to the JSON property answerText

Returns:

  • (String)


19033
19034
19035
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19033

def answer_text
  @answer_text
end

#blob_attachmentsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerBlobAttachment>

Output only. List of blob attachments in the answer. Corresponds to the JSON property blobAttachments



19038
19039
19040
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19038

def blob_attachments
  @blob_attachments
end

#citationsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerCitation>

Citations. Corresponds to the JSON property citations



19043
19044
19045
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19043

def citations
  @citations
end

#complete_timeString

Output only. Answer completed timestamp. Corresponds to the JSON property completeTime

Returns:

  • (String)


19048
19049
19050
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19048

def complete_time
  @complete_time
end

#create_timeString

Output only. Answer creation timestamp. Corresponds to the JSON property createTime

Returns:

  • (String)


19053
19054
19055
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19053

def create_time
  @create_time
end

#grounding_scoreFloat

A score in the range of [0, 1] describing how grounded the answer is by the reference chunks. Corresponds to the JSON property groundingScore

Returns:

  • (Float)


19059
19060
19061
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19059

def grounding_score
  @grounding_score
end

#grounding_supportsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerGroundingSupport>

Optional. Grounding supports. Corresponds to the JSON property groundingSupports



19064
19065
19066
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19064

def grounding_supports
  @grounding_supports
end

#nameString

Immutable. Fully qualified name projects/project/locations/global/ collections/collection/engines/engine/sessions/*/answers/* Corresponds to the JSON property name

Returns:

  • (String)


19070
19071
19072
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19070

def name
  @name
end

#query_understanding_infoGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryUnderstandingInfo

Query understanding information. Corresponds to the JSON property queryUnderstandingInfo



19075
19076
19077
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19075

def query_understanding_info
  @query_understanding_info
end

#referencesArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerReference>

References. Corresponds to the JSON property references



19080
19081
19082
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19080

def references
  @references
end

Suggested related questions. Corresponds to the JSON property relatedQuestions

Returns:

  • (Array<String>)


19085
19086
19087
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19085

def related_questions
  @related_questions
end

#safety_ratingsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSafetyRating>

Optional. Safety ratings. Corresponds to the JSON property safetyRatings



19090
19091
19092
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19090

def safety_ratings
  @safety_ratings
end

#stateString

The state of the answer generation. Corresponds to the JSON property state

Returns:

  • (String)


19095
19096
19097
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19095

def state
  @state
end

#stepsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerStep>

Answer generation steps. Corresponds to the JSON property steps



19100
19101
19102
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19100

def steps
  @steps
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19107
19108
19109
19110
19111
19112
19113
19114
19115
19116
19117
19118
19119
19120
19121
19122
19123
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19107

def update!(**args)
  @answer_skipped_reasons = args[:answer_skipped_reasons] if args.key?(:answer_skipped_reasons)
  @answer_text = args[:answer_text] if args.key?(:answer_text)
  @blob_attachments = args[:blob_attachments] if args.key?(:blob_attachments)
  @citations = args[:citations] if args.key?(:citations)
  @complete_time = args[:complete_time] if args.key?(:complete_time)
  @create_time = args[:create_time] if args.key?(:create_time)
  @grounding_score = args[:grounding_score] if args.key?(:grounding_score)
  @grounding_supports = args[:grounding_supports] if args.key?(:grounding_supports)
  @name = args[:name] if args.key?(:name)
  @query_understanding_info = args[:query_understanding_info] if args.key?(:query_understanding_info)
  @references = args[:references] if args.key?(:references)
  @related_questions = args[:related_questions] if args.key?(:related_questions)
  @safety_ratings = args[:safety_ratings] if args.key?(:safety_ratings)
  @state = args[:state] if args.key?(:state)
  @steps = args[:steps] if args.key?(:steps)
end