Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswer
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswer
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Defines an answer.
Instance Attribute Summary collapse
-
#answer_skipped_reasons ⇒ Array<String>
Additional answer-skipped reasons.
-
#answer_text ⇒ String
The textual answer.
-
#blob_attachments ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerBlobAttachment>
Output only.
-
#citations ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerCitation>
Citations.
-
#complete_time ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#grounding_score ⇒ Float
A score in the range of [0, 1] describing how grounded the answer is by the reference chunks.
-
#grounding_supports ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerGroundingSupport>
Optional.
-
#name ⇒ String
Immutable.
-
#query_understanding_info ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryUnderstandingInfo
Query understanding information.
-
#references ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerReference>
References.
-
#related_questions ⇒ Array<String>
Suggested related questions.
-
#safety_ratings ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSafetyRating>
Optional.
-
#state ⇒ String
The state of the answer generation.
-
#steps ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerStep>
Answer generation steps.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswer
constructor
A new instance of GoogleCloudDiscoveryengineV1betaAnswer.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswer
Returns a new instance of GoogleCloudDiscoveryengineV1betaAnswer.
19102 19103 19104 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19102 def initialize(**args) update!(**args) end |
Instance Attribute Details
#answer_skipped_reasons ⇒ Array<String>
Additional answer-skipped reasons. This provides the reason for ignored cases.
If nothing is skipped, this field is not set.
Corresponds to the JSON property answerSkippedReasons
19028 19029 19030 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19028 def answer_skipped_reasons @answer_skipped_reasons end |
#answer_text ⇒ String
The textual answer.
Corresponds to the JSON property answerText
19033 19034 19035 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19033 def answer_text @answer_text end |
#blob_attachments ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerBlobAttachment>
Output only. List of blob attachments in the answer.
Corresponds to the JSON property blobAttachments
19038 19039 19040 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19038 def @blob_attachments end |
#citations ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerCitation>
Citations.
Corresponds to the JSON property citations
19043 19044 19045 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19043 def citations @citations end |
#complete_time ⇒ String
Output only. Answer completed timestamp.
Corresponds to the JSON property completeTime
19048 19049 19050 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19048 def complete_time @complete_time end |
#create_time ⇒ String
Output only. Answer creation timestamp.
Corresponds to the JSON property createTime
19053 19054 19055 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19053 def create_time @create_time end |
#grounding_score ⇒ Float
A score in the range of [0, 1] describing how grounded the answer is by the
reference chunks.
Corresponds to the JSON property groundingScore
19059 19060 19061 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19059 def grounding_score @grounding_score end |
#grounding_supports ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerGroundingSupport>
Optional. Grounding supports.
Corresponds to the JSON property groundingSupports
19064 19065 19066 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19064 def grounding_supports @grounding_supports end |
#name ⇒ String
Immutable. Fully qualified name projects/project/locations/global/
collections/collection/engines/engine/sessions/*/answers/*
Corresponds to the JSON property name
19070 19071 19072 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19070 def name @name end |
#query_understanding_info ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryUnderstandingInfo
Query understanding information.
Corresponds to the JSON property queryUnderstandingInfo
19075 19076 19077 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19075 def query_understanding_info @query_understanding_info end |
#references ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerReference>
References.
Corresponds to the JSON property references
19080 19081 19082 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19080 def references @references end |
#related_questions ⇒ Array<String>
Suggested related questions.
Corresponds to the JSON property relatedQuestions
19085 19086 19087 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19085 def @related_questions end |
#safety_ratings ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSafetyRating>
Optional. Safety ratings.
Corresponds to the JSON property safetyRatings
19090 19091 19092 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19090 def @safety_ratings end |
#state ⇒ String
The state of the answer generation.
Corresponds to the JSON property state
19095 19096 19097 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19095 def state @state end |
#steps ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerStep>
Answer generation steps.
Corresponds to the JSON property steps
19100 19101 19102 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19100 def steps @steps end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19107 19108 19109 19110 19111 19112 19113 19114 19115 19116 19117 19118 19119 19120 19121 19122 19123 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19107 def update!(**args) @answer_skipped_reasons = args[:answer_skipped_reasons] if args.key?(:answer_skipped_reasons) @answer_text = args[:answer_text] if args.key?(:answer_text) @blob_attachments = args[:blob_attachments] if args.key?(:blob_attachments) @citations = args[:citations] if args.key?(:citations) @complete_time = args[:complete_time] if args.key?(:complete_time) @create_time = args[:create_time] if args.key?(:create_time) @grounding_score = args[:grounding_score] if args.key?(:grounding_score) @grounding_supports = args[:grounding_supports] if args.key?(:grounding_supports) @name = args[:name] if args.key?(:name) @query_understanding_info = args[:query_understanding_info] if args.key?(:query_understanding_info) @references = args[:references] if args.key?(:references) @related_questions = args[:related_questions] if args.key?(:related_questions) @safety_ratings = args[:safety_ratings] if args.key?(:safety_ratings) @state = args[:state] if args.key?(:state) @steps = args[:steps] if args.key?(:steps) end |