Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswer

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Defines an answer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswer

Returns a new instance of GoogleCloudDiscoveryengineV1betaAnswer.



18222
18223
18224
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18222

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#answer_skipped_reasonsArray<String>

Additional answer-skipped reasons. This provides the reason for ignored cases. If nothing is skipped, this field is not set. Corresponds to the JSON property answerSkippedReasons

Returns:

  • (Array<String>)


18148
18149
18150
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18148

def answer_skipped_reasons
  @answer_skipped_reasons
end

#answer_textString

The textual answer. Corresponds to the JSON property answerText

Returns:

  • (String)


18153
18154
18155
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18153

def answer_text
  @answer_text
end

#blob_attachmentsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerBlobAttachment>

Output only. List of blob attachments in the answer. Corresponds to the JSON property blobAttachments



18158
18159
18160
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18158

def blob_attachments
  @blob_attachments
end

#citationsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerCitation>

Citations. Corresponds to the JSON property citations



18163
18164
18165
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18163

def citations
  @citations
end

#complete_timeString

Output only. Answer completed timestamp. Corresponds to the JSON property completeTime

Returns:

  • (String)


18168
18169
18170
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18168

def complete_time
  @complete_time
end

#create_timeString

Output only. Answer creation timestamp. Corresponds to the JSON property createTime

Returns:

  • (String)


18173
18174
18175
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18173

def create_time
  @create_time
end

#grounding_scoreFloat

A score in the range of [0, 1] describing how grounded the answer is by the reference chunks. Corresponds to the JSON property groundingScore

Returns:

  • (Float)


18179
18180
18181
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18179

def grounding_score
  @grounding_score
end

#grounding_supportsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerGroundingSupport>

Optional. Grounding supports. Corresponds to the JSON property groundingSupports



18184
18185
18186
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18184

def grounding_supports
  @grounding_supports
end

#nameString

Immutable. Fully qualified name projects/project/locations/global/ collections/collection/engines/engine/sessions/*/answers/* Corresponds to the JSON property name

Returns:

  • (String)


18190
18191
18192
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18190

def name
  @name
end

#query_understanding_infoGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryUnderstandingInfo

Query understanding information. Corresponds to the JSON property queryUnderstandingInfo



18195
18196
18197
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18195

def query_understanding_info
  @query_understanding_info
end

#referencesArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerReference>

References. Corresponds to the JSON property references



18200
18201
18202
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18200

def references
  @references
end

Suggested related questions. Corresponds to the JSON property relatedQuestions

Returns:

  • (Array<String>)


18205
18206
18207
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18205

def related_questions
  @related_questions
end

#safety_ratingsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSafetyRating>

Optional. Safety ratings. Corresponds to the JSON property safetyRatings



18210
18211
18212
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18210

def safety_ratings
  @safety_ratings
end

#stateString

The state of the answer generation. Corresponds to the JSON property state

Returns:

  • (String)


18215
18216
18217
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18215

def state
  @state
end

#stepsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerStep>

Answer generation steps. Corresponds to the JSON property steps



18220
18221
18222
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18220

def steps
  @steps
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18227
18228
18229
18230
18231
18232
18233
18234
18235
18236
18237
18238
18239
18240
18241
18242
18243
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18227

def update!(**args)
  @answer_skipped_reasons = args[:answer_skipped_reasons] if args.key?(:answer_skipped_reasons)
  @answer_text = args[:answer_text] if args.key?(:answer_text)
  @blob_attachments = args[:blob_attachments] if args.key?(:blob_attachments)
  @citations = args[:citations] if args.key?(:citations)
  @complete_time = args[:complete_time] if args.key?(:complete_time)
  @create_time = args[:create_time] if args.key?(:create_time)
  @grounding_score = args[:grounding_score] if args.key?(:grounding_score)
  @grounding_supports = args[:grounding_supports] if args.key?(:grounding_supports)
  @name = args[:name] if args.key?(:name)
  @query_understanding_info = args[:query_understanding_info] if args.key?(:query_understanding_info)
  @references = args[:references] if args.key?(:references)
  @related_questions = args[:related_questions] if args.key?(:related_questions)
  @safety_ratings = args[:safety_ratings] if args.key?(:safety_ratings)
  @state = args[:state] if args.key?(:state)
  @steps = args[:steps] if args.key?(:steps)
end