Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerCitation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Citation info for a segment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerCitation

Returns a new instance of GoogleCloudDiscoveryengineV1betaAnswerCitation.



18524
18525
18526
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18524

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_indexFixnum

End of the attributed segment, exclusive. Measured in bytes (UTF-8 unicode). If there are multi-byte characters,such as non-ASCII characters, the index measurement is longer than the string length. Corresponds to the JSON property endIndex

Returns:

  • (Fixnum)


18510
18511
18512
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18510

def end_index
  @end_index
end

#sourcesArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerCitationSource>

Citation sources for the attributed segment. Corresponds to the JSON property sources



18515
18516
18517
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18515

def sources
  @sources
end

#start_indexFixnum

Index indicates the start of the segment, measured in bytes (UTF-8 unicode). If there are multi-byte characters,such as non-ASCII characters, the index measurement is longer than the string length. Corresponds to the JSON property startIndex

Returns:

  • (Fixnum)


18522
18523
18524
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18522

def start_index
  @start_index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18529
18530
18531
18532
18533
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18529

def update!(**args)
  @end_index = args[:end_index] if args.key?(:end_index)
  @sources = args[:sources] if args.key?(:sources)
  @start_index = args[:start_index] if args.key?(:start_index)
end