Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerCitation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Citation info for a segment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerCitation

Returns a new instance of GoogleCloudDiscoveryengineV1betaAnswerCitation.



18320
18321
18322
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18320

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_indexFixnum

End of the attributed segment, exclusive. Measured in bytes (UTF-8 unicode). If there are multi-byte characters,such as non-ASCII characters, the index measurement is longer than the string length. Corresponds to the JSON property endIndex

Returns:

  • (Fixnum)


18306
18307
18308
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18306

def end_index
  @end_index
end

#sourcesArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerCitationSource>

Citation sources for the attributed segment. Corresponds to the JSON property sources



18311
18312
18313
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18311

def sources
  @sources
end

#start_indexFixnum

Index indicates the start of the segment, measured in bytes (UTF-8 unicode). If there are multi-byte characters,such as non-ASCII characters, the index measurement is longer than the string length. Corresponds to the JSON property startIndex

Returns:

  • (Fixnum)


18318
18319
18320
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18318

def start_index
  @start_index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18325
18326
18327
18328
18329
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18325

def update!(**args)
  @end_index = args[:end_index] if args.key?(:end_index)
  @sources = args[:sources] if args.key?(:sources)
  @start_index = args[:start_index] if args.key?(:start_index)
end