Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerGenerationSpecUserDefinedClassifierSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

The specification for user defined classifier.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerGenerationSpecUserDefinedClassifierSpec

Returns a new instance of GoogleCloudDiscoveryengineV1betaAnswerGenerationSpecUserDefinedClassifierSpec.



19295
19296
19297
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19295

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_user_defined_classifierBoolean Also known as: enable_user_defined_classifier?

Optional. Whether or not to enable and include user defined classifier. Corresponds to the JSON property enableUserDefinedClassifier

Returns:

  • (Boolean)


19257
19258
19259
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19257

def enable_user_defined_classifier
  @enable_user_defined_classifier
end

#model_idString

Optional. The model id to be used for the user defined classifier. Corresponds to the JSON property modelId

Returns:

  • (String)


19263
19264
19265
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19263

def model_id
  @model_id
end

#preambleString

Optional. The preamble to be used for the user defined classifier. Corresponds to the JSON property preamble

Returns:

  • (String)


19268
19269
19270
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19268

def preamble
  @preamble
end

#seedFixnum

Optional. The seed value to be used for the user defined classifier. Corresponds to the JSON property seed

Returns:

  • (Fixnum)


19273
19274
19275
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19273

def seed
  @seed
end

#task_markerString

Optional. The task marker to be used for the user defined classifier. Corresponds to the JSON property taskMarker

Returns:

  • (String)


19278
19279
19280
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19278

def task_marker
  @task_marker
end

#temperatureFloat

Optional. The temperature value to be used for the user defined classifier. Corresponds to the JSON property temperature

Returns:

  • (Float)


19283
19284
19285
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19283

def temperature
  @temperature
end

#top_kFixnum

Optional. The top-k value to be used for the user defined classifier. Corresponds to the JSON property topK

Returns:

  • (Fixnum)


19288
19289
19290
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19288

def top_k
  @top_k
end

#top_pFloat

Optional. The top-p value to be used for the user defined classifier. Corresponds to the JSON property topP

Returns:

  • (Float)


19293
19294
19295
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19293

def top_p
  @top_p
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19300
19301
19302
19303
19304
19305
19306
19307
19308
19309
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19300

def update!(**args)
  @enable_user_defined_classifier = args[:enable_user_defined_classifier] if args.key?(:enable_user_defined_classifier)
  @model_id = args[:model_id] if args.key?(:model_id)
  @preamble = args[:preamble] if args.key?(:preamble)
  @seed = args[:seed] if args.key?(:seed)
  @task_marker = args[:task_marker] if args.key?(:task_marker)
  @temperature = args[:temperature] if args.key?(:temperature)
  @top_k = args[:top_k] if args.key?(:top_k)
  @top_p = args[:top_p] if args.key?(:top_p)
end