Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerGenerationSpecUserDefinedClassifierSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

The specification for user defined classifier.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerGenerationSpecUserDefinedClassifierSpec

Returns a new instance of GoogleCloudDiscoveryengineV1betaAnswerGenerationSpecUserDefinedClassifierSpec.



19264
19265
19266
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19264

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_user_defined_classifierBoolean Also known as: enable_user_defined_classifier?

Optional. Whether or not to enable and include user defined classifier. Corresponds to the JSON property enableUserDefinedClassifier

Returns:

  • (Boolean)


19226
19227
19228
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19226

def enable_user_defined_classifier
  @enable_user_defined_classifier
end

#model_idString

Optional. The model id to be used for the user defined classifier. Corresponds to the JSON property modelId

Returns:

  • (String)


19232
19233
19234
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19232

def model_id
  @model_id
end

#preambleString

Optional. The preamble to be used for the user defined classifier. Corresponds to the JSON property preamble

Returns:

  • (String)


19237
19238
19239
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19237

def preamble
  @preamble
end

#seedFixnum

Optional. The seed value to be used for the user defined classifier. Corresponds to the JSON property seed

Returns:

  • (Fixnum)


19242
19243
19244
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19242

def seed
  @seed
end

#task_markerString

Optional. The task marker to be used for the user defined classifier. Corresponds to the JSON property taskMarker

Returns:

  • (String)


19247
19248
19249
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19247

def task_marker
  @task_marker
end

#temperatureFloat

Optional. The temperature value to be used for the user defined classifier. Corresponds to the JSON property temperature

Returns:

  • (Float)


19252
19253
19254
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19252

def temperature
  @temperature
end

#top_kFixnum

Optional. The top-k value to be used for the user defined classifier. Corresponds to the JSON property topK

Returns:

  • (Fixnum)


19257
19258
19259
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19257

def top_k
  @top_k
end

#top_pFloat

Optional. The top-p value to be used for the user defined classifier. Corresponds to the JSON property topP

Returns:

  • (Float)


19262
19263
19264
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19262

def top_p
  @top_p
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19269
19270
19271
19272
19273
19274
19275
19276
19277
19278
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19269

def update!(**args)
  @enable_user_defined_classifier = args[:enable_user_defined_classifier] if args.key?(:enable_user_defined_classifier)
  @model_id = args[:model_id] if args.key?(:model_id)
  @preamble = args[:preamble] if args.key?(:preamble)
  @seed = args[:seed] if args.key?(:seed)
  @task_marker = args[:task_marker] if args.key?(:task_marker)
  @temperature = args[:temperature] if args.key?(:temperature)
  @top_k = args[:top_k] if args.key?(:top_k)
  @top_p = args[:top_p] if args.key?(:top_p)
end