Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerGenerationSpecUserDefinedClassifierSpec
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerGenerationSpecUserDefinedClassifierSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
The specification for user defined classifier.
Instance Attribute Summary collapse
-
#enable_user_defined_classifier ⇒ Boolean
(also: #enable_user_defined_classifier?)
Optional.
-
#model_id ⇒ String
Optional.
-
#preamble ⇒ String
Optional.
-
#seed ⇒ Fixnum
Optional.
-
#task_marker ⇒ String
Optional.
-
#temperature ⇒ Float
Optional.
-
#top_k ⇒ Fixnum
Optional.
-
#top_p ⇒ Float
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerGenerationSpecUserDefinedClassifierSpec
constructor
A new instance of GoogleCloudDiscoveryengineV1betaAnswerGenerationSpecUserDefinedClassifierSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerGenerationSpecUserDefinedClassifierSpec
Returns a new instance of GoogleCloudDiscoveryengineV1betaAnswerGenerationSpecUserDefinedClassifierSpec.
18619 18620 18621 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18619 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable_user_defined_classifier ⇒ Boolean Also known as: enable_user_defined_classifier?
Optional. Whether or not to enable and include user defined classifier.
Corresponds to the JSON property enableUserDefinedClassifier
18581 18582 18583 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18581 def enable_user_defined_classifier @enable_user_defined_classifier end |
#model_id ⇒ String
Optional. The model id to be used for the user defined classifier.
Corresponds to the JSON property modelId
18587 18588 18589 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18587 def model_id @model_id end |
#preamble ⇒ String
Optional. The preamble to be used for the user defined classifier.
Corresponds to the JSON property preamble
18592 18593 18594 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18592 def preamble @preamble end |
#seed ⇒ Fixnum
Optional. The seed value to be used for the user defined classifier.
Corresponds to the JSON property seed
18597 18598 18599 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18597 def seed @seed end |
#task_marker ⇒ String
Optional. The task marker to be used for the user defined classifier.
Corresponds to the JSON property taskMarker
18602 18603 18604 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18602 def task_marker @task_marker end |
#temperature ⇒ Float
Optional. The temperature value to be used for the user defined classifier.
Corresponds to the JSON property temperature
18607 18608 18609 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18607 def temperature @temperature end |
#top_k ⇒ Fixnum
Optional. The top-k value to be used for the user defined classifier.
Corresponds to the JSON property topK
18612 18613 18614 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18612 def top_k @top_k end |
#top_p ⇒ Float
Optional. The top-p value to be used for the user defined classifier.
Corresponds to the JSON property topP
18617 18618 18619 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18617 def top_p @top_p end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18624 18625 18626 18627 18628 18629 18630 18631 18632 18633 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18624 def update!(**args) @enable_user_defined_classifier = args[:enable_user_defined_classifier] if args.key?(:enable_user_defined_classifier) @model_id = args[:model_id] if args.key?(:model_id) @preamble = args[:preamble] if args.key?(:preamble) @seed = args[:seed] if args.key?(:seed) @task_marker = args[:task_marker] if args.key?(:task_marker) @temperature = args[:temperature] if args.key?(:temperature) @top_k = args[:top_k] if args.key?(:top_k) @top_p = args[:top_p] if args.key?(:top_p) end |