Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerGenerationSpecUserDefinedClassifierSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

The specification for user defined classifier.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerGenerationSpecUserDefinedClassifierSpec

Returns a new instance of GoogleCloudDiscoveryengineV1betaAnswerGenerationSpecUserDefinedClassifierSpec.



18415
18416
18417
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18415

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_user_defined_classifierBoolean Also known as: enable_user_defined_classifier?

Optional. Whether or not to enable and include user defined classifier. Corresponds to the JSON property enableUserDefinedClassifier

Returns:

  • (Boolean)


18377
18378
18379
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18377

def enable_user_defined_classifier
  @enable_user_defined_classifier
end

#model_idString

Optional. The model id to be used for the user defined classifier. Corresponds to the JSON property modelId

Returns:

  • (String)


18383
18384
18385
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18383

def model_id
  @model_id
end

#preambleString

Optional. The preamble to be used for the user defined classifier. Corresponds to the JSON property preamble

Returns:

  • (String)


18388
18389
18390
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18388

def preamble
  @preamble
end

#seedFixnum

Optional. The seed value to be used for the user defined classifier. Corresponds to the JSON property seed

Returns:

  • (Fixnum)


18393
18394
18395
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18393

def seed
  @seed
end

#task_markerString

Optional. The task marker to be used for the user defined classifier. Corresponds to the JSON property taskMarker

Returns:

  • (String)


18398
18399
18400
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18398

def task_marker
  @task_marker
end

#temperatureFloat

Optional. The temperature value to be used for the user defined classifier. Corresponds to the JSON property temperature

Returns:

  • (Float)


18403
18404
18405
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18403

def temperature
  @temperature
end

#top_kFixnum

Optional. The top-k value to be used for the user defined classifier. Corresponds to the JSON property topK

Returns:

  • (Fixnum)


18408
18409
18410
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18408

def top_k
  @top_k
end

#top_pFloat

Optional. The top-p value to be used for the user defined classifier. Corresponds to the JSON property topP

Returns:

  • (Float)


18413
18414
18415
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18413

def top_p
  @top_p
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18420
18421
18422
18423
18424
18425
18426
18427
18428
18429
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18420

def update!(**args)
  @enable_user_defined_classifier = args[:enable_user_defined_classifier] if args.key?(:enable_user_defined_classifier)
  @model_id = args[:model_id] if args.key?(:model_id)
  @preamble = args[:preamble] if args.key?(:preamble)
  @seed = args[:seed] if args.key?(:seed)
  @task_marker = args[:task_marker] if args.key?(:task_marker)
  @temperature = args[:temperature] if args.key?(:temperature)
  @top_k = args[:top_k] if args.key?(:top_k)
  @top_p = args[:top_p] if args.key?(:top_p)
end