Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerGroundingSupport
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerGroundingSupport
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Grounding support for a claim in answer_text.
Instance Attribute Summary collapse
-
#end_index ⇒ Fixnum
Required.
-
#grounding_check_required ⇒ Boolean
(also: #grounding_check_required?)
Indicates that this claim required grounding check.
-
#grounding_score ⇒ Float
A score in the range of [0, 1] describing how grounded is a specific claim by the references.
-
#sources ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerCitationSource>
Optional.
-
#start_index ⇒ Fixnum
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerGroundingSupport
constructor
A new instance of GoogleCloudDiscoveryengineV1betaAnswerGroundingSupport.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerGroundingSupport
Returns a new instance of GoogleCloudDiscoveryengineV1betaAnswerGroundingSupport.
19348 19349 19350 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19348 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_index ⇒ Fixnum
Required. End of the claim, exclusive.
Corresponds to the JSON property endIndex
19319 19320 19321 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19319 def end_index @end_index end |
#grounding_check_required ⇒ Boolean Also known as: grounding_check_required?
Indicates that this claim required grounding check. When the system decided
this claim didn't require attribution/grounding check, this field is set to
false. In that case, no grounding check was done for the claim and therefore
grounding_score, sources is not returned.
Corresponds to the JSON property groundingCheckRequired
19327 19328 19329 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19327 def grounding_check_required @grounding_check_required end |
#grounding_score ⇒ Float
A score in the range of [0, 1] describing how grounded is a specific claim by
the references. Higher value means that the claim is better supported by the
reference chunks.
Corresponds to the JSON property groundingScore
19335 19336 19337 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19335 def grounding_score @grounding_score end |
#sources ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerCitationSource>
Optional. Citation sources for the claim.
Corresponds to the JSON property sources
19340 19341 19342 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19340 def sources @sources end |
#start_index ⇒ Fixnum
Required. Index indicates the start of the claim, measured in bytes (UTF-8
unicode).
Corresponds to the JSON property startIndex
19346 19347 19348 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19346 def start_index @start_index end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19353 19354 19355 19356 19357 19358 19359 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19353 def update!(**args) @end_index = args[:end_index] if args.key?(:end_index) @grounding_check_required = args[:grounding_check_required] if args.key?(:grounding_check_required) @grounding_score = args[:grounding_score] if args.key?(:grounding_score) @sources = args[:sources] if args.key?(:sources) @start_index = args[:start_index] if args.key?(:start_index) end |