Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Request message for ConversationalSearchService.AnswerQuery method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerQueryRequest

Returns a new instance of GoogleCloudDiscoveryengineV1betaAnswerQueryRequest.



19423
19424
19425
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19423

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#answer_generation_specGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestAnswerGenerationSpec

Answer generation specification. Corresponds to the JSON property answerGenerationSpec



19338
19339
19340
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19338

def answer_generation_spec
  @answer_generation_spec
end

#asynchronous_modeBoolean Also known as: asynchronous_mode?

Deprecated: This field is deprecated. Streaming Answer API will be supported. Asynchronous mode control. If enabled, the response will be returned with answer/session resource name without final answer. The API users need to do the polling to get the latest status of answer/session by calling ConversationalSearchService.GetAnswer or ConversationalSearchService. GetSession method. Corresponds to the JSON property asynchronousMode

Returns:

  • (Boolean)


19348
19349
19350
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19348

def asynchronous_mode
  @asynchronous_mode
end

#end_user_specGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestEndUserSpec

End user specification. Corresponds to the JSON property endUserSpec



19354
19355
19356
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19354

def end_user_spec
  @end_user_spec
end

#grounding_specGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestGroundingSpec

Grounding specification. Corresponds to the JSON property groundingSpec



19359
19360
19361
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19359

def grounding_spec
  @grounding_spec
end

#queryGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaQuery

Defines a user inputed query. Corresponds to the JSON property query



19364
19365
19366
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19364

def query
  @query
end

#query_understanding_specGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestQueryUnderstandingSpec

Query understanding specification. Corresponds to the JSON property queryUnderstandingSpec



19369
19370
19371
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19369

def query_understanding_spec
  @query_understanding_spec
end

Related questions specification. Corresponds to the JSON property relatedQuestionsSpec



19374
19375
19376
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19374

def related_questions_spec
  @related_questions_spec
end

#safety_specGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSafetySpec

Safety specification. There are two use cases: 1. when only safety_spec.enable is set, the BLOCK_LOW_AND_ABOVE threshold will be applied for all categories.

  1. when safety_spec.enable is set and some safety_settings are set, only specified safety_settings are applied. Corresponds to the JSON property safetySpec


19382
19383
19384
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19382

def safety_spec
  @safety_spec
end

#search_specGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpec

Search specification. Corresponds to the JSON property searchSpec



19387
19388
19389
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19387

def search_spec
  @search_spec
end

#sessionString

The session resource name. Not required. When session field is not set, the API is in sessionless mode. We support auto session mode: users can use the wildcard symbol - as session ID. A new ID will be automatically generated and assigned. Corresponds to the JSON property session

Returns:

  • (String)


19395
19396
19397
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19395

def session
  @session
end

#user_labelsHash<String,String>

The user labels applied to a resource must meet the following requirements: * Each resource can have multiple labels, up to a maximum of 64. * Each label must be a key-value pair. * Keys have a minimum length of 1 character and a maximum length of 63 characters and cannot be empty. Values can be empty and have a maximum length of 63 characters. * Keys and values can contain only lowercase letters, numeric characters, underscores, and dashes. All characters must use UTF-8 encoding, and international characters are allowed. * The key portion of a label must be unique. However, you can use the same key with multiple resources. * Keys must start with a lowercase letter or international character. See Google Cloud Document for more details. Corresponds to the JSON property userLabels

Returns:

  • (Hash<String,String>)


19410
19411
19412
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19410

def user_labels
  @user_labels
end

#user_pseudo_idString

A unique identifier for tracking visitors. For example, this could be implemented with an HTTP cookie, which should be able to uniquely identify a visitor on a single device. This unique identifier should not change if the visitor logs in or out of the website. This field should NOT have a fixed value such as unknown_visitor. The field must be a UTF-8 encoded string with a length limit of 128 characters. Otherwise, an INVALID_ARGUMENT error is returned. Corresponds to the JSON property userPseudoId

Returns:

  • (String)


19421
19422
19423
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19421

def user_pseudo_id
  @user_pseudo_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19428
19429
19430
19431
19432
19433
19434
19435
19436
19437
19438
19439
19440
19441
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19428

def update!(**args)
  @answer_generation_spec = args[:answer_generation_spec] if args.key?(:answer_generation_spec)
  @asynchronous_mode = args[:asynchronous_mode] if args.key?(:asynchronous_mode)
  @end_user_spec = args[:end_user_spec] if args.key?(:end_user_spec)
  @grounding_spec = args[:grounding_spec] if args.key?(:grounding_spec)
  @query = args[:query] if args.key?(:query)
  @query_understanding_spec = args[:query_understanding_spec] if args.key?(:query_understanding_spec)
  @related_questions_spec = args[:related_questions_spec] if args.key?(:related_questions_spec)
  @safety_spec = args[:safety_spec] if args.key?(:safety_spec)
  @search_spec = args[:search_spec] if args.key?(:search_spec)
  @session = args[:session] if args.key?(:session)
  @user_labels = args[:user_labels] if args.key?(:user_labels)
  @user_pseudo_id = args[:user_pseudo_id] if args.key?(:user_pseudo_id)
end