Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestAnswerGenerationSpec
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestAnswerGenerationSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Answer generation specification.
Instance Attribute Summary collapse
-
#answer_language_code ⇒ String
Language code for Answer.
-
#ignore_adversarial_query ⇒ Boolean
(also: #ignore_adversarial_query?)
Specifies whether to filter out adversarial queries.
-
#ignore_jail_breaking_query ⇒ Boolean
(also: #ignore_jail_breaking_query?)
Optional.
-
#ignore_low_relevant_content ⇒ Boolean
(also: #ignore_low_relevant_content?)
Specifies whether to filter out queries that have low relevance.
-
#ignore_non_answer_seeking_query ⇒ Boolean
(also: #ignore_non_answer_seeking_query?)
Specifies whether to filter out queries that are not answer-seeking.
-
#include_citations ⇒ Boolean
(also: #include_citations?)
Specifies whether to include citation metadata in the answer.
-
#model_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestAnswerGenerationSpecModelSpec
Answer Generation Model specification.
-
#multimodal_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestAnswerGenerationSpecMultimodalSpec
Multimodal specification: Will return an image from specified source.
-
#prompt_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestAnswerGenerationSpecPromptSpec
Answer generation prompt specification.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerQueryRequestAnswerGenerationSpec
constructor
A new instance of GoogleCloudDiscoveryengineV1betaAnswerQueryRequestAnswerGenerationSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerQueryRequestAnswerGenerationSpec
Returns a new instance of GoogleCloudDiscoveryengineV1betaAnswerQueryRequestAnswerGenerationSpec.
18673 18674 18675 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18673 def initialize(**args) update!(**args) end |
Instance Attribute Details
#answer_language_code ⇒ String
Language code for Answer. Use language tags defined by BCP47. Note: This is an experimental feature.
Corresponds to the JSON property answerLanguageCode
18603 18604 18605 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18603 def answer_language_code @answer_language_code end |
#ignore_adversarial_query ⇒ Boolean Also known as: ignore_adversarial_query?
Specifies whether to filter out adversarial queries. The default value is
false. Google employs search-query classification to detect adversarial
queries. No answer is returned if the search query is classified as an
adversarial query. For example, a user might ask a question regarding negative
comments about the company or submit a query designed to generate unsafe,
policy-violating output. If this field is set to true, we skip generating
answers for adversarial queries and return fallback messages instead.
Corresponds to the JSON property ignoreAdversarialQuery
18614 18615 18616 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18614 def ignore_adversarial_query @ignore_adversarial_query end |
#ignore_jail_breaking_query ⇒ Boolean Also known as: ignore_jail_breaking_query?
Optional. Specifies whether to filter out jail-breaking queries. The default
value is false. Google employs search-query classification to detect jail-
breaking queries. No summary is returned if the search query is classified as
a jail-breaking query. A user might add instructions to the query to change
the tone, style, language, content of the answer, or ask the model to act as a
different entity, e.g. "Reply in the tone of a competing company's CEO". If
this field is set to true, we skip generating summaries for jail-breaking
queries and return fallback messages instead.
Corresponds to the JSON property ignoreJailBreakingQuery
18627 18628 18629 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18627 def ignore_jail_breaking_query @ignore_jail_breaking_query end |
#ignore_low_relevant_content ⇒ Boolean Also known as: ignore_low_relevant_content?
Specifies whether to filter out queries that have low relevance. If this field
is set to false, all search results are used regardless of relevance to
generate answers. If set to true or unset, the behavior will be determined
automatically by the service.
Corresponds to the JSON property ignoreLowRelevantContent
18636 18637 18638 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18636 def ignore_low_relevant_content @ignore_low_relevant_content end |
#ignore_non_answer_seeking_query ⇒ Boolean Also known as: ignore_non_answer_seeking_query?
Specifies whether to filter out queries that are not answer-seeking. The
default value is false. Google employs search-query classification to detect
answer-seeking queries. No answer is returned if the search query is
classified as a non-answer seeking query. If this field is set to true, we
skip generating answers for non-answer seeking queries and return fallback
messages instead.
Corresponds to the JSON property ignoreNonAnswerSeekingQuery
18647 18648 18649 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18647 def ignore_non_answer_seeking_query @ignore_non_answer_seeking_query end |
#include_citations ⇒ Boolean Also known as: include_citations?
Specifies whether to include citation metadata in the answer. The default
value is false.
Corresponds to the JSON property includeCitations
18654 18655 18656 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18654 def include_citations @include_citations end |
#model_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestAnswerGenerationSpecModelSpec
Answer Generation Model specification.
Corresponds to the JSON property modelSpec
18660 18661 18662 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18660 def model_spec @model_spec end |
#multimodal_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestAnswerGenerationSpecMultimodalSpec
Multimodal specification: Will return an image from specified source. If
multiple sources are specified, the pick is a quality based decision.
Corresponds to the JSON property multimodalSpec
18666 18667 18668 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18666 def multimodal_spec @multimodal_spec end |
#prompt_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestAnswerGenerationSpecPromptSpec
Answer generation prompt specification.
Corresponds to the JSON property promptSpec
18671 18672 18673 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18671 def prompt_spec @prompt_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18678 18679 18680 18681 18682 18683 18684 18685 18686 18687 18688 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18678 def update!(**args) @answer_language_code = args[:answer_language_code] if args.key?(:answer_language_code) @ignore_adversarial_query = args[:ignore_adversarial_query] if args.key?(:ignore_adversarial_query) @ignore_jail_breaking_query = args[:ignore_jail_breaking_query] if args.key?(:ignore_jail_breaking_query) @ignore_low_relevant_content = args[:ignore_low_relevant_content] if args.key?(:ignore_low_relevant_content) @ignore_non_answer_seeking_query = args[:ignore_non_answer_seeking_query] if args.key?(:ignore_non_answer_seeking_query) @include_citations = args[:include_citations] if args.key?(:include_citations) @model_spec = args[:model_spec] if args.key?(:model_spec) @multimodal_spec = args[:multimodal_spec] if args.key?(:multimodal_spec) @prompt_spec = args[:prompt_spec] if args.key?(:prompt_spec) end |