Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestEndUserSpecEndUserMetaDataChunkInfo
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestEndUserSpecEndUserMetaDataChunkInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Chunk information.
Instance Attribute Summary collapse
-
#content ⇒ String
Chunk textual content.
-
#document_metadata ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestEndUserSpecEndUserMetaDataChunkInfoDocumentMetadata
Document metadata contains the information of the document of the current chunk.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerQueryRequestEndUserSpecEndUserMetaDataChunkInfo
constructor
A new instance of GoogleCloudDiscoveryengineV1betaAnswerQueryRequestEndUserSpecEndUserMetaDataChunkInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerQueryRequestEndUserSpecEndUserMetaDataChunkInfo
Returns a new instance of GoogleCloudDiscoveryengineV1betaAnswerQueryRequestEndUserSpecEndUserMetaDataChunkInfo.
19007 19008 19009 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19007 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content ⇒ String
Chunk textual content. It is limited to 8000 characters.
Corresponds to the JSON property content
18999 19000 19001 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18999 def content @content end |
#document_metadata ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestEndUserSpecEndUserMetaDataChunkInfoDocumentMetadata
Document metadata contains the information of the document of the current
chunk.
Corresponds to the JSON property documentMetadata
19005 19006 19007 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19005 def @document_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19012 19013 19014 19015 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19012 def update!(**args) @content = args[:content] if args.key?(:content) @document_metadata = args[:document_metadata] if args.key?(:document_metadata) end |