Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestEndUserSpecEndUserMetaDataChunkInfo
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestEndUserSpecEndUserMetaDataChunkInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Chunk information.
Instance Attribute Summary collapse
-
#content ⇒ String
Chunk textual content.
-
#document_metadata ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestEndUserSpecEndUserMetaDataChunkInfoDocumentMetadata
Document metadata contains the information of the document of the current chunk.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerQueryRequestEndUserSpecEndUserMetaDataChunkInfo
constructor
A new instance of GoogleCloudDiscoveryengineV1betaAnswerQueryRequestEndUserSpecEndUserMetaDataChunkInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerQueryRequestEndUserSpecEndUserMetaDataChunkInfo
Returns a new instance of GoogleCloudDiscoveryengineV1betaAnswerQueryRequestEndUserSpecEndUserMetaDataChunkInfo.
18803 18804 18805 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18803 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content ⇒ String
Chunk textual content. It is limited to 8000 characters.
Corresponds to the JSON property content
18795 18796 18797 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18795 def content @content end |
#document_metadata ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestEndUserSpecEndUserMetaDataChunkInfoDocumentMetadata
Document metadata contains the information of the document of the current
chunk.
Corresponds to the JSON property documentMetadata
18801 18802 18803 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18801 def @document_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18808 18809 18810 18811 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 18808 def update!(**args) @content = args[:content] if args.key?(:content) @document_metadata = args[:document_metadata] if args.key?(:document_metadata) end |