Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestGroundingSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Grounding specification.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerQueryRequestGroundingSpec

Returns a new instance of GoogleCloudDiscoveryengineV1betaAnswerQueryRequestGroundingSpec.



19756
19757
19758
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19756

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#filtering_levelString

Optional. Specifies whether to enable the filtering based on grounding score and at what level. Corresponds to the JSON property filteringLevel

Returns:

  • (String)


19746
19747
19748
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19746

def filtering_level
  @filtering_level
end

#include_grounding_supportsBoolean Also known as: include_grounding_supports?

Optional. Specifies whether to include grounding_supports in the answer. The default value is false. When this field is set to true, returned answer will have grounding_score and will contain GroundingSupports for each claim. Corresponds to the JSON property includeGroundingSupports

Returns:

  • (Boolean)


19753
19754
19755
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19753

def include_grounding_supports
  @include_grounding_supports
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19761
19762
19763
19764
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19761

def update!(**args)
  @filtering_level = args[:filtering_level] if args.key?(:filtering_level)
  @include_grounding_supports = args[:include_grounding_supports] if args.key?(:include_grounding_supports)
end