Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultChunkInfo
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultChunkInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Chunk information.
Instance Attribute Summary collapse
-
#chunk ⇒ String
Chunk resource name.
-
#content ⇒ String
Chunk textual content.
-
#document_metadata ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultChunkInfoDocumentMetadata
Document metadata contains the information of the document of the current chunk.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultChunkInfo
constructor
A new instance of GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultChunkInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultChunkInfo
Returns a new instance of GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultChunkInfo.
20056 20057 20058 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20056 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chunk ⇒ String
Chunk resource name.
Corresponds to the JSON property chunk
20043 20044 20045 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20043 def chunk @chunk end |
#content ⇒ String
Chunk textual content.
Corresponds to the JSON property content
20048 20049 20050 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20048 def content @content end |
#document_metadata ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultChunkInfoDocumentMetadata
Document metadata contains the information of the document of the current
chunk.
Corresponds to the JSON property documentMetadata
20054 20055 20056 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20054 def @document_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20061 20062 20063 20064 20065 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20061 def update!(**args) @chunk = args[:chunk] if args.key?(:chunk) @content = args[:content] if args.key?(:content) @document_metadata = args[:document_metadata] if args.key?(:document_metadata) end |