Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultChunkInfo
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultChunkInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Chunk information.
Instance Attribute Summary collapse
-
#chunk ⇒ String
Chunk resource name.
-
#content ⇒ String
Chunk textual content.
-
#document_metadata ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultChunkInfoDocumentMetadata
Document metadata contains the information of the document of the current chunk.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultChunkInfo
constructor
A new instance of GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultChunkInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultChunkInfo
Returns a new instance of GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultChunkInfo.
19207 19208 19209 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19207 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chunk ⇒ String
Chunk resource name.
Corresponds to the JSON property chunk
19194 19195 19196 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19194 def chunk @chunk end |
#content ⇒ String
Chunk textual content.
Corresponds to the JSON property content
19199 19200 19201 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19199 def content @content end |
#document_metadata ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultChunkInfoDocumentMetadata
Document metadata contains the information of the document of the current
chunk.
Corresponds to the JSON property documentMetadata
19205 19206 19207 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19205 def @document_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19212 19213 19214 19215 19216 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19212 def update!(**args) @chunk = args[:chunk] if args.key?(:chunk) @content = args[:content] if args.key?(:content) @document_metadata = args[:document_metadata] if args.key?(:document_metadata) end |