Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfo
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Unstructured document information.
Instance Attribute Summary collapse
-
#document ⇒ String
Document resource name.
-
#document_contexts ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfoDocumentContext>
List of document contexts.
-
#extractive_answers ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfoExtractiveAnswer>
Deprecated: This field is deprecated and will have no effect on the Answer generation.
-
#extractive_segments ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfoExtractiveSegment>
List of extractive segments.
-
#title ⇒ String
Title.
-
#uri ⇒ String
URI for the document.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfo
constructor
A new instance of GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfo
Returns a new instance of GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfo.
20285 20286 20287 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20285 def initialize(**args) update!(**args) end |
Instance Attribute Details
#document ⇒ String
Document resource name.
Corresponds to the JSON property document
20254 20255 20256 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20254 def document @document end |
#document_contexts ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfoDocumentContext>
List of document contexts. The content will be used for Answer Generation.
This is supposed to be the main content of the document that can be long and
comprehensive.
Corresponds to the JSON property documentContexts
20261 20262 20263 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20261 def document_contexts @document_contexts end |
#extractive_answers ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfoExtractiveAnswer>
Deprecated: This field is deprecated and will have no effect on the Answer
generation. Please use document_contexts and extractive_segments fields. List
of extractive answers.
Corresponds to the JSON property extractiveAnswers
20268 20269 20270 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20268 def extractive_answers @extractive_answers end |
#extractive_segments ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfoExtractiveSegment>
List of extractive segments.
Corresponds to the JSON property extractiveSegments
20273 20274 20275 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20273 def extractive_segments @extractive_segments end |
#title ⇒ String
Title.
Corresponds to the JSON property title
20278 20279 20280 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20278 def title @title end |
#uri ⇒ String
URI for the document.
Corresponds to the JSON property uri
20283 20284 20285 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20283 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20290 20291 20292 20293 20294 20295 20296 20297 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20290 def update!(**args) @document = args[:document] if args.key?(:document) @document_contexts = args[:document_contexts] if args.key?(:document_contexts) @extractive_answers = args[:extractive_answers] if args.key?(:extractive_answers) @extractive_segments = args[:extractive_segments] if args.key?(:extractive_segments) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) end |