Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Unstructured document information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfo

Returns a new instance of GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfo.



20163
20164
20165
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20163

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#documentString

Document resource name. Corresponds to the JSON property document

Returns:

  • (String)


20132
20133
20134
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20132

def document
  @document
end

#document_contextsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfoDocumentContext>

List of document contexts. The content will be used for Answer Generation. This is supposed to be the main content of the document that can be long and comprehensive. Corresponds to the JSON property documentContexts



20139
20140
20141
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20139

def document_contexts
  @document_contexts
end

#extractive_answersArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfoExtractiveAnswer>

Deprecated: This field is deprecated and will have no effect on the Answer generation. Please use document_contexts and extractive_segments fields. List of extractive answers. Corresponds to the JSON property extractiveAnswers



20146
20147
20148
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20146

def extractive_answers
  @extractive_answers
end

#extractive_segmentsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfoExtractiveSegment>

List of extractive segments. Corresponds to the JSON property extractiveSegments



20151
20152
20153
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20151

def extractive_segments
  @extractive_segments
end

#titleString

Title. Corresponds to the JSON property title

Returns:

  • (String)


20156
20157
20158
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20156

def title
  @title
end

#uriString

URI for the document. Corresponds to the JSON property uri

Returns:

  • (String)


20161
20162
20163
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20161

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20168
20169
20170
20171
20172
20173
20174
20175
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20168

def update!(**args)
  @document = args[:document] if args.key?(:document)
  @document_contexts = args[:document_contexts] if args.key?(:document_contexts)
  @extractive_answers = args[:extractive_answers] if args.key?(:extractive_answers)
  @extractive_segments = args[:extractive_segments] if args.key?(:extractive_segments)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end