Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Unstructured document information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfo

Returns a new instance of GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfo.



19487
19488
19489
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19487

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#documentString

Document resource name. Corresponds to the JSON property document

Returns:

  • (String)


19456
19457
19458
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19456

def document
  @document
end

#document_contextsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfoDocumentContext>

List of document contexts. The content will be used for Answer Generation. This is supposed to be the main content of the document that can be long and comprehensive. Corresponds to the JSON property documentContexts



19463
19464
19465
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19463

def document_contexts
  @document_contexts
end

#extractive_answersArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfoExtractiveAnswer>

Deprecated: This field is deprecated and will have no effect on the Answer generation. Please use document_contexts and extractive_segments fields. List of extractive answers. Corresponds to the JSON property extractiveAnswers



19470
19471
19472
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19470

def extractive_answers
  @extractive_answers
end

#extractive_segmentsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfoExtractiveSegment>

List of extractive segments. Corresponds to the JSON property extractiveSegments



19475
19476
19477
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19475

def extractive_segments
  @extractive_segments
end

#titleString

Title. Corresponds to the JSON property title

Returns:

  • (String)


19480
19481
19482
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19480

def title
  @title
end

#uriString

URI for the document. Corresponds to the JSON property uri

Returns:

  • (String)


19485
19486
19487
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19485

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19492
19493
19494
19495
19496
19497
19498
19499
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19492

def update!(**args)
  @document = args[:document] if args.key?(:document)
  @document_contexts = args[:document_contexts] if args.key?(:document_contexts)
  @extractive_answers = args[:extractive_answers] if args.key?(:extractive_answers)
  @extractive_segments = args[:extractive_segments] if args.key?(:extractive_segments)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end