Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Unstructured document information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfo

Returns a new instance of GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfo.



19283
19284
19285
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19283

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#documentString

Document resource name. Corresponds to the JSON property document

Returns:

  • (String)


19252
19253
19254
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19252

def document
  @document
end

#document_contextsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfoDocumentContext>

List of document contexts. The content will be used for Answer Generation. This is supposed to be the main content of the document that can be long and comprehensive. Corresponds to the JSON property documentContexts



19259
19260
19261
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19259

def document_contexts
  @document_contexts
end

#extractive_answersArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfoExtractiveAnswer>

Deprecated: This field is deprecated and will have no effect on the Answer generation. Please use document_contexts and extractive_segments fields. List of extractive answers. Corresponds to the JSON property extractiveAnswers



19266
19267
19268
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19266

def extractive_answers
  @extractive_answers
end

#extractive_segmentsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerQueryRequestSearchSpecSearchResultListSearchResultUnstructuredDocumentInfoExtractiveSegment>

List of extractive segments. Corresponds to the JSON property extractiveSegments



19271
19272
19273
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19271

def extractive_segments
  @extractive_segments
end

#titleString

Title. Corresponds to the JSON property title

Returns:

  • (String)


19276
19277
19278
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19276

def title
  @title
end

#uriString

URI for the document. Corresponds to the JSON property uri

Returns:

  • (String)


19281
19282
19283
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19281

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19288
19289
19290
19291
19292
19293
19294
19295
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19288

def update!(**args)
  @document = args[:document] if args.key?(:document)
  @document_contexts = args[:document_contexts] if args.key?(:document_contexts)
  @extractive_answers = args[:extractive_answers] if args.key?(:extractive_answers)
  @extractive_segments = args[:extractive_segments] if args.key?(:extractive_segments)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end