Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerReferenceChunkInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Chunk information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerReferenceChunkInfo

Returns a new instance of GoogleCloudDiscoveryengineV1betaAnswerReferenceChunkInfo.



19719
19720
19721
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19719

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blob_attachment_indexesArray<Fixnum>

Output only. Stores indexes of blobattachments linked to this chunk. Corresponds to the JSON property blobAttachmentIndexes

Returns:

  • (Array<Fixnum>)


19694
19695
19696
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19694

def blob_attachment_indexes
  @blob_attachment_indexes
end

#chunkString

Chunk resource name. Corresponds to the JSON property chunk

Returns:

  • (String)


19699
19700
19701
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19699

def chunk
  @chunk
end

#contentString

Chunk textual content. Corresponds to the JSON property content

Returns:

  • (String)


19704
19705
19706
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19704

def content
  @content
end

#document_metadataGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerReferenceChunkInfoDocumentMetadata

Document metadata. Corresponds to the JSON property documentMetadata



19709
19710
19711
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19709

def 
  @document_metadata
end

#relevance_scoreFloat

The relevance of the chunk for a given query. Values range from 0.0 ( completely irrelevant) to 1.0 (completely relevant). This value is for informational purpose only. It may change for the same query and chunk at any time due to a model retraining or change in implementation. Corresponds to the JSON property relevanceScore

Returns:

  • (Float)


19717
19718
19719
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19717

def relevance_score
  @relevance_score
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19724
19725
19726
19727
19728
19729
19730
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19724

def update!(**args)
  @blob_attachment_indexes = args[:blob_attachment_indexes] if args.key?(:blob_attachment_indexes)
  @chunk = args[:chunk] if args.key?(:chunk)
  @content = args[:content] if args.key?(:content)
  @document_metadata = args[:document_metadata] if args.key?(:document_metadata)
  @relevance_score = args[:relevance_score] if args.key?(:relevance_score)
end