Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerReferenceUnstructuredDocumentInfo
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerReferenceUnstructuredDocumentInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Unstructured document information.
Instance Attribute Summary collapse
-
#chunk_contents ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerReferenceUnstructuredDocumentInfoChunkContent>
List of cited chunk contents derived from document content.
-
#document ⇒ String
Document resource name.
-
#struct_data ⇒ Hash<String,Object>
The structured JSON metadata for the document.
-
#title ⇒ String
Title.
-
#uri ⇒ String
URI for the document.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerReferenceUnstructuredDocumentInfo
constructor
A new instance of GoogleCloudDiscoveryengineV1betaAnswerReferenceUnstructuredDocumentInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerReferenceUnstructuredDocumentInfo
Returns a new instance of GoogleCloudDiscoveryengineV1betaAnswerReferenceUnstructuredDocumentInfo.
20544 20545 20546 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20544 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chunk_contents ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerReferenceUnstructuredDocumentInfoChunkContent>
List of cited chunk contents derived from document content.
Corresponds to the JSON property chunkContents
20521 20522 20523 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20521 def chunk_contents @chunk_contents end |
#document ⇒ String
Document resource name.
Corresponds to the JSON property document
20526 20527 20528 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20526 def document @document end |
#struct_data ⇒ Hash<String,Object>
The structured JSON metadata for the document. It is populated from the struct
data from the Chunk in search result.
Corresponds to the JSON property structData
20532 20533 20534 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20532 def struct_data @struct_data end |
#title ⇒ String
Title.
Corresponds to the JSON property title
20537 20538 20539 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20537 def title @title end |
#uri ⇒ String
URI for the document.
Corresponds to the JSON property uri
20542 20543 20544 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20542 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20549 20550 20551 20552 20553 20554 20555 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20549 def update!(**args) @chunk_contents = args[:chunk_contents] if args.key?(:chunk_contents) @document = args[:document] if args.key?(:document) @struct_data = args[:struct_data] if args.key?(:struct_data) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) end |