Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerReferenceUnstructuredDocumentInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Unstructured document information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerReferenceUnstructuredDocumentInfo

Returns a new instance of GoogleCloudDiscoveryengineV1betaAnswerReferenceUnstructuredDocumentInfo.



20520
20521
20522
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20520

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chunk_contentsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerReferenceUnstructuredDocumentInfoChunkContent>

List of cited chunk contents derived from document content. Corresponds to the JSON property chunkContents



20497
20498
20499
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20497

def chunk_contents
  @chunk_contents
end

#documentString

Document resource name. Corresponds to the JSON property document

Returns:

  • (String)


20502
20503
20504
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20502

def document
  @document
end

#struct_dataHash<String,Object>

The structured JSON metadata for the document. It is populated from the struct data from the Chunk in search result. Corresponds to the JSON property structData

Returns:

  • (Hash<String,Object>)


20508
20509
20510
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20508

def struct_data
  @struct_data
end

#titleString

Title. Corresponds to the JSON property title

Returns:

  • (String)


20513
20514
20515
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20513

def title
  @title
end

#uriString

URI for the document. Corresponds to the JSON property uri

Returns:

  • (String)


20518
20519
20520
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20518

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20525
20526
20527
20528
20529
20530
20531
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20525

def update!(**args)
  @chunk_contents = args[:chunk_contents] if args.key?(:chunk_contents)
  @document = args[:document] if args.key?(:document)
  @struct_data = args[:struct_data] if args.key?(:struct_data)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end