Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerReferenceUnstructuredDocumentInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Unstructured document information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerReferenceUnstructuredDocumentInfo

Returns a new instance of GoogleCloudDiscoveryengineV1betaAnswerReferenceUnstructuredDocumentInfo.



19640
19641
19642
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19640

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chunk_contentsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerReferenceUnstructuredDocumentInfoChunkContent>

List of cited chunk contents derived from document content. Corresponds to the JSON property chunkContents



19617
19618
19619
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19617

def chunk_contents
  @chunk_contents
end

#documentString

Document resource name. Corresponds to the JSON property document

Returns:

  • (String)


19622
19623
19624
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19622

def document
  @document
end

#struct_dataHash<String,Object>

The structured JSON metadata for the document. It is populated from the struct data from the Chunk in search result. Corresponds to the JSON property structData

Returns:

  • (Hash<String,Object>)


19628
19629
19630
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19628

def struct_data
  @struct_data
end

#titleString

Title. Corresponds to the JSON property title

Returns:

  • (String)


19633
19634
19635
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19633

def title
  @title
end

#uriString

URI for the document. Corresponds to the JSON property uri

Returns:

  • (String)


19638
19639
19640
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19638

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19645
19646
19647
19648
19649
19650
19651
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19645

def update!(**args)
  @chunk_contents = args[:chunk_contents] if args.key?(:chunk_contents)
  @document = args[:document] if args.key?(:document)
  @struct_data = args[:struct_data] if args.key?(:struct_data)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end