Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerReferenceUnstructuredDocumentInfoChunkContent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Chunk content.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerReferenceUnstructuredDocumentInfoChunkContent

Returns a new instance of GoogleCloudDiscoveryengineV1betaAnswerReferenceUnstructuredDocumentInfoChunkContent.



20585
20586
20587
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20585

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blob_attachment_indexesArray<Fixnum>

Output only. Stores indexes of blobattachments linked to this chunk. Corresponds to the JSON property blobAttachmentIndexes

Returns:

  • (Array<Fixnum>)


20565
20566
20567
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20565

def blob_attachment_indexes
  @blob_attachment_indexes
end

#contentString

Chunk textual content. Corresponds to the JSON property content

Returns:

  • (String)


20570
20571
20572
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20570

def content
  @content
end

#page_identifierString

Page identifier. Corresponds to the JSON property pageIdentifier

Returns:

  • (String)


20575
20576
20577
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20575

def page_identifier
  @page_identifier
end

#relevance_scoreFloat

The relevance of the chunk for a given query. Values range from 0.0 ( completely irrelevant) to 1.0 (completely relevant). This value is for informational purpose only. It may change for the same query and chunk at any time due to a model retraining or change in implementation. Corresponds to the JSON property relevanceScore

Returns:

  • (Float)


20583
20584
20585
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20583

def relevance_score
  @relevance_score
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20590
20591
20592
20593
20594
20595
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20590

def update!(**args)
  @blob_attachment_indexes = args[:blob_attachment_indexes] if args.key?(:blob_attachment_indexes)
  @content = args[:content] if args.key?(:content)
  @page_identifier = args[:page_identifier] if args.key?(:page_identifier)
  @relevance_score = args[:relevance_score] if args.key?(:relevance_score)
end