Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerReferenceUnstructuredDocumentInfoChunkContent
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerReferenceUnstructuredDocumentInfoChunkContent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Chunk content.
Instance Attribute Summary collapse
-
#blob_attachment_indexes ⇒ Array<Fixnum>
Output only.
-
#content ⇒ String
Chunk textual content.
-
#page_identifier ⇒ String
Page identifier.
-
#relevance_score ⇒ Float
The relevance of the chunk for a given query.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerReferenceUnstructuredDocumentInfoChunkContent
constructor
A new instance of GoogleCloudDiscoveryengineV1betaAnswerReferenceUnstructuredDocumentInfoChunkContent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerReferenceUnstructuredDocumentInfoChunkContent
Returns a new instance of GoogleCloudDiscoveryengineV1betaAnswerReferenceUnstructuredDocumentInfoChunkContent.
19681 19682 19683 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19681 def initialize(**args) update!(**args) end |
Instance Attribute Details
#blob_attachment_indexes ⇒ Array<Fixnum>
Output only. Stores indexes of blobattachments linked to this chunk.
Corresponds to the JSON property blobAttachmentIndexes
19661 19662 19663 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19661 def @blob_attachment_indexes end |
#content ⇒ String
Chunk textual content.
Corresponds to the JSON property content
19666 19667 19668 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19666 def content @content end |
#page_identifier ⇒ String
Page identifier.
Corresponds to the JSON property pageIdentifier
19671 19672 19673 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19671 def page_identifier @page_identifier end |
#relevance_score ⇒ Float
The relevance of the chunk for a given query. Values range from 0.0 (
completely irrelevant) to 1.0 (completely relevant). This value is for
informational purpose only. It may change for the same query and chunk at any
time due to a model retraining or change in implementation.
Corresponds to the JSON property relevanceScore
19679 19680 19681 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19679 def relevance_score @relevance_score end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19686 19687 19688 19689 19690 19691 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19686 def update!(**args) @blob_attachment_indexes = args[:blob_attachment_indexes] if args.key?(:blob_attachment_indexes) @content = args[:content] if args.key?(:content) @page_identifier = args[:page_identifier] if args.key?(:page_identifier) @relevance_score = args[:relevance_score] if args.key?(:relevance_score) end |