Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerStepActionObservation
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerStepActionObservation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Observation.
Instance Attribute Summary collapse
-
#search_results ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerStepActionObservationSearchResult>
Search results observed by the search action, it can be snippets info or chunk info, depending on the citation type set by the user.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerStepActionObservation
constructor
A new instance of GoogleCloudDiscoveryengineV1betaAnswerStepActionObservation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerStepActionObservation
Returns a new instance of GoogleCloudDiscoveryengineV1betaAnswerStepActionObservation.
20768 20769 20770 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20768 def initialize(**args) update!(**args) end |
Instance Attribute Details
#search_results ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerStepActionObservationSearchResult>
Search results observed by the search action, it can be snippets info or chunk
info, depending on the citation type set by the user.
Corresponds to the JSON property searchResults
20766 20767 20768 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20766 def search_results @search_results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20773 20774 20775 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20773 def update!(**args) @search_results = args[:search_results] if args.key?(:search_results) end |