Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerStepActionObservationSearchResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerStepActionObservationSearchResult

Returns a new instance of GoogleCloudDiscoveryengineV1betaAnswerStepActionObservationSearchResult.



20814
20815
20816
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20814

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chunk_infoArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerStepActionObservationSearchResultChunkInfo>

If citation_type is CHUNK_LEVEL_CITATION and chunk mode is on, populate chunk info. Corresponds to the JSON property chunkInfo



20786
20787
20788
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20786

def chunk_info
  @chunk_info
end

#documentString

Document resource name. Corresponds to the JSON property document

Returns:

  • (String)


20791
20792
20793
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20791

def document
  @document
end

#snippet_infoArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerStepActionObservationSearchResultSnippetInfo>

If citation_type is DOCUMENT_LEVEL_CITATION, populate document level snippets. Corresponds to the JSON property snippetInfo



20796
20797
20798
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20796

def snippet_info
  @snippet_info
end

#struct_dataHash<String,Object>

Data representation. The structured JSON data for the document. It's populated from the struct data from the Document, or the Chunk in search result. Corresponds to the JSON property structData

Returns:

  • (Hash<String,Object>)


20802
20803
20804
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20802

def struct_data
  @struct_data
end

#titleString

Title. Corresponds to the JSON property title

Returns:

  • (String)


20807
20808
20809
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20807

def title
  @title
end

#uriString

URI for the document. Corresponds to the JSON property uri

Returns:

  • (String)


20812
20813
20814
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20812

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20819
20820
20821
20822
20823
20824
20825
20826
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20819

def update!(**args)
  @chunk_info = args[:chunk_info] if args.key?(:chunk_info)
  @document = args[:document] if args.key?(:document)
  @snippet_info = args[:snippet_info] if args.key?(:snippet_info)
  @struct_data = args[:struct_data] if args.key?(:struct_data)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end