Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerStepActionObservationSearchResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerStepActionObservationSearchResult

Returns a new instance of GoogleCloudDiscoveryengineV1betaAnswerStepActionObservationSearchResult.



20828
20829
20830
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20828

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chunk_infoArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerStepActionObservationSearchResultChunkInfo>

If citation_type is CHUNK_LEVEL_CITATION and chunk mode is on, populate chunk info. Corresponds to the JSON property chunkInfo



20800
20801
20802
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20800

def chunk_info
  @chunk_info
end

#documentString

Document resource name. Corresponds to the JSON property document

Returns:

  • (String)


20805
20806
20807
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20805

def document
  @document
end

#snippet_infoArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerStepActionObservationSearchResultSnippetInfo>

If citation_type is DOCUMENT_LEVEL_CITATION, populate document level snippets. Corresponds to the JSON property snippetInfo



20810
20811
20812
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20810

def snippet_info
  @snippet_info
end

#struct_dataHash<String,Object>

Data representation. The structured JSON data for the document. It's populated from the struct data from the Document, or the Chunk in search result. Corresponds to the JSON property structData

Returns:

  • (Hash<String,Object>)


20816
20817
20818
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20816

def struct_data
  @struct_data
end

#titleString

Title. Corresponds to the JSON property title

Returns:

  • (String)


20821
20822
20823
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20821

def title
  @title
end

#uriString

URI for the document. Corresponds to the JSON property uri

Returns:

  • (String)


20826
20827
20828
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20826

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20833
20834
20835
20836
20837
20838
20839
20840
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20833

def update!(**args)
  @chunk_info = args[:chunk_info] if args.key?(:chunk_info)
  @document = args[:document] if args.key?(:document)
  @snippet_info = args[:snippet_info] if args.key?(:snippet_info)
  @struct_data = args[:struct_data] if args.key?(:struct_data)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end