Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerStepActionObservationSearchResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerStepActionObservationSearchResult

Returns a new instance of GoogleCloudDiscoveryengineV1betaAnswerStepActionObservationSearchResult.



20692
20693
20694
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20692

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chunk_infoArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerStepActionObservationSearchResultChunkInfo>

If citation_type is CHUNK_LEVEL_CITATION and chunk mode is on, populate chunk info. Corresponds to the JSON property chunkInfo



20664
20665
20666
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20664

def chunk_info
  @chunk_info
end

#documentString

Document resource name. Corresponds to the JSON property document

Returns:

  • (String)


20669
20670
20671
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20669

def document
  @document
end

#snippet_infoArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerStepActionObservationSearchResultSnippetInfo>

If citation_type is DOCUMENT_LEVEL_CITATION, populate document level snippets. Corresponds to the JSON property snippetInfo



20674
20675
20676
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20674

def snippet_info
  @snippet_info
end

#struct_dataHash<String,Object>

Data representation. The structured JSON data for the document. It's populated from the struct data from the Document, or the Chunk in search result. Corresponds to the JSON property structData

Returns:

  • (Hash<String,Object>)


20680
20681
20682
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20680

def struct_data
  @struct_data
end

#titleString

Title. Corresponds to the JSON property title

Returns:

  • (String)


20685
20686
20687
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20685

def title
  @title
end

#uriString

URI for the document. Corresponds to the JSON property uri

Returns:

  • (String)


20690
20691
20692
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20690

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20697
20698
20699
20700
20701
20702
20703
20704
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20697

def update!(**args)
  @chunk_info = args[:chunk_info] if args.key?(:chunk_info)
  @document = args[:document] if args.key?(:document)
  @snippet_info = args[:snippet_info] if args.key?(:snippet_info)
  @struct_data = args[:struct_data] if args.key?(:struct_data)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end