Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerStepActionObservationSearchResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerStepActionObservationSearchResult

Returns a new instance of GoogleCloudDiscoveryengineV1betaAnswerStepActionObservationSearchResult.



20016
20017
20018
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20016

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chunk_infoArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerStepActionObservationSearchResultChunkInfo>

If citation_type is CHUNK_LEVEL_CITATION and chunk mode is on, populate chunk info. Corresponds to the JSON property chunkInfo



19988
19989
19990
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19988

def chunk_info
  @chunk_info
end

#documentString

Document resource name. Corresponds to the JSON property document

Returns:

  • (String)


19993
19994
19995
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19993

def document
  @document
end

#snippet_infoArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerStepActionObservationSearchResultSnippetInfo>

If citation_type is DOCUMENT_LEVEL_CITATION, populate document level snippets. Corresponds to the JSON property snippetInfo



19998
19999
20000
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19998

def snippet_info
  @snippet_info
end

#struct_dataHash<String,Object>

Data representation. The structured JSON data for the document. It's populated from the struct data from the Document, or the Chunk in search result. Corresponds to the JSON property structData

Returns:

  • (Hash<String,Object>)


20004
20005
20006
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20004

def struct_data
  @struct_data
end

#titleString

Title. Corresponds to the JSON property title

Returns:

  • (String)


20009
20010
20011
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20009

def title
  @title
end

#uriString

URI for the document. Corresponds to the JSON property uri

Returns:

  • (String)


20014
20015
20016
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20014

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20021
20022
20023
20024
20025
20026
20027
20028
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20021

def update!(**args)
  @chunk_info = args[:chunk_info] if args.key?(:chunk_info)
  @document = args[:document] if args.key?(:document)
  @snippet_info = args[:snippet_info] if args.key?(:snippet_info)
  @struct_data = args[:struct_data] if args.key?(:struct_data)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end