Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerStepActionObservationSearchResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAnswerStepActionObservationSearchResult

Returns a new instance of GoogleCloudDiscoveryengineV1betaAnswerStepActionObservationSearchResult.



19812
19813
19814
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19812

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chunk_infoArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerStepActionObservationSearchResultChunkInfo>

If citation_type is CHUNK_LEVEL_CITATION and chunk mode is on, populate chunk info. Corresponds to the JSON property chunkInfo



19784
19785
19786
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19784

def chunk_info
  @chunk_info
end

#documentString

Document resource name. Corresponds to the JSON property document

Returns:

  • (String)


19789
19790
19791
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19789

def document
  @document
end

#snippet_infoArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAnswerStepActionObservationSearchResultSnippetInfo>

If citation_type is DOCUMENT_LEVEL_CITATION, populate document level snippets. Corresponds to the JSON property snippetInfo



19794
19795
19796
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19794

def snippet_info
  @snippet_info
end

#struct_dataHash<String,Object>

Data representation. The structured JSON data for the document. It's populated from the struct data from the Document, or the Chunk in search result. Corresponds to the JSON property structData

Returns:

  • (Hash<String,Object>)


19800
19801
19802
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19800

def struct_data
  @struct_data
end

#titleString

Title. Corresponds to the JSON property title

Returns:

  • (String)


19805
19806
19807
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19805

def title
  @title
end

#uriString

URI for the document. Corresponds to the JSON property uri

Returns:

  • (String)


19810
19811
19812
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19810

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19817
19818
19819
19820
19821
19822
19823
19824
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19817

def update!(**args)
  @chunk_info = args[:chunk_info] if args.key?(:chunk_info)
  @document = args[:document] if args.key?(:document)
  @snippet_info = args[:snippet_info] if args.key?(:snippet_info)
  @struct_data = args[:struct_data] if args.key?(:struct_data)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end