Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistAnswer

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

AssistAnswer resource, main part of AssistResponse.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistAnswer

Returns a new instance of GoogleCloudDiscoveryengineV1betaAssistAnswer.



20842
20843
20844
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20842

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assist_skipped_reasonsArray<String>

Reasons for not answering the assist call. Corresponds to the JSON property assistSkippedReasons

Returns:

  • (Array<String>)


20816
20817
20818
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20816

def assist_skipped_reasons
  @assist_skipped_reasons
end

#customer_policy_enforcement_resultGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistAnswerCustomerPolicyEnforcementResult

Customer policy enforcement results. Contains the results of the various policy checks, like the banned phrases or the Model Armor checks. Corresponds to the JSON property customerPolicyEnforcementResult



20822
20823
20824
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20822

def customer_policy_enforcement_result
  @customer_policy_enforcement_result
end

#nameString

Immutable. Identifier. Resource name of the AssistAnswer. Format: projects/ project/locations/location/collections/collection/engines/engine/ sessions/session/assistAnswers/assist_answer`This field must be a UTF-8 encoded string with a length limit of 1024 characters. Corresponds to the JSON propertyname`

Returns:

  • (String)


20830
20831
20832
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20830

def name
  @name
end

#repliesArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistAnswerReply>

Replies of the assistant. Corresponds to the JSON property replies



20835
20836
20837
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20835

def replies
  @replies
end

#stateString

State of the answer generation. Corresponds to the JSON property state

Returns:

  • (String)


20840
20841
20842
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20840

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20847
20848
20849
20850
20851
20852
20853
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20847

def update!(**args)
  @assist_skipped_reasons = args[:assist_skipped_reasons] if args.key?(:assist_skipped_reasons)
  @customer_policy_enforcement_result = args[:customer_policy_enforcement_result] if args.key?(:customer_policy_enforcement_result)
  @name = args[:name] if args.key?(:name)
  @replies = args[:replies] if args.key?(:replies)
  @state = args[:state] if args.key?(:state)
end