Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistAnswer

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

AssistAnswer resource, main part of AssistResponse.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistAnswer

Returns a new instance of GoogleCloudDiscoveryengineV1betaAssistAnswer.



19938
19939
19940
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19938

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assist_skipped_reasonsArray<String>

Reasons for not answering the assist call. Corresponds to the JSON property assistSkippedReasons

Returns:

  • (Array<String>)


19912
19913
19914
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19912

def assist_skipped_reasons
  @assist_skipped_reasons
end

#customer_policy_enforcement_resultGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistAnswerCustomerPolicyEnforcementResult

Customer policy enforcement results. Contains the results of the various policy checks, like the banned phrases or the Model Armor checks. Corresponds to the JSON property customerPolicyEnforcementResult



19918
19919
19920
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19918

def customer_policy_enforcement_result
  @customer_policy_enforcement_result
end

#nameString

Immutable. Identifier. Resource name of the AssistAnswer. Format: projects/ project/locations/location/collections/collection/engines/engine/ sessions/session/assistAnswers/assist_answer`This field must be a UTF-8 encoded string with a length limit of 1024 characters. Corresponds to the JSON propertyname`

Returns:

  • (String)


19926
19927
19928
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19926

def name
  @name
end

#repliesArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistAnswerReply>

Replies of the assistant. Corresponds to the JSON property replies



19931
19932
19933
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19931

def replies
  @replies
end

#stateString

State of the answer generation. Corresponds to the JSON property state

Returns:

  • (String)


19936
19937
19938
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19936

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19943
19944
19945
19946
19947
19948
19949
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19943

def update!(**args)
  @assist_skipped_reasons = args[:assist_skipped_reasons] if args.key?(:assist_skipped_reasons)
  @customer_policy_enforcement_result = args[:customer_policy_enforcement_result] if args.key?(:customer_policy_enforcement_result)
  @name = args[:name] if args.key?(:name)
  @replies = args[:replies] if args.key?(:replies)
  @state = args[:state] if args.key?(:state)
end