Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistAnswerCustomerPolicyEnforcementResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Customer policy enforcement results. Contains the results of the various policy checks, like the banned phrases or the Model Armor checks.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistAnswerCustomerPolicyEnforcementResult

Returns a new instance of GoogleCloudDiscoveryengineV1betaAssistAnswerCustomerPolicyEnforcementResult.



20874
20875
20876
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20874

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#policy_resultsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistAnswerCustomerPolicyEnforcementResultPolicyEnforcementResult>

Customer policy enforcement results. Populated only if the assist call was skipped due to a policy violation. It contains results from those filters that blocked the processing of the query. Corresponds to the JSON property policyResults



20866
20867
20868
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20866

def policy_results
  @policy_results
end

#verdictString

Final verdict of the customer policy enforcement. If only one policy blocked the processing, the verdict is BLOCK. Corresponds to the JSON property verdict

Returns:

  • (String)


20872
20873
20874
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20872

def verdict
  @verdict
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20879
20880
20881
20882
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20879

def update!(**args)
  @policy_results = args[:policy_results] if args.key?(:policy_results)
  @verdict = args[:verdict] if args.key?(:verdict)
end