Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistAnswerCustomerPolicyEnforcementResult
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistAnswerCustomerPolicyEnforcementResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Customer policy enforcement results. Contains the results of the various policy checks, like the banned phrases or the Model Armor checks.
Instance Attribute Summary collapse
-
#policy_results ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistAnswerCustomerPolicyEnforcementResultPolicyEnforcementResult>
Customer policy enforcement results.
-
#verdict ⇒ String
Final verdict of the customer policy enforcement.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistAnswerCustomerPolicyEnforcementResult
constructor
A new instance of GoogleCloudDiscoveryengineV1betaAssistAnswerCustomerPolicyEnforcementResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistAnswerCustomerPolicyEnforcementResult
Returns a new instance of GoogleCloudDiscoveryengineV1betaAssistAnswerCustomerPolicyEnforcementResult.
20850 20851 20852 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20850 def initialize(**args) update!(**args) end |
Instance Attribute Details
#policy_results ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistAnswerCustomerPolicyEnforcementResultPolicyEnforcementResult>
Customer policy enforcement results. Populated only if the assist call was
skipped due to a policy violation. It contains results from those filters that
blocked the processing of the query.
Corresponds to the JSON property policyResults
20842 20843 20844 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20842 def policy_results @policy_results end |
#verdict ⇒ String
Final verdict of the customer policy enforcement. If only one policy blocked
the processing, the verdict is BLOCK.
Corresponds to the JSON property verdict
20848 20849 20850 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20848 def verdict @verdict end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20855 20856 20857 20858 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20855 def update!(**args) @policy_results = args[:policy_results] if args.key?(:policy_results) @verdict = args[:verdict] if args.key?(:verdict) end |