Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistAnswerCustomerPolicyEnforcementResultBannedPhraseEnforcementResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Customer policy enforcement result for the banned phrase policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistAnswerCustomerPolicyEnforcementResultBannedPhraseEnforcementResult

Returns a new instance of GoogleCloudDiscoveryengineV1betaAssistAnswerCustomerPolicyEnforcementResultBannedPhraseEnforcementResult.



20894
20895
20896
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20894

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#banned_phrasesArray<String>

The banned phrases that were found in the query or the answer. Corresponds to the JSON property bannedPhrases

Returns:

  • (Array<String>)


20892
20893
20894
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20892

def banned_phrases
  @banned_phrases
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20899
20900
20901
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20899

def update!(**args)
  @banned_phrases = args[:banned_phrases] if args.key?(:banned_phrases)
end