Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistAnswerCustomerPolicyEnforcementResultBannedPhraseEnforcementResult
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistAnswerCustomerPolicyEnforcementResultBannedPhraseEnforcementResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Customer policy enforcement result for the banned phrase policy.
Instance Attribute Summary collapse
-
#banned_phrases ⇒ Array<String>
The banned phrases that were found in the query or the answer.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistAnswerCustomerPolicyEnforcementResultBannedPhraseEnforcementResult
constructor
A new instance of GoogleCloudDiscoveryengineV1betaAssistAnswerCustomerPolicyEnforcementResultBannedPhraseEnforcementResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistAnswerCustomerPolicyEnforcementResultBannedPhraseEnforcementResult
Returns a new instance of GoogleCloudDiscoveryengineV1betaAssistAnswerCustomerPolicyEnforcementResultBannedPhraseEnforcementResult.
20194 20195 20196 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20194 def initialize(**args) update!(**args) end |
Instance Attribute Details
#banned_phrases ⇒ Array<String>
The banned phrases that were found in the query or the answer.
Corresponds to the JSON property bannedPhrases
20192 20193 20194 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20192 def banned_phrases @banned_phrases end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20199 20200 20201 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20199 def update!(**args) @banned_phrases = args[:banned_phrases] if args.key?(:banned_phrases) end |