Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistAnswerCustomerPolicyEnforcementResultBannedPhraseEnforcementResult
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistAnswerCustomerPolicyEnforcementResultBannedPhraseEnforcementResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Customer policy enforcement result for the banned phrase policy.
Instance Attribute Summary collapse
-
#banned_phrases ⇒ Array<String>
The banned phrases that were found in the query or the answer.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistAnswerCustomerPolicyEnforcementResultBannedPhraseEnforcementResult
constructor
A new instance of GoogleCloudDiscoveryengineV1betaAssistAnswerCustomerPolicyEnforcementResultBannedPhraseEnforcementResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistAnswerCustomerPolicyEnforcementResultBannedPhraseEnforcementResult
Returns a new instance of GoogleCloudDiscoveryengineV1betaAssistAnswerCustomerPolicyEnforcementResultBannedPhraseEnforcementResult.
19990 19991 19992 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19990 def initialize(**args) update!(**args) end |
Instance Attribute Details
#banned_phrases ⇒ Array<String>
The banned phrases that were found in the query or the answer.
Corresponds to the JSON property bannedPhrases
19988 19989 19990 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19988 def banned_phrases @banned_phrases end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19995 19996 19997 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 19995 def update!(**args) @banned_phrases = args[:banned_phrases] if args.key?(:banned_phrases) end |