Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistAnswerCustomerPolicyEnforcementResultModelArmorEnforcementResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Customer policy enforcement result for the Model Armor policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistAnswerCustomerPolicyEnforcementResultModelArmorEnforcementResult

Returns a new instance of GoogleCloudDiscoveryengineV1betaAssistAnswerCustomerPolicyEnforcementResultModelArmorEnforcementResult.



20868
20869
20870
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20868

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::DiscoveryengineV1beta::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



20861
20862
20863
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20861

def error
  @error
end

#model_armor_violationString

The Model Armor violation that was found. Corresponds to the JSON property modelArmorViolation

Returns:

  • (String)


20866
20867
20868
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20866

def model_armor_violation
  @model_armor_violation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20873
20874
20875
20876
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20873

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @model_armor_violation = args[:model_armor_violation] if args.key?(:model_armor_violation)
end