Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistUserMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

User metadata of the request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistUserMetadata

Returns a new instance of GoogleCloudDiscoveryengineV1betaAssistUserMetadata.



21114
21115
21116
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21114

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#preferred_language_codeString

Optional. Preferred language to be used for answering if language detection fails. Also used as the language of error messages created by actions, regardless of language detection results. Corresponds to the JSON property preferredLanguageCode

Returns:

  • (String)


21107
21108
21109
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21107

def preferred_language_code
  @preferred_language_code
end

#time_zoneString

Optional. IANA time zone, e.g. Europe/Budapest. Corresponds to the JSON property timeZone

Returns:

  • (String)


21112
21113
21114
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21112

def time_zone
  @time_zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21119
21120
21121
21122
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21119

def update!(**args)
  @preferred_language_code = args[:preferred_language_code] if args.key?(:preferred_language_code)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
end