Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistUserMetadata
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistUserMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
User metadata of the request.
Instance Attribute Summary collapse
-
#preferred_language_code ⇒ String
Optional.
-
#time_zone ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistUserMetadata
constructor
A new instance of GoogleCloudDiscoveryengineV1betaAssistUserMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistUserMetadata
Returns a new instance of GoogleCloudDiscoveryengineV1betaAssistUserMetadata.
20302 20303 20304 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20302 def initialize(**args) update!(**args) end |
Instance Attribute Details
#preferred_language_code ⇒ String
Optional. Preferred language to be used for answering if language detection
fails. Also used as the language of error messages created by actions,
regardless of language detection results.
Corresponds to the JSON property preferredLanguageCode
20295 20296 20297 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20295 def preferred_language_code @preferred_language_code end |
#time_zone ⇒ String
Optional. IANA time zone, e.g. Europe/Budapest.
Corresponds to the JSON property timeZone
20300 20301 20302 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20300 def time_zone @time_zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20307 20308 20309 20310 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20307 def update!(**args) @preferred_language_code = args[:preferred_language_code] if args.key?(:preferred_language_code) @time_zone = args[:time_zone] if args.key?(:time_zone) end |