Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistUserMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

User metadata of the request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistUserMetadata

Returns a new instance of GoogleCloudDiscoveryengineV1betaAssistUserMetadata.



20098
20099
20100
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20098

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#preferred_language_codeString

Optional. Preferred language to be used for answering if language detection fails. Also used as the language of error messages created by actions, regardless of language detection results. Corresponds to the JSON property preferredLanguageCode

Returns:

  • (String)


20091
20092
20093
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20091

def preferred_language_code
  @preferred_language_code
end

#time_zoneString

Optional. IANA time zone, e.g. Europe/Budapest. Corresponds to the JSON property timeZone

Returns:

  • (String)


20096
20097
20098
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20096

def time_zone
  @time_zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20103
20104
20105
20106
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20103

def update!(**args)
  @preferred_language_code = args[:preferred_language_code] if args.key?(:preferred_language_code)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
end