Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistant

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Discovery Engine Assistant resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistant

Returns a new instance of GoogleCloudDiscoveryengineV1betaAssistant.



21087
21088
21089
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21087

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Represents the time when this Assistant was created. Corresponds to the JSON property createTime

Returns:

  • (String)


21020
21021
21022
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21020

def create_time
  @create_time
end

#customer_policyGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantCustomerPolicy

Customer-defined policy for the assistant. Corresponds to the JSON property customerPolicy



21025
21026
21027
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21025

def customer_policy
  @customer_policy
end

#default_web_grounding_toggle_offBoolean Also known as: default_web_grounding_toggle_off?

Optional. This field controls the default web grounding toggle for end users if web_grounding_type is set to WEB_GROUNDING_TYPE_GOOGLE_SEARCH or WEB_GROUNDING_TYPE_ENTERPRISE_WEB_SEARCH. By default, this field is set to false. If web_grounding_type is WEB_GROUNDING_TYPE_GOOGLE_SEARCH or WEB_GROUNDING_TYPE_ENTERPRISE_WEB_SEARCH, end users will have web grounding enabled by default on UI. If true, grounding toggle will be disabled by default on UI. End users can still enable web grounding in the UI if web grounding is enabled. Corresponds to the JSON property defaultWebGroundingToggleOff

Returns:

  • (Boolean)


21037
21038
21039
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21037

def default_web_grounding_toggle_off
  @default_web_grounding_toggle_off
end

#descriptionString

Optional. Description for additional information. Expected to be shown on the configuration UI, not to the users of the assistant. Corresponds to the JSON property description

Returns:

  • (String)


21044
21045
21046
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21044

def description
  @description
end

#display_nameString

Required. The assistant display name. It must be a UTF-8 encoded string with a length limit of 128 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


21050
21051
21052
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21050

def display_name
  @display_name
end

#enabled_toolsHash<String,Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantToolList>

Optional. Note: not implemented yet. Use enabled_actions instead. The enabled tools on this assistant. The keys are connector name, for example "projects/ projectId/locations/locationId/collections/collectionId/dataconnector The values consist of admin enabled tools towards the connector instance. Admin can selectively enable multiple tools on any of the connector instances that they created in the project. For example "jira1ConnectorName": [(toolId1, " createTicket"), (toolId2, "transferTicket")], "gmail1ConnectorName": [(toolId3, "sendEmail"),..] Corresponds to the JSON property enabledTools



21062
21063
21064
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21062

def enabled_tools
  @enabled_tools
end

#generation_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantGenerationConfig

Configuration for the generation of the assistant response. Corresponds to the JSON property generationConfig



21067
21068
21069
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21067

def generation_config
  @generation_config
end

#nameString

Immutable. Resource name of the assistant. Format: projects/project/ locations/location/collections/collection/engines/engine/assistants/ assistant`It must be a UTF-8 encoded string with a length limit of 1024 characters. Corresponds to the JSON propertyname`

Returns:

  • (String)


21075
21076
21077
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21075

def name
  @name
end

#update_timeString

Output only. Represents the time when this Assistant was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


21080
21081
21082
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21080

def update_time
  @update_time
end

#web_grounding_typeString

Optional. The type of web grounding to use. Corresponds to the JSON property webGroundingType

Returns:

  • (String)


21085
21086
21087
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21085

def web_grounding_type
  @web_grounding_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21092
21093
21094
21095
21096
21097
21098
21099
21100
21101
21102
21103
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21092

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @customer_policy = args[:customer_policy] if args.key?(:customer_policy)
  @default_web_grounding_toggle_off = args[:default_web_grounding_toggle_off] if args.key?(:default_web_grounding_toggle_off)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @enabled_tools = args[:enabled_tools] if args.key?(:enabled_tools)
  @generation_config = args[:generation_config] if args.key?(:generation_config)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
  @web_grounding_type = args[:web_grounding_type] if args.key?(:web_grounding_type)
end