Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistant
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistant
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Discovery Engine Assistant resource.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#customer_policy ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantCustomerPolicy
Customer-defined policy for the assistant.
-
#default_web_grounding_toggle_off ⇒ Boolean
(also: #default_web_grounding_toggle_off?)
Optional.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Required.
-
#enabled_tools ⇒ Hash<String,Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantToolList>
Optional.
-
#generation_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantGenerationConfig
Configuration for the generation of the assistant response.
-
#name ⇒ String
Immutable.
-
#update_time ⇒ String
Output only.
-
#web_grounding_type ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistant
constructor
A new instance of GoogleCloudDiscoveryengineV1betaAssistant.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistant
Returns a new instance of GoogleCloudDiscoveryengineV1betaAssistant.
20183 20184 20185 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20183 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Represents the time when this Assistant was created.
Corresponds to the JSON property createTime
20116 20117 20118 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20116 def create_time @create_time end |
#customer_policy ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantCustomerPolicy
Customer-defined policy for the assistant.
Corresponds to the JSON property customerPolicy
20121 20122 20123 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20121 def customer_policy @customer_policy end |
#default_web_grounding_toggle_off ⇒ Boolean Also known as: default_web_grounding_toggle_off?
Optional. This field controls the default web grounding toggle for end users
if web_grounding_type is set to WEB_GROUNDING_TYPE_GOOGLE_SEARCH or
WEB_GROUNDING_TYPE_ENTERPRISE_WEB_SEARCH. By default, this field is set to
false. If web_grounding_type is WEB_GROUNDING_TYPE_GOOGLE_SEARCH or
WEB_GROUNDING_TYPE_ENTERPRISE_WEB_SEARCH, end users will have web grounding
enabled by default on UI. If true, grounding toggle will be disabled by
default on UI. End users can still enable web grounding in the UI if web
grounding is enabled.
Corresponds to the JSON property defaultWebGroundingToggleOff
20133 20134 20135 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20133 def default_web_grounding_toggle_off @default_web_grounding_toggle_off end |
#description ⇒ String
Optional. Description for additional information. Expected to be shown on the
configuration UI, not to the users of the assistant.
Corresponds to the JSON property description
20140 20141 20142 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20140 def description @description end |
#display_name ⇒ String
Required. The assistant display name. It must be a UTF-8 encoded string with a
length limit of 128 characters.
Corresponds to the JSON property displayName
20146 20147 20148 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20146 def display_name @display_name end |
#enabled_tools ⇒ Hash<String,Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantToolList>
Optional. Note: not implemented yet. Use enabled_actions instead. The enabled
tools on this assistant. The keys are connector name, for example "projects/
projectId/locations/locationId/collections/collectionId/dataconnector The
values consist of admin enabled tools towards the connector instance. Admin
can selectively enable multiple tools on any of the connector instances that
they created in the project. For example "jira1ConnectorName": [(toolId1, "
createTicket"), (toolId2, "transferTicket")], "gmail1ConnectorName": [(toolId3,
"sendEmail"),..]
Corresponds to the JSON property enabledTools
20158 20159 20160 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20158 def enabled_tools @enabled_tools end |
#generation_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantGenerationConfig
Configuration for the generation of the assistant response.
Corresponds to the JSON property generationConfig
20163 20164 20165 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20163 def generation_config @generation_config end |
#name ⇒ String
Immutable. Resource name of the assistant. Format: projects/project/
locations/location/collections/collection/engines/engine/assistants/
assistant`It must be a UTF-8 encoded string with a length limit of 1024
characters.
Corresponds to the JSON propertyname`
20171 20172 20173 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20171 def name @name end |
#update_time ⇒ String
Output only. Represents the time when this Assistant was most recently updated.
Corresponds to the JSON property updateTime
20176 20177 20178 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20176 def update_time @update_time end |
#web_grounding_type ⇒ String
Optional. The type of web grounding to use.
Corresponds to the JSON property webGroundingType
20181 20182 20183 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20181 def web_grounding_type @web_grounding_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20188 20189 20190 20191 20192 20193 20194 20195 20196 20197 20198 20199 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20188 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @customer_policy = args[:customer_policy] if args.key?(:customer_policy) @default_web_grounding_toggle_off = args[:default_web_grounding_toggle_off] if args.key?(:default_web_grounding_toggle_off) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @enabled_tools = args[:enabled_tools] if args.key?(:enabled_tools) @generation_config = args[:generation_config] if args.key?(:generation_config) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) @web_grounding_type = args[:web_grounding_type] if args.key?(:web_grounding_type) end |