Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantContent
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantContent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Multi-modal content.
Instance Attribute Summary collapse
-
#code_execution_result ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantContentCodeExecutionResult
Result of executing ExecutableCode.
-
#executable_code ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantContentExecutableCode
Code generated by the model that is meant to be executed by the model.
-
#file ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantContentFile
A file, e.g., an audio summary.
-
#inline_data ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantContentBlob
Inline blob.
-
#role ⇒ String
The producer of the content.
-
#text ⇒ String
Inline text.
-
#thought ⇒ Boolean
(also: #thought?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistantContent
constructor
A new instance of GoogleCloudDiscoveryengineV1betaAssistantContent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistantContent
Returns a new instance of GoogleCloudDiscoveryengineV1betaAssistantContent.
21258 21259 21260 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21258 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code_execution_result ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantContentCodeExecutionResult
Result of executing ExecutableCode.
Corresponds to the JSON property codeExecutionResult
21225 21226 21227 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21225 def code_execution_result @code_execution_result end |
#executable_code ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantContentExecutableCode
Code generated by the model that is meant to be executed by the model.
Corresponds to the JSON property executableCode
21230 21231 21232 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21230 def executable_code @executable_code end |
#file ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantContentFile
A file, e.g., an audio summary.
Corresponds to the JSON property file
21235 21236 21237 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21235 def file @file end |
#inline_data ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantContentBlob
Inline blob.
Corresponds to the JSON property inlineData
21240 21241 21242 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21240 def inline_data @inline_data end |
#role ⇒ String
The producer of the content. Can be "model" or "user".
Corresponds to the JSON property role
21245 21246 21247 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21245 def role @role end |
#text ⇒ String
Inline text.
Corresponds to the JSON property text
21250 21251 21252 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21250 def text @text end |
#thought ⇒ Boolean Also known as: thought?
Optional. Indicates if the part is thought from the model.
Corresponds to the JSON property thought
21255 21256 21257 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21255 def thought @thought end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21263 21264 21265 21266 21267 21268 21269 21270 21271 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21263 def update!(**args) @code_execution_result = args[:code_execution_result] if args.key?(:code_execution_result) @executable_code = args[:executable_code] if args.key?(:executable_code) @file = args[:file] if args.key?(:file) @inline_data = args[:inline_data] if args.key?(:inline_data) @role = args[:role] if args.key?(:role) @text = args[:text] if args.key?(:text) @thought = args[:thought] if args.key?(:thought) end |