Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantContent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Multi-modal content.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistantContent

Returns a new instance of GoogleCloudDiscoveryengineV1betaAssistantContent.



21122
21123
21124
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21122

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#code_execution_resultGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantContentCodeExecutionResult

Result of executing ExecutableCode. Corresponds to the JSON property codeExecutionResult



21089
21090
21091
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21089

def code_execution_result
  @code_execution_result
end

#executable_codeGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantContentExecutableCode

Code generated by the model that is meant to be executed by the model. Corresponds to the JSON property executableCode



21094
21095
21096
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21094

def executable_code
  @executable_code
end

#fileGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantContentFile

A file, e.g., an audio summary. Corresponds to the JSON property file



21099
21100
21101
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21099

def file
  @file
end

#inline_dataGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantContentBlob

Inline blob. Corresponds to the JSON property inlineData



21104
21105
21106
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21104

def inline_data
  @inline_data
end

#roleString

The producer of the content. Can be "model" or "user". Corresponds to the JSON property role

Returns:

  • (String)


21109
21110
21111
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21109

def role
  @role
end

#textString

Inline text. Corresponds to the JSON property text

Returns:

  • (String)


21114
21115
21116
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21114

def text
  @text
end

#thoughtBoolean Also known as: thought?

Optional. Indicates if the part is thought from the model. Corresponds to the JSON property thought

Returns:

  • (Boolean)


21119
21120
21121
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21119

def thought
  @thought
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21127
21128
21129
21130
21131
21132
21133
21134
21135
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21127

def update!(**args)
  @code_execution_result = args[:code_execution_result] if args.key?(:code_execution_result)
  @executable_code = args[:executable_code] if args.key?(:executable_code)
  @file = args[:file] if args.key?(:file)
  @inline_data = args[:inline_data] if args.key?(:inline_data)
  @role = args[:role] if args.key?(:role)
  @text = args[:text] if args.key?(:text)
  @thought = args[:thought] if args.key?(:thought)
end