Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantContent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Multi-modal content.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistantContent

Returns a new instance of GoogleCloudDiscoveryengineV1betaAssistantContent.



20446
20447
20448
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20446

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#code_execution_resultGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantContentCodeExecutionResult

Result of executing ExecutableCode. Corresponds to the JSON property codeExecutionResult



20413
20414
20415
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20413

def code_execution_result
  @code_execution_result
end

#executable_codeGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantContentExecutableCode

Code generated by the model that is meant to be executed by the model. Corresponds to the JSON property executableCode



20418
20419
20420
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20418

def executable_code
  @executable_code
end

#fileGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantContentFile

A file, e.g., an audio summary. Corresponds to the JSON property file



20423
20424
20425
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20423

def file
  @file
end

#inline_dataGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantContentBlob

Inline blob. Corresponds to the JSON property inlineData



20428
20429
20430
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20428

def inline_data
  @inline_data
end

#roleString

The producer of the content. Can be "model" or "user". Corresponds to the JSON property role

Returns:

  • (String)


20433
20434
20435
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20433

def role
  @role
end

#textString

Inline text. Corresponds to the JSON property text

Returns:

  • (String)


20438
20439
20440
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20438

def text
  @text
end

#thoughtBoolean Also known as: thought?

Optional. Indicates if the part is thought from the model. Corresponds to the JSON property thought

Returns:

  • (Boolean)


20443
20444
20445
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20443

def thought
  @thought
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20451
20452
20453
20454
20455
20456
20457
20458
20459
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20451

def update!(**args)
  @code_execution_result = args[:code_execution_result] if args.key?(:code_execution_result)
  @executable_code = args[:executable_code] if args.key?(:executable_code)
  @file = args[:file] if args.key?(:file)
  @inline_data = args[:inline_data] if args.key?(:inline_data)
  @role = args[:role] if args.key?(:role)
  @text = args[:text] if args.key?(:text)
  @thought = args[:thought] if args.key?(:thought)
end