Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantContent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Multi-modal content.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistantContent

Returns a new instance of GoogleCloudDiscoveryengineV1betaAssistantContent.



20242
20243
20244
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20242

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#code_execution_resultGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantContentCodeExecutionResult

Result of executing ExecutableCode. Corresponds to the JSON property codeExecutionResult



20209
20210
20211
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20209

def code_execution_result
  @code_execution_result
end

#executable_codeGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantContentExecutableCode

Code generated by the model that is meant to be executed by the model. Corresponds to the JSON property executableCode



20214
20215
20216
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20214

def executable_code
  @executable_code
end

#fileGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantContentFile

A file, e.g., an audio summary. Corresponds to the JSON property file



20219
20220
20221
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20219

def file
  @file
end

#inline_dataGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantContentBlob

Inline blob. Corresponds to the JSON property inlineData



20224
20225
20226
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20224

def inline_data
  @inline_data
end

#roleString

The producer of the content. Can be "model" or "user". Corresponds to the JSON property role

Returns:

  • (String)


20229
20230
20231
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20229

def role
  @role
end

#textString

Inline text. Corresponds to the JSON property text

Returns:

  • (String)


20234
20235
20236
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20234

def text
  @text
end

#thoughtBoolean Also known as: thought?

Optional. Indicates if the part is thought from the model. Corresponds to the JSON property thought

Returns:

  • (Boolean)


20239
20240
20241
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20239

def thought
  @thought
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20247
20248
20249
20250
20251
20252
20253
20254
20255
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20247

def update!(**args)
  @code_execution_result = args[:code_execution_result] if args.key?(:code_execution_result)
  @executable_code = args[:executable_code] if args.key?(:executable_code)
  @file = args[:file] if args.key?(:file)
  @inline_data = args[:inline_data] if args.key?(:inline_data)
  @role = args[:role] if args.key?(:role)
  @text = args[:text] if args.key?(:text)
  @thought = args[:thought] if args.key?(:thought)
end