Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantCustomerPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Customer-defined policy for the assistant.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistantCustomerPolicy

Returns a new instance of GoogleCloudDiscoveryengineV1betaAssistantCustomerPolicy.



21273
21274
21275
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21273

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#banned_phrasesArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantCustomerPolicyBannedPhrase>

Optional. List of banned phrases. Corresponds to the JSON property bannedPhrases



21265
21266
21267
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21265

def banned_phrases
  @banned_phrases
end

#model_armor_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantCustomerPolicyModelArmorConfig

Configuration for customer defined Model Armor templates to be used for sanitizing user prompts and assistant responses. Corresponds to the JSON property modelArmorConfig



21271
21272
21273
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21271

def model_armor_config
  @model_armor_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21278
21279
21280
21281
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21278

def update!(**args)
  @banned_phrases = args[:banned_phrases] if args.key?(:banned_phrases)
  @model_armor_config = args[:model_armor_config] if args.key?(:model_armor_config)
end