Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantCustomerPolicy
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantCustomerPolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Customer-defined policy for the assistant.
Instance Attribute Summary collapse
-
#banned_phrases ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantCustomerPolicyBannedPhrase>
Optional.
-
#model_armor_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantCustomerPolicyModelArmorConfig
Configuration for customer defined Model Armor templates to be used for sanitizing user prompts and assistant responses.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistantCustomerPolicy
constructor
A new instance of GoogleCloudDiscoveryengineV1betaAssistantCustomerPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistantCustomerPolicy
Returns a new instance of GoogleCloudDiscoveryengineV1betaAssistantCustomerPolicy.
20369 20370 20371 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20369 def initialize(**args) update!(**args) end |
Instance Attribute Details
#banned_phrases ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantCustomerPolicyBannedPhrase>
Optional. List of banned phrases.
Corresponds to the JSON property bannedPhrases
20361 20362 20363 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20361 def banned_phrases @banned_phrases end |
#model_armor_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantCustomerPolicyModelArmorConfig
Configuration for customer defined Model Armor templates to be used for
sanitizing user prompts and assistant responses.
Corresponds to the JSON property modelArmorConfig
20367 20368 20369 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20367 def model_armor_config @model_armor_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20374 20375 20376 20377 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20374 def update!(**args) @banned_phrases = args[:banned_phrases] if args.key?(:banned_phrases) @model_armor_config = args[:model_armor_config] if args.key?(:model_armor_config) end |