Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantCustomerPolicyBannedPhrase
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantCustomerPolicyBannedPhrase
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Definition of a customer-defined banned phrase. A banned phrase is not allowed to appear in the user query or the LLM response, or else the answer will be refused.
Instance Attribute Summary collapse
-
#ignore_diacritics ⇒ Boolean
(also: #ignore_diacritics?)
Optional.
-
#match_type ⇒ String
Optional.
-
#phrase ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistantCustomerPolicyBannedPhrase
constructor
A new instance of GoogleCloudDiscoveryengineV1betaAssistantCustomerPolicyBannedPhrase.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistantCustomerPolicyBannedPhrase
Returns a new instance of GoogleCloudDiscoveryengineV1betaAssistantCustomerPolicyBannedPhrase.
20607 20608 20609 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20607 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ignore_diacritics ⇒ Boolean Also known as: ignore_diacritics?
Optional. If true, diacritical marks (e.g., accents, umlauts) are ignored when
matching banned phrases. For example, "cafe" would match "café".
Corresponds to the JSON property ignoreDiacritics
20594 20595 20596 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20594 def ignore_diacritics @ignore_diacritics end |
#match_type ⇒ String
Optional. Match type for the banned phrase.
Corresponds to the JSON property matchType
20600 20601 20602 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20600 def match_type @match_type end |
#phrase ⇒ String
Required. The raw string content to be banned.
Corresponds to the JSON property phrase
20605 20606 20607 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20605 def phrase @phrase end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20612 20613 20614 20615 20616 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20612 def update!(**args) @ignore_diacritics = args[:ignore_diacritics] if args.key?(:ignore_diacritics) @match_type = args[:match_type] if args.key?(:match_type) @phrase = args[:phrase] if args.key?(:phrase) end |