Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantCustomerPolicyModelArmorConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Configuration for customer defined Model Armor templates to be used for sanitizing user prompts and assistant responses.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistantCustomerPolicyModelArmorConfig

Returns a new instance of GoogleCloudDiscoveryengineV1betaAssistantCustomerPolicyModelArmorConfig.



20441
20442
20443
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20441

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#failure_modeString

Optional. Defines the failure mode for Model Armor sanitization. Corresponds to the JSON property failureMode

Returns:

  • (String)


20423
20424
20425
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20423

def failure_mode
  @failure_mode
end

#response_templateString

Optional. The resource name of the Model Armor template for sanitizing assistant responses. Format: projects/project/locations/location/ templates/template_id`If not specified, no sanitization will be applied to the assistant response. Corresponds to the JSON propertyresponseTemplate`

Returns:

  • (String)


20431
20432
20433
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20431

def response_template
  @response_template
end

#user_prompt_templateString

Optional. The resource name of the Model Armor template for sanitizing user prompts. Format: projects/project/locations/location/templates/ template_id`If not specified, no sanitization will be applied to the user prompt. Corresponds to the JSON propertyuserPromptTemplate`

Returns:

  • (String)


20439
20440
20441
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20439

def user_prompt_template
  @user_prompt_template
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20446
20447
20448
20449
20450
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20446

def update!(**args)
  @failure_mode = args[:failure_mode] if args.key?(:failure_mode)
  @response_template = args[:response_template] if args.key?(:response_template)
  @user_prompt_template = args[:user_prompt_template] if args.key?(:user_prompt_template)
end