Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantGenerationConfig
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantGenerationConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Configuration for the generation of the assistant response.
Instance Attribute Summary collapse
-
#allowed_model_ids ⇒ Array<String>
Optional.
-
#default_language ⇒ String
The default language to use for the generation of the assistant response.
-
#default_model_id ⇒ String
Optional.
-
#system_instruction ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantGenerationConfigSystemInstruction
System instruction, also known as the prompt preamble for LLM calls.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistantGenerationConfig
constructor
A new instance of GoogleCloudDiscoveryengineV1betaAssistantGenerationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistantGenerationConfig
Returns a new instance of GoogleCloudDiscoveryengineV1betaAssistantGenerationConfig.
20479 20480 20481 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20479 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowed_model_ids ⇒ Array<String>
Optional. The list of models that are allowed to be used for assistant.
Corresponds to the JSON property allowedModelIds
20460 20461 20462 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20460 def allowed_model_ids @allowed_model_ids end |
#default_language ⇒ String
The default language to use for the generation of the assistant response. Use
an ISO 639-1 language code such as en. If not specified, the language will
be automatically detected.
Corresponds to the JSON property defaultLanguage
20467 20468 20469 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20467 def default_language @default_language end |
#default_model_id ⇒ String
Optional. The default model to use for assistant.
Corresponds to the JSON property defaultModelId
20472 20473 20474 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20472 def default_model_id @default_model_id end |
#system_instruction ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantGenerationConfigSystemInstruction
System instruction, also known as the prompt preamble for LLM calls.
Corresponds to the JSON property systemInstruction
20477 20478 20479 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20477 def system_instruction @system_instruction end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20484 20485 20486 20487 20488 20489 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20484 def update!(**args) @allowed_model_ids = args[:allowed_model_ids] if args.key?(:allowed_model_ids) @default_language = args[:default_language] if args.key?(:default_language) @default_model_id = args[:default_model_id] if args.key?(:default_model_id) @system_instruction = args[:system_instruction] if args.key?(:system_instruction) end |