Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantGenerationConfigSystemInstruction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

System instruction, also known as the prompt preamble for LLM calls.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistantGenerationConfigSystemInstruction

Returns a new instance of GoogleCloudDiscoveryengineV1betaAssistantGenerationConfigSystemInstruction.



20706
20707
20708
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20706

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_system_instructionString

Optional. Additional system instruction that will be added to the default system instruction. Corresponds to the JSON property additionalSystemInstruction

Returns:

  • (String)


20704
20705
20706
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20704

def additional_system_instruction
  @additional_system_instruction
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20711
20712
20713
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20711

def update!(**args)
  @additional_system_instruction = args[:additional_system_instruction] if args.key?(:additional_system_instruction)
end