Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantGenerationConfigSystemInstruction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

System instruction, also known as the prompt preamble for LLM calls.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistantGenerationConfigSystemInstruction

Returns a new instance of GoogleCloudDiscoveryengineV1betaAssistantGenerationConfigSystemInstruction.



20502
20503
20504
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20502

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_system_instructionString

Optional. Additional system instruction that will be added to the default system instruction. Corresponds to the JSON property additionalSystemInstruction

Returns:

  • (String)


20500
20501
20502
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20500

def additional_system_instruction
  @additional_system_instruction
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20507
20508
20509
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20507

def update!(**args)
  @additional_system_instruction = args[:additional_system_instruction] if args.key?(:additional_system_instruction)
end