Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantGroundedContent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

A piece of content and possibly its grounding information. Not all content needs grounding. Phrases like "Of course, I will gladly search it for you." do not need grounding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistantGroundedContent

Returns a new instance of GoogleCloudDiscoveryengineV1betaAssistantGroundedContent.



21549
21550
21551
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21549

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#citation_metadataGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCitationMetadata

A collection of source attributions for a piece of content. Corresponds to the JSON property citationMetadata



21537
21538
21539
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21537

def 
  @citation_metadata
end

#contentGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantContent

Multi-modal content. Corresponds to the JSON property content



21542
21543
21544
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21542

def content
  @content
end

#text_grounding_metadataGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantGroundedContentTextGroundingMetadata

Grounding details for text sources. Corresponds to the JSON property textGroundingMetadata



21547
21548
21549
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21547

def 
  @text_grounding_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21554
21555
21556
21557
21558
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21554

def update!(**args)
  @citation_metadata = args[:citation_metadata] if args.key?(:citation_metadata)
  @content = args[:content] if args.key?(:content)
  @text_grounding_metadata = args[:text_grounding_metadata] if args.key?(:text_grounding_metadata)
end