Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantGroundedContent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

A piece of content and possibly its grounding information. Not all content needs grounding. Phrases like "Of course, I will gladly search it for you." do not need grounding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistantGroundedContent

Returns a new instance of GoogleCloudDiscoveryengineV1betaAssistantGroundedContent.



21382
21383
21384
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21382

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#citation_metadataGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCitationMetadata

A collection of source attributions for a piece of content. Corresponds to the JSON property citationMetadata



21370
21371
21372
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21370

def 
  @citation_metadata
end

#contentGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantContent

Multi-modal content. Corresponds to the JSON property content



21375
21376
21377
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21375

def content
  @content
end

#text_grounding_metadataGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantGroundedContentTextGroundingMetadata

Grounding details for text sources. Corresponds to the JSON property textGroundingMetadata



21380
21381
21382
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21380

def 
  @text_grounding_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21387
21388
21389
21390
21391
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21387

def update!(**args)
  @citation_metadata = args[:citation_metadata] if args.key?(:citation_metadata)
  @content = args[:content] if args.key?(:content)
  @text_grounding_metadata = args[:text_grounding_metadata] if args.key?(:text_grounding_metadata)
end