Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantGroundedContent
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantGroundedContent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
A piece of content and possibly its grounding information. Not all content needs grounding. Phrases like "Of course, I will gladly search it for you." do not need grounding.
Instance Attribute Summary collapse
-
#citation_metadata ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCitationMetadata
A collection of source attributions for a piece of content.
-
#content ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantContent
Multi-modal content.
-
#text_grounding_metadata ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantGroundedContentTextGroundingMetadata
Grounding details for text sources.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistantGroundedContent
constructor
A new instance of GoogleCloudDiscoveryengineV1betaAssistantGroundedContent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistantGroundedContent
Returns a new instance of GoogleCloudDiscoveryengineV1betaAssistantGroundedContent.
20533 20534 20535 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20533 def initialize(**args) update!(**args) end |
Instance Attribute Details
#citation_metadata ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCitationMetadata
A collection of source attributions for a piece of content.
Corresponds to the JSON property citationMetadata
20521 20522 20523 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20521 def @citation_metadata end |
#content ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantContent
Multi-modal content.
Corresponds to the JSON property content
20526 20527 20528 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20526 def content @content end |
#text_grounding_metadata ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantGroundedContentTextGroundingMetadata
Grounding details for text sources.
Corresponds to the JSON property textGroundingMetadata
20531 20532 20533 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20531 def @text_grounding_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20538 20539 20540 20541 20542 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20538 def update!(**args) @citation_metadata = args[:citation_metadata] if args.key?(:citation_metadata) @content = args[:content] if args.key?(:content) @text_grounding_metadata = args[:text_grounding_metadata] if args.key?(:text_grounding_metadata) end |