Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Document metadata.
Instance Attribute Summary collapse
-
#document ⇒ String
Document resource name.
-
#domain ⇒ String
Domain name from the document URI.
-
#language ⇒ String
Corresponds to the JSON property
language. -
#mime_type ⇒ String
The mime type of the document.
-
#page_identifier ⇒ String
Page identifier.
-
#title ⇒ String
Title.
-
#uri ⇒ String
URI for the document.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata
constructor
A new instance of GoogleCloudDiscoveryengineV1betaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata
Returns a new instance of GoogleCloudDiscoveryengineV1betaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata.
21530 21531 21532 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21530 def initialize(**args) update!(**args) end |
Instance Attribute Details
#document ⇒ String
Document resource name.
Corresponds to the JSON property document
21494 21495 21496 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21494 def document @document end |
#domain ⇒ String
Domain name from the document URI. Note that the uri field may contain a URL
that redirects to the actual website, in which case this will contain the
domain name of the target site.
Corresponds to the JSON property domain
21501 21502 21503 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21501 def domain @domain end |
#language ⇒ String
Corresponds to the JSON property language
21506 21507 21508 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21506 def language @language end |
#mime_type ⇒ String
The mime type of the document. https://www.iana.org/assignments/media-types/
media-types.xhtml.
Corresponds to the JSON property mimeType
21512 21513 21514 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21512 def mime_type @mime_type end |
#page_identifier ⇒ String
Page identifier.
Corresponds to the JSON property pageIdentifier
21517 21518 21519 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21517 def page_identifier @page_identifier end |
#title ⇒ String
Title.
Corresponds to the JSON property title
21522 21523 21524 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21522 def title @title end |
#uri ⇒ String
URI for the document. It may contain a URL that redirects to the actual
website.
Corresponds to the JSON property uri
21528 21529 21530 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21528 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21535 21536 21537 21538 21539 21540 21541 21542 21543 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21535 def update!(**args) @document = args[:document] if args.key?(:document) @domain = args[:domain] if args.key?(:domain) @language = args[:language] if args.key?(:language) @mime_type = args[:mime_type] if args.key?(:mime_type) @page_identifier = args[:page_identifier] if args.key?(:page_identifier) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) end |