Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Document metadata.
Instance Attribute Summary collapse
-
#document ⇒ String
Document resource name.
-
#domain ⇒ String
Domain name from the document URI.
-
#language ⇒ String
Corresponds to the JSON property
language. -
#mime_type ⇒ String
The mime type of the document.
-
#page_identifier ⇒ String
Page identifier.
-
#title ⇒ String
Title.
-
#uri ⇒ String
URI for the document.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata
constructor
A new instance of GoogleCloudDiscoveryengineV1betaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata
Returns a new instance of GoogleCloudDiscoveryengineV1betaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata.
21499 21500 21501 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21499 def initialize(**args) update!(**args) end |
Instance Attribute Details
#document ⇒ String
Document resource name.
Corresponds to the JSON property document
21463 21464 21465 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21463 def document @document end |
#domain ⇒ String
Domain name from the document URI. Note that the uri field may contain a URL
that redirects to the actual website, in which case this will contain the
domain name of the target site.
Corresponds to the JSON property domain
21470 21471 21472 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21470 def domain @domain end |
#language ⇒ String
Corresponds to the JSON property language
21475 21476 21477 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21475 def language @language end |
#mime_type ⇒ String
The mime type of the document. https://www.iana.org/assignments/media-types/
media-types.xhtml.
Corresponds to the JSON property mimeType
21481 21482 21483 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21481 def mime_type @mime_type end |
#page_identifier ⇒ String
Page identifier.
Corresponds to the JSON property pageIdentifier
21486 21487 21488 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21486 def page_identifier @page_identifier end |
#title ⇒ String
Title.
Corresponds to the JSON property title
21491 21492 21493 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21491 def title @title end |
#uri ⇒ String
URI for the document. It may contain a URL that redirects to the actual
website.
Corresponds to the JSON property uri
21497 21498 21499 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21497 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21504 21505 21506 21507 21508 21509 21510 21511 21512 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21504 def update!(**args) @document = args[:document] if args.key?(:document) @domain = args[:domain] if args.key?(:domain) @language = args[:language] if args.key?(:language) @mime_type = args[:mime_type] if args.key?(:mime_type) @page_identifier = args[:page_identifier] if args.key?(:page_identifier) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) end |