Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Document metadata.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata

Returns a new instance of GoogleCloudDiscoveryengineV1betaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata.



20854
20855
20856
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20854

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#documentString

Document resource name. Corresponds to the JSON property document

Returns:

  • (String)


20818
20819
20820
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20818

def document
  @document
end

#domainString

Domain name from the document URI. Note that the uri field may contain a URL that redirects to the actual website, in which case this will contain the domain name of the target site. Corresponds to the JSON property domain

Returns:

  • (String)


20825
20826
20827
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20825

def domain
  @domain
end

#languageString

Corresponds to the JSON property language

Returns:

  • (String)


20830
20831
20832
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20830

def language
  @language
end

#mime_typeString

The mime type of the document. https://www.iana.org/assignments/media-types/ media-types.xhtml. Corresponds to the JSON property mimeType

Returns:

  • (String)


20836
20837
20838
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20836

def mime_type
  @mime_type
end

#page_identifierString

Page identifier. Corresponds to the JSON property pageIdentifier

Returns:

  • (String)


20841
20842
20843
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20841

def page_identifier
  @page_identifier
end

#titleString

Title. Corresponds to the JSON property title

Returns:

  • (String)


20846
20847
20848
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20846

def title
  @title
end

#uriString

URI for the document. It may contain a URL that redirects to the actual website. Corresponds to the JSON property uri

Returns:

  • (String)


20852
20853
20854
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20852

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20859
20860
20861
20862
20863
20864
20865
20866
20867
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20859

def update!(**args)
  @document = args[:document] if args.key?(:document)
  @domain = args[:domain] if args.key?(:domain)
  @language = args[:language] if args.key?(:language)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
  @page_identifier = args[:page_identifier] if args.key?(:page_identifier)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end