Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Document metadata.
Instance Attribute Summary collapse
-
#document ⇒ String
Document resource name.
-
#domain ⇒ String
Domain name from the document URI.
-
#language ⇒ String
Corresponds to the JSON property
language. -
#mime_type ⇒ String
The mime type of the document.
-
#page_identifier ⇒ String
Page identifier.
-
#title ⇒ String
Title.
-
#uri ⇒ String
URI for the document.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata
constructor
A new instance of GoogleCloudDiscoveryengineV1betaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata
Returns a new instance of GoogleCloudDiscoveryengineV1betaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata.
20854 20855 20856 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20854 def initialize(**args) update!(**args) end |
Instance Attribute Details
#document ⇒ String
Document resource name.
Corresponds to the JSON property document
20818 20819 20820 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20818 def document @document end |
#domain ⇒ String
Domain name from the document URI. Note that the uri field may contain a URL
that redirects to the actual website, in which case this will contain the
domain name of the target site.
Corresponds to the JSON property domain
20825 20826 20827 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20825 def domain @domain end |
#language ⇒ String
Corresponds to the JSON property language
20830 20831 20832 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20830 def language @language end |
#mime_type ⇒ String
The mime type of the document. https://www.iana.org/assignments/media-types/
media-types.xhtml.
Corresponds to the JSON property mimeType
20836 20837 20838 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20836 def mime_type @mime_type end |
#page_identifier ⇒ String
Page identifier.
Corresponds to the JSON property pageIdentifier
20841 20842 20843 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20841 def page_identifier @page_identifier end |
#title ⇒ String
Title.
Corresponds to the JSON property title
20846 20847 20848 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20846 def title @title end |
#uri ⇒ String
URI for the document. It may contain a URL that redirects to the actual
website.
Corresponds to the JSON property uri
20852 20853 20854 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20852 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20859 20860 20861 20862 20863 20864 20865 20866 20867 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20859 def update!(**args) @document = args[:document] if args.key?(:document) @domain = args[:domain] if args.key?(:domain) @language = args[:language] if args.key?(:language) @mime_type = args[:mime_type] if args.key?(:mime_type) @page_identifier = args[:page_identifier] if args.key?(:page_identifier) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) end |