Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Document metadata.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata

Returns a new instance of GoogleCloudDiscoveryengineV1betaAssistantGroundedContentTextGroundingMetadataReferenceDocumentMetadata.



20650
20651
20652
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20650

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#documentString

Document resource name. Corresponds to the JSON property document

Returns:

  • (String)


20614
20615
20616
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20614

def document
  @document
end

#domainString

Domain name from the document URI. Note that the uri field may contain a URL that redirects to the actual website, in which case this will contain the domain name of the target site. Corresponds to the JSON property domain

Returns:

  • (String)


20621
20622
20623
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20621

def domain
  @domain
end

#languageString

Corresponds to the JSON property language

Returns:

  • (String)


20626
20627
20628
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20626

def language
  @language
end

#mime_typeString

The mime type of the document. https://www.iana.org/assignments/media-types/ media-types.xhtml. Corresponds to the JSON property mimeType

Returns:

  • (String)


20632
20633
20634
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20632

def mime_type
  @mime_type
end

#page_identifierString

Page identifier. Corresponds to the JSON property pageIdentifier

Returns:

  • (String)


20637
20638
20639
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20637

def page_identifier
  @page_identifier
end

#titleString

Title. Corresponds to the JSON property title

Returns:

  • (String)


20642
20643
20644
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20642

def title
  @title
end

#uriString

URI for the document. It may contain a URL that redirects to the actual website. Corresponds to the JSON property uri

Returns:

  • (String)


20648
20649
20650
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20648

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20655
20656
20657
20658
20659
20660
20661
20662
20663
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20655

def update!(**args)
  @document = args[:document] if args.key?(:document)
  @domain = args[:domain] if args.key?(:domain)
  @language = args[:language] if args.key?(:language)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
  @page_identifier = args[:page_identifier] if args.key?(:page_identifier)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end