Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantGroundedContentTextGroundingMetadataSegment
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantGroundedContentTextGroundingMetadataSegment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Grounding information for a segment of the text.
Instance Attribute Summary collapse
-
#end_index ⇒ Fixnum
End of the segment, exclusive.
-
#grounding_score ⇒ Float
Score for the segment.
-
#reference_indices ⇒ Array<Fixnum>
References for the segment.
-
#start_index ⇒ Fixnum
Zero-based index indicating the start of the segment, measured in bytes of a UTF-8 string (i.e. characters encoded on multiple bytes have a length of more than one).
-
#text ⇒ String
The text segment itself.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistantGroundedContentTextGroundingMetadataSegment
constructor
A new instance of GoogleCloudDiscoveryengineV1betaAssistantGroundedContentTextGroundingMetadataSegment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistantGroundedContentTextGroundingMetadataSegment
Returns a new instance of GoogleCloudDiscoveryengineV1betaAssistantGroundedContentTextGroundingMetadataSegment.
21577 21578 21579 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21577 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_index ⇒ Fixnum
End of the segment, exclusive.
Corresponds to the JSON property endIndex
21553 21554 21555 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21553 def end_index @end_index end |
#grounding_score ⇒ Float
Score for the segment.
Corresponds to the JSON property groundingScore
21558 21559 21560 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21558 def grounding_score @grounding_score end |
#reference_indices ⇒ Array<Fixnum>
References for the segment.
Corresponds to the JSON property referenceIndices
21563 21564 21565 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21563 def reference_indices @reference_indices end |
#start_index ⇒ Fixnum
Zero-based index indicating the start of the segment, measured in bytes of a
UTF-8 string (i.e. characters encoded on multiple bytes have a length of more
than one).
Corresponds to the JSON property startIndex
21570 21571 21572 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21570 def start_index @start_index end |
#text ⇒ String
The text segment itself.
Corresponds to the JSON property text
21575 21576 21577 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21575 def text @text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21582 21583 21584 21585 21586 21587 21588 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21582 def update!(**args) @end_index = args[:end_index] if args.key?(:end_index) @grounding_score = args[:grounding_score] if args.key?(:grounding_score) @reference_indices = args[:reference_indices] if args.key?(:reference_indices) @start_index = args[:start_index] if args.key?(:start_index) @text = args[:text] if args.key?(:text) end |