Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantGroundedContentTextGroundingMetadataSegment
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantGroundedContentTextGroundingMetadataSegment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Grounding information for a segment of the text.
Instance Attribute Summary collapse
-
#end_index ⇒ Fixnum
End of the segment, exclusive.
-
#grounding_score ⇒ Float
Score for the segment.
-
#reference_indices ⇒ Array<Fixnum>
References for the segment.
-
#start_index ⇒ Fixnum
Zero-based index indicating the start of the segment, measured in bytes of a UTF-8 string (i.e. characters encoded on multiple bytes have a length of more than one).
-
#text ⇒ String
The text segment itself.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistantGroundedContentTextGroundingMetadataSegment
constructor
A new instance of GoogleCloudDiscoveryengineV1betaAssistantGroundedContentTextGroundingMetadataSegment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistantGroundedContentTextGroundingMetadataSegment
Returns a new instance of GoogleCloudDiscoveryengineV1betaAssistantGroundedContentTextGroundingMetadataSegment.
21546 21547 21548 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21546 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_index ⇒ Fixnum
End of the segment, exclusive.
Corresponds to the JSON property endIndex
21522 21523 21524 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21522 def end_index @end_index end |
#grounding_score ⇒ Float
Score for the segment.
Corresponds to the JSON property groundingScore
21527 21528 21529 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21527 def grounding_score @grounding_score end |
#reference_indices ⇒ Array<Fixnum>
References for the segment.
Corresponds to the JSON property referenceIndices
21532 21533 21534 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21532 def reference_indices @reference_indices end |
#start_index ⇒ Fixnum
Zero-based index indicating the start of the segment, measured in bytes of a
UTF-8 string (i.e. characters encoded on multiple bytes have a length of more
than one).
Corresponds to the JSON property startIndex
21539 21540 21541 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21539 def start_index @start_index end |
#text ⇒ String
The text segment itself.
Corresponds to the JSON property text
21544 21545 21546 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21544 def text @text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21551 21552 21553 21554 21555 21556 21557 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21551 def update!(**args) @end_index = args[:end_index] if args.key?(:end_index) @grounding_score = args[:grounding_score] if args.key?(:grounding_score) @reference_indices = args[:reference_indices] if args.key?(:reference_indices) @start_index = args[:start_index] if args.key?(:start_index) @text = args[:text] if args.key?(:text) end |