Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantToolInfo
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantToolInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Information to identify a tool.
Instance Attribute Summary collapse
-
#tool_display_name ⇒ String
The display name of the tool.
-
#tool_name ⇒ String
The name of the tool as defined by DataConnectorService.QueryAvailableActions.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistantToolInfo
constructor
A new instance of GoogleCloudDiscoveryengineV1betaAssistantToolInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistantToolInfo
Returns a new instance of GoogleCloudDiscoveryengineV1betaAssistantToolInfo.
20958 20959 20960 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20958 def initialize(**args) update!(**args) end |
Instance Attribute Details
#tool_display_name ⇒ String
The display name of the tool.
Corresponds to the JSON property toolDisplayName
20949 20950 20951 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20949 def tool_display_name @tool_display_name end |
#tool_name ⇒ String
The name of the tool as defined by DataConnectorService.QueryAvailableActions.
Note: it's using action in the DataConnectorService apis, but they are the
same as the tool here.
Corresponds to the JSON property toolName
20956 20957 20958 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20956 def tool_name @tool_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20963 20964 20965 20966 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20963 def update!(**args) @tool_display_name = args[:tool_display_name] if args.key?(:tool_display_name) @tool_name = args[:tool_name] if args.key?(:tool_name) end |