Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistantToolInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Information to identify a tool.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaAssistantToolInfo

Returns a new instance of GoogleCloudDiscoveryengineV1betaAssistantToolInfo.



20754
20755
20756
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20754

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#tool_display_nameString

The display name of the tool. Corresponds to the JSON property toolDisplayName

Returns:

  • (String)


20745
20746
20747
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20745

def tool_display_name
  @tool_display_name
end

#tool_nameString

The name of the tool as defined by DataConnectorService.QueryAvailableActions. Note: it's using action in the DataConnectorService apis, but they are the same as the tool here. Corresponds to the JSON property toolName

Returns:

  • (String)


20752
20753
20754
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20752

def tool_name
  @tool_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20759
20760
20761
20762
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20759

def update!(**args)
  @tool_display_name = args[:tool_display_name] if args.key?(:tool_display_name)
  @tool_name = args[:tool_name] if args.key?(:tool_name)
end