Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaBatchUpdateUserLicensesMetadata
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaBatchUpdateUserLicensesMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Metadata related to the progress of the UserLicenseService. BatchUpdateUserLicenses operation. This will be returned by the google. longrunning.Operation.metadata field.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Operation create time.
-
#failure_count ⇒ Fixnum
Count of user licenses that failed to be updated.
-
#success_count ⇒ Fixnum
Count of user licenses successfully updated.
-
#update_time ⇒ String
Operation last update time.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaBatchUpdateUserLicensesMetadata
constructor
A new instance of GoogleCloudDiscoveryengineV1betaBatchUpdateUserLicensesMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaBatchUpdateUserLicensesMetadata
Returns a new instance of GoogleCloudDiscoveryengineV1betaBatchUpdateUserLicensesMetadata.
20962 20963 20964 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20962 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Operation create time.
Corresponds to the JSON property createTime
20944 20945 20946 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20944 def create_time @create_time end |
#failure_count ⇒ Fixnum
Count of user licenses that failed to be updated.
Corresponds to the JSON property failureCount
20949 20950 20951 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20949 def failure_count @failure_count end |
#success_count ⇒ Fixnum
Count of user licenses successfully updated.
Corresponds to the JSON property successCount
20954 20955 20956 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20954 def success_count @success_count end |
#update_time ⇒ String
Operation last update time. If the operation is done, this is also the finish
time.
Corresponds to the JSON property updateTime
20960 20961 20962 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20960 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20967 20968 20969 20970 20971 20972 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 20967 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @failure_count = args[:failure_count] if args.key?(:failure_count) @success_count = args[:success_count] if args.key?(:success_count) @update_time = args[:update_time] if args.key?(:update_time) end |