Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaBatchUpdateUserLicensesRequest
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaBatchUpdateUserLicensesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Request message for UserLicenseService.BatchUpdateUserLicenses method.
Instance Attribute Summary collapse
-
#delete_unassigned_user_licenses ⇒ Boolean
(also: #delete_unassigned_user_licenses?)
Optional.
-
#inline_source ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaBatchUpdateUserLicensesRequestInlineSource
The inline source for the input config for BatchUpdateUserLicenses method.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaBatchUpdateUserLicensesRequest
constructor
A new instance of GoogleCloudDiscoveryengineV1betaBatchUpdateUserLicensesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaBatchUpdateUserLicensesRequest
Returns a new instance of GoogleCloudDiscoveryengineV1betaBatchUpdateUserLicensesRequest.
22008 22009 22010 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22008 def initialize(**args) update!(**args) end |
Instance Attribute Details
#delete_unassigned_user_licenses ⇒ Boolean Also known as: delete_unassigned_user_licenses?
Optional. If true, if user licenses removed associated license config, the
user license will be deleted. By default which is false, the user license will
be updated to unassigned state.
Corresponds to the JSON property deleteUnassignedUserLicenses
22000 22001 22002 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22000 def delete_unassigned_user_licenses @delete_unassigned_user_licenses end |
#inline_source ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaBatchUpdateUserLicensesRequestInlineSource
The inline source for the input config for BatchUpdateUserLicenses method.
Corresponds to the JSON property inlineSource
22006 22007 22008 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22006 def inline_source @inline_source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22013 22014 22015 22016 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22013 def update!(**args) @delete_unassigned_user_licenses = args[:delete_unassigned_user_licenses] if args.key?(:delete_unassigned_user_licenses) @inline_source = args[:inline_source] if args.key?(:inline_source) end |