Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaBatchUpdateUserLicensesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Request message for UserLicenseService.BatchUpdateUserLicenses method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaBatchUpdateUserLicensesRequest

Returns a new instance of GoogleCloudDiscoveryengineV1betaBatchUpdateUserLicensesRequest.



21196
21197
21198
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21196

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#delete_unassigned_user_licensesBoolean Also known as: delete_unassigned_user_licenses?

Optional. If true, if user licenses removed associated license config, the user license will be deleted. By default which is false, the user license will be updated to unassigned state. Corresponds to the JSON property deleteUnassignedUserLicenses

Returns:

  • (Boolean)


21188
21189
21190
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21188

def delete_unassigned_user_licenses
  @delete_unassigned_user_licenses
end

#inline_sourceGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaBatchUpdateUserLicensesRequestInlineSource

The inline source for the input config for BatchUpdateUserLicenses method. Corresponds to the JSON property inlineSource



21194
21195
21196
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21194

def inline_source
  @inline_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21201
21202
21203
21204
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21201

def update!(**args)
  @delete_unassigned_user_licenses = args[:delete_unassigned_user_licenses] if args.key?(:delete_unassigned_user_licenses)
  @inline_source = args[:inline_source] if args.key?(:inline_source)
end