Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaBigQuerySource
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaBigQuerySource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
BigQuery source import data from.
Instance Attribute Summary collapse
-
#data_schema ⇒ String
The schema to use when parsing the data from the source.
-
#dataset_id ⇒ String
Required.
-
#gcs_staging_dir ⇒ String
Intermediate Cloud Storage directory used for the import with a length limit of 2,000 characters.
-
#partition_date ⇒ Google::Apis::DiscoveryengineV1beta::GoogleTypeDate
Represents a whole or partial calendar date, such as a birthday.
-
#project_id ⇒ String
The project ID or the project number that contains the BigQuery source.
-
#table_id ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaBigQuerySource
constructor
A new instance of GoogleCloudDiscoveryengineV1betaBigQuerySource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaBigQuerySource
Returns a new instance of GoogleCloudDiscoveryengineV1betaBigQuerySource.
21120 21121 21122 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21120 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_schema ⇒ String
The schema to use when parsing the data from the source. Supported values for
user event imports: * user_event (default): One UserEvent per row. Supported
values for document imports: * document (default): One Document format per
row. Each document must have a valid Document.id and one of Document.json_data
or Document.struct_data. * custom: One custom data per row in arbitrary
format that conforms to the defined Schema of the data store. This can only be
used by the GENERIC Data Store vertical.
Corresponds to the JSON property dataSchema
21080 21081 21082 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21080 def data_schema @data_schema end |
#dataset_id ⇒ String
Required. The BigQuery data set to copy the data from with a length limit of 1,
024 characters.
Corresponds to the JSON property datasetId
21086 21087 21088 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21086 def dataset_id @dataset_id end |
#gcs_staging_dir ⇒ String
Intermediate Cloud Storage directory used for the import with a length limit
of 2,000 characters. Can be specified if one wants to have the BigQuery export
to a specific Cloud Storage directory.
Corresponds to the JSON property gcsStagingDir
21093 21094 21095 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21093 def gcs_staging_dir @gcs_staging_dir end |
#partition_date ⇒ Google::Apis::DiscoveryengineV1beta::GoogleTypeDate
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property partitionDate
21105 21106 21107 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21105 def partition_date @partition_date end |
#project_id ⇒ String
The project ID or the project number that contains the BigQuery source. Has a
length limit of 128 characters. If not specified, inherits the project ID from
the parent request.
Corresponds to the JSON property projectId
21112 21113 21114 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21112 def project_id @project_id end |
#table_id ⇒ String
Required. The BigQuery table to copy the data from with a length limit of 1,
024 characters.
Corresponds to the JSON property tableId
21118 21119 21120 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21118 def table_id @table_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21125 21126 21127 21128 21129 21130 21131 21132 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21125 def update!(**args) @data_schema = args[:data_schema] if args.key?(:data_schema) @dataset_id = args[:dataset_id] if args.key?(:dataset_id) @gcs_staging_dir = args[:gcs_staging_dir] if args.key?(:gcs_staging_dir) @partition_date = args[:partition_date] if args.key?(:partition_date) @project_id = args[:project_id] if args.key?(:project_id) @table_id = args[:table_id] if args.key?(:table_id) end |