Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaBigtableOptionsBigtableColumn
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaBigtableOptionsBigtableColumn
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
The column of the Bigtable.
Instance Attribute Summary collapse
-
#encoding ⇒ String
The encoding mode of the values when the type is not
STRING. -
#field_name ⇒ String
The field name to use for this column in the document.
-
#qualifier ⇒ String
Required.
-
#type ⇒ String
The type of values in this column family.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaBigtableOptionsBigtableColumn
constructor
A new instance of GoogleCloudDiscoveryengineV1betaBigtableOptionsBigtableColumn.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaBigtableOptionsBigtableColumn
Returns a new instance of GoogleCloudDiscoveryengineV1betaBigtableOptionsBigtableColumn.
21198 21199 21200 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21198 def initialize(**args) update!(**args) end |
Instance Attribute Details
#encoding ⇒ String
The encoding mode of the values when the type is not STRING. Acceptable
encoding values are: * TEXT: indicates values are alphanumeric text strings.
BINARY: indicates values are encoded usingHBase Bytes.toBytesfamily of functions. This can be overridden for a specific column by listing that column incolumnsand specifying an encoding for it. Corresponds to the JSON propertyencoding
21174 21175 21176 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21174 def encoding @encoding end |
#field_name ⇒ String
The field name to use for this column in the document. The name has to match
the pattern a-zA-Z0-9*. If not set, it is parsed from the qualifier bytes
with best effort. However, due to different naming patterns, field name
collisions could happen, where parsing behavior is undefined.
Corresponds to the JSON property fieldName
21182 21183 21184 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21182 def field_name @field_name end |
#qualifier ⇒ String
Required. Qualifier of the column. If it cannot be decoded with utf-8, use a
base-64 encoded string instead.
Corresponds to the JSON property qualifier
NOTE: Values are automatically base64 encoded/decoded in the client library.
21189 21190 21191 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21189 def qualifier @qualifier end |
#type ⇒ String
The type of values in this column family. The values are expected to be
encoded using HBase Bytes.toBytes function when the encoding value is set to
BINARY.
Corresponds to the JSON property type
21196 21197 21198 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21196 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21203 21204 21205 21206 21207 21208 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21203 def update!(**args) @encoding = args[:encoding] if args.key?(:encoding) @field_name = args[:field_name] if args.key?(:field_name) @qualifier = args[:qualifier] if args.key?(:qualifier) @type = args[:type] if args.key?(:type) end |