Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaBigtableOptionsBigtableColumnFamily
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaBigtableOptionsBigtableColumnFamily
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
The column family of the Bigtable.
Instance Attribute Summary collapse
-
#columns ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaBigtableOptionsBigtableColumn>
The list of objects that contains column level information for each column.
-
#encoding ⇒ String
The encoding mode of the values when the type is not STRING.
-
#field_name ⇒ String
The field name to use for this column family in the document.
-
#type ⇒ String
The type of values in this column family.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaBigtableOptionsBigtableColumnFamily
constructor
A new instance of GoogleCloudDiscoveryengineV1betaBigtableOptionsBigtableColumnFamily.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaBigtableOptionsBigtableColumnFamily
Returns a new instance of GoogleCloudDiscoveryengineV1betaBigtableOptionsBigtableColumnFamily.
22094 22095 22096 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22094 def initialize(**args) update!(**args) end |
Instance Attribute Details
#columns ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaBigtableOptionsBigtableColumn>
The list of objects that contains column level information for each column. If
a column is not present in this list it will be ignored.
Corresponds to the JSON property columns
22068 22069 22070 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22068 def columns @columns end |
#encoding ⇒ String
The encoding mode of the values when the type is not STRING. Acceptable
encoding values are: * TEXT: indicates values are alphanumeric text strings.
BINARY: indicates values are encoded usingHBase Bytes.toBytesfamily of functions. This can be overridden for a specific column by listing that column incolumnsand specifying an encoding for it. Corresponds to the JSON propertyencoding
22077 22078 22079 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22077 def encoding @encoding end |
#field_name ⇒ String
The field name to use for this column family in the document. The name has to
match the pattern a-zA-Z0-9*. If not set, it is parsed from the family name
with best effort. However, due to different naming patterns, field name
collisions could happen, where parsing behavior is undefined.
Corresponds to the JSON property fieldName
22085 22086 22087 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22085 def field_name @field_name end |
#type ⇒ String
The type of values in this column family. The values are expected to be
encoded using HBase Bytes.toBytes function when the encoding value is set to
BINARY.
Corresponds to the JSON property type
22092 22093 22094 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22092 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22099 22100 22101 22102 22103 22104 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22099 def update!(**args) @columns = args[:columns] if args.key?(:columns) @encoding = args[:encoding] if args.key?(:encoding) @field_name = args[:field_name] if args.key?(:field_name) @type = args[:type] if args.key?(:type) end |