Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaBigtableOptionsBigtableColumnFamily

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

The column family of the Bigtable.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaBigtableOptionsBigtableColumnFamily

Returns a new instance of GoogleCloudDiscoveryengineV1betaBigtableOptionsBigtableColumnFamily.



21449
21450
21451
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21449

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#columnsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaBigtableOptionsBigtableColumn>

The list of objects that contains column level information for each column. If a column is not present in this list it will be ignored. Corresponds to the JSON property columns



21423
21424
21425
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21423

def columns
  @columns
end

#encodingString

The encoding mode of the values when the type is not STRING. Acceptable encoding values are: * TEXT: indicates values are alphanumeric text strings.

  • BINARY: indicates values are encoded using HBase Bytes.toBytes family of functions. This can be overridden for a specific column by listing that column in columns and specifying an encoding for it. Corresponds to the JSON property encoding

Returns:

  • (String)


21432
21433
21434
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21432

def encoding
  @encoding
end

#field_nameString

The field name to use for this column family in the document. The name has to match the pattern a-zA-Z0-9*. If not set, it is parsed from the family name with best effort. However, due to different naming patterns, field name collisions could happen, where parsing behavior is undefined. Corresponds to the JSON property fieldName

Returns:

  • (String)


21440
21441
21442
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21440

def field_name
  @field_name
end

#typeString

The type of values in this column family. The values are expected to be encoded using HBase Bytes.toBytes function when the encoding value is set to BINARY. Corresponds to the JSON property type

Returns:

  • (String)


21447
21448
21449
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21447

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21454
21455
21456
21457
21458
21459
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21454

def update!(**args)
  @columns = args[:columns] if args.key?(:columns)
  @encoding = args[:encoding] if args.key?(:encoding)
  @field_name = args[:field_name] if args.key?(:field_name)
  @type = args[:type] if args.key?(:type)
end