Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaBigtableOptionsBigtableColumnFamily
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaBigtableOptionsBigtableColumnFamily
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
The column family of the Bigtable.
Instance Attribute Summary collapse
-
#columns ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaBigtableOptionsBigtableColumn>
The list of objects that contains column level information for each column.
-
#encoding ⇒ String
The encoding mode of the values when the type is not STRING.
-
#field_name ⇒ String
The field name to use for this column family in the document.
-
#type ⇒ String
The type of values in this column family.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaBigtableOptionsBigtableColumnFamily
constructor
A new instance of GoogleCloudDiscoveryengineV1betaBigtableOptionsBigtableColumnFamily.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaBigtableOptionsBigtableColumnFamily
Returns a new instance of GoogleCloudDiscoveryengineV1betaBigtableOptionsBigtableColumnFamily.
21245 21246 21247 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21245 def initialize(**args) update!(**args) end |
Instance Attribute Details
#columns ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaBigtableOptionsBigtableColumn>
The list of objects that contains column level information for each column. If
a column is not present in this list it will be ignored.
Corresponds to the JSON property columns
21219 21220 21221 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21219 def columns @columns end |
#encoding ⇒ String
The encoding mode of the values when the type is not STRING. Acceptable
encoding values are: * TEXT: indicates values are alphanumeric text strings.
BINARY: indicates values are encoded usingHBase Bytes.toBytesfamily of functions. This can be overridden for a specific column by listing that column incolumnsand specifying an encoding for it. Corresponds to the JSON propertyencoding
21228 21229 21230 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21228 def encoding @encoding end |
#field_name ⇒ String
The field name to use for this column family in the document. The name has to
match the pattern a-zA-Z0-9*. If not set, it is parsed from the family name
with best effort. However, due to different naming patterns, field name
collisions could happen, where parsing behavior is undefined.
Corresponds to the JSON property fieldName
21236 21237 21238 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21236 def field_name @field_name end |
#type ⇒ String
The type of values in this column family. The values are expected to be
encoded using HBase Bytes.toBytes function when the encoding value is set to
BINARY.
Corresponds to the JSON property type
21243 21244 21245 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21243 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21250 21251 21252 21253 21254 21255 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21250 def update!(**args) @columns = args[:columns] if args.key?(:columns) @encoding = args[:encoding] if args.key?(:encoding) @field_name = args[:field_name] if args.key?(:field_name) @type = args[:type] if args.key?(:type) end |