Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaBigtableSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

The Cloud Bigtable source for importing data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaBigtableSource

Returns a new instance of GoogleCloudDiscoveryengineV1betaBigtableSource.



22187
22188
22189
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22187

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bigtable_optionsGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaBigtableOptions

The Bigtable Options object that contains information to support the import. Corresponds to the JSON property bigtableOptions



22169
22170
22171
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22169

def bigtable_options
  @bigtable_options
end

#instance_idString

Required. The instance ID of the Cloud Bigtable that needs to be imported. Corresponds to the JSON property instanceId

Returns:

  • (String)


22174
22175
22176
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22174

def instance_id
  @instance_id
end

#project_idString

The project ID that contains the Bigtable source. Has a length limit of 128 characters. If not specified, inherits the project ID from the parent request. Corresponds to the JSON property projectId

Returns:

  • (String)


22180
22181
22182
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22180

def project_id
  @project_id
end

#table_idString

Required. The table ID of the Cloud Bigtable that needs to be imported. Corresponds to the JSON property tableId

Returns:

  • (String)


22185
22186
22187
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22185

def table_id
  @table_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22192
22193
22194
22195
22196
22197
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22192

def update!(**args)
  @bigtable_options = args[:bigtable_options] if args.key?(:bigtable_options)
  @instance_id = args[:instance_id] if args.key?(:instance_id)
  @project_id = args[:project_id] if args.key?(:project_id)
  @table_id = args[:table_id] if args.key?(:table_id)
end