Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCheckGroundingResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Response message for the GroundedGenerationService.CheckGrounding method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaCheckGroundingResponse

Returns a new instance of GoogleCloudDiscoveryengineV1betaCheckGroundingResponse.



22220
22221
22222
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22220

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cited_chunksArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaFactChunk>

List of facts cited across all claims in the answer candidate. These are derived from the facts supplied in the request. Corresponds to the JSON property citedChunks



22200
22201
22202
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22200

def cited_chunks
  @cited_chunks
end

#cited_factsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCheckGroundingResponseCheckGroundingFactChunk>

List of facts cited across all claims in the answer candidate. These are derived from the facts supplied in the request. Corresponds to the JSON property citedFacts



22206
22207
22208
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22206

def cited_facts
  @cited_facts
end

#claimsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCheckGroundingResponseClaim>

Claim texts and citation info across all claims in the answer candidate. Corresponds to the JSON property claims



22211
22212
22213
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22211

def claims
  @claims
end

#support_scoreFloat

The support score for the input answer candidate. Higher the score, higher is the fraction of claims that are supported by the provided facts. This is always set when a response is returned. Corresponds to the JSON property supportScore

Returns:

  • (Float)


22218
22219
22220
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22218

def support_score
  @support_score
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22225
22226
22227
22228
22229
22230
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22225

def update!(**args)
  @cited_chunks = args[:cited_chunks] if args.key?(:cited_chunks)
  @cited_facts = args[:cited_facts] if args.key?(:cited_facts)
  @claims = args[:claims] if args.key?(:claims)
  @support_score = args[:support_score] if args.key?(:support_score)
end