Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCheckGroundingResponse
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCheckGroundingResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Response message for the GroundedGenerationService.CheckGrounding method.
Instance Attribute Summary collapse
-
#cited_chunks ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaFactChunk>
List of facts cited across all claims in the answer candidate.
-
#cited_facts ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCheckGroundingResponseCheckGroundingFactChunk>
List of facts cited across all claims in the answer candidate.
-
#claims ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCheckGroundingResponseClaim>
Claim texts and citation info across all claims in the answer candidate.
-
#support_score ⇒ Float
The support score for the input answer candidate.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaCheckGroundingResponse
constructor
A new instance of GoogleCloudDiscoveryengineV1betaCheckGroundingResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaCheckGroundingResponse
Returns a new instance of GoogleCloudDiscoveryengineV1betaCheckGroundingResponse.
21371 21372 21373 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21371 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cited_chunks ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaFactChunk>
List of facts cited across all claims in the answer candidate. These are
derived from the facts supplied in the request.
Corresponds to the JSON property citedChunks
21351 21352 21353 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21351 def cited_chunks @cited_chunks end |
#cited_facts ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCheckGroundingResponseCheckGroundingFactChunk>
List of facts cited across all claims in the answer candidate. These are
derived from the facts supplied in the request.
Corresponds to the JSON property citedFacts
21357 21358 21359 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21357 def cited_facts @cited_facts end |
#claims ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCheckGroundingResponseClaim>
Claim texts and citation info across all claims in the answer candidate.
Corresponds to the JSON property claims
21362 21363 21364 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21362 def claims @claims end |
#support_score ⇒ Float
The support score for the input answer candidate. Higher the score, higher is
the fraction of claims that are supported by the provided facts. This is
always set when a response is returned.
Corresponds to the JSON property supportScore
21369 21370 21371 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21369 def support_score @support_score end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21376 21377 21378 21379 21380 21381 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21376 def update!(**args) @cited_chunks = args[:cited_chunks] if args.key?(:cited_chunks) @cited_facts = args[:cited_facts] if args.key?(:cited_facts) @claims = args[:claims] if args.key?(:claims) @support_score = args[:support_score] if args.key?(:support_score) end |