Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCheckGroundingResponseClaim
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCheckGroundingResponseClaim
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Text and citation info for a claim in the answer candidate.
Instance Attribute Summary collapse
-
#citation_indices ⇒ Array<Fixnum>
A list of indices (into 'cited_chunks') specifying the citations associated with the claim.
-
#claim_text ⇒ String
Text for the claim in the answer candidate.
-
#end_pos ⇒ Fixnum
Position indicating the end of the claim in the answer candidate, exclusive, in bytes.
-
#grounding_check_required ⇒ Boolean
(also: #grounding_check_required?)
Indicates that this claim required grounding check.
-
#score ⇒ Float
Confidence score for the claim in the answer candidate, in the range of [0, 1].
-
#start_pos ⇒ Fixnum
Position indicating the start of the claim in the answer candidate, measured in bytes.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaCheckGroundingResponseClaim
constructor
A new instance of GoogleCloudDiscoveryengineV1betaCheckGroundingResponseClaim.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaCheckGroundingResponseClaim
Returns a new instance of GoogleCloudDiscoveryengineV1betaCheckGroundingResponseClaim.
22338 22339 22340 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22338 def initialize(**args) update!(**args) end |
Instance Attribute Details
#citation_indices ⇒ Array<Fixnum>
A list of indices (into 'cited_chunks') specifying the citations associated
with the claim. For instance [1,3,4] means that cited_chunks[1], cited_chunks[
3], cited_chunks[4] are the facts cited supporting for the claim. A citation
to a fact indicates that the claim is supported by the fact.
Corresponds to the JSON property citationIndices
22293 22294 22295 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22293 def citation_indices @citation_indices end |
#claim_text ⇒ String
Text for the claim in the answer candidate. Always provided regardless of
whether citations or anti-citations are found.
Corresponds to the JSON property claimText
22299 22300 22301 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22299 def claim_text @claim_text end |
#end_pos ⇒ Fixnum
Position indicating the end of the claim in the answer candidate, exclusive,
in bytes. Note that this is not measured in characters and, therefore, must be
rendered as such. For example, if the claim text contains non-ASCII characters,
the start and end positions vary when measured in characters (programming-
language-dependent) and when measured in bytes (programming-language-
independent).
Corresponds to the JSON property endPos
22309 22310 22311 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22309 def end_pos @end_pos end |
#grounding_check_required ⇒ Boolean Also known as: grounding_check_required?
Indicates that this claim required grounding check. When the system decided
this claim doesn't require attribution/grounding check, this field will be set
to false. In that case, no grounding check was done for the claim and
therefore citation_indices should not be returned.
Corresponds to the JSON property groundingCheckRequired
22317 22318 22319 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22317 def grounding_check_required @grounding_check_required end |
#score ⇒ Float
Confidence score for the claim in the answer candidate, in the range of [0, 1].
This is set only when CheckGroundingRequest.grounding_spec.
enable_claim_level_score is true.
Corresponds to the JSON property score
22325 22326 22327 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22325 def score @score end |
#start_pos ⇒ Fixnum
Position indicating the start of the claim in the answer candidate, measured
in bytes. Note that this is not measured in characters and, therefore, must be
rendered in the user interface keeping in mind that some characters may take
more than one byte. For example, if the claim text contains non-ASCII
characters, the start and end positions vary when measured in characters (
programming-language-dependent) and when measured in bytes (programming-
language-independent).
Corresponds to the JSON property startPos
22336 22337 22338 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22336 def start_pos @start_pos end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22343 22344 22345 22346 22347 22348 22349 22350 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22343 def update!(**args) @citation_indices = args[:citation_indices] if args.key?(:citation_indices) @claim_text = args[:claim_text] if args.key?(:claim_text) @end_pos = args[:end_pos] if args.key?(:end_pos) @grounding_check_required = args[:grounding_check_required] if args.key?(:grounding_check_required) @score = args[:score] if args.key?(:score) @start_pos = args[:start_pos] if args.key?(:start_pos) end |