Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaChunk

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Chunk captures all raw metadata information of items to be recommended or searched in the chunk mode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaChunk

Returns a new instance of GoogleCloudDiscoveryengineV1betaChunk.



21778
21779
21780
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21778

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotation_contentsArray<String>

Output only. Annotation contents if the current chunk contains annotations. Corresponds to the JSON property annotationContents

Returns:

  • (Array<String>)


21715
21716
21717
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21715

def annotation_contents
  @annotation_contents
end

#annotation_metadataArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaChunkAnnotationMetadata>

Output only. The annotation metadata includes structured content in the current chunk. Corresponds to the JSON property annotationMetadata



21721
21722
21723
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21721

def 
  @annotation_metadata
end

#chunk_metadataGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaChunkChunkMetadata

Metadata of the current chunk. This field is only populated on SearchService. Search API. Corresponds to the JSON property chunkMetadata



21727
21728
21729
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21727

def 
  @chunk_metadata
end

#contentString

Content is a string from a document (parsed content). Corresponds to the JSON property content

Returns:

  • (String)


21732
21733
21734
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21732

def content
  @content
end

#data_urlsArray<String>

Output only. Image Data URLs if the current chunk contains images. Data URLs are composed of four parts: a prefix (data:), a MIME type indicating the type of data, an optional base64 token if non-textual, and the data itself: data:, Corresponds to the JSON property dataUrls

Returns:

  • (Array<String>)


21739
21740
21741
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21739

def data_urls
  @data_urls
end

#derived_struct_dataHash<String,Object>

Output only. This field is OUTPUT_ONLY. It contains derived data that are not in the original input document. Corresponds to the JSON property derivedStructData

Returns:

  • (Hash<String,Object>)


21745
21746
21747
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21745

def derived_struct_data
  @derived_struct_data
end

#document_metadataGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaChunkDocumentMetadata

Document metadata contains the information of the document of the current chunk. Corresponds to the JSON property documentMetadata



21751
21752
21753
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21751

def 
  @document_metadata
end

#idString

Unique chunk ID of the current chunk. Corresponds to the JSON property id

Returns:

  • (String)


21756
21757
21758
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21756

def id
  @id
end

#nameString

The full resource name of the chunk. Format: projects/project/locations/ location/collections/collection/dataStores/data_store/branches/branch/ documents/document_id/chunks/chunk_id`. This field must be a UTF-8 encoded string with a length limit of 1024 characters. Corresponds to the JSON propertyname`

Returns:

  • (String)


21764
21765
21766
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21764

def name
  @name
end

#page_spanGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaChunkPageSpan

Page span of the chunk. Corresponds to the JSON property pageSpan



21769
21770
21771
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21769

def page_span
  @page_span
end

#relevance_scoreFloat

Output only. Represents the relevance score based on similarity. Higher score indicates higher chunk relevance. The score is in range [-1.0, 1.0]. Only populated on SearchResponse. Corresponds to the JSON property relevanceScore

Returns:

  • (Float)


21776
21777
21778
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21776

def relevance_score
  @relevance_score
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21783
21784
21785
21786
21787
21788
21789
21790
21791
21792
21793
21794
21795
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21783

def update!(**args)
  @annotation_contents = args[:annotation_contents] if args.key?(:annotation_contents)
  @annotation_metadata = args[:annotation_metadata] if args.key?(:annotation_metadata)
  @chunk_metadata = args[:chunk_metadata] if args.key?(:chunk_metadata)
  @content = args[:content] if args.key?(:content)
  @data_urls = args[:data_urls] if args.key?(:data_urls)
  @derived_struct_data = args[:derived_struct_data] if args.key?(:derived_struct_data)
  @document_metadata = args[:document_metadata] if args.key?(:document_metadata)
  @id = args[:id] if args.key?(:id)
  @name = args[:name] if args.key?(:name)
  @page_span = args[:page_span] if args.key?(:page_span)
  @relevance_score = args[:relevance_score] if args.key?(:relevance_score)
end