Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaChunkDocumentMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Document metadata contains the information of the document of the current chunk.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaChunkDocumentMetadata

Returns a new instance of GoogleCloudDiscoveryengineV1betaChunkDocumentMetadata.



22693
22694
22695
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22693

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#mime_typeString

The mime type of the document. https://www.iana.org/assignments/media-types/ media-types.xhtml. Corresponds to the JSON property mimeType

Returns:

  • (String)


22675
22676
22677
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22675

def mime_type
  @mime_type
end

#struct_dataHash<String,Object>

Data representation. The structured JSON data for the document. It should conform to the registered Schema or an INVALID_ARGUMENT error is thrown. Corresponds to the JSON property structData

Returns:

  • (Hash<String,Object>)


22681
22682
22683
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22681

def struct_data
  @struct_data
end

#titleString

Title of the document. Corresponds to the JSON property title

Returns:

  • (String)


22686
22687
22688
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22686

def title
  @title
end

#uriString

Uri of the document. Corresponds to the JSON property uri

Returns:

  • (String)


22691
22692
22693
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22691

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22698
22699
22700
22701
22702
22703
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22698

def update!(**args)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
  @struct_data = args[:struct_data] if args.key?(:struct_data)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end