Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaChunkDocumentMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Document metadata contains the information of the document of the current chunk.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaChunkDocumentMetadata

Returns a new instance of GoogleCloudDiscoveryengineV1betaChunkDocumentMetadata.



22581
22582
22583
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22581

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#mime_typeString

The mime type of the document. https://www.iana.org/assignments/media-types/ media-types.xhtml. Corresponds to the JSON property mimeType

Returns:

  • (String)


22563
22564
22565
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22563

def mime_type
  @mime_type
end

#struct_dataHash<String,Object>

Data representation. The structured JSON data for the document. It should conform to the registered Schema or an INVALID_ARGUMENT error is thrown. Corresponds to the JSON property structData

Returns:

  • (Hash<String,Object>)


22569
22570
22571
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22569

def struct_data
  @struct_data
end

#titleString

Title of the document. Corresponds to the JSON property title

Returns:

  • (String)


22574
22575
22576
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22574

def title
  @title
end

#uriString

Uri of the document. Corresponds to the JSON property uri

Returns:

  • (String)


22579
22580
22581
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22579

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22586
22587
22588
22589
22590
22591
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22586

def update!(**args)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
  @struct_data = args[:struct_data] if args.key?(:struct_data)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end