Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaChunkDocumentMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Document metadata contains the information of the document of the current chunk.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaChunkDocumentMetadata

Returns a new instance of GoogleCloudDiscoveryengineV1betaChunkDocumentMetadata.



21881
21882
21883
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21881

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#mime_typeString

The mime type of the document. https://www.iana.org/assignments/media-types/ media-types.xhtml. Corresponds to the JSON property mimeType

Returns:

  • (String)


21863
21864
21865
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21863

def mime_type
  @mime_type
end

#struct_dataHash<String,Object>

Data representation. The structured JSON data for the document. It should conform to the registered Schema or an INVALID_ARGUMENT error is thrown. Corresponds to the JSON property structData

Returns:

  • (Hash<String,Object>)


21869
21870
21871
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21869

def struct_data
  @struct_data
end

#titleString

Title of the document. Corresponds to the JSON property title

Returns:

  • (String)


21874
21875
21876
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21874

def title
  @title
end

#uriString

Uri of the document. Corresponds to the JSON property uri

Returns:

  • (String)


21879
21880
21881
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21879

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21886
21887
21888
21889
21890
21891
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21886

def update!(**args)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
  @struct_data = args[:struct_data] if args.key?(:struct_data)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end