Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCitation
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCitation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Source attributions for content.
Instance Attribute Summary collapse
-
#end_index ⇒ Fixnum
Output only.
-
#license ⇒ String
Output only.
-
#publication_date ⇒ Google::Apis::DiscoveryengineV1beta::GoogleTypeDate
Represents a whole or partial calendar date, such as a birthday.
-
#start_index ⇒ Fixnum
Output only.
-
#title ⇒ String
Output only.
-
#uri ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaCitation
constructor
A new instance of GoogleCloudDiscoveryengineV1betaCitation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaCitation
Returns a new instance of GoogleCloudDiscoveryengineV1betaCitation.
21985 21986 21987 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21985 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_index ⇒ Fixnum
Output only. End index into the content.
Corresponds to the JSON property endIndex
21951 21952 21953 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21951 def end_index @end_index end |
#license ⇒ String
Output only. License of the attribution.
Corresponds to the JSON property license
21956 21957 21958 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21956 def license @license end |
#publication_date ⇒ Google::Apis::DiscoveryengineV1beta::GoogleTypeDate
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property publicationDate
21968 21969 21970 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21968 def publication_date @publication_date end |
#start_index ⇒ Fixnum
Output only. Start index into the content.
Corresponds to the JSON property startIndex
21973 21974 21975 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21973 def start_index @start_index end |
#title ⇒ String
Output only. Title of the attribution.
Corresponds to the JSON property title
21978 21979 21980 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21978 def title @title end |
#uri ⇒ String
Output only. Url reference of the attribution.
Corresponds to the JSON property uri
21983 21984 21985 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21983 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21990 21991 21992 21993 21994 21995 21996 21997 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21990 def update!(**args) @end_index = args[:end_index] if args.key?(:end_index) @license = args[:license] if args.key?(:license) @publication_date = args[:publication_date] if args.key?(:publication_date) @start_index = args[:start_index] if args.key?(:start_index) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) end |