Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCloudSqlSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Cloud SQL source import data from.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaCloudSqlSource

Returns a new instance of GoogleCloudDiscoveryengineV1betaCloudSqlSource.



22739
22740
22741
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22739

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#database_idString

Required. The Cloud SQL database to copy the data from with a length limit of 256 characters. Corresponds to the JSON property databaseId

Returns:

  • (String)


22703
22704
22705
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22703

def database_id
  @database_id
end

#gcs_staging_dirString

Intermediate Cloud Storage directory used for the import with a length limit of 2,000 characters. Can be specified if one wants to have the Cloud SQL export to a specific Cloud Storage directory. Ensure that the Cloud SQL service account has the necessary Cloud Storage Admin permissions to access the specified Cloud Storage directory. Corresponds to the JSON property gcsStagingDir

Returns:

  • (String)


22712
22713
22714
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22712

def gcs_staging_dir
  @gcs_staging_dir
end

#instance_idString

Required. The Cloud SQL instance to copy the data from with a length limit of 256 characters. Corresponds to the JSON property instanceId

Returns:

  • (String)


22718
22719
22720
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22718

def instance_id
  @instance_id
end

#offloadBoolean Also known as: offload?

Option for serverless export. Enabling this option will incur additional cost. More info can be found here. Corresponds to the JSON property offload

Returns:

  • (Boolean)


22724
22725
22726
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22724

def offload
  @offload
end

#project_idString

The project ID that contains the Cloud SQL source. Has a length limit of 128 characters. If not specified, inherits the project ID from the parent request. Corresponds to the JSON property projectId

Returns:

  • (String)


22731
22732
22733
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22731

def project_id
  @project_id
end

#table_idString

Required. The Cloud SQL table to copy the data from with a length limit of 256 characters. Corresponds to the JSON property tableId

Returns:

  • (String)


22737
22738
22739
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22737

def table_id
  @table_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22744
22745
22746
22747
22748
22749
22750
22751
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22744

def update!(**args)
  @database_id = args[:database_id] if args.key?(:database_id)
  @gcs_staging_dir = args[:gcs_staging_dir] if args.key?(:gcs_staging_dir)
  @instance_id = args[:instance_id] if args.key?(:instance_id)
  @offload = args[:offload] if args.key?(:offload)
  @project_id = args[:project_id] if args.key?(:project_id)
  @table_id = args[:table_id] if args.key?(:table_id)
end