Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCloudSqlSource
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCloudSqlSource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Cloud SQL source import data from.
Instance Attribute Summary collapse
-
#database_id ⇒ String
Required.
-
#gcs_staging_dir ⇒ String
Intermediate Cloud Storage directory used for the import with a length limit of 2,000 characters.
-
#instance_id ⇒ String
Required.
-
#offload ⇒ Boolean
(also: #offload?)
Option for serverless export.
-
#project_id ⇒ String
The project ID that contains the Cloud SQL source.
-
#table_id ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaCloudSqlSource
constructor
A new instance of GoogleCloudDiscoveryengineV1betaCloudSqlSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaCloudSqlSource
Returns a new instance of GoogleCloudDiscoveryengineV1betaCloudSqlSource.
22708 22709 22710 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22708 def initialize(**args) update!(**args) end |
Instance Attribute Details
#database_id ⇒ String
Required. The Cloud SQL database to copy the data from with a length limit of
256 characters.
Corresponds to the JSON property databaseId
22672 22673 22674 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22672 def database_id @database_id end |
#gcs_staging_dir ⇒ String
Intermediate Cloud Storage directory used for the import with a length limit
of 2,000 characters. Can be specified if one wants to have the Cloud SQL
export to a specific Cloud Storage directory. Ensure that the Cloud SQL
service account has the necessary Cloud Storage Admin permissions to access
the specified Cloud Storage directory.
Corresponds to the JSON property gcsStagingDir
22681 22682 22683 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22681 def gcs_staging_dir @gcs_staging_dir end |
#instance_id ⇒ String
Required. The Cloud SQL instance to copy the data from with a length limit of
256 characters.
Corresponds to the JSON property instanceId
22687 22688 22689 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22687 def instance_id @instance_id end |
#offload ⇒ Boolean Also known as: offload?
Option for serverless export. Enabling this option will incur additional cost.
More info can be found here.
Corresponds to the JSON property offload
22693 22694 22695 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22693 def offload @offload end |
#project_id ⇒ String
The project ID that contains the Cloud SQL source. Has a length limit of 128
characters. If not specified, inherits the project ID from the parent request.
Corresponds to the JSON property projectId
22700 22701 22702 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22700 def project_id @project_id end |
#table_id ⇒ String
Required. The Cloud SQL table to copy the data from with a length limit of 256
characters.
Corresponds to the JSON property tableId
22706 22707 22708 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22706 def table_id @table_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22713 22714 22715 22716 22717 22718 22719 22720 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22713 def update!(**args) @database_id = args[:database_id] if args.key?(:database_id) @gcs_staging_dir = args[:gcs_staging_dir] if args.key?(:gcs_staging_dir) @instance_id = args[:instance_id] if args.key?(:instance_id) @offload = args[:offload] if args.key?(:offload) @project_id = args[:project_id] if args.key?(:project_id) @table_id = args[:table_id] if args.key?(:table_id) end |