Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCloudSqlSource
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCloudSqlSource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Cloud SQL source import data from.
Instance Attribute Summary collapse
-
#database_id ⇒ String
Required.
-
#gcs_staging_dir ⇒ String
Intermediate Cloud Storage directory used for the import with a length limit of 2,000 characters.
-
#instance_id ⇒ String
Required.
-
#offload ⇒ Boolean
(also: #offload?)
Option for serverless export.
-
#project_id ⇒ String
The project ID that contains the Cloud SQL source.
-
#table_id ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaCloudSqlSource
constructor
A new instance of GoogleCloudDiscoveryengineV1betaCloudSqlSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaCloudSqlSource
Returns a new instance of GoogleCloudDiscoveryengineV1betaCloudSqlSource.
21859 21860 21861 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21859 def initialize(**args) update!(**args) end |
Instance Attribute Details
#database_id ⇒ String
Required. The Cloud SQL database to copy the data from with a length limit of
256 characters.
Corresponds to the JSON property databaseId
21823 21824 21825 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21823 def database_id @database_id end |
#gcs_staging_dir ⇒ String
Intermediate Cloud Storage directory used for the import with a length limit
of 2,000 characters. Can be specified if one wants to have the Cloud SQL
export to a specific Cloud Storage directory. Ensure that the Cloud SQL
service account has the necessary Cloud Storage Admin permissions to access
the specified Cloud Storage directory.
Corresponds to the JSON property gcsStagingDir
21832 21833 21834 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21832 def gcs_staging_dir @gcs_staging_dir end |
#instance_id ⇒ String
Required. The Cloud SQL instance to copy the data from with a length limit of
256 characters.
Corresponds to the JSON property instanceId
21838 21839 21840 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21838 def instance_id @instance_id end |
#offload ⇒ Boolean Also known as: offload?
Option for serverless export. Enabling this option will incur additional cost.
More info can be found here.
Corresponds to the JSON property offload
21844 21845 21846 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21844 def offload @offload end |
#project_id ⇒ String
The project ID that contains the Cloud SQL source. Has a length limit of 128
characters. If not specified, inherits the project ID from the parent request.
Corresponds to the JSON property projectId
21851 21852 21853 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21851 def project_id @project_id end |
#table_id ⇒ String
Required. The Cloud SQL table to copy the data from with a length limit of 256
characters.
Corresponds to the JSON property tableId
21857 21858 21859 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21857 def table_id @table_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21864 21865 21866 21867 21868 21869 21870 21871 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21864 def update!(**args) @database_id = args[:database_id] if args.key?(:database_id) @gcs_staging_dir = args[:gcs_staging_dir] if args.key?(:gcs_staging_dir) @instance_id = args[:instance_id] if args.key?(:instance_id) @offload = args[:offload] if args.key?(:offload) @project_id = args[:project_id] if args.key?(:project_id) @table_id = args[:table_id] if args.key?(:table_id) end |