Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCmekConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Configurations used to enable CMEK data encryption with Cloud KMS keys.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaCmekConfig

Returns a new instance of GoogleCloudDiscoveryengineV1betaCmekConfig.



22772
22773
22774
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22772

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#is_defaultBoolean Also known as: is_default?

Output only. The default CmekConfig for the Customer. Corresponds to the JSON property isDefault

Returns:

  • (Boolean)


22730
22731
22732
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22730

def is_default
  @is_default
end

#kms_keyString

Required. KMS key resource name which will be used to encrypt resources projects/project/locations/location/keyRings/keyRing/cryptoKeys/keyId`. Corresponds to the JSON propertykmsKey`

Returns:

  • (String)


22737
22738
22739
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22737

def kms_key
  @kms_key
end

#kms_key_versionString

Output only. KMS key version resource name which will be used to encrypt resources /cryptoKeyVersions/keyVersion`. Corresponds to the JSON propertykmsKeyVersion`

Returns:

  • (String)


22743
22744
22745
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22743

def kms_key_version
  @kms_key_version
end

#last_rotation_timestamp_microsFixnum

Output only. The timestamp of the last key rotation. Corresponds to the JSON property lastRotationTimestampMicros

Returns:

  • (Fixnum)


22748
22749
22750
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22748

def last_rotation_timestamp_micros
  @last_rotation_timestamp_micros
end

#nameString

Required. The name of the CmekConfig of the form projects/project/locations/ location/cmekConfig or projects/project/locations/location/cmekConfigs/ cmek_config`. Corresponds to the JSON propertyname`

Returns:

  • (String)


22755
22756
22757
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22755

def name
  @name
end

#notebooklm_stateString

Output only. Whether the NotebookLM Corpus is ready to be used. Corresponds to the JSON property notebooklmState

Returns:

  • (String)


22760
22761
22762
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22760

def notebooklm_state
  @notebooklm_state
end

#single_region_keysArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSingleRegionKey>

Optional. Single-regional CMEKs that are required for some VAIS features. Corresponds to the JSON property singleRegionKeys



22765
22766
22767
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22765

def single_region_keys
  @single_region_keys
end

#stateString

Output only. The states of the CmekConfig. Corresponds to the JSON property state

Returns:

  • (String)


22770
22771
22772
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22770

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22777
22778
22779
22780
22781
22782
22783
22784
22785
22786
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22777

def update!(**args)
  @is_default = args[:is_default] if args.key?(:is_default)
  @kms_key = args[:kms_key] if args.key?(:kms_key)
  @kms_key_version = args[:kms_key_version] if args.key?(:kms_key_version)
  @last_rotation_timestamp_micros = args[:last_rotation_timestamp_micros] if args.key?(:last_rotation_timestamp_micros)
  @name = args[:name] if args.key?(:name)
  @notebooklm_state = args[:notebooklm_state] if args.key?(:notebooklm_state)
  @single_region_keys = args[:single_region_keys] if args.key?(:single_region_keys)
  @state = args[:state] if args.key?(:state)
end