Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCmekConfig
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCmekConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Configurations used to enable CMEK data encryption with Cloud KMS keys.
Instance Attribute Summary collapse
-
#is_default ⇒ Boolean
(also: #is_default?)
Output only.
-
#kms_key ⇒ String
Required.
-
#kms_key_version ⇒ String
Output only.
-
#last_rotation_timestamp_micros ⇒ Fixnum
Output only.
-
#name ⇒ String
Required.
-
#notebooklm_state ⇒ String
Output only.
-
#single_region_keys ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSingleRegionKey>
Optional.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaCmekConfig
constructor
A new instance of GoogleCloudDiscoveryengineV1betaCmekConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaCmekConfig
Returns a new instance of GoogleCloudDiscoveryengineV1betaCmekConfig.
21923 21924 21925 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21923 def initialize(**args) update!(**args) end |
Instance Attribute Details
#is_default ⇒ Boolean Also known as: is_default?
Output only. The default CmekConfig for the Customer.
Corresponds to the JSON property isDefault
21881 21882 21883 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21881 def is_default @is_default end |
#kms_key ⇒ String
Required. KMS key resource name which will be used to encrypt resources
projects/project/locations/location/keyRings/keyRing/cryptoKeys/keyId`.
Corresponds to the JSON propertykmsKey`
21888 21889 21890 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21888 def kms_key @kms_key end |
#kms_key_version ⇒ String
Output only. KMS key version resource name which will be used to encrypt
resources /cryptoKeyVersions/keyVersion`.
Corresponds to the JSON propertykmsKeyVersion`
21894 21895 21896 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21894 def kms_key_version @kms_key_version end |
#last_rotation_timestamp_micros ⇒ Fixnum
Output only. The timestamp of the last key rotation.
Corresponds to the JSON property lastRotationTimestampMicros
21899 21900 21901 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21899 def @last_rotation_timestamp_micros end |
#name ⇒ String
Required. The name of the CmekConfig of the form projects/project/locations/
location/cmekConfig or projects/project/locations/location/cmekConfigs/
cmek_config`.
Corresponds to the JSON propertyname`
21906 21907 21908 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21906 def name @name end |
#notebooklm_state ⇒ String
Output only. Whether the NotebookLM Corpus is ready to be used.
Corresponds to the JSON property notebooklmState
21911 21912 21913 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21911 def notebooklm_state @notebooklm_state end |
#single_region_keys ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSingleRegionKey>
Optional. Single-regional CMEKs that are required for some VAIS features.
Corresponds to the JSON property singleRegionKeys
21916 21917 21918 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21916 def single_region_keys @single_region_keys end |
#state ⇒ String
Output only. The states of the CmekConfig.
Corresponds to the JSON property state
21921 21922 21923 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21921 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21928 21929 21930 21931 21932 21933 21934 21935 21936 21937 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 21928 def update!(**args) @is_default = args[:is_default] if args.key?(:is_default) @kms_key = args[:kms_key] if args.key?(:kms_key) @kms_key_version = args[:kms_key_version] if args.key?(:kms_key_version) @last_rotation_timestamp_micros = args[:last_rotation_timestamp_micros] if args.key?(:last_rotation_timestamp_micros) @name = args[:name] if args.key?(:name) @notebooklm_state = args[:notebooklm_state] if args.key?(:notebooklm_state) @single_region_keys = args[:single_region_keys] if args.key?(:single_region_keys) @state = args[:state] if args.key?(:state) end |