Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCompletionSuggestion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Autocomplete suggestions that are imported from Customer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaCompletionSuggestion

Returns a new instance of GoogleCloudDiscoveryengineV1betaCompletionSuggestion.



22915
22916
22917
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22915

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#alternative_phrasesArray<String>

Alternative matching phrases for this suggestion. Corresponds to the JSON property alternativePhrases

Returns:

  • (Array<String>)


22879
22880
22881
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22879

def alternative_phrases
  @alternative_phrases
end

#frequencyFixnum

Frequency of this suggestion. Will be used to rank suggestions when score is not available. Corresponds to the JSON property frequency

Returns:

  • (Fixnum)


22885
22886
22887
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22885

def frequency
  @frequency
end

#global_scoreFloat

Global score of this suggestion. Control how this suggestion would be scored / ranked. Corresponds to the JSON property globalScore

Returns:

  • (Float)


22891
22892
22893
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22891

def global_score
  @global_score
end

#group_idString

If two suggestions have the same groupId, they will not be returned together. Instead the one ranked higher will be returned. This can be used to deduplicate semantically identical suggestions. Corresponds to the JSON property groupId

Returns:

  • (String)


22898
22899
22900
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22898

def group_id
  @group_id
end

#group_scoreFloat

The score of this suggestion within its group. Corresponds to the JSON property groupScore

Returns:

  • (Float)


22903
22904
22905
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22903

def group_score
  @group_score
end

#language_codeString

BCP-47 language code of this suggestion. Corresponds to the JSON property languageCode

Returns:

  • (String)


22908
22909
22910
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22908

def language_code
  @language_code
end

#suggestionString

Required. The suggestion text. Corresponds to the JSON property suggestion

Returns:

  • (String)


22913
22914
22915
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22913

def suggestion
  @suggestion
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22920
22921
22922
22923
22924
22925
22926
22927
22928
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22920

def update!(**args)
  @alternative_phrases = args[:alternative_phrases] if args.key?(:alternative_phrases)
  @frequency = args[:frequency] if args.key?(:frequency)
  @global_score = args[:global_score] if args.key?(:global_score)
  @group_id = args[:group_id] if args.key?(:group_id)
  @group_score = args[:group_score] if args.key?(:group_score)
  @language_code = args[:language_code] if args.key?(:language_code)
  @suggestion = args[:suggestion] if args.key?(:suggestion)
end