Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaControl
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaControl
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Defines a conditioned behavior to employ during serving. Must be attached to a
ServingConfig to be considered at serving time. Permitted actions dependent on
SolutionType.
Instance Attribute Summary collapse
-
#associated_serving_config_ids ⇒ Array<String>
Output only.
-
#boost_action ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaControlBoostAction
Adjusts order of products in returned list.
-
#conditions ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCondition>
Determines when the associated action will trigger.
-
#display_name ⇒ String
Required.
-
#filter_action ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaControlFilterAction
Specified which products may be included in results.
-
#name ⇒ String
Immutable.
-
#promote_action ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaControlPromoteAction
Promote certain links based on some trigger queries.
-
#redirect_action ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaControlRedirectAction
Redirects a shopper to the provided URI.
-
#solution_type ⇒ String
Required.
-
#synonyms_action ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaControlSynonymsAction
Creates a set of terms that will act as synonyms of one another.
-
#use_cases ⇒ Array<String>
Specifies the use case for the control.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaControl
constructor
A new instance of GoogleCloudDiscoveryengineV1betaControl.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaControl
Returns a new instance of GoogleCloudDiscoveryengineV1betaControl.
23261 23262 23263 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23261 def initialize(**args) update!(**args) end |
Instance Attribute Details
#associated_serving_config_ids ⇒ Array<String>
Output only. List of all ServingConfig IDs this control is attached to. May
take up to 10 minutes to update after changes.
Corresponds to the JSON property associatedServingConfigIds
23196 23197 23198 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23196 def associated_serving_config_ids @associated_serving_config_ids end |
#boost_action ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaControlBoostAction
Adjusts order of products in returned list.
Corresponds to the JSON property boostAction
23201 23202 23203 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23201 def boost_action @boost_action end |
#conditions ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCondition>
Determines when the associated action will trigger. Omit to always apply the
action. Currently only a single condition may be specified. Otherwise an
INVALID ARGUMENT error is thrown.
Corresponds to the JSON property conditions
23208 23209 23210 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23208 def conditions @conditions end |
#display_name ⇒ String
Required. Human readable name. The identifier used in UI views. Must be UTF-8
encoded string. Length limit is 128 characters. Otherwise an INVALID ARGUMENT
error is thrown.
Corresponds to the JSON property displayName
23215 23216 23217 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23215 def display_name @display_name end |
#filter_action ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaControlFilterAction
Specified which products may be included in results. Uses same filter as boost.
Corresponds to the JSON property filterAction
23220 23221 23222 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23220 def filter_action @filter_action end |
#name ⇒ String
Immutable. Fully qualified name projects/*/locations/global/dataStore/*/
controls/*
Corresponds to the JSON property name
23226 23227 23228 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23226 def name @name end |
#promote_action ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaControlPromoteAction
Promote certain links based on some trigger queries. Example: Promote shoe
store link when searching for shoe keyword. The link can be outside of
associated data store.
Corresponds to the JSON property promoteAction
23233 23234 23235 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23233 def promote_action @promote_action end |
#redirect_action ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaControlRedirectAction
Redirects a shopper to the provided URI.
Corresponds to the JSON property redirectAction
23238 23239 23240 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23238 def redirect_action @redirect_action end |
#solution_type ⇒ String
Required. Immutable. What solution the control belongs to. Must be compatible
with vertical of resource. Otherwise an INVALID ARGUMENT error is thrown.
Corresponds to the JSON property solutionType
23244 23245 23246 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23244 def solution_type @solution_type end |
#synonyms_action ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaControlSynonymsAction
Creates a set of terms that will act as synonyms of one another. Example: "
happy" will also be considered as "glad", "glad" will also be considered as "
happy".
Corresponds to the JSON property synonymsAction
23251 23252 23253 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23251 def synonyms_action @synonyms_action end |
#use_cases ⇒ Array<String>
Specifies the use case for the control. Affects what condition fields can be
set. Only applies to SOLUTION_TYPE_SEARCH. Currently only allow one use case
per control. Must be set when solution_type is SolutionType.
SOLUTION_TYPE_SEARCH.
Corresponds to the JSON property useCases
23259 23260 23261 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23259 def use_cases @use_cases end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23266 23267 23268 23269 23270 23271 23272 23273 23274 23275 23276 23277 23278 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23266 def update!(**args) @associated_serving_config_ids = args[:associated_serving_config_ids] if args.key?(:associated_serving_config_ids) @boost_action = args[:boost_action] if args.key?(:boost_action) @conditions = args[:conditions] if args.key?(:conditions) @display_name = args[:display_name] if args.key?(:display_name) @filter_action = args[:filter_action] if args.key?(:filter_action) @name = args[:name] if args.key?(:name) @promote_action = args[:promote_action] if args.key?(:promote_action) @redirect_action = args[:redirect_action] if args.key?(:redirect_action) @solution_type = args[:solution_type] if args.key?(:solution_type) @synonyms_action = args[:synonyms_action] if args.key?(:synonyms_action) @use_cases = args[:use_cases] if args.key?(:use_cases) end |