Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaControl
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaControl
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Defines a conditioned behavior to employ during serving. Must be attached to a
ServingConfig to be considered at serving time. Permitted actions dependent on
SolutionType.
Instance Attribute Summary collapse
-
#associated_serving_config_ids ⇒ Array<String>
Output only.
-
#boost_action ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaControlBoostAction
Adjusts order of products in returned list.
-
#conditions ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCondition>
Determines when the associated action will trigger.
-
#display_name ⇒ String
Required.
-
#filter_action ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaControlFilterAction
Specified which products may be included in results.
-
#name ⇒ String
Immutable.
-
#promote_action ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaControlPromoteAction
Promote certain links based on some trigger queries.
-
#redirect_action ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaControlRedirectAction
Redirects a shopper to the provided URI.
-
#solution_type ⇒ String
Required.
-
#synonyms_action ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaControlSynonymsAction
Creates a set of terms that will act as synonyms of one another.
-
#use_cases ⇒ Array<String>
Specifies the use case for the control.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaControl
constructor
A new instance of GoogleCloudDiscoveryengineV1betaControl.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaControl
Returns a new instance of GoogleCloudDiscoveryengineV1betaControl.
22449 22450 22451 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22449 def initialize(**args) update!(**args) end |
Instance Attribute Details
#associated_serving_config_ids ⇒ Array<String>
Output only. List of all ServingConfig IDs this control is attached to. May
take up to 10 minutes to update after changes.
Corresponds to the JSON property associatedServingConfigIds
22384 22385 22386 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22384 def associated_serving_config_ids @associated_serving_config_ids end |
#boost_action ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaControlBoostAction
Adjusts order of products in returned list.
Corresponds to the JSON property boostAction
22389 22390 22391 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22389 def boost_action @boost_action end |
#conditions ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCondition>
Determines when the associated action will trigger. Omit to always apply the
action. Currently only a single condition may be specified. Otherwise an
INVALID ARGUMENT error is thrown.
Corresponds to the JSON property conditions
22396 22397 22398 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22396 def conditions @conditions end |
#display_name ⇒ String
Required. Human readable name. The identifier used in UI views. Must be UTF-8
encoded string. Length limit is 128 characters. Otherwise an INVALID ARGUMENT
error is thrown.
Corresponds to the JSON property displayName
22403 22404 22405 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22403 def display_name @display_name end |
#filter_action ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaControlFilterAction
Specified which products may be included in results. Uses same filter as boost.
Corresponds to the JSON property filterAction
22408 22409 22410 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22408 def filter_action @filter_action end |
#name ⇒ String
Immutable. Fully qualified name projects/*/locations/global/dataStore/*/
controls/*
Corresponds to the JSON property name
22414 22415 22416 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22414 def name @name end |
#promote_action ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaControlPromoteAction
Promote certain links based on some trigger queries. Example: Promote shoe
store link when searching for shoe keyword. The link can be outside of
associated data store.
Corresponds to the JSON property promoteAction
22421 22422 22423 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22421 def promote_action @promote_action end |
#redirect_action ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaControlRedirectAction
Redirects a shopper to the provided URI.
Corresponds to the JSON property redirectAction
22426 22427 22428 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22426 def redirect_action @redirect_action end |
#solution_type ⇒ String
Required. Immutable. What solution the control belongs to. Must be compatible
with vertical of resource. Otherwise an INVALID ARGUMENT error is thrown.
Corresponds to the JSON property solutionType
22432 22433 22434 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22432 def solution_type @solution_type end |
#synonyms_action ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaControlSynonymsAction
Creates a set of terms that will act as synonyms of one another. Example: "
happy" will also be considered as "glad", "glad" will also be considered as "
happy".
Corresponds to the JSON property synonymsAction
22439 22440 22441 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22439 def synonyms_action @synonyms_action end |
#use_cases ⇒ Array<String>
Specifies the use case for the control. Affects what condition fields can be
set. Only applies to SOLUTION_TYPE_SEARCH. Currently only allow one use case
per control. Must be set when solution_type is SolutionType.
SOLUTION_TYPE_SEARCH.
Corresponds to the JSON property useCases
22447 22448 22449 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22447 def use_cases @use_cases end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22454 22455 22456 22457 22458 22459 22460 22461 22462 22463 22464 22465 22466 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22454 def update!(**args) @associated_serving_config_ids = args[:associated_serving_config_ids] if args.key?(:associated_serving_config_ids) @boost_action = args[:boost_action] if args.key?(:boost_action) @conditions = args[:conditions] if args.key?(:conditions) @display_name = args[:display_name] if args.key?(:display_name) @filter_action = args[:filter_action] if args.key?(:filter_action) @name = args[:name] if args.key?(:name) @promote_action = args[:promote_action] if args.key?(:promote_action) @redirect_action = args[:redirect_action] if args.key?(:redirect_action) @solution_type = args[:solution_type] if args.key?(:solution_type) @synonyms_action = args[:synonyms_action] if args.key?(:synonyms_action) @use_cases = args[:use_cases] if args.key?(:use_cases) end |