Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaControlBoostAction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Adjusts order of products in returned list.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaControlBoostAction

Returns a new instance of GoogleCloudDiscoveryengineV1betaControlBoostAction.



23183
23184
23185
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23183

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#boostFloat

Strength of the boost, which should be in [-1, 1]. Negative boost means demotion. Default is 0.0 (No-op). Corresponds to the JSON property boost

Returns:

  • (Float)


23153
23154
23155
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23153

def boost
  @boost
end

#data_storeString

Required. Specifies which data store's documents can be boosted by this control. Full data store name e.g. projects/123/locations/global/collections/ default_collection/dataStores/default_data_store Corresponds to the JSON property dataStore

Returns:

  • (String)


23160
23161
23162
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23160

def data_store
  @data_store
end

#filterString

Required. Specifies which products to apply the boost to. If no filter is provided all products will be boosted (No-op). Syntax documentation: https:// cloud.google.com/retail/docs/filter-and-order Maximum length is 5000 characters. Otherwise an INVALID ARGUMENT error is thrown. Corresponds to the JSON property filter

Returns:

  • (String)


23168
23169
23170
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23168

def filter
  @filter
end

#fixed_boostFloat

Optional. Strength of the boost, which should be in [-1, 1]. Negative boost means demotion. Default is 0.0 (No-op). Corresponds to the JSON property fixedBoost

Returns:

  • (Float)


23174
23175
23176
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23174

def fixed_boost
  @fixed_boost
end

#interpolation_boost_specGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaControlBoostActionInterpolationBoostSpec

Specification for custom ranking based on customer specified attribute value. It provides more controls for customized ranking than the simple (condition, boost) combination above. Corresponds to the JSON property interpolationBoostSpec



23181
23182
23183
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23181

def interpolation_boost_spec
  @interpolation_boost_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23188
23189
23190
23191
23192
23193
23194
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23188

def update!(**args)
  @boost = args[:boost] if args.key?(:boost)
  @data_store = args[:data_store] if args.key?(:data_store)
  @filter = args[:filter] if args.key?(:filter)
  @fixed_boost = args[:fixed_boost] if args.key?(:fixed_boost)
  @interpolation_boost_spec = args[:interpolation_boost_spec] if args.key?(:interpolation_boost_spec)
end