Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaControlBoostAction
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaControlBoostAction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Adjusts order of products in returned list.
Instance Attribute Summary collapse
-
#boost ⇒ Float
Strength of the boost, which should be in [-1, 1].
-
#data_store ⇒ String
Required.
-
#filter ⇒ String
Required.
-
#fixed_boost ⇒ Float
Optional.
-
#interpolation_boost_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaControlBoostActionInterpolationBoostSpec
Specification for custom ranking based on customer specified attribute value.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaControlBoostAction
constructor
A new instance of GoogleCloudDiscoveryengineV1betaControlBoostAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaControlBoostAction
Returns a new instance of GoogleCloudDiscoveryengineV1betaControlBoostAction.
23152 23153 23154 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23152 def initialize(**args) update!(**args) end |
Instance Attribute Details
#boost ⇒ Float
Strength of the boost, which should be in [-1, 1]. Negative boost means
demotion. Default is 0.0 (No-op).
Corresponds to the JSON property boost
23122 23123 23124 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23122 def boost @boost end |
#data_store ⇒ String
Required. Specifies which data store's documents can be boosted by this
control. Full data store name e.g. projects/123/locations/global/collections/
default_collection/dataStores/default_data_store
Corresponds to the JSON property dataStore
23129 23130 23131 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23129 def data_store @data_store end |
#filter ⇒ String
Required. Specifies which products to apply the boost to. If no filter is
provided all products will be boosted (No-op). Syntax documentation: https://
cloud.google.com/retail/docs/filter-and-order Maximum length is 5000
characters. Otherwise an INVALID ARGUMENT error is thrown.
Corresponds to the JSON property filter
23137 23138 23139 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23137 def filter @filter end |
#fixed_boost ⇒ Float
Optional. Strength of the boost, which should be in [-1, 1]. Negative boost
means demotion. Default is 0.0 (No-op).
Corresponds to the JSON property fixedBoost
23143 23144 23145 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23143 def fixed_boost @fixed_boost end |
#interpolation_boost_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaControlBoostActionInterpolationBoostSpec
Specification for custom ranking based on customer specified attribute value.
It provides more controls for customized ranking than the simple (condition,
boost) combination above.
Corresponds to the JSON property interpolationBoostSpec
23150 23151 23152 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23150 def interpolation_boost_spec @interpolation_boost_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23157 23158 23159 23160 23161 23162 23163 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23157 def update!(**args) @boost = args[:boost] if args.key?(:boost) @data_store = args[:data_store] if args.key?(:data_store) @filter = args[:filter] if args.key?(:filter) @fixed_boost = args[:fixed_boost] if args.key?(:fixed_boost) @interpolation_boost_spec = args[:interpolation_boost_spec] if args.key?(:interpolation_boost_spec) end |