Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaControlBoostActionInterpolationBoostSpec
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaControlBoostActionInterpolationBoostSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Specification for custom ranking based on customer specified attribute value. It provides more controls for customized ranking than the simple (condition, boost) combination above.
Instance Attribute Summary collapse
-
#attribute_type ⇒ String
Optional.
-
#control_points ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaControlBoostActionInterpolationBoostSpecControlPoint>
Optional.
-
#field_name ⇒ String
Optional.
-
#interpolation_type ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaControlBoostActionInterpolationBoostSpec
constructor
A new instance of GoogleCloudDiscoveryengineV1betaControlBoostActionInterpolationBoostSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaControlBoostActionInterpolationBoostSpec
Returns a new instance of GoogleCloudDiscoveryengineV1betaControlBoostActionInterpolationBoostSpec.
22351 22352 22353 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22351 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attribute_type ⇒ String
Optional. The attribute type to be used to determine the boost amount. The
attribute value can be derived from the field value of the specified
field_name. In the case of numerical it is straightforward i.e.
attribute_value = numerical_field_value. In the case of freshness however,
attribute_value = (time.now() - datetime_field_value).
Corresponds to the JSON property attributeType
22330 22331 22332 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22330 def attribute_type @attribute_type end |
#control_points ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaControlBoostActionInterpolationBoostSpecControlPoint>
Optional. The control points used to define the curve. The monotonic function (
defined through the interpolation_type above) passes through the control
points listed here.
Corresponds to the JSON property controlPoints
22337 22338 22339 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22337 def control_points @control_points end |
#field_name ⇒ String
Optional. The name of the field whose value will be used to determine the
boost amount.
Corresponds to the JSON property fieldName
22343 22344 22345 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22343 def field_name @field_name end |
#interpolation_type ⇒ String
Optional. The interpolation type to be applied to connect the control points
listed below.
Corresponds to the JSON property interpolationType
22349 22350 22351 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22349 def interpolation_type @interpolation_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22356 22357 22358 22359 22360 22361 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22356 def update!(**args) @attribute_type = args[:attribute_type] if args.key?(:attribute_type) @control_points = args[:control_points] if args.key?(:control_points) @field_name = args[:field_name] if args.key?(:field_name) @interpolation_type = args[:interpolation_type] if args.key?(:interpolation_type) end |