Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaControlBoostActionInterpolationBoostSpecControlPoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

The control points used to define the curve. The curve defined through these control points can only be monotonically increasing or decreasing(constant values are acceptable).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaControlBoostActionInterpolationBoostSpecControlPoint

Returns a new instance of GoogleCloudDiscoveryengineV1betaControlBoostActionInterpolationBoostSpecControlPoint.



22384
22385
22386
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22384

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attribute_valueString

Optional. Can be one of: 1. The numerical field value. 2. The duration spec for freshness: The value must be formatted as an XSD dayTimeDuration value ( a restricted subset of an ISO 8601 duration value). The pattern for this is: nDnM]. Corresponds to the JSON property attributeValue

Returns:

  • (String)


22376
22377
22378
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22376

def attribute_value
  @attribute_value
end

#boost_amountFloat

Optional. The value between -1 to 1 by which to boost the score if the attribute_value evaluates to the value specified above. Corresponds to the JSON property boostAmount

Returns:

  • (Float)


22382
22383
22384
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22382

def boost_amount
  @boost_amount
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22389
22390
22391
22392
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 22389

def update!(**args)
  @attribute_value = args[:attribute_value] if args.key?(:attribute_value)
  @boost_amount = args[:boost_amount] if args.key?(:boost_amount)
end