Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDataStore
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDataStore
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
DataStore captures global settings and configs at the DataStore level.
Instance Attribute Summary collapse
-
#acl_enabled ⇒ Boolean
(also: #acl_enabled?)
Immutable.
-
#advanced_site_search_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAdvancedSiteSearchConfig
Configuration data for advance site search.
-
#billing_estimation ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDataStoreBillingEstimation
Estimation of data size per data store.
-
#cmek_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCmekConfig
Configurations used to enable CMEK data encryption with Cloud KMS keys.
-
#configurable_billing_approach ⇒ String
Optional.
-
#configurable_billing_approach_update_time ⇒ String
Output only.
-
#content_config ⇒ String
Immutable.
-
#create_time ⇒ String
Output only.
-
#default_schema_id ⇒ String
Output only.
-
#display_name ⇒ String
Required.
-
#document_processing_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocumentProcessingConfig
A singleton resource of DataStore.
-
#federated_search_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDataStoreFederatedSearchConfig
Stores information for federated search.
-
#healthcare_fhir_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaHealthcareFhirConfig
Config to data store for
HEALTHCARE_FHIRvertical. -
#identity_mapping_store ⇒ String
Immutable.
-
#industry_vertical ⇒ String
Immutable.
-
#is_infobot_faq_data_store ⇒ Boolean
(also: #is_infobot_faq_data_store?)
Optional.
-
#kms_key_name ⇒ String
Input only.
-
#language_info ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaLanguageInfo
Language info for DataStore.
-
#name ⇒ String
Immutable.
-
#natural_language_query_understanding_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaNaturalLanguageQueryUnderstandingConfig
Configuration for Natural Language Query Understanding.
-
#serving_config_data_store ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDataStoreServingConfigDataStore
Stores information regarding the serving configurations at DataStore level.
-
#solution_types ⇒ Array<String>
The solutions that the data store enrolls.
-
#starting_schema ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSchema
Defines the structure and layout of a type of document data.
-
#workspace_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaWorkspaceConfig
Config to store data store type configuration for workspace data Corresponds to the JSON property
workspaceConfig.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaDataStore
constructor
A new instance of GoogleCloudDiscoveryengineV1betaDataStore.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaDataStore
Returns a new instance of GoogleCloudDiscoveryengineV1betaDataStore.
23172 23173 23174 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23172 def initialize(**args) update!(**args) end |
Instance Attribute Details
#acl_enabled ⇒ Boolean Also known as: acl_enabled?
Immutable. Whether data in the DataStore has ACL information. If set to true,
the source data must have ACL. ACL will be ingested when data is ingested by
DocumentService.ImportDocuments methods. When ACL is enabled for the DataStore,
Document can't be accessed by calling DocumentService.GetDocument or
DocumentService.ListDocuments. Currently ACL is only supported in GENERIC
industry vertical with non-PUBLIC_WEBSITE content config.
Corresponds to the JSON property aclEnabled
23036 23037 23038 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23036 def acl_enabled @acl_enabled end |
#advanced_site_search_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAdvancedSiteSearchConfig
Configuration data for advance site search.
Corresponds to the JSON property advancedSiteSearchConfig
23042 23043 23044 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23042 def advanced_site_search_config @advanced_site_search_config end |
#billing_estimation ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDataStoreBillingEstimation
Estimation of data size per data store.
Corresponds to the JSON property billingEstimation
23047 23048 23049 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23047 def billing_estimation @billing_estimation end |
#cmek_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCmekConfig
Configurations used to enable CMEK data encryption with Cloud KMS keys.
Corresponds to the JSON property cmekConfig
23052 23053 23054 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23052 def cmek_config @cmek_config end |
#configurable_billing_approach ⇒ String
Optional. Configuration for configurable billing approach. See
Corresponds to the JSON property configurableBillingApproach
23057 23058 23059 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23057 def configurable_billing_approach @configurable_billing_approach end |
#configurable_billing_approach_update_time ⇒ String
Output only. The timestamp when configurable_billing_approach was last updated.
Corresponds to the JSON property configurableBillingApproachUpdateTime
23062 23063 23064 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23062 def configurable_billing_approach_update_time @configurable_billing_approach_update_time end |
#content_config ⇒ String
Immutable. The content config of the data store. If this field is unset, the
server behavior defaults to ContentConfig.NO_CONTENT.
Corresponds to the JSON property contentConfig
23068 23069 23070 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23068 def content_config @content_config end |
#create_time ⇒ String
Output only. Timestamp the DataStore was created at.
Corresponds to the JSON property createTime
23073 23074 23075 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23073 def create_time @create_time end |
#default_schema_id ⇒ String
Output only. The id of the default Schema associated to this data store.
Corresponds to the JSON property defaultSchemaId
23078 23079 23080 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23078 def default_schema_id @default_schema_id end |
#display_name ⇒ String
Required. The data store display name. This field must be a UTF-8 encoded
string with a length limit of 128 characters. Otherwise, an INVALID_ARGUMENT
error is returned.
Corresponds to the JSON property displayName
23085 23086 23087 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23085 def display_name @display_name end |
#document_processing_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocumentProcessingConfig
A singleton resource of DataStore. If it's empty when DataStore is created and
DataStore is set to DataStore.ContentConfig.CONTENT_REQUIRED, the default
parser will default to digital parser.
Corresponds to the JSON property documentProcessingConfig
23092 23093 23094 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23092 def document_processing_config @document_processing_config end |
#federated_search_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDataStoreFederatedSearchConfig
Stores information for federated search.
Corresponds to the JSON property federatedSearchConfig
23097 23098 23099 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23097 def federated_search_config @federated_search_config end |
#healthcare_fhir_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaHealthcareFhirConfig
Config to data store for HEALTHCARE_FHIR vertical.
Corresponds to the JSON property healthcareFhirConfig
23102 23103 23104 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23102 def healthcare_fhir_config @healthcare_fhir_config end |
#identity_mapping_store ⇒ String
Immutable. The fully qualified resource name of the associated
IdentityMappingStore. This field can only be set for acl_enabled DataStores
with THIRD_PARTY or GSUITE IdP. Format: projects/project/locations/
location/identityMappingStores/identity_mapping_store`.
Corresponds to the JSON propertyidentityMappingStore`
23110 23111 23112 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23110 def identity_mapping_store @identity_mapping_store end |
#industry_vertical ⇒ String
Immutable. The industry vertical that the data store registers.
Corresponds to the JSON property industryVertical
23115 23116 23117 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23115 def industry_vertical @industry_vertical end |
#is_infobot_faq_data_store ⇒ Boolean Also known as: is_infobot_faq_data_store?
Optional. If set, this DataStore is an Infobot FAQ DataStore.
Corresponds to the JSON property isInfobotFaqDataStore
23120 23121 23122 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23120 def is_infobot_faq_data_store @is_infobot_faq_data_store end |
#kms_key_name ⇒ String
Input only. The KMS key to be used to protect this DataStore at creation time.
Must be set for requests that need to comply with CMEK Org Policy protections.
If this field is set and processed successfully, the DataStore will be
protected by the KMS key, as indicated in the cmek_config field.
Corresponds to the JSON property kmsKeyName
23129 23130 23131 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23129 def kms_key_name @kms_key_name end |
#language_info ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaLanguageInfo
Language info for DataStore.
Corresponds to the JSON property languageInfo
23134 23135 23136 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23134 def language_info @language_info end |
#name ⇒ String
Immutable. Identifier. The full resource name of the data store. Format:
projects/project/locations/location/collections/collection_id/dataStores/
data_store_id`. This field must be a UTF-8 encoded string with a length
limit of 1024 characters.
Corresponds to the JSON propertyname`
23142 23143 23144 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23142 def name @name end |
#natural_language_query_understanding_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaNaturalLanguageQueryUnderstandingConfig
Configuration for Natural Language Query Understanding.
Corresponds to the JSON property naturalLanguageQueryUnderstandingConfig
23147 23148 23149 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23147 def natural_language_query_understanding_config @natural_language_query_understanding_config end |
#serving_config_data_store ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDataStoreServingConfigDataStore
Stores information regarding the serving configurations at DataStore level.
Corresponds to the JSON property servingConfigDataStore
23152 23153 23154 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23152 def serving_config_data_store @serving_config_data_store end |
#solution_types ⇒ Array<String>
The solutions that the data store enrolls. Available solutions for each
industry_vertical: * MEDIA: SOLUTION_TYPE_RECOMMENDATION and
SOLUTION_TYPE_SEARCH. * SITE_SEARCH: SOLUTION_TYPE_SEARCH is
automatically enrolled. Other solutions cannot be enrolled.
Corresponds to the JSON property solutionTypes
23160 23161 23162 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23160 def solution_types @solution_types end |
#starting_schema ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSchema
Defines the structure and layout of a type of document data.
Corresponds to the JSON property startingSchema
23165 23166 23167 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23165 def starting_schema @starting_schema end |
#workspace_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaWorkspaceConfig
Config to store data store type configuration for workspace data
Corresponds to the JSON property workspaceConfig
23170 23171 23172 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23170 def workspace_config @workspace_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23177 23178 23179 23180 23181 23182 23183 23184 23185 23186 23187 23188 23189 23190 23191 23192 23193 23194 23195 23196 23197 23198 23199 23200 23201 23202 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23177 def update!(**args) @acl_enabled = args[:acl_enabled] if args.key?(:acl_enabled) @advanced_site_search_config = args[:advanced_site_search_config] if args.key?(:advanced_site_search_config) @billing_estimation = args[:billing_estimation] if args.key?(:billing_estimation) @cmek_config = args[:cmek_config] if args.key?(:cmek_config) @configurable_billing_approach = args[:configurable_billing_approach] if args.key?(:configurable_billing_approach) @configurable_billing_approach_update_time = args[:configurable_billing_approach_update_time] if args.key?(:configurable_billing_approach_update_time) @content_config = args[:content_config] if args.key?(:content_config) @create_time = args[:create_time] if args.key?(:create_time) @default_schema_id = args[:default_schema_id] if args.key?(:default_schema_id) @display_name = args[:display_name] if args.key?(:display_name) @document_processing_config = args[:document_processing_config] if args.key?(:document_processing_config) @federated_search_config = args[:federated_search_config] if args.key?(:federated_search_config) @healthcare_fhir_config = args[:healthcare_fhir_config] if args.key?(:healthcare_fhir_config) @identity_mapping_store = args[:identity_mapping_store] if args.key?(:identity_mapping_store) @industry_vertical = args[:industry_vertical] if args.key?(:industry_vertical) @is_infobot_faq_data_store = args[:is_infobot_faq_data_store] if args.key?(:is_infobot_faq_data_store) @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name) @language_info = args[:language_info] if args.key?(:language_info) @name = args[:name] if args.key?(:name) @natural_language_query_understanding_config = args[:natural_language_query_understanding_config] if args.key?(:natural_language_query_understanding_config) @serving_config_data_store = args[:serving_config_data_store] if args.key?(:serving_config_data_store) @solution_types = args[:solution_types] if args.key?(:solution_types) @starting_schema = args[:starting_schema] if args.key?(:starting_schema) @workspace_config = args[:workspace_config] if args.key?(:workspace_config) end |