Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDataStoreBillingEstimation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Estimation of data size per data store.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaDataStoreBillingEstimation

Returns a new instance of GoogleCloudDiscoveryengineV1betaDataStoreBillingEstimation.



24255
24256
24257
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24255

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#structured_data_sizeFixnum

Data size for structured data in terms of bytes. Corresponds to the JSON property structuredDataSize

Returns:

  • (Fixnum)


24228
24229
24230
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24228

def structured_data_size
  @structured_data_size
end

#structured_data_update_timeString

Last updated timestamp for structured data. Corresponds to the JSON property structuredDataUpdateTime

Returns:

  • (String)


24233
24234
24235
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24233

def structured_data_update_time
  @structured_data_update_time
end

#unstructured_data_sizeFixnum

Data size for unstructured data in terms of bytes. Corresponds to the JSON property unstructuredDataSize

Returns:

  • (Fixnum)


24238
24239
24240
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24238

def unstructured_data_size
  @unstructured_data_size
end

#unstructured_data_update_timeString

Last updated timestamp for unstructured data. Corresponds to the JSON property unstructuredDataUpdateTime

Returns:

  • (String)


24243
24244
24245
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24243

def unstructured_data_update_time
  @unstructured_data_update_time
end

#website_data_sizeFixnum

Data size for websites in terms of bytes. Corresponds to the JSON property websiteDataSize

Returns:

  • (Fixnum)


24248
24249
24250
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24248

def website_data_size
  @website_data_size
end

#website_data_update_timeString

Last updated timestamp for websites. Corresponds to the JSON property websiteDataUpdateTime

Returns:

  • (String)


24253
24254
24255
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24253

def website_data_update_time
  @website_data_update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24260
24261
24262
24263
24264
24265
24266
24267
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24260

def update!(**args)
  @structured_data_size = args[:structured_data_size] if args.key?(:structured_data_size)
  @structured_data_update_time = args[:structured_data_update_time] if args.key?(:structured_data_update_time)
  @unstructured_data_size = args[:unstructured_data_size] if args.key?(:unstructured_data_size)
  @unstructured_data_update_time = args[:unstructured_data_update_time] if args.key?(:unstructured_data_update_time)
  @website_data_size = args[:website_data_size] if args.key?(:website_data_size)
  @website_data_update_time = args[:website_data_update_time] if args.key?(:website_data_update_time)
end