Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDataStoreBillingEstimation
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDataStoreBillingEstimation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Estimation of data size per data store.
Instance Attribute Summary collapse
-
#structured_data_size ⇒ Fixnum
Data size for structured data in terms of bytes.
-
#structured_data_update_time ⇒ String
Last updated timestamp for structured data.
-
#unstructured_data_size ⇒ Fixnum
Data size for unstructured data in terms of bytes.
-
#unstructured_data_update_time ⇒ String
Last updated timestamp for unstructured data.
-
#website_data_size ⇒ Fixnum
Data size for websites in terms of bytes.
-
#website_data_update_time ⇒ String
Last updated timestamp for websites.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaDataStoreBillingEstimation
constructor
A new instance of GoogleCloudDiscoveryengineV1betaDataStoreBillingEstimation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaDataStoreBillingEstimation
Returns a new instance of GoogleCloudDiscoveryengineV1betaDataStoreBillingEstimation.
24119 24120 24121 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24119 def initialize(**args) update!(**args) end |
Instance Attribute Details
#structured_data_size ⇒ Fixnum
Data size for structured data in terms of bytes.
Corresponds to the JSON property structuredDataSize
24092 24093 24094 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24092 def structured_data_size @structured_data_size end |
#structured_data_update_time ⇒ String
Last updated timestamp for structured data.
Corresponds to the JSON property structuredDataUpdateTime
24097 24098 24099 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24097 def structured_data_update_time @structured_data_update_time end |
#unstructured_data_size ⇒ Fixnum
Data size for unstructured data in terms of bytes.
Corresponds to the JSON property unstructuredDataSize
24102 24103 24104 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24102 def unstructured_data_size @unstructured_data_size end |
#unstructured_data_update_time ⇒ String
Last updated timestamp for unstructured data.
Corresponds to the JSON property unstructuredDataUpdateTime
24107 24108 24109 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24107 def unstructured_data_update_time @unstructured_data_update_time end |
#website_data_size ⇒ Fixnum
Data size for websites in terms of bytes.
Corresponds to the JSON property websiteDataSize
24112 24113 24114 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24112 def website_data_size @website_data_size end |
#website_data_update_time ⇒ String
Last updated timestamp for websites.
Corresponds to the JSON property websiteDataUpdateTime
24117 24118 24119 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24117 def website_data_update_time @website_data_update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24124 24125 24126 24127 24128 24129 24130 24131 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24124 def update!(**args) @structured_data_size = args[:structured_data_size] if args.key?(:structured_data_size) @structured_data_update_time = args[:structured_data_update_time] if args.key?(:structured_data_update_time) @unstructured_data_size = args[:unstructured_data_size] if args.key?(:unstructured_data_size) @unstructured_data_update_time = args[:unstructured_data_update_time] if args.key?(:unstructured_data_update_time) @website_data_size = args[:website_data_size] if args.key?(:website_data_size) @website_data_update_time = args[:website_data_update_time] if args.key?(:website_data_update_time) end |