Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDataStoreBillingEstimation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Estimation of data size per data store.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaDataStoreBillingEstimation

Returns a new instance of GoogleCloudDiscoveryengineV1betaDataStoreBillingEstimation.



24088
24089
24090
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24088

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#structured_data_sizeFixnum

Data size for structured data in terms of bytes. Corresponds to the JSON property structuredDataSize

Returns:

  • (Fixnum)


24061
24062
24063
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24061

def structured_data_size
  @structured_data_size
end

#structured_data_update_timeString

Last updated timestamp for structured data. Corresponds to the JSON property structuredDataUpdateTime

Returns:

  • (String)


24066
24067
24068
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24066

def structured_data_update_time
  @structured_data_update_time
end

#unstructured_data_sizeFixnum

Data size for unstructured data in terms of bytes. Corresponds to the JSON property unstructuredDataSize

Returns:

  • (Fixnum)


24071
24072
24073
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24071

def unstructured_data_size
  @unstructured_data_size
end

#unstructured_data_update_timeString

Last updated timestamp for unstructured data. Corresponds to the JSON property unstructuredDataUpdateTime

Returns:

  • (String)


24076
24077
24078
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24076

def unstructured_data_update_time
  @unstructured_data_update_time
end

#website_data_sizeFixnum

Data size for websites in terms of bytes. Corresponds to the JSON property websiteDataSize

Returns:

  • (Fixnum)


24081
24082
24083
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24081

def website_data_size
  @website_data_size
end

#website_data_update_timeString

Last updated timestamp for websites. Corresponds to the JSON property websiteDataUpdateTime

Returns:

  • (String)


24086
24087
24088
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24086

def website_data_update_time
  @website_data_update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24093
24094
24095
24096
24097
24098
24099
24100
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24093

def update!(**args)
  @structured_data_size = args[:structured_data_size] if args.key?(:structured_data_size)
  @structured_data_update_time = args[:structured_data_update_time] if args.key?(:structured_data_update_time)
  @unstructured_data_size = args[:unstructured_data_size] if args.key?(:unstructured_data_size)
  @unstructured_data_update_time = args[:unstructured_data_update_time] if args.key?(:unstructured_data_update_time)
  @website_data_size = args[:website_data_size] if args.key?(:website_data_size)
  @website_data_update_time = args[:website_data_update_time] if args.key?(:website_data_update_time)
end