Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDataStoreBillingEstimation
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDataStoreBillingEstimation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Estimation of data size per data store.
Instance Attribute Summary collapse
-
#structured_data_size ⇒ Fixnum
Data size for structured data in terms of bytes.
-
#structured_data_update_time ⇒ String
Last updated timestamp for structured data.
-
#unstructured_data_size ⇒ Fixnum
Data size for unstructured data in terms of bytes.
-
#unstructured_data_update_time ⇒ String
Last updated timestamp for unstructured data.
-
#website_data_size ⇒ Fixnum
Data size for websites in terms of bytes.
-
#website_data_update_time ⇒ String
Last updated timestamp for websites.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaDataStoreBillingEstimation
constructor
A new instance of GoogleCloudDiscoveryengineV1betaDataStoreBillingEstimation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaDataStoreBillingEstimation
Returns a new instance of GoogleCloudDiscoveryengineV1betaDataStoreBillingEstimation.
23443 23444 23445 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23443 def initialize(**args) update!(**args) end |
Instance Attribute Details
#structured_data_size ⇒ Fixnum
Data size for structured data in terms of bytes.
Corresponds to the JSON property structuredDataSize
23416 23417 23418 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23416 def structured_data_size @structured_data_size end |
#structured_data_update_time ⇒ String
Last updated timestamp for structured data.
Corresponds to the JSON property structuredDataUpdateTime
23421 23422 23423 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23421 def structured_data_update_time @structured_data_update_time end |
#unstructured_data_size ⇒ Fixnum
Data size for unstructured data in terms of bytes.
Corresponds to the JSON property unstructuredDataSize
23426 23427 23428 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23426 def unstructured_data_size @unstructured_data_size end |
#unstructured_data_update_time ⇒ String
Last updated timestamp for unstructured data.
Corresponds to the JSON property unstructuredDataUpdateTime
23431 23432 23433 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23431 def unstructured_data_update_time @unstructured_data_update_time end |
#website_data_size ⇒ Fixnum
Data size for websites in terms of bytes.
Corresponds to the JSON property websiteDataSize
23436 23437 23438 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23436 def website_data_size @website_data_size end |
#website_data_update_time ⇒ String
Last updated timestamp for websites.
Corresponds to the JSON property websiteDataUpdateTime
23441 23442 23443 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23441 def website_data_update_time @website_data_update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23448 23449 23450 23451 23452 23453 23454 23455 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23448 def update!(**args) @structured_data_size = args[:structured_data_size] if args.key?(:structured_data_size) @structured_data_update_time = args[:structured_data_update_time] if args.key?(:structured_data_update_time) @unstructured_data_size = args[:unstructured_data_size] if args.key?(:unstructured_data_size) @unstructured_data_update_time = args[:unstructured_data_update_time] if args.key?(:unstructured_data_update_time) @website_data_size = args[:website_data_size] if args.key?(:website_data_size) @website_data_update_time = args[:website_data_update_time] if args.key?(:website_data_update_time) end |