Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDataStoreFederatedSearchConfigAlloyDbConfigAlloyDbConnectionConfig
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDataStoreFederatedSearchConfigAlloyDbConfigAlloyDbConnectionConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Configuration for connecting to AlloyDB.
Instance Attribute Summary collapse
-
#auth_mode ⇒ String
Optional.
-
#database ⇒ String
Required.
-
#enable_psvs ⇒ Boolean
(also: #enable_psvs?)
Optional.
-
#instance ⇒ String
Required.
-
#password ⇒ String
Required.
-
#user ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaDataStoreFederatedSearchConfigAlloyDbConfigAlloyDbConnectionConfig
constructor
A new instance of GoogleCloudDiscoveryengineV1betaDataStoreFederatedSearchConfigAlloyDbConfigAlloyDbConnectionConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaDataStoreFederatedSearchConfigAlloyDbConfigAlloyDbConnectionConfig
Returns a new instance of GoogleCloudDiscoveryengineV1betaDataStoreFederatedSearchConfigAlloyDbConfigAlloyDbConnectionConfig.
24280 24281 24282 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24280 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auth_mode ⇒ String
Optional. Auth mode.
Corresponds to the JSON property authMode
24248 24249 24250 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24248 def auth_mode @auth_mode end |
#database ⇒ String
Required. The AlloyDB database to connect to.
Corresponds to the JSON property database
24253 24254 24255 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24253 def database @database end |
#enable_psvs ⇒ Boolean Also known as: enable_psvs?
Optional. If true, enable PSVS for AlloyDB.
Corresponds to the JSON property enablePsvs
24258 24259 24260 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24258 def enable_psvs @enable_psvs end |
#instance ⇒ String
Required. The AlloyDB instance to connect to.
Corresponds to the JSON property instance
24264 24265 24266 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24264 def instance @instance end |
#password ⇒ String
Required. Database password. If auth_mode = END_USER_ACCOUNT, it can be unset.
In that case, the password will be inferred on the AlloyDB side, based on the
authenticated user.
Corresponds to the JSON property password
24271 24272 24273 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24271 def password @password end |
#user ⇒ String
Required. Database user. If auth_mode = END_USER_ACCOUNT, it can be unset. In
that case, the user will be inferred on the AlloyDB side, based on the
authenticated user.
Corresponds to the JSON property user
24278 24279 24280 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24278 def user @user end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24285 24286 24287 24288 24289 24290 24291 24292 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24285 def update!(**args) @auth_mode = args[:auth_mode] if args.key?(:auth_mode) @database = args[:database] if args.key?(:database) @enable_psvs = args[:enable_psvs] if args.key?(:enable_psvs) @instance = args[:instance] if args.key?(:instance) @password = args[:password] if args.key?(:password) @user = args[:user] if args.key?(:user) end |