Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDataStoreFederatedSearchConfigAlloyDbConfigAlloyDbConnectionConfig
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDataStoreFederatedSearchConfigAlloyDbConfigAlloyDbConnectionConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Configuration for connecting to AlloyDB.
Instance Attribute Summary collapse
-
#auth_mode ⇒ String
Optional.
-
#database ⇒ String
Required.
-
#enable_psvs ⇒ Boolean
(also: #enable_psvs?)
Optional.
-
#instance ⇒ String
Required.
-
#password ⇒ String
Required.
-
#user ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaDataStoreFederatedSearchConfigAlloyDbConfigAlloyDbConnectionConfig
constructor
A new instance of GoogleCloudDiscoveryengineV1betaDataStoreFederatedSearchConfigAlloyDbConfigAlloyDbConnectionConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaDataStoreFederatedSearchConfigAlloyDbConfigAlloyDbConnectionConfig
Returns a new instance of GoogleCloudDiscoveryengineV1betaDataStoreFederatedSearchConfigAlloyDbConfigAlloyDbConnectionConfig.
24256 24257 24258 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24256 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auth_mode ⇒ String
Optional. Auth mode.
Corresponds to the JSON property authMode
24224 24225 24226 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24224 def auth_mode @auth_mode end |
#database ⇒ String
Required. The AlloyDB database to connect to.
Corresponds to the JSON property database
24229 24230 24231 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24229 def database @database end |
#enable_psvs ⇒ Boolean Also known as: enable_psvs?
Optional. If true, enable PSVS for AlloyDB.
Corresponds to the JSON property enablePsvs
24234 24235 24236 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24234 def enable_psvs @enable_psvs end |
#instance ⇒ String
Required. The AlloyDB instance to connect to.
Corresponds to the JSON property instance
24240 24241 24242 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24240 def instance @instance end |
#password ⇒ String
Required. Database password. If auth_mode = END_USER_ACCOUNT, it can be unset.
In that case, the password will be inferred on the AlloyDB side, based on the
authenticated user.
Corresponds to the JSON property password
24247 24248 24249 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24247 def password @password end |
#user ⇒ String
Required. Database user. If auth_mode = END_USER_ACCOUNT, it can be unset. In
that case, the user will be inferred on the AlloyDB side, based on the
authenticated user.
Corresponds to the JSON property user
24254 24255 24256 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24254 def user @user end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24261 24262 24263 24264 24265 24266 24267 24268 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24261 def update!(**args) @auth_mode = args[:auth_mode] if args.key?(:auth_mode) @database = args[:database] if args.key?(:database) @enable_psvs = args[:enable_psvs] if args.key?(:enable_psvs) @instance = args[:instance] if args.key?(:instance) @password = args[:password] if args.key?(:password) @user = args[:user] if args.key?(:user) end |