Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDataStoreFederatedSearchConfigAlloyDbConfigAlloyDbConnectionConfig
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDataStoreFederatedSearchConfigAlloyDbConfigAlloyDbConnectionConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Configuration for connecting to AlloyDB.
Instance Attribute Summary collapse
-
#auth_mode ⇒ String
Optional.
-
#database ⇒ String
Required.
-
#enable_psvs ⇒ Boolean
(also: #enable_psvs?)
Optional.
-
#instance ⇒ String
Required.
-
#password ⇒ String
Required.
-
#user ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaDataStoreFederatedSearchConfigAlloyDbConfigAlloyDbConnectionConfig
constructor
A new instance of GoogleCloudDiscoveryengineV1betaDataStoreFederatedSearchConfigAlloyDbConfigAlloyDbConnectionConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaDataStoreFederatedSearchConfigAlloyDbConfigAlloyDbConnectionConfig
Returns a new instance of GoogleCloudDiscoveryengineV1betaDataStoreFederatedSearchConfigAlloyDbConfigAlloyDbConnectionConfig.
24225 24226 24227 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24225 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auth_mode ⇒ String
Optional. Auth mode.
Corresponds to the JSON property authMode
24193 24194 24195 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24193 def auth_mode @auth_mode end |
#database ⇒ String
Required. The AlloyDB database to connect to.
Corresponds to the JSON property database
24198 24199 24200 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24198 def database @database end |
#enable_psvs ⇒ Boolean Also known as: enable_psvs?
Optional. If true, enable PSVS for AlloyDB.
Corresponds to the JSON property enablePsvs
24203 24204 24205 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24203 def enable_psvs @enable_psvs end |
#instance ⇒ String
Required. The AlloyDB instance to connect to.
Corresponds to the JSON property instance
24209 24210 24211 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24209 def instance @instance end |
#password ⇒ String
Required. Database password. If auth_mode = END_USER_ACCOUNT, it can be unset.
In that case, the password will be inferred on the AlloyDB side, based on the
authenticated user.
Corresponds to the JSON property password
24216 24217 24218 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24216 def password @password end |
#user ⇒ String
Required. Database user. If auth_mode = END_USER_ACCOUNT, it can be unset. In
that case, the user will be inferred on the AlloyDB side, based on the
authenticated user.
Corresponds to the JSON property user
24223 24224 24225 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24223 def user @user end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24230 24231 24232 24233 24234 24235 24236 24237 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24230 def update!(**args) @auth_mode = args[:auth_mode] if args.key?(:auth_mode) @database = args[:database] if args.key?(:database) @enable_psvs = args[:enable_psvs] if args.key?(:enable_psvs) @instance = args[:instance] if args.key?(:instance) @password = args[:password] if args.key?(:password) @user = args[:user] if args.key?(:user) end |