Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDataStoreFederatedSearchConfigAlloyDbConfigAlloyDbConnectionConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Configuration for connecting to AlloyDB.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaDataStoreFederatedSearchConfigAlloyDbConfigAlloyDbConnectionConfig

Returns a new instance of GoogleCloudDiscoveryengineV1betaDataStoreFederatedSearchConfigAlloyDbConfigAlloyDbConnectionConfig.



23376
23377
23378
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23376

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auth_modeString

Optional. Auth mode. Corresponds to the JSON property authMode

Returns:

  • (String)


23344
23345
23346
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23344

def auth_mode
  @auth_mode
end

#databaseString

Required. The AlloyDB database to connect to. Corresponds to the JSON property database

Returns:

  • (String)


23349
23350
23351
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23349

def database
  @database
end

#enable_psvsBoolean Also known as: enable_psvs?

Optional. If true, enable PSVS for AlloyDB. Corresponds to the JSON property enablePsvs

Returns:

  • (Boolean)


23354
23355
23356
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23354

def enable_psvs
  @enable_psvs
end

#instanceString

Required. The AlloyDB instance to connect to. Corresponds to the JSON property instance

Returns:

  • (String)


23360
23361
23362
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23360

def instance
  @instance
end

#passwordString

Required. Database password. If auth_mode = END_USER_ACCOUNT, it can be unset. In that case, the password will be inferred on the AlloyDB side, based on the authenticated user. Corresponds to the JSON property password

Returns:

  • (String)


23367
23368
23369
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23367

def password
  @password
end

#userString

Required. Database user. If auth_mode = END_USER_ACCOUNT, it can be unset. In that case, the user will be inferred on the AlloyDB side, based on the authenticated user. Corresponds to the JSON property user

Returns:

  • (String)


23374
23375
23376
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23374

def user
  @user
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23381
23382
23383
23384
23385
23386
23387
23388
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23381

def update!(**args)
  @auth_mode = args[:auth_mode] if args.key?(:auth_mode)
  @database = args[:database] if args.key?(:database)
  @enable_psvs = args[:enable_psvs] if args.key?(:enable_psvs)
  @instance = args[:instance] if args.key?(:instance)
  @password = args[:password] if args.key?(:password)
  @user = args[:user] if args.key?(:user)
end