Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDataStoreFederatedSearchConfigAlloyDbConfigAlloyDbConnectionConfig
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDataStoreFederatedSearchConfigAlloyDbConfigAlloyDbConnectionConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Configuration for connecting to AlloyDB.
Instance Attribute Summary collapse
-
#auth_mode ⇒ String
Optional.
-
#database ⇒ String
Required.
-
#enable_psvs ⇒ Boolean
(also: #enable_psvs?)
Optional.
-
#instance ⇒ String
Required.
-
#password ⇒ String
Required.
-
#user ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaDataStoreFederatedSearchConfigAlloyDbConfigAlloyDbConnectionConfig
constructor
A new instance of GoogleCloudDiscoveryengineV1betaDataStoreFederatedSearchConfigAlloyDbConfigAlloyDbConnectionConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaDataStoreFederatedSearchConfigAlloyDbConfigAlloyDbConnectionConfig
Returns a new instance of GoogleCloudDiscoveryengineV1betaDataStoreFederatedSearchConfigAlloyDbConfigAlloyDbConnectionConfig.
23376 23377 23378 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23376 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auth_mode ⇒ String
Optional. Auth mode.
Corresponds to the JSON property authMode
23344 23345 23346 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23344 def auth_mode @auth_mode end |
#database ⇒ String
Required. The AlloyDB database to connect to.
Corresponds to the JSON property database
23349 23350 23351 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23349 def database @database end |
#enable_psvs ⇒ Boolean Also known as: enable_psvs?
Optional. If true, enable PSVS for AlloyDB.
Corresponds to the JSON property enablePsvs
23354 23355 23356 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23354 def enable_psvs @enable_psvs end |
#instance ⇒ String
Required. The AlloyDB instance to connect to.
Corresponds to the JSON property instance
23360 23361 23362 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23360 def instance @instance end |
#password ⇒ String
Required. Database password. If auth_mode = END_USER_ACCOUNT, it can be unset.
In that case, the password will be inferred on the AlloyDB side, based on the
authenticated user.
Corresponds to the JSON property password
23367 23368 23369 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23367 def password @password end |
#user ⇒ String
Required. Database user. If auth_mode = END_USER_ACCOUNT, it can be unset. In
that case, the user will be inferred on the AlloyDB side, based on the
authenticated user.
Corresponds to the JSON property user
23374 23375 23376 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23374 def user @user end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23381 23382 23383 23384 23385 23386 23387 23388 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23381 def update!(**args) @auth_mode = args[:auth_mode] if args.key?(:auth_mode) @database = args[:database] if args.key?(:database) @enable_psvs = args[:enable_psvs] if args.key?(:enable_psvs) @instance = args[:instance] if args.key?(:instance) @password = args[:password] if args.key?(:password) @user = args[:user] if args.key?(:user) end |