Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDistributeLicenseConfigRequest
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDistributeLicenseConfigRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Request message for LicenseConfigService.DistributeLicenseConfig method.
Instance Attribute Summary collapse
-
#license_config_id ⇒ String
Optional.
-
#license_count ⇒ Fixnum
Required.
-
#location ⇒ String
Required.
-
#project_number ⇒ Fixnum
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaDistributeLicenseConfigRequest
constructor
A new instance of GoogleCloudDiscoveryengineV1betaDistributeLicenseConfigRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaDistributeLicenseConfigRequest
Returns a new instance of GoogleCloudDiscoveryengineV1betaDistributeLicenseConfigRequest.
24623 24624 24625 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24623 def initialize(**args) update!(**args) end |
Instance Attribute Details
#license_config_id ⇒ String
Optional. Distribute seats to this license config instead of creating a new
one. If not specified, a new license config will be created from the billing
account license config.
Corresponds to the JSON property licenseConfigId
24606 24607 24608 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24606 def license_config_id @license_config_id end |
#license_count ⇒ Fixnum
Required. The number of licenses to distribute.
Corresponds to the JSON property licenseCount
24611 24612 24613 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24611 def license_count @license_count end |
#location ⇒ String
Required. The target GCP project region to distribute the license config to.
Corresponds to the JSON property location
24616 24617 24618 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24616 def location @location end |
#project_number ⇒ Fixnum
Required. The target GCP project number to distribute the license config to.
Corresponds to the JSON property projectNumber
24621 24622 24623 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24621 def project_number @project_number end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24628 24629 24630 24631 24632 24633 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24628 def update!(**args) @license_config_id = args[:license_config_id] if args.key?(:license_config_id) @license_count = args[:license_count] if args.key?(:license_count) @location = args[:location] if args.key?(:location) @project_number = args[:project_number] if args.key?(:project_number) end |