Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDistributeLicenseConfigRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Request message for LicenseConfigService.DistributeLicenseConfig method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaDistributeLicenseConfigRequest

Returns a new instance of GoogleCloudDiscoveryengineV1betaDistributeLicenseConfigRequest.



24592
24593
24594
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24592

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#license_config_idString

Optional. Distribute seats to this license config instead of creating a new one. If not specified, a new license config will be created from the billing account license config. Corresponds to the JSON property licenseConfigId

Returns:

  • (String)


24575
24576
24577
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24575

def license_config_id
  @license_config_id
end

#license_countFixnum

Required. The number of licenses to distribute. Corresponds to the JSON property licenseCount

Returns:

  • (Fixnum)


24580
24581
24582
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24580

def license_count
  @license_count
end

#locationString

Required. The target GCP project region to distribute the license config to. Corresponds to the JSON property location

Returns:

  • (String)


24585
24586
24587
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24585

def location
  @location
end

#project_numberFixnum

Required. The target GCP project number to distribute the license config to. Corresponds to the JSON property projectNumber

Returns:

  • (Fixnum)


24590
24591
24592
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24590

def project_number
  @project_number
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24597
24598
24599
24600
24601
24602
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24597

def update!(**args)
  @license_config_id = args[:license_config_id] if args.key?(:license_config_id)
  @license_count = args[:license_count] if args.key?(:license_count)
  @location = args[:location] if args.key?(:location)
  @project_number = args[:project_number] if args.key?(:project_number)
end