Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDistributeLicenseConfigRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Request message for LicenseConfigService.DistributeLicenseConfig method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaDistributeLicenseConfigRequest

Returns a new instance of GoogleCloudDiscoveryengineV1betaDistributeLicenseConfigRequest.



23743
23744
23745
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23743

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#license_config_idString

Optional. Distribute seats to this license config instead of creating a new one. If not specified, a new license config will be created from the billing account license config. Corresponds to the JSON property licenseConfigId

Returns:

  • (String)


23726
23727
23728
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23726

def license_config_id
  @license_config_id
end

#license_countFixnum

Required. The number of licenses to distribute. Corresponds to the JSON property licenseCount

Returns:

  • (Fixnum)


23731
23732
23733
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23731

def license_count
  @license_count
end

#locationString

Required. The target GCP project region to distribute the license config to. Corresponds to the JSON property location

Returns:

  • (String)


23736
23737
23738
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23736

def location
  @location
end

#project_numberFixnum

Required. The target GCP project number to distribute the license config to. Corresponds to the JSON property projectNumber

Returns:

  • (Fixnum)


23741
23742
23743
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23741

def project_number
  @project_number
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23748
23749
23750
23751
23752
23753
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23748

def update!(**args)
  @license_config_id = args[:license_config_id] if args.key?(:license_config_id)
  @license_count = args[:license_count] if args.key?(:license_count)
  @location = args[:location] if args.key?(:location)
  @project_number = args[:project_number] if args.key?(:project_number)
end