Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocument
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocument
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Document captures all raw metadata information of items to be recommended or searched.
Instance Attribute Summary collapse
-
#acl_info ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocumentAclInfo
ACL Information of the Document.
-
#content ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocumentContent
Unstructured data linked to this document.
-
#derived_struct_data ⇒ Hash<String,Object>
Output only.
-
#id ⇒ String
Immutable.
-
#index_status ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocumentIndexStatus
Index status of the document.
-
#index_time ⇒ String
Output only.
-
#json_data ⇒ String
The JSON string representation of the document.
-
#name ⇒ String
Immutable.
-
#parent_document_id ⇒ String
The identifier of the parent document.
-
#schema_id ⇒ String
The identifier of the schema located in the same data store.
-
#struct_data ⇒ Hash<String,Object>
The structured JSON data for the document.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaDocument
constructor
A new instance of GoogleCloudDiscoveryengineV1betaDocument.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaDocument
Returns a new instance of GoogleCloudDiscoveryengineV1betaDocument.
24753 24754 24755 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24753 def initialize(**args) update!(**args) end |
Instance Attribute Details
#acl_info ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocumentAclInfo
ACL Information of the Document.
Corresponds to the JSON property aclInfo
24687 24688 24689 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24687 def acl_info @acl_info end |
#content ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocumentContent
Unstructured data linked to this document.
Corresponds to the JSON property content
24692 24693 24694 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24692 def content @content end |
#derived_struct_data ⇒ Hash<String,Object>
Output only. This field is OUTPUT_ONLY. It contains derived data that are not
in the original input document.
Corresponds to the JSON property derivedStructData
24698 24699 24700 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24698 def derived_struct_data @derived_struct_data end |
#id ⇒ String
Immutable. The identifier of the document. Id should conform to RFC-1034 standard with a length limit of 128
characters.
Corresponds to the JSON property id
24705 24706 24707 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24705 def id @id end |
#index_status ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocumentIndexStatus
Index status of the document.
Corresponds to the JSON property indexStatus
24710 24711 24712 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24710 def index_status @index_status end |
#index_time ⇒ String
Output only. The time when the document was last indexed. If this field is
populated, it means the document has been indexed. While documents typically
become searchable within seconds of indexing, it can sometimes take up to a
few hours. If this field is not populated, it means the document has never
been indexed.
Corresponds to the JSON property indexTime
24719 24720 24721 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24719 def index_time @index_time end |
#json_data ⇒ String
The JSON string representation of the document. It should conform to the
registered Schema or an INVALID_ARGUMENT error is thrown.
Corresponds to the JSON property jsonData
24725 24726 24727 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24725 def json_data @json_data end |
#name ⇒ String
Immutable. The full resource name of the document. Format: projects/project/
locations/location/collections/collection/dataStores/data_store/branches/
branch/documents/document_id`. This field must be a UTF-8 encoded string
with a length limit of 1024 characters.
Corresponds to the JSON propertyname`
24733 24734 24735 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24733 def name @name end |
#parent_document_id ⇒ String
The identifier of the parent document. Currently supports at most two level
document hierarchy. Id should conform to RFC-1034 standard with a length limit of 63 characters.
Corresponds to the JSON property parentDocumentId
24740 24741 24742 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24740 def parent_document_id @parent_document_id end |
#schema_id ⇒ String
The identifier of the schema located in the same data store.
Corresponds to the JSON property schemaId
24745 24746 24747 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24745 def schema_id @schema_id end |
#struct_data ⇒ Hash<String,Object>
The structured JSON data for the document. It should conform to the registered
Schema or an INVALID_ARGUMENT error is thrown.
Corresponds to the JSON property structData
24751 24752 24753 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24751 def struct_data @struct_data end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24758 24759 24760 24761 24762 24763 24764 24765 24766 24767 24768 24769 24770 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24758 def update!(**args) @acl_info = args[:acl_info] if args.key?(:acl_info) @content = args[:content] if args.key?(:content) @derived_struct_data = args[:derived_struct_data] if args.key?(:derived_struct_data) @id = args[:id] if args.key?(:id) @index_status = args[:index_status] if args.key?(:index_status) @index_time = args[:index_time] if args.key?(:index_time) @json_data = args[:json_data] if args.key?(:json_data) @name = args[:name] if args.key?(:name) @parent_document_id = args[:parent_document_id] if args.key?(:parent_document_id) @schema_id = args[:schema_id] if args.key?(:schema_id) @struct_data = args[:struct_data] if args.key?(:struct_data) end |