Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocument

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Document captures all raw metadata information of items to be recommended or searched.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaDocument

Returns a new instance of GoogleCloudDiscoveryengineV1betaDocument.



24729
24730
24731
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24729

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#acl_infoGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocumentAclInfo

ACL Information of the Document. Corresponds to the JSON property aclInfo



24663
24664
24665
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24663

def acl_info
  @acl_info
end

#contentGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocumentContent

Unstructured data linked to this document. Corresponds to the JSON property content



24668
24669
24670
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24668

def content
  @content
end

#derived_struct_dataHash<String,Object>

Output only. This field is OUTPUT_ONLY. It contains derived data that are not in the original input document. Corresponds to the JSON property derivedStructData

Returns:

  • (Hash<String,Object>)


24674
24675
24676
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24674

def derived_struct_data
  @derived_struct_data
end

#idString

Immutable. The identifier of the document. Id should conform to RFC-1034 standard with a length limit of 128 characters. Corresponds to the JSON property id

Returns:

  • (String)


24681
24682
24683
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24681

def id
  @id
end

#index_statusGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocumentIndexStatus

Index status of the document. Corresponds to the JSON property indexStatus



24686
24687
24688
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24686

def index_status
  @index_status
end

#index_timeString

Output only. The time when the document was last indexed. If this field is populated, it means the document has been indexed. While documents typically become searchable within seconds of indexing, it can sometimes take up to a few hours. If this field is not populated, it means the document has never been indexed. Corresponds to the JSON property indexTime

Returns:

  • (String)


24695
24696
24697
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24695

def index_time
  @index_time
end

#json_dataString

The JSON string representation of the document. It should conform to the registered Schema or an INVALID_ARGUMENT error is thrown. Corresponds to the JSON property jsonData

Returns:

  • (String)


24701
24702
24703
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24701

def json_data
  @json_data
end

#nameString

Immutable. The full resource name of the document. Format: projects/project/ locations/location/collections/collection/dataStores/data_store/branches/ branch/documents/document_id`. This field must be a UTF-8 encoded string with a length limit of 1024 characters. Corresponds to the JSON propertyname`

Returns:

  • (String)


24709
24710
24711
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24709

def name
  @name
end

#parent_document_idString

The identifier of the parent document. Currently supports at most two level document hierarchy. Id should conform to RFC-1034 standard with a length limit of 63 characters. Corresponds to the JSON property parentDocumentId

Returns:

  • (String)


24716
24717
24718
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24716

def parent_document_id
  @parent_document_id
end

#schema_idString

The identifier of the schema located in the same data store. Corresponds to the JSON property schemaId

Returns:

  • (String)


24721
24722
24723
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24721

def schema_id
  @schema_id
end

#struct_dataHash<String,Object>

The structured JSON data for the document. It should conform to the registered Schema or an INVALID_ARGUMENT error is thrown. Corresponds to the JSON property structData

Returns:

  • (Hash<String,Object>)


24727
24728
24729
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24727

def struct_data
  @struct_data
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24734
24735
24736
24737
24738
24739
24740
24741
24742
24743
24744
24745
24746
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24734

def update!(**args)
  @acl_info = args[:acl_info] if args.key?(:acl_info)
  @content = args[:content] if args.key?(:content)
  @derived_struct_data = args[:derived_struct_data] if args.key?(:derived_struct_data)
  @id = args[:id] if args.key?(:id)
  @index_status = args[:index_status] if args.key?(:index_status)
  @index_time = args[:index_time] if args.key?(:index_time)
  @json_data = args[:json_data] if args.key?(:json_data)
  @name = args[:name] if args.key?(:name)
  @parent_document_id = args[:parent_document_id] if args.key?(:parent_document_id)
  @schema_id = args[:schema_id] if args.key?(:schema_id)
  @struct_data = args[:struct_data] if args.key?(:struct_data)
end