Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocumentIndexStatus
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocumentIndexStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Index status of the document.
Instance Attribute Summary collapse
-
#error_samples ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>
A sample of errors encountered while indexing the document.
-
#index_time ⇒ String
The time when the document was indexed.
-
#pending_message ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaDocumentIndexStatus
constructor
A new instance of GoogleCloudDiscoveryengineV1betaDocumentIndexStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaDocumentIndexStatus
Returns a new instance of GoogleCloudDiscoveryengineV1betaDocumentIndexStatus.
25010 25011 25012 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25010 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_samples ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>
A sample of errors encountered while indexing the document. If this field is
populated, the document is not indexed due to errors.
Corresponds to the JSON property errorSamples
24995 24996 24997 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24995 def error_samples @error_samples end |
#index_time ⇒ String
The time when the document was indexed. If this field is populated, it means
the document has been indexed. While documents typically become searchable
within seconds of indexing, it can sometimes take up to a few hours.
Corresponds to the JSON property indexTime
25002 25003 25004 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25002 def index_time @index_time end |
#pending_message ⇒ String
Immutable. The message indicates the document index is in progress. If this
field is populated, the document index is pending.
Corresponds to the JSON property pendingMessage
25008 25009 25010 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25008 def @pending_message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25015 25016 25017 25018 25019 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25015 def update!(**args) @error_samples = args[:error_samples] if args.key?(:error_samples) @index_time = args[:index_time] if args.key?(:index_time) @pending_message = args[:pending_message] if args.key?(:pending_message) end |