Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocumentIndexStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Index status of the document.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaDocumentIndexStatus

Returns a new instance of GoogleCloudDiscoveryengineV1betaDocumentIndexStatus.



23994
23995
23996
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23994

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_samplesArray<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>

A sample of errors encountered while indexing the document. If this field is populated, the document is not indexed due to errors. Corresponds to the JSON property errorSamples



23979
23980
23981
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23979

def error_samples
  @error_samples
end

#index_timeString

The time when the document was indexed. If this field is populated, it means the document has been indexed. While documents typically become searchable within seconds of indexing, it can sometimes take up to a few hours. Corresponds to the JSON property indexTime

Returns:

  • (String)


23986
23987
23988
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23986

def index_time
  @index_time
end

#pending_messageString

Immutable. The message indicates the document index is in progress. If this field is populated, the document index is pending. Corresponds to the JSON property pendingMessage

Returns:

  • (String)


23992
23993
23994
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23992

def pending_message
  @pending_message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23999
24000
24001
24002
24003
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 23999

def update!(**args)
  @error_samples = args[:error_samples] if args.key?(:error_samples)
  @index_time = args[:index_time] if args.key?(:index_time)
  @pending_message = args[:pending_message] if args.key?(:pending_message)
end