Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocumentInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Detailed document information associated with a user event.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaDocumentInfo

Returns a new instance of GoogleCloudDiscoveryengineV1betaDocumentInfo.



24259
24260
24261
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24259

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversion_valueFloat

Optional. The conversion value associated with this Document. Must be set if UserEvent.event_type is "conversion". For example, a value of 1000 signifies that 1000 seconds were spent viewing a Document for the watch conversion type. Corresponds to the JSON property conversionValue

Returns:

  • (Float)


24220
24221
24222
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24220

def conversion_value
  @conversion_value
end

#idString

The Document resource ID. Corresponds to the JSON property id

Returns:

  • (String)


24225
24226
24227
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24225

def id
  @id
end

#joinedBoolean Also known as: joined?

Output only. Whether the referenced Document can be found in the data store. Corresponds to the JSON property joined

Returns:

  • (Boolean)


24230
24231
24232
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24230

def joined
  @joined
end

#nameString

The Document resource full name, of the form: projects/project/locations/ location/collections/collection_id/dataStores/data_store_id/branches/ branch_id/documents/document_id` Corresponds to the JSON propertyname`

Returns:

  • (String)


24238
24239
24240
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24238

def name
  @name
end

#promotion_idsArray<String>

The promotion IDs associated with this Document. Currently, this field is restricted to at most one ID. Corresponds to the JSON property promotionIds

Returns:

  • (Array<String>)


24244
24245
24246
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24244

def promotion_ids
  @promotion_ids
end

#quantityFixnum

Quantity of the Document associated with the user event. Defaults to 1. For example, this field is 2 if two quantities of the same Document are involved in a add-to-cart event. Required for events of the following event types: * add-to-cart * purchase Corresponds to the JSON property quantity

Returns:

  • (Fixnum)


24252
24253
24254
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24252

def quantity
  @quantity
end

#uriString

The Document URI - only allowed for website data stores. Corresponds to the JSON property uri

Returns:

  • (String)


24257
24258
24259
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24257

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24264
24265
24266
24267
24268
24269
24270
24271
24272
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24264

def update!(**args)
  @conversion_value = args[:conversion_value] if args.key?(:conversion_value)
  @id = args[:id] if args.key?(:id)
  @joined = args[:joined] if args.key?(:joined)
  @name = args[:name] if args.key?(:name)
  @promotion_ids = args[:promotion_ids] if args.key?(:promotion_ids)
  @quantity = args[:quantity] if args.key?(:quantity)
  @uri = args[:uri] if args.key?(:uri)
end