Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocumentInfo
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocumentInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Detailed document information associated with a user event.
Instance Attribute Summary collapse
-
#conversion_value ⇒ Float
Optional.
-
#id ⇒ String
The Document resource ID.
-
#joined ⇒ Boolean
(also: #joined?)
Output only.
-
#name ⇒ String
The Document resource full name, of the form:
projects/project/locations/location/collections/collection_id/dataStores/data_store_id/branches/branch_id/documents/document_id`Corresponds to the JSON propertyname`. -
#promotion_ids ⇒ Array<String>
The promotion IDs associated with this Document.
-
#quantity ⇒ Fixnum
Quantity of the Document associated with the user event.
-
#uri ⇒ String
The Document URI - only allowed for website data stores.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaDocumentInfo
constructor
A new instance of GoogleCloudDiscoveryengineV1betaDocumentInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaDocumentInfo
Returns a new instance of GoogleCloudDiscoveryengineV1betaDocumentInfo.
24055 24056 24057 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24055 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversion_value ⇒ Float
Optional. The conversion value associated with this Document. Must be set if
UserEvent.event_type is "conversion". For example, a value of 1000 signifies
that 1000 seconds were spent viewing a Document for the watch conversion
type.
Corresponds to the JSON property conversionValue
24016 24017 24018 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24016 def conversion_value @conversion_value end |
#id ⇒ String
The Document resource ID.
Corresponds to the JSON property id
24021 24022 24023 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24021 def id @id end |
#joined ⇒ Boolean Also known as: joined?
Output only. Whether the referenced Document can be found in the data store.
Corresponds to the JSON property joined
24026 24027 24028 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24026 def joined @joined end |
#name ⇒ String
The Document resource full name, of the form: projects/project/locations/
location/collections/collection_id/dataStores/data_store_id/branches/
branch_id/documents/document_id`
Corresponds to the JSON propertyname`
24034 24035 24036 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24034 def name @name end |
#promotion_ids ⇒ Array<String>
The promotion IDs associated with this Document. Currently, this field is
restricted to at most one ID.
Corresponds to the JSON property promotionIds
24040 24041 24042 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24040 def promotion_ids @promotion_ids end |
#quantity ⇒ Fixnum
Quantity of the Document associated with the user event. Defaults to 1. For
example, this field is 2 if two quantities of the same Document are involved
in a add-to-cart event. Required for events of the following event types: *
add-to-cart * purchase
Corresponds to the JSON property quantity
24048 24049 24050 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24048 def quantity @quantity end |
#uri ⇒ String
The Document URI - only allowed for website data stores.
Corresponds to the JSON property uri
24053 24054 24055 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24053 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24060 24061 24062 24063 24064 24065 24066 24067 24068 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24060 def update!(**args) @conversion_value = args[:conversion_value] if args.key?(:conversion_value) @id = args[:id] if args.key?(:id) @joined = args[:joined] if args.key?(:joined) @name = args[:name] if args.key?(:name) @promotion_ids = args[:promotion_ids] if args.key?(:promotion_ids) @quantity = args[:quantity] if args.key?(:quantity) @uri = args[:uri] if args.key?(:uri) end |