Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocumentProcessingConfigParsingConfigLayoutParsingConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

The layout parsing configurations for documents.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaDocumentProcessingConfigParsingConfigLayoutParsingConfig

Returns a new instance of GoogleCloudDiscoveryengineV1betaDocumentProcessingConfigParsingConfigLayoutParsingConfig.



25112
25113
25114
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25112

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_get_processed_documentBoolean Also known as: enable_get_processed_document?

Optional. If true, the processed document will be made available for the GetProcessedDocument API. Corresponds to the JSON property enableGetProcessedDocument

Returns:

  • (Boolean)


25068
25069
25070
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25068

def enable_get_processed_document
  @enable_get_processed_document
end

#enable_image_annotationBoolean Also known as: enable_image_annotation?

Optional. If true, the LLM based annotation is added to the image during parsing. Corresponds to the JSON property enableImageAnnotation

Returns:

  • (Boolean)


25075
25076
25077
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25075

def enable_image_annotation
  @enable_image_annotation
end

#enable_llm_layout_parsingBoolean Also known as: enable_llm_layout_parsing?

Optional. If true, the pdf layout will be refined using an LLM. Corresponds to the JSON property enableLlmLayoutParsing

Returns:

  • (Boolean)


25081
25082
25083
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25081

def enable_llm_layout_parsing
  @enable_llm_layout_parsing
end

#enable_table_annotationBoolean Also known as: enable_table_annotation?

Optional. If true, the LLM based annotation is added to the table during parsing. Corresponds to the JSON property enableTableAnnotation

Returns:

  • (Boolean)


25088
25089
25090
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25088

def enable_table_annotation
  @enable_table_annotation
end

#exclude_html_classesArray<String>

Optional. List of HTML classes to exclude from the parsed content. Corresponds to the JSON property excludeHtmlClasses

Returns:

  • (Array<String>)


25094
25095
25096
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25094

def exclude_html_classes
  @exclude_html_classes
end

#exclude_html_elementsArray<String>

Optional. List of HTML elements to exclude from the parsed content. Corresponds to the JSON property excludeHtmlElements

Returns:

  • (Array<String>)


25099
25100
25101
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25099

def exclude_html_elements
  @exclude_html_elements
end

#exclude_html_idsArray<String>

Optional. List of HTML ids to exclude from the parsed content. Corresponds to the JSON property excludeHtmlIds

Returns:

  • (Array<String>)


25104
25105
25106
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25104

def exclude_html_ids
  @exclude_html_ids
end

#structured_content_typesArray<String>

Optional. Contains the required structure types to extract from the document. Supported values: * shareholder-structure Corresponds to the JSON property structuredContentTypes

Returns:

  • (Array<String>)


25110
25111
25112
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25110

def structured_content_types
  @structured_content_types
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25117
25118
25119
25120
25121
25122
25123
25124
25125
25126
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25117

def update!(**args)
  @enable_get_processed_document = args[:enable_get_processed_document] if args.key?(:enable_get_processed_document)
  @enable_image_annotation = args[:enable_image_annotation] if args.key?(:enable_image_annotation)
  @enable_llm_layout_parsing = args[:enable_llm_layout_parsing] if args.key?(:enable_llm_layout_parsing)
  @enable_table_annotation = args[:enable_table_annotation] if args.key?(:enable_table_annotation)
  @exclude_html_classes = args[:exclude_html_classes] if args.key?(:exclude_html_classes)
  @exclude_html_elements = args[:exclude_html_elements] if args.key?(:exclude_html_elements)
  @exclude_html_ids = args[:exclude_html_ids] if args.key?(:exclude_html_ids)
  @structured_content_types = args[:structured_content_types] if args.key?(:structured_content_types)
end