Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocumentProcessingConfigParsingConfigOcrParsingConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

The OCR parsing configurations for documents.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaDocumentProcessingConfigParsingConfigOcrParsingConfig

Returns a new instance of GoogleCloudDiscoveryengineV1betaDocumentProcessingConfigParsingConfigOcrParsingConfig.



24501
24502
24503
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24501

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enhanced_document_elementsArray<String>

[DEPRECATED] This field is deprecated. To use the additional enhanced document elements processing, please switch to layout_parsing_config. Corresponds to the JSON property enhancedDocumentElements

Returns:

  • (Array<String>)


24492
24493
24494
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24492

def enhanced_document_elements
  @enhanced_document_elements
end

#use_native_textBoolean Also known as: use_native_text?

If true, will use native text instead of OCR text on pages containing native text. Corresponds to the JSON property useNativeText

Returns:

  • (Boolean)


24498
24499
24500
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24498

def use_native_text
  @use_native_text
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24506
24507
24508
24509
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24506

def update!(**args)
  @enhanced_document_elements = args[:enhanced_document_elements] if args.key?(:enhanced_document_elements)
  @use_native_text = args[:use_native_text] if args.key?(:use_native_text)
end