Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaEngine

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Metadata that describes the training and serving parameters of an Engine.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaEngine

Returns a new instance of GoogleCloudDiscoveryengineV1betaEngine.



24561
24562
24563
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24561

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_gateway_settingGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAgentGatewaySetting

Agent Gateway setting, which may be attached to Gemini Enterprise resources for egress control of Gemini Enterprise agents to agents and tools outside of Gemini Enterprise. Corresponds to the JSON property agentGatewaySetting



24409
24410
24411
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24409

def agent_gateway_setting
  @agent_gateway_setting
end

#app_typeString

Optional. Immutable. This the application type which this engine resource represents. NOTE: this is a new concept independ of existing industry vertical or solution type. Corresponds to the JSON property appType

Returns:

  • (String)


24416
24417
24418
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24416

def app_type
  @app_type
end

#chat_engine_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaEngineChatEngineConfig

Configurations for a Chat Engine. Corresponds to the JSON property chatEngineConfig



24421
24422
24423
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24421

def chat_engine_config
  @chat_engine_config
end

#chat_engine_metadataGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaEngineChatEngineMetadata

Additional information of a Chat Engine. Fields in this message are output only. Corresponds to the JSON property chatEngineMetadata



24427
24428
24429
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24427

def 
  @chat_engine_metadata
end

#cmek_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCmekConfig

Configurations used to enable CMEK data encryption with Cloud KMS keys. Corresponds to the JSON property cmekConfig



24432
24433
24434
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24432

def cmek_config
  @cmek_config
end

#common_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaEngineCommonConfig

Common configurations for an Engine. Corresponds to the JSON property commonConfig



24437
24438
24439
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24437

def common_config
  @common_config
end

#configurable_billing_approachString

Optional. Configuration for configurable billing approach. Corresponds to the JSON property configurableBillingApproach

Returns:

  • (String)


24442
24443
24444
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24442

def configurable_billing_approach
  @configurable_billing_approach
end

#connector_tenant_infoHash<String,String>

Optional. Maps a connector ID (e.g., "hybrid-github", "shopify") to tenant- specific information required for that connector. The structure of the tenant information string is connector-dependent. Corresponds to the JSON property connectorTenantInfo

Returns:

  • (Hash<String,String>)


24449
24450
24451
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24449

def connector_tenant_info
  @connector_tenant_info
end

#create_timeString

Output only. Timestamp the Recommendation Engine was created at. Corresponds to the JSON property createTime

Returns:

  • (String)


24454
24455
24456
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24454

def create_time
  @create_time
end

#data_store_idsArray<String>

Optional. The data stores associated with this engine. For SOLUTION_TYPE_SEARCH and SOLUTION_TYPE_RECOMMENDATION type of engines, they can only associate with at most one data store. If solution_type is SOLUTION_TYPE_CHAT, multiple DataStores in the same Collection can be associated here. Note that when used in CreateEngineRequest, one DataStore id must be provided as the system will use it for necessary initializations. Corresponds to the JSON property dataStoreIds

Returns:

  • (Array<String>)


24464
24465
24466
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24464

def data_store_ids
  @data_store_ids
end

#disable_analyticsBoolean Also known as: disable_analytics?

Optional. Whether to disable analytics for searches performed on this engine. Corresponds to the JSON property disableAnalytics

Returns:

  • (Boolean)


24469
24470
24471
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24469

def disable_analytics
  @disable_analytics
end

#display_nameString

Required. The display name of the engine. Should be human readable. UTF-8 encoded string with limit of 1024 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


24476
24477
24478
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24476

def display_name
  @display_name
end

#featuresHash<String,String>

Optional. Feature config for the engine to opt in or opt out of features. Supported keys: * *: all features, if it's present, all other feature state settings are ignored. * agent-gallery * no-code-agent-builder * prompt- gallery * model-selector * notebook-lm * people-search * people-search- org-chart * bi-directional-audio * feedback * session-sharing * personalization-memory * personalization-suggested-highlights * disable- mobile-app-access * disable-agent-sharing * disable-image-generation * disable-video-generation * disable-onedrive-upload * disable-talk-to- content * disable-google-drive-upload * disable-welcome-emails * disable- canvas * disable-canvas-workspace * disable-skills * enable-end-user- sharing-with-groups * single-agent-orchestration * multi-agent- orchestration * cross-product-intelligence Corresponds to the JSON property features

Returns:

  • (Hash<String,String>)


24492
24493
24494
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24492

def features
  @features
end

#industry_verticalString

Optional. The industry vertical that the engine registers. The restriction of the Engine industry vertical is based on DataStore: Vertical on Engine has to match vertical of the DataStore linked to the engine. Corresponds to the JSON property industryVertical

Returns:

  • (String)


24499
24500
24501
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24499

def industry_vertical
  @industry_vertical
end

#knowledge_graph_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaEngineKnowledgeGraphConfig

Configuration message for the Knowledge Graph. Corresponds to the JSON property knowledgeGraphConfig



24504
24505
24506
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24504

def knowledge_graph_config
  @knowledge_graph_config
end

#marketplace_agent_visibilityString

Optional. The visibility of marketplace agents in the agent gallery. Corresponds to the JSON property marketplaceAgentVisibility

Returns:

  • (String)


24509
24510
24511
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24509

def marketplace_agent_visibility
  @marketplace_agent_visibility
end

#media_recommendation_engine_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaEngineMediaRecommendationEngineConfig

Additional config specs for a Media Recommendation engine. Corresponds to the JSON property mediaRecommendationEngineConfig



24514
24515
24516
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24514

def media_recommendation_engine_config
  @media_recommendation_engine_config
end

#model_configsHash<String,String>

Optional. Maps a model name to its specific configuration for this engine. This allows admin users to turn on/off individual models. This only stores models whose states are overridden by the admin. When the state is unspecified, or model_configs is empty for this model, the system will decide if this model should be available or not based on the default configuration. For example, a preview model should be disabled by default if the admin has not chosen to enable it. Corresponds to the JSON property modelConfigs

Returns:

  • (Hash<String,String>)


24525
24526
24527
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24525

def model_configs
  @model_configs
end

#nameString

Immutable. Identifier. The fully qualified resource name of the engine. This field must be a UTF-8 encoded string with a length limit of 1024 characters. Format: projects/project/locations/location/collections/collection/ engines/engine`engine should be 1-63 characters, and valid characters are / a-z0-9*/. Otherwise, an INVALID_ARGUMENT error is returned. Corresponds to the JSON propertyname`

Returns:

  • (String)


24534
24535
24536
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24534

def name
  @name
end

#observability_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaObservabilityConfig

Observability config for a resource. Corresponds to the JSON property observabilityConfig



24539
24540
24541
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24539

def observability_config
  @observability_config
end

#procurement_contact_emailsArray<String>

Optional. The emails of the procurement contacts. Corresponds to the JSON property procurementContactEmails

Returns:

  • (Array<String>)


24544
24545
24546
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24544

def procurement_contact_emails
  @procurement_contact_emails
end

#search_engine_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaEngineSearchEngineConfig

Configurations for a Search Engine. Corresponds to the JSON property searchEngineConfig



24549
24550
24551
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24549

def search_engine_config
  @search_engine_config
end

#solution_typeString

Required. The solutions of the engine. Corresponds to the JSON property solutionType

Returns:

  • (String)


24554
24555
24556
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24554

def solution_type
  @solution_type
end

#update_timeString

Output only. Timestamp the Recommendation Engine was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


24559
24560
24561
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24559

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24566
24567
24568
24569
24570
24571
24572
24573
24574
24575
24576
24577
24578
24579
24580
24581
24582
24583
24584
24585
24586
24587
24588
24589
24590
24591
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24566

def update!(**args)
  @agent_gateway_setting = args[:agent_gateway_setting] if args.key?(:agent_gateway_setting)
  @app_type = args[:app_type] if args.key?(:app_type)
  @chat_engine_config = args[:chat_engine_config] if args.key?(:chat_engine_config)
  @chat_engine_metadata = args[:chat_engine_metadata] if args.key?(:chat_engine_metadata)
  @cmek_config = args[:cmek_config] if args.key?(:cmek_config)
  @common_config = args[:common_config] if args.key?(:common_config)
  @configurable_billing_approach = args[:configurable_billing_approach] if args.key?(:configurable_billing_approach)
  @connector_tenant_info = args[:connector_tenant_info] if args.key?(:connector_tenant_info)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_store_ids = args[:data_store_ids] if args.key?(:data_store_ids)
  @disable_analytics = args[:disable_analytics] if args.key?(:disable_analytics)
  @display_name = args[:display_name] if args.key?(:display_name)
  @features = args[:features] if args.key?(:features)
  @industry_vertical = args[:industry_vertical] if args.key?(:industry_vertical)
  @knowledge_graph_config = args[:knowledge_graph_config] if args.key?(:knowledge_graph_config)
  @marketplace_agent_visibility = args[:marketplace_agent_visibility] if args.key?(:marketplace_agent_visibility)
  @media_recommendation_engine_config = args[:media_recommendation_engine_config] if args.key?(:media_recommendation_engine_config)
  @model_configs = args[:model_configs] if args.key?(:model_configs)
  @name = args[:name] if args.key?(:name)
  @observability_config = args[:observability_config] if args.key?(:observability_config)
  @procurement_contact_emails = args[:procurement_contact_emails] if args.key?(:procurement_contact_emails)
  @search_engine_config = args[:search_engine_config] if args.key?(:search_engine_config)
  @solution_type = args[:solution_type] if args.key?(:solution_type)
  @update_time = args[:update_time] if args.key?(:update_time)
end