Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaEngineChatEngineConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Configurations for a Chat Engine.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaEngineChatEngineConfig

Returns a new instance of GoogleCloudDiscoveryengineV1betaEngineChatEngineConfig.



25517
25518
25519
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25517

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_creation_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaEngineChatEngineConfigAgentCreationConfig

Configurations for generating a Dialogflow agent. Note that these configurations are one-time consumed by and passed to Dialogflow service. It means they cannot be retrieved using EngineService.GetEngine or EngineService. ListEngines API after engine creation. Corresponds to the JSON property agentCreationConfig



25492
25493
25494
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25492

def agent_creation_config
  @agent_creation_config
end

#allow_cross_regionBoolean Also known as: allow_cross_region?

Optional. If the flag set to true, we allow the agent and engine are in different locations, otherwise the agent and engine are required to be in the same location. The flag is set to false by default. Note that the allow_cross_region are one-time consumed by and passed to EngineService. CreateEngine. It means they cannot be retrieved using EngineService.GetEngine or EngineService.ListEngines API after engine creation. Corresponds to the JSON property allowCrossRegion

Returns:

  • (Boolean)


25502
25503
25504
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25502

def allow_cross_region
  @allow_cross_region
end

The resource name of an exist Dialogflow agent to link to this Chat Engine. Customers can either provide agent_creation_config to create agent or provide an agent name that links the agent with the Chat engine. Format: projects//locations//agents/. Note that the dialogflow_agent_to_link are one-time consumed by and passed to Dialogflow service. It means they cannot be retrieved using EngineService.GetEngine or EngineService.ListEngines API after engine creation. Use ChatEngineMetadata.dialogflow_agent for actual agent association after Engine is created. Corresponds to the JSON property dialogflowAgentToLink

Returns:

  • (String)


25515
25516
25517
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25515

def dialogflow_agent_to_link
  @dialogflow_agent_to_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25522
25523
25524
25525
25526
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25522

def update!(**args)
  @agent_creation_config = args[:agent_creation_config] if args.key?(:agent_creation_config)
  @allow_cross_region = args[:allow_cross_region] if args.key?(:allow_cross_region)
  @dialogflow_agent_to_link = args[:dialogflow_agent_to_link] if args.key?(:dialogflow_agent_to_link)
end