Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaEngineCommonConfig
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaEngineCommonConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Common configurations for an Engine.
Instance Attribute Summary collapse
-
#company_name ⇒ String
The name of the company, business or entity that is associated with the engine.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaEngineCommonConfig
constructor
A new instance of GoogleCloudDiscoveryengineV1betaEngineCommonConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaEngineCommonConfig
Returns a new instance of GoogleCloudDiscoveryengineV1betaEngineCommonConfig.
25630 25631 25632 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25630 def initialize(**args) update!(**args) end |
Instance Attribute Details
#company_name ⇒ String
The name of the company, business or entity that is associated with the engine.
Setting this may help improve LLM related features.
Corresponds to the JSON property companyName
25628 25629 25630 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25628 def company_name @company_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25635 25636 25637 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25635 def update!(**args) @company_name = args[:company_name] if args.key?(:company_name) end |