Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaEngineKnowledgeGraphConfig
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaEngineKnowledgeGraphConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Configuration message for the Knowledge Graph.
Instance Attribute Summary collapse
-
#cloud_knowledge_graph_types ⇒ Array<String>
Specify entity types to support.
-
#enable_cloud_knowledge_graph ⇒ Boolean
(also: #enable_cloud_knowledge_graph?)
Whether to enable the Cloud Knowledge Graph for the engine.
-
#enable_private_knowledge_graph ⇒ Boolean
(also: #enable_private_knowledge_graph?)
Whether to enable the Private Knowledge Graph for the engine.
-
#feature_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaEngineKnowledgeGraphConfigFeatureConfig
Feature config for the Knowledge Graph.
-
#private_knowledge_graph_types ⇒ Array<String>
Specify entity types to support.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaEngineKnowledgeGraphConfig
constructor
A new instance of GoogleCloudDiscoveryengineV1betaEngineKnowledgeGraphConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaEngineKnowledgeGraphConfig
Returns a new instance of GoogleCloudDiscoveryengineV1betaEngineKnowledgeGraphConfig.
24973 24974 24975 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24973 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cloud_knowledge_graph_types ⇒ Array<String>
Specify entity types to support.
Corresponds to the JSON property cloudKnowledgeGraphTypes
24947 24948 24949 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24947 def cloud_knowledge_graph_types @cloud_knowledge_graph_types end |
#enable_cloud_knowledge_graph ⇒ Boolean Also known as: enable_cloud_knowledge_graph?
Whether to enable the Cloud Knowledge Graph for the engine. Defaults to false
if not specified.
Corresponds to the JSON property enableCloudKnowledgeGraph
24953 24954 24955 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24953 def enable_cloud_knowledge_graph @enable_cloud_knowledge_graph end |
#enable_private_knowledge_graph ⇒ Boolean Also known as: enable_private_knowledge_graph?
Whether to enable the Private Knowledge Graph for the engine. Defaults to
false if not specified.
Corresponds to the JSON property enablePrivateKnowledgeGraph
24960 24961 24962 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24960 def enable_private_knowledge_graph @enable_private_knowledge_graph end |
#feature_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaEngineKnowledgeGraphConfigFeatureConfig
Feature config for the Knowledge Graph.
Corresponds to the JSON property featureConfig
24966 24967 24968 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24966 def feature_config @feature_config end |
#private_knowledge_graph_types ⇒ Array<String>
Specify entity types to support.
Corresponds to the JSON property privateKnowledgeGraphTypes
24971 24972 24973 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24971 def private_knowledge_graph_types @private_knowledge_graph_types end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24978 24979 24980 24981 24982 24983 24984 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 24978 def update!(**args) @cloud_knowledge_graph_types = args[:cloud_knowledge_graph_types] if args.key?(:cloud_knowledge_graph_types) @enable_cloud_knowledge_graph = args[:enable_cloud_knowledge_graph] if args.key?(:enable_cloud_knowledge_graph) @enable_private_knowledge_graph = args[:enable_private_knowledge_graph] if args.key?(:enable_private_knowledge_graph) @feature_config = args[:feature_config] if args.key?(:feature_config) @private_knowledge_graph_types = args[:private_knowledge_graph_types] if args.key?(:private_knowledge_graph_types) end |