Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaEngineMediaRecommendationEngineConfig
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaEngineMediaRecommendationEngineConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Additional config specs for a Media Recommendation engine.
Instance Attribute Summary collapse
-
#engine_features_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaEngineMediaRecommendationEngineConfigEngineFeaturesConfig
More feature configs of the selected engine type.
-
#optimization_objective ⇒ String
The optimization objective.
-
#optimization_objective_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaEngineMediaRecommendationEngineConfigOptimizationObjectiveConfig
Custom threshold for
cvroptimization_objective. -
#training_state ⇒ String
The training state that the engine is in (e.g.
TRAININGorPAUSED). -
#type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaEngineMediaRecommendationEngineConfig
constructor
A new instance of GoogleCloudDiscoveryengineV1betaEngineMediaRecommendationEngineConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaEngineMediaRecommendationEngineConfig
Returns a new instance of GoogleCloudDiscoveryengineV1betaEngineMediaRecommendationEngineConfig.
25773 25774 25775 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25773 def initialize(**args) update!(**args) end |
Instance Attribute Details
#engine_features_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaEngineMediaRecommendationEngineConfigEngineFeaturesConfig
More feature configs of the selected engine type.
Corresponds to the JSON property engineFeaturesConfig
25739 25740 25741 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25739 def engine_features_config @engine_features_config end |
#optimization_objective ⇒ String
The optimization objective. e.g., cvr. This field together with
optimization_objective describe engine metadata to use to control engine
training and serving. Currently supported values: ctr, cvr. If not
specified, we choose default based on engine type. Default depends on type of
recommendation: recommended-for-you => ctr others-you-may-like => ctr
Corresponds to the JSON property optimizationObjective
25748 25749 25750 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25748 def optimization_objective @optimization_objective end |
#optimization_objective_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaEngineMediaRecommendationEngineConfigOptimizationObjectiveConfig
Custom threshold for cvr optimization_objective.
Corresponds to the JSON property optimizationObjectiveConfig
25753 25754 25755 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25753 def optimization_objective_config @optimization_objective_config end |
#training_state ⇒ String
The training state that the engine is in (e.g. TRAINING or PAUSED). Since
part of the cost of running the service is frequency of training - this can be
used to determine when to train engine in order to control cost. If not
specified: the default value for CreateEngine method is TRAINING. The
default value for UpdateEngine method is to keep the state the same as
before.
Corresponds to the JSON property trainingState
25763 25764 25765 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25763 def training_state @training_state end |
#type ⇒ String
Required. The type of engine. e.g., recommended-for-you. This field together
with optimization_objective describe engine metadata to use to control engine
training and serving. Currently supported values: recommended-for-you,
others-you-may-like, more-like-this, most-popular-items.
Corresponds to the JSON property type
25771 25772 25773 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25771 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25778 25779 25780 25781 25782 25783 25784 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25778 def update!(**args) @engine_features_config = args[:engine_features_config] if args.key?(:engine_features_config) @optimization_objective = args[:optimization_objective] if args.key?(:optimization_objective) @optimization_objective_config = args[:optimization_objective_config] if args.key?(:optimization_objective_config) @training_state = args[:training_state] if args.key?(:training_state) @type = args[:type] if args.key?(:type) end |