Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaEngineSearchEngineConfig
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaEngineSearchEngineConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Configurations for a Search Engine.
Instance Attribute Summary collapse
-
#required_subscription_tier ⇒ String
Optional.
-
#search_add_ons ⇒ Array<String>
The add-on that this search engine enables.
-
#search_tier ⇒ String
The search feature tier of this engine.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaEngineSearchEngineConfig
constructor
A new instance of GoogleCloudDiscoveryengineV1betaEngineSearchEngineConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaEngineSearchEngineConfig
Returns a new instance of GoogleCloudDiscoveryengineV1betaEngineSearchEngineConfig.
25853 25854 25855 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25853 def initialize(**args) update!(**args) end |
Instance Attribute Details
#required_subscription_tier ⇒ String
Optional. The required subscription tier of this engine. If the required
subscription tier is search, user with higher license tier like assist can
still access the standalone app associated with this engine. Web grounding
feature is only available on the app if it is set as SubscriptionTier.
SUBSCRIPTION_TIER_SEARCH_AND_ASSISTANT.
Corresponds to the JSON property requiredSubscriptionTier
25839 25840 25841 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25839 def required_subscription_tier @required_subscription_tier end |
#search_add_ons ⇒ Array<String>
The add-on that this search engine enables.
Corresponds to the JSON property searchAddOns
25844 25845 25846 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25844 def search_add_ons @search_add_ons end |
#search_tier ⇒ String
The search feature tier of this engine. Different tiers might have different
pricing. To learn more, check the pricing documentation. Defaults to
SearchTier.SEARCH_TIER_STANDARD if not specified.
Corresponds to the JSON property searchTier
25851 25852 25853 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25851 def search_tier @search_tier end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25858 25859 25860 25861 25862 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25858 def update!(**args) @required_subscription_tier = args[:required_subscription_tier] if args.key?(:required_subscription_tier) @search_add_ons = args[:search_add_ons] if args.key?(:search_add_ons) @search_tier = args[:search_tier] if args.key?(:search_tier) end |