Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaEvaluation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

An evaluation is a single execution (or run) of an evaluation process. It encapsulates the state of the evaluation and the resulting data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaEvaluation

Returns a new instance of GoogleCloudDiscoveryengineV1betaEvaluation.



26084
26085
26086
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26084

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp the Evaluation was created at. Corresponds to the JSON property createTime

Returns:

  • (String)


26040
26041
26042
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26040

def create_time
  @create_time
end

#end_timeString

Output only. Timestamp the Evaluation was completed at. Corresponds to the JSON property endTime

Returns:

  • (String)


26045
26046
26047
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26045

def end_time
  @end_time
end

#errorGoogle::Apis::DiscoveryengineV1beta::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



26055
26056
26057
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26055

def error
  @error
end

#error_samplesArray<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>

Output only. A sample of errors encountered while processing the request. Corresponds to the JSON property errorSamples



26060
26061
26062
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26060

def error_samples
  @error_samples
end

#evaluation_specGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaEvaluationEvaluationSpec

Describes the specification of the evaluation. Corresponds to the JSON property evaluationSpec



26065
26066
26067
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26065

def evaluation_spec
  @evaluation_spec
end

#nameString

Identifier. The full resource name of the Evaluation, in the format of projects/project/locations/location/evaluations/evaluation`. This field must be a UTF-8 encoded string with a length limit of 1024 characters. Corresponds to the JSON propertyname`

Returns:

  • (String)


26072
26073
26074
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26072

def name
  @name
end

#quality_metricsGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaQualityMetrics

Describes the metrics produced by the evaluation. Corresponds to the JSON property qualityMetrics



26077
26078
26079
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26077

def quality_metrics
  @quality_metrics
end

#stateString

Output only. The state of the evaluation. Corresponds to the JSON property state

Returns:

  • (String)


26082
26083
26084
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26082

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26089
26090
26091
26092
26093
26094
26095
26096
26097
26098
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26089

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @error = args[:error] if args.key?(:error)
  @error_samples = args[:error_samples] if args.key?(:error_samples)
  @evaluation_spec = args[:evaluation_spec] if args.key?(:evaluation_spec)
  @name = args[:name] if args.key?(:name)
  @quality_metrics = args[:quality_metrics] if args.key?(:quality_metrics)
  @state = args[:state] if args.key?(:state)
end