Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaEvaluation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

An evaluation is a single execution (or run) of an evaluation process. It encapsulates the state of the evaluation and the resulting data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaEvaluation

Returns a new instance of GoogleCloudDiscoveryengineV1betaEvaluation.



25948
25949
25950
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25948

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp the Evaluation was created at. Corresponds to the JSON property createTime

Returns:

  • (String)


25904
25905
25906
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25904

def create_time
  @create_time
end

#end_timeString

Output only. Timestamp the Evaluation was completed at. Corresponds to the JSON property endTime

Returns:

  • (String)


25909
25910
25911
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25909

def end_time
  @end_time
end

#errorGoogle::Apis::DiscoveryengineV1beta::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



25919
25920
25921
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25919

def error
  @error
end

#error_samplesArray<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>

Output only. A sample of errors encountered while processing the request. Corresponds to the JSON property errorSamples



25924
25925
25926
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25924

def error_samples
  @error_samples
end

#evaluation_specGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaEvaluationEvaluationSpec

Describes the specification of the evaluation. Corresponds to the JSON property evaluationSpec



25929
25930
25931
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25929

def evaluation_spec
  @evaluation_spec
end

#nameString

Identifier. The full resource name of the Evaluation, in the format of projects/project/locations/location/evaluations/evaluation`. This field must be a UTF-8 encoded string with a length limit of 1024 characters. Corresponds to the JSON propertyname`

Returns:

  • (String)


25936
25937
25938
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25936

def name
  @name
end

#quality_metricsGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaQualityMetrics

Describes the metrics produced by the evaluation. Corresponds to the JSON property qualityMetrics



25941
25942
25943
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25941

def quality_metrics
  @quality_metrics
end

#stateString

Output only. The state of the evaluation. Corresponds to the JSON property state

Returns:

  • (String)


25946
25947
25948
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25946

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25953
25954
25955
25956
25957
25958
25959
25960
25961
25962
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25953

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @error = args[:error] if args.key?(:error)
  @error_samples = args[:error_samples] if args.key?(:error_samples)
  @evaluation_spec = args[:evaluation_spec] if args.key?(:evaluation_spec)
  @name = args[:name] if args.key?(:name)
  @quality_metrics = args[:quality_metrics] if args.key?(:quality_metrics)
  @state = args[:state] if args.key?(:state)
end