Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaFactChunk
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaFactChunk
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Fact Chunk.
Instance Attribute Summary collapse
-
#chunk_text ⇒ String
Text content of the fact chunk.
-
#domain ⇒ String
The domain of the source.
-
#index ⇒ Fixnum
The index of this chunk.
-
#source ⇒ String
Source from which this fact chunk was retrieved.
-
#source_metadata ⇒ Hash<String,String>
More fine-grained information for the source reference.
-
#title ⇒ String
The title of the source.
-
#uri ⇒ String
The URI of the source.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaFactChunk
constructor
A new instance of GoogleCloudDiscoveryengineV1betaFactChunk.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaFactChunk
Returns a new instance of GoogleCloudDiscoveryengineV1betaFactChunk.
26175 26176 26177 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26175 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chunk_text ⇒ String
Text content of the fact chunk. Can be at most 10K characters long.
Corresponds to the JSON property chunkText
26141 26142 26143 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26141 def chunk_text @chunk_text end |
#domain ⇒ String
The domain of the source.
Corresponds to the JSON property domain
26146 26147 26148 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26146 def domain @domain end |
#index ⇒ Fixnum
The index of this chunk. Currently, only used for the streaming mode.
Corresponds to the JSON property index
26151 26152 26153 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26151 def index @index end |
#source ⇒ String
Source from which this fact chunk was retrieved. If it was retrieved from the
GroundingFacts provided in the request then this field will contain the index
of the specific fact from which this chunk was retrieved.
Corresponds to the JSON property source
26158 26159 26160 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26158 def source @source end |
#source_metadata ⇒ Hash<String,String>
More fine-grained information for the source reference.
Corresponds to the JSON property sourceMetadata
26163 26164 26165 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26163 def @source_metadata end |
#title ⇒ String
The title of the source.
Corresponds to the JSON property title
26168 26169 26170 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26168 def title @title end |
#uri ⇒ String
The URI of the source.
Corresponds to the JSON property uri
26173 26174 26175 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26173 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26180 26181 26182 26183 26184 26185 26186 26187 26188 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26180 def update!(**args) @chunk_text = args[:chunk_text] if args.key?(:chunk_text) @domain = args[:domain] if args.key?(:domain) @index = args[:index] if args.key?(:index) @source = args[:source] if args.key?(:source) @source_metadata = args[:source_metadata] if args.key?(:source_metadata) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) end |