Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaFactChunk

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Fact Chunk.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaFactChunk

Returns a new instance of GoogleCloudDiscoveryengineV1betaFactChunk.



26188
26189
26190
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26188

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chunk_textString

Text content of the fact chunk. Can be at most 10K characters long. Corresponds to the JSON property chunkText

Returns:

  • (String)


26154
26155
26156
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26154

def chunk_text
  @chunk_text
end

#domainString

The domain of the source. Corresponds to the JSON property domain

Returns:

  • (String)


26159
26160
26161
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26159

def domain
  @domain
end

#indexFixnum

The index of this chunk. Currently, only used for the streaming mode. Corresponds to the JSON property index

Returns:

  • (Fixnum)


26164
26165
26166
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26164

def index
  @index
end

#sourceString

Source from which this fact chunk was retrieved. If it was retrieved from the GroundingFacts provided in the request then this field will contain the index of the specific fact from which this chunk was retrieved. Corresponds to the JSON property source

Returns:

  • (String)


26171
26172
26173
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26171

def source
  @source
end

#source_metadataHash<String,String>

More fine-grained information for the source reference. Corresponds to the JSON property sourceMetadata

Returns:

  • (Hash<String,String>)


26176
26177
26178
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26176

def 
  @source_metadata
end

#titleString

The title of the source. Corresponds to the JSON property title

Returns:

  • (String)


26181
26182
26183
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26181

def title
  @title
end

#uriString

The URI of the source. Corresponds to the JSON property uri

Returns:

  • (String)


26186
26187
26188
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26186

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26193
26194
26195
26196
26197
26198
26199
26200
26201
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26193

def update!(**args)
  @chunk_text = args[:chunk_text] if args.key?(:chunk_text)
  @domain = args[:domain] if args.key?(:domain)
  @index = args[:index] if args.key?(:index)
  @source = args[:source] if args.key?(:source)
  @source_metadata = args[:source_metadata] if args.key?(:source_metadata)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end