Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaFactChunk

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Fact Chunk.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaFactChunk

Returns a new instance of GoogleCloudDiscoveryengineV1betaFactChunk.



26052
26053
26054
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26052

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chunk_textString

Text content of the fact chunk. Can be at most 10K characters long. Corresponds to the JSON property chunkText

Returns:

  • (String)


26018
26019
26020
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26018

def chunk_text
  @chunk_text
end

#domainString

The domain of the source. Corresponds to the JSON property domain

Returns:

  • (String)


26023
26024
26025
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26023

def domain
  @domain
end

#indexFixnum

The index of this chunk. Currently, only used for the streaming mode. Corresponds to the JSON property index

Returns:

  • (Fixnum)


26028
26029
26030
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26028

def index
  @index
end

#sourceString

Source from which this fact chunk was retrieved. If it was retrieved from the GroundingFacts provided in the request then this field will contain the index of the specific fact from which this chunk was retrieved. Corresponds to the JSON property source

Returns:

  • (String)


26035
26036
26037
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26035

def source
  @source
end

#source_metadataHash<String,String>

More fine-grained information for the source reference. Corresponds to the JSON property sourceMetadata

Returns:

  • (Hash<String,String>)


26040
26041
26042
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26040

def 
  @source_metadata
end

#titleString

The title of the source. Corresponds to the JSON property title

Returns:

  • (String)


26045
26046
26047
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26045

def title
  @title
end

#uriString

The URI of the source. Corresponds to the JSON property uri

Returns:

  • (String)


26050
26051
26052
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26050

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26057
26058
26059
26060
26061
26062
26063
26064
26065
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26057

def update!(**args)
  @chunk_text = args[:chunk_text] if args.key?(:chunk_text)
  @domain = args[:domain] if args.key?(:domain)
  @index = args[:index] if args.key?(:index)
  @source = args[:source] if args.key?(:source)
  @source_metadata = args[:source_metadata] if args.key?(:source_metadata)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end