Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaFactChunk

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Fact Chunk.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaFactChunk

Returns a new instance of GoogleCloudDiscoveryengineV1betaFactChunk.



26021
26022
26023
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26021

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chunk_textString

Text content of the fact chunk. Can be at most 10K characters long. Corresponds to the JSON property chunkText

Returns:

  • (String)


25987
25988
25989
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25987

def chunk_text
  @chunk_text
end

#domainString

The domain of the source. Corresponds to the JSON property domain

Returns:

  • (String)


25992
25993
25994
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25992

def domain
  @domain
end

#indexFixnum

The index of this chunk. Currently, only used for the streaming mode. Corresponds to the JSON property index

Returns:

  • (Fixnum)


25997
25998
25999
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25997

def index
  @index
end

#sourceString

Source from which this fact chunk was retrieved. If it was retrieved from the GroundingFacts provided in the request then this field will contain the index of the specific fact from which this chunk was retrieved. Corresponds to the JSON property source

Returns:

  • (String)


26004
26005
26006
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26004

def source
  @source
end

#source_metadataHash<String,String>

More fine-grained information for the source reference. Corresponds to the JSON property sourceMetadata

Returns:

  • (Hash<String,String>)


26009
26010
26011
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26009

def 
  @source_metadata
end

#titleString

The title of the source. Corresponds to the JSON property title

Returns:

  • (String)


26014
26015
26016
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26014

def title
  @title
end

#uriString

The URI of the source. Corresponds to the JSON property uri

Returns:

  • (String)


26019
26020
26021
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26019

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26026
26027
26028
26029
26030
26031
26032
26033
26034
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26026

def update!(**args)
  @chunk_text = args[:chunk_text] if args.key?(:chunk_text)
  @domain = args[:domain] if args.key?(:domain)
  @index = args[:index] if args.key?(:index)
  @source = args[:source] if args.key?(:source)
  @source_metadata = args[:source_metadata] if args.key?(:source_metadata)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end