Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaFactChunk

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Fact Chunk.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaFactChunk

Returns a new instance of GoogleCloudDiscoveryengineV1betaFactChunk.



25375
25376
25377
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25375

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chunk_textString

Text content of the fact chunk. Can be at most 10K characters long. Corresponds to the JSON property chunkText

Returns:

  • (String)


25341
25342
25343
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25341

def chunk_text
  @chunk_text
end

#domainString

The domain of the source. Corresponds to the JSON property domain

Returns:

  • (String)


25346
25347
25348
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25346

def domain
  @domain
end

#indexFixnum

The index of this chunk. Currently, only used for the streaming mode. Corresponds to the JSON property index

Returns:

  • (Fixnum)


25351
25352
25353
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25351

def index
  @index
end

#sourceString

Source from which this fact chunk was retrieved. If it was retrieved from the GroundingFacts provided in the request then this field will contain the index of the specific fact from which this chunk was retrieved. Corresponds to the JSON property source

Returns:

  • (String)


25358
25359
25360
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25358

def source
  @source
end

#source_metadataHash<String,String>

More fine-grained information for the source reference. Corresponds to the JSON property sourceMetadata

Returns:

  • (Hash<String,String>)


25363
25364
25365
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25363

def 
  @source_metadata
end

#titleString

The title of the source. Corresponds to the JSON property title

Returns:

  • (String)


25368
25369
25370
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25368

def title
  @title
end

#uriString

The URI of the source. Corresponds to the JSON property uri

Returns:

  • (String)


25373
25374
25375
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25373

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25380
25381
25382
25383
25384
25385
25386
25387
25388
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25380

def update!(**args)
  @chunk_text = args[:chunk_text] if args.key?(:chunk_text)
  @domain = args[:domain] if args.key?(:domain)
  @index = args[:index] if args.key?(:index)
  @source = args[:source] if args.key?(:source)
  @source_metadata = args[:source_metadata] if args.key?(:source_metadata)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end