Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaFeedback
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaFeedback
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Information about the user feedback. This information will be used for logging and metrics purpose.
Instance Attribute Summary collapse
-
#comment ⇒ String
Optional.
-
#component_version ⇒ String
Optional.
-
#conversation_info ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaFeedbackConversationInfo
The conversation information such as the question index and session name.
-
#data_terms_accepted ⇒ Boolean
(also: #data_terms_accepted?)
Optional.
-
#feedback_source ⇒ String
Optional.
-
#feedback_type ⇒ String
Required.
-
#llm_model_version ⇒ String
The version of the LLM model that was used to generate the response.
-
#reasons ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaFeedback
constructor
A new instance of GoogleCloudDiscoveryengineV1betaFeedback.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaFeedback
Returns a new instance of GoogleCloudDiscoveryengineV1betaFeedback.
26086 26087 26088 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26086 def initialize(**args) update!(**args) end |
Instance Attribute Details
#comment ⇒ String
Optional. The additional user comment of the feedback if user gives a thumb
down.
Corresponds to the JSON property comment
26046 26047 26048 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26046 def comment @comment end |
#component_version ⇒ String
Optional. The version of the component that this report is being sent from.
Corresponds to the JSON property componentVersion
26051 26052 26053 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26051 def component_version @component_version end |
#conversation_info ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaFeedbackConversationInfo
The conversation information such as the question index and session name.
Corresponds to the JSON property conversationInfo
26056 26057 26058 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26056 def conversation_info @conversation_info end |
#data_terms_accepted ⇒ Boolean Also known as: data_terms_accepted?
Optional. Whether the customer accepted data use terms.
Corresponds to the JSON property dataTermsAccepted
26061 26062 26063 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26061 def data_terms_accepted @data_terms_accepted end |
#feedback_source ⇒ String
Optional. The UI component the user feedback comes from, which could be
GOOGLE_CONSOLE, GOOGLE_WIDGET, GOOGLE_WEBAPP.
Corresponds to the JSON property feedbackSource
26068 26069 26070 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26068 def feedback_source @feedback_source end |
#feedback_type ⇒ String
Required. Indicate whether the user gives a positive or negative feedback. If
the user gives a negative feedback, there might be more feedback details.
Corresponds to the JSON property feedbackType
26074 26075 26076 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26074 def feedback_type @feedback_type end |
#llm_model_version ⇒ String
The version of the LLM model that was used to generate the response.
Corresponds to the JSON property llmModelVersion
26079 26080 26081 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26079 def llm_model_version @llm_model_version end |
#reasons ⇒ Array<String>
Optional. The reason if user gives a thumb down.
Corresponds to the JSON property reasons
26084 26085 26086 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26084 def reasons @reasons end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26091 26092 26093 26094 26095 26096 26097 26098 26099 26100 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26091 def update!(**args) @comment = args[:comment] if args.key?(:comment) @component_version = args[:component_version] if args.key?(:component_version) @conversation_info = args[:conversation_info] if args.key?(:conversation_info) @data_terms_accepted = args[:data_terms_accepted] if args.key?(:data_terms_accepted) @feedback_source = args[:feedback_source] if args.key?(:feedback_source) @feedback_type = args[:feedback_type] if args.key?(:feedback_type) @llm_model_version = args[:llm_model_version] if args.key?(:llm_model_version) @reasons = args[:reasons] if args.key?(:reasons) end |