Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaFeedback
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaFeedback
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Information about the user feedback. This information will be used for logging and metrics purpose.
Instance Attribute Summary collapse
-
#comment ⇒ String
Optional.
-
#component_version ⇒ String
Optional.
-
#conversation_info ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaFeedbackConversationInfo
The conversation information such as the question index and session name.
-
#data_terms_accepted ⇒ Boolean
(also: #data_terms_accepted?)
Optional.
-
#feedback_source ⇒ String
Optional.
-
#feedback_type ⇒ String
Required.
-
#llm_model_version ⇒ String
The version of the LLM model that was used to generate the response.
-
#reasons ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaFeedback
constructor
A new instance of GoogleCloudDiscoveryengineV1betaFeedback.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaFeedback
Returns a new instance of GoogleCloudDiscoveryengineV1betaFeedback.
25228 25229 25230 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25228 def initialize(**args) update!(**args) end |
Instance Attribute Details
#comment ⇒ String
Optional. The additional user comment of the feedback if user gives a thumb
down.
Corresponds to the JSON property comment
25188 25189 25190 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25188 def comment @comment end |
#component_version ⇒ String
Optional. The version of the component that this report is being sent from.
Corresponds to the JSON property componentVersion
25193 25194 25195 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25193 def component_version @component_version end |
#conversation_info ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaFeedbackConversationInfo
The conversation information such as the question index and session name.
Corresponds to the JSON property conversationInfo
25198 25199 25200 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25198 def conversation_info @conversation_info end |
#data_terms_accepted ⇒ Boolean Also known as: data_terms_accepted?
Optional. Whether the customer accepted data use terms.
Corresponds to the JSON property dataTermsAccepted
25203 25204 25205 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25203 def data_terms_accepted @data_terms_accepted end |
#feedback_source ⇒ String
Optional. The UI component the user feedback comes from, which could be
GOOGLE_CONSOLE, GOOGLE_WIDGET, GOOGLE_WEBAPP.
Corresponds to the JSON property feedbackSource
25210 25211 25212 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25210 def feedback_source @feedback_source end |
#feedback_type ⇒ String
Required. Indicate whether the user gives a positive or negative feedback. If
the user gives a negative feedback, there might be more feedback details.
Corresponds to the JSON property feedbackType
25216 25217 25218 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25216 def feedback_type @feedback_type end |
#llm_model_version ⇒ String
The version of the LLM model that was used to generate the response.
Corresponds to the JSON property llmModelVersion
25221 25222 25223 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25221 def llm_model_version @llm_model_version end |
#reasons ⇒ Array<String>
Optional. The reason if user gives a thumb down.
Corresponds to the JSON property reasons
25226 25227 25228 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25226 def reasons @reasons end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25233 25234 25235 25236 25237 25238 25239 25240 25241 25242 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25233 def update!(**args) @comment = args[:comment] if args.key?(:comment) @component_version = args[:component_version] if args.key?(:component_version) @conversation_info = args[:conversation_info] if args.key?(:conversation_info) @data_terms_accepted = args[:data_terms_accepted] if args.key?(:data_terms_accepted) @feedback_source = args[:feedback_source] if args.key?(:feedback_source) @feedback_type = args[:feedback_type] if args.key?(:feedback_type) @llm_model_version = args[:llm_model_version] if args.key?(:llm_model_version) @reasons = args[:reasons] if args.key?(:reasons) end |