Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaFeedbackConversationInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

The conversation information such as the question index and session name.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaFeedbackConversationInfo

Returns a new instance of GoogleCloudDiscoveryengineV1betaFeedbackConversationInfo.



26299
26300
26301
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26299

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#answer_query_tokenString

Optional. The token which could be used to fetch the answer log. Corresponds to the JSON property answerQueryToken

Returns:

  • (String)


26277
26278
26279
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26277

def answer_query_token
  @answer_query_token
end

#assist_tokenString

Optional. The token which could be used to fetch the assistant log. Corresponds to the JSON property assistToken

Returns:

  • (String)


26282
26283
26284
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26282

def assist_token
  @assist_token
end

#queryGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaQuery

Defines a user inputed query. Corresponds to the JSON property query



26287
26288
26289
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26287

def query
  @query
end

#question_indexFixnum

The index of the user input within the conversation messages. Corresponds to the JSON property questionIndex

Returns:

  • (Fixnum)


26292
26293
26294
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26292

def question_index
  @question_index
end

#sessionString

Name of the newly generated or continued session. Corresponds to the JSON property session

Returns:

  • (String)


26297
26298
26299
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26297

def session
  @session
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26304
26305
26306
26307
26308
26309
26310
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26304

def update!(**args)
  @answer_query_token = args[:answer_query_token] if args.key?(:answer_query_token)
  @assist_token = args[:assist_token] if args.key?(:assist_token)
  @query = args[:query] if args.key?(:query)
  @question_index = args[:question_index] if args.key?(:question_index)
  @session = args[:session] if args.key?(:session)
end