Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaFeedbackConversationInfo
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaFeedbackConversationInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
The conversation information such as the question index and session name.
Instance Attribute Summary collapse
-
#answer_query_token ⇒ String
Optional.
-
#assist_token ⇒ String
Optional.
-
#query ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaQuery
Defines a user inputed query.
-
#question_index ⇒ Fixnum
The index of the user input within the conversation messages.
-
#session ⇒ String
Name of the newly generated or continued session.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaFeedbackConversationInfo
constructor
A new instance of GoogleCloudDiscoveryengineV1betaFeedbackConversationInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaFeedbackConversationInfo
Returns a new instance of GoogleCloudDiscoveryengineV1betaFeedbackConversationInfo.
26163 26164 26165 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26163 def initialize(**args) update!(**args) end |
Instance Attribute Details
#answer_query_token ⇒ String
Optional. The token which could be used to fetch the answer log.
Corresponds to the JSON property answerQueryToken
26141 26142 26143 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26141 def answer_query_token @answer_query_token end |
#assist_token ⇒ String
Optional. The token which could be used to fetch the assistant log.
Corresponds to the JSON property assistToken
26146 26147 26148 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26146 def assist_token @assist_token end |
#query ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaQuery
Defines a user inputed query.
Corresponds to the JSON property query
26151 26152 26153 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26151 def query @query end |
#question_index ⇒ Fixnum
The index of the user input within the conversation messages.
Corresponds to the JSON property questionIndex
26156 26157 26158 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26156 def question_index @question_index end |
#session ⇒ String
Name of the newly generated or continued session.
Corresponds to the JSON property session
26161 26162 26163 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26161 def session @session end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26168 26169 26170 26171 26172 26173 26174 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26168 def update!(**args) @answer_query_token = args[:answer_query_token] if args.key?(:answer_query_token) @assist_token = args[:assist_token] if args.key?(:assist_token) @query = args[:query] if args.key?(:query) @question_index = args[:question_index] if args.key?(:question_index) @session = args[:session] if args.key?(:session) end |