Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaFeedbackConversationInfo
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaFeedbackConversationInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
The conversation information such as the question index and session name.
Instance Attribute Summary collapse
-
#answer_query_token ⇒ String
Optional.
-
#assist_token ⇒ String
Optional.
-
#query ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaQuery
Defines a user inputed query.
-
#question_index ⇒ Fixnum
The index of the user input within the conversation messages.
-
#session ⇒ String
Name of the newly generated or continued session.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaFeedbackConversationInfo
constructor
A new instance of GoogleCloudDiscoveryengineV1betaFeedbackConversationInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaFeedbackConversationInfo
Returns a new instance of GoogleCloudDiscoveryengineV1betaFeedbackConversationInfo.
25274 25275 25276 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25274 def initialize(**args) update!(**args) end |
Instance Attribute Details
#answer_query_token ⇒ String
Optional. The token which could be used to fetch the answer log.
Corresponds to the JSON property answerQueryToken
25252 25253 25254 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25252 def answer_query_token @answer_query_token end |
#assist_token ⇒ String
Optional. The token which could be used to fetch the assistant log.
Corresponds to the JSON property assistToken
25257 25258 25259 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25257 def assist_token @assist_token end |
#query ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaQuery
Defines a user inputed query.
Corresponds to the JSON property query
25262 25263 25264 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25262 def query @query end |
#question_index ⇒ Fixnum
The index of the user input within the conversation messages.
Corresponds to the JSON property questionIndex
25267 25268 25269 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25267 def question_index @question_index end |
#session ⇒ String
Name of the newly generated or continued session.
Corresponds to the JSON property session
25272 25273 25274 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25272 def session @session end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25279 25280 25281 25282 25283 25284 25285 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25279 def update!(**args) @answer_query_token = args[:answer_query_token] if args.key?(:answer_query_token) @assist_token = args[:assist_token] if args.key?(:assist_token) @query = args[:query] if args.key?(:query) @question_index = args[:question_index] if args.key?(:question_index) @session = args[:session] if args.key?(:session) end |