Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaFhirStoreSource
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaFhirStoreSource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Cloud FhirStore source import data from.
Instance Attribute Summary collapse
-
#fhir_store ⇒ String
Required.
-
#gcs_staging_dir ⇒ String
Intermediate Cloud Storage directory used for the import with a length limit of 2,000 characters.
-
#resource_types ⇒ Array<String>
The FHIR resource types to import.
-
#update_from_latest_predefined_schema ⇒ Boolean
(also: #update_from_latest_predefined_schema?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaFhirStoreSource
constructor
A new instance of GoogleCloudDiscoveryengineV1betaFhirStoreSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaFhirStoreSource
Returns a new instance of GoogleCloudDiscoveryengineV1betaFhirStoreSource.
26409 26410 26411 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26409 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fhir_store ⇒ String
Required. The full resource name of the FHIR store to import data from, in the
format of projects/project/locations/location/datasets/dataset/
fhirStores/fhir_store`.
Corresponds to the JSON propertyfhirStore`
26381 26382 26383 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26381 def fhir_store @fhir_store end |
#gcs_staging_dir ⇒ String
Intermediate Cloud Storage directory used for the import with a length limit
of 2,000 characters. Can be specified if one wants to have the FhirStore
export to a specific Cloud Storage directory.
Corresponds to the JSON property gcsStagingDir
26388 26389 26390 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26388 def gcs_staging_dir @gcs_staging_dir end |
#resource_types ⇒ Array<String>
The FHIR resource types to import. The resource types should be a subset of
all supported FHIR resource types. Default to
all supported FHIR resource types if empty.
Corresponds to the JSON property resourceTypes
26396 26397 26398 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26396 def resource_types @resource_types end |
#update_from_latest_predefined_schema ⇒ Boolean Also known as: update_from_latest_predefined_schema?
Optional. Whether to update the DataStore schema to the latest predefined
schema. If true, the DataStore schema will be updated to include any FHIR
fields or resource types that have been added since the last import and
corresponding FHIR resources will be imported from the FHIR store. Note this
field cannot be used in conjunction with resource_types. It should be used
after initial import.
Corresponds to the JSON property updateFromLatestPredefinedSchema
26406 26407 26408 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26406 def update_from_latest_predefined_schema @update_from_latest_predefined_schema end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26414 26415 26416 26417 26418 26419 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26414 def update!(**args) @fhir_store = args[:fhir_store] if args.key?(:fhir_store) @gcs_staging_dir = args[:gcs_staging_dir] if args.key?(:gcs_staging_dir) @resource_types = args[:resource_types] if args.key?(:resource_types) @update_from_latest_predefined_schema = args[:update_from_latest_predefined_schema] if args.key?(:update_from_latest_predefined_schema) end |