Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaFhirStoreSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Cloud FhirStore source import data from.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaFhirStoreSource

Returns a new instance of GoogleCloudDiscoveryengineV1betaFhirStoreSource.



25397
25398
25399
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25397

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fhir_storeString

Required. The full resource name of the FHIR store to import data from, in the format of projects/project/locations/location/datasets/dataset/ fhirStores/fhir_store`. Corresponds to the JSON propertyfhirStore`

Returns:

  • (String)


25369
25370
25371
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25369

def fhir_store
  @fhir_store
end

#gcs_staging_dirString

Intermediate Cloud Storage directory used for the import with a length limit of 2,000 characters. Can be specified if one wants to have the FhirStore export to a specific Cloud Storage directory. Corresponds to the JSON property gcsStagingDir

Returns:

  • (String)


25376
25377
25378
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25376

def gcs_staging_dir
  @gcs_staging_dir
end

#resource_typesArray<String>

The FHIR resource types to import. The resource types should be a subset of all supported FHIR resource types. Default to all supported FHIR resource types if empty. Corresponds to the JSON property resourceTypes

Returns:

  • (Array<String>)


25384
25385
25386
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25384

def resource_types
  @resource_types
end

#update_from_latest_predefined_schemaBoolean Also known as: update_from_latest_predefined_schema?

Optional. Whether to update the DataStore schema to the latest predefined schema. If true, the DataStore schema will be updated to include any FHIR fields or resource types that have been added since the last import and corresponding FHIR resources will be imported from the FHIR store. Note this field cannot be used in conjunction with resource_types. It should be used after initial import. Corresponds to the JSON property updateFromLatestPredefinedSchema

Returns:

  • (Boolean)


25394
25395
25396
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25394

def update_from_latest_predefined_schema
  @update_from_latest_predefined_schema
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25402
25403
25404
25405
25406
25407
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25402

def update!(**args)
  @fhir_store = args[:fhir_store] if args.key?(:fhir_store)
  @gcs_staging_dir = args[:gcs_staging_dir] if args.key?(:gcs_staging_dir)
  @resource_types = args[:resource_types] if args.key?(:resource_types)
  @update_from_latest_predefined_schema = args[:update_from_latest_predefined_schema] if args.key?(:update_from_latest_predefined_schema)
end