Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaFirestoreSource
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaFirestoreSource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Firestore source import data from.
Instance Attribute Summary collapse
-
#collection_id ⇒ String
Required.
-
#database_id ⇒ String
Required.
-
#gcs_staging_dir ⇒ String
Intermediate Cloud Storage directory used for the import with a length limit of 2,000 characters.
-
#project_id ⇒ String
The project ID that the Cloud SQL source is in with a length limit of 128 characters.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaFirestoreSource
constructor
A new instance of GoogleCloudDiscoveryengineV1betaFirestoreSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaFirestoreSource
Returns a new instance of GoogleCloudDiscoveryengineV1betaFirestoreSource.
26330 26331 26332 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26330 def initialize(**args) update!(**args) end |
Instance Attribute Details
#collection_id ⇒ String
Required. The Firestore collection (or entity) to copy the data from with a
length limit of 1,500 characters.
Corresponds to the JSON property collectionId
26307 26308 26309 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26307 def collection_id @collection_id end |
#database_id ⇒ String
Required. The Firestore database to copy the data from with a length limit of
256 characters.
Corresponds to the JSON property databaseId
26313 26314 26315 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26313 def database_id @database_id end |
#gcs_staging_dir ⇒ String
Intermediate Cloud Storage directory used for the import with a length limit
of 2,000 characters. Can be specified if one wants to have the Firestore
export to a specific Cloud Storage directory. Ensure that the Firestore
service account has the necessary Cloud Storage Admin permissions to access
the specified Cloud Storage directory.
Corresponds to the JSON property gcsStagingDir
26322 26323 26324 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26322 def gcs_staging_dir @gcs_staging_dir end |
#project_id ⇒ String
The project ID that the Cloud SQL source is in with a length limit of 128
characters. If not specified, inherits the project ID from the parent request.
Corresponds to the JSON property projectId
26328 26329 26330 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26328 def project_id @project_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26335 26336 26337 26338 26339 26340 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26335 def update!(**args) @collection_id = args[:collection_id] if args.key?(:collection_id) @database_id = args[:database_id] if args.key?(:database_id) @gcs_staging_dir = args[:gcs_staging_dir] if args.key?(:gcs_staging_dir) @project_id = args[:project_id] if args.key?(:project_id) end |