Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaFirestoreSource
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaFirestoreSource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Firestore source import data from.
Instance Attribute Summary collapse
-
#collection_id ⇒ String
Required.
-
#database_id ⇒ String
Required.
-
#gcs_staging_dir ⇒ String
Intermediate Cloud Storage directory used for the import with a length limit of 2,000 characters.
-
#project_id ⇒ String
The project ID that the Cloud SQL source is in with a length limit of 128 characters.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaFirestoreSource
constructor
A new instance of GoogleCloudDiscoveryengineV1betaFirestoreSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaFirestoreSource
Returns a new instance of GoogleCloudDiscoveryengineV1betaFirestoreSource.
26299 26300 26301 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26299 def initialize(**args) update!(**args) end |
Instance Attribute Details
#collection_id ⇒ String
Required. The Firestore collection (or entity) to copy the data from with a
length limit of 1,500 characters.
Corresponds to the JSON property collectionId
26276 26277 26278 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26276 def collection_id @collection_id end |
#database_id ⇒ String
Required. The Firestore database to copy the data from with a length limit of
256 characters.
Corresponds to the JSON property databaseId
26282 26283 26284 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26282 def database_id @database_id end |
#gcs_staging_dir ⇒ String
Intermediate Cloud Storage directory used for the import with a length limit
of 2,000 characters. Can be specified if one wants to have the Firestore
export to a specific Cloud Storage directory. Ensure that the Firestore
service account has the necessary Cloud Storage Admin permissions to access
the specified Cloud Storage directory.
Corresponds to the JSON property gcsStagingDir
26291 26292 26293 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26291 def gcs_staging_dir @gcs_staging_dir end |
#project_id ⇒ String
The project ID that the Cloud SQL source is in with a length limit of 128
characters. If not specified, inherits the project ID from the parent request.
Corresponds to the JSON property projectId
26297 26298 26299 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26297 def project_id @project_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26304 26305 26306 26307 26308 26309 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26304 def update!(**args) @collection_id = args[:collection_id] if args.key?(:collection_id) @database_id = args[:database_id] if args.key?(:database_id) @gcs_staging_dir = args[:gcs_staging_dir] if args.key?(:gcs_staging_dir) @project_id = args[:project_id] if args.key?(:project_id) end |