Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaFirestoreSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Firestore source import data from.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaFirestoreSource

Returns a new instance of GoogleCloudDiscoveryengineV1betaFirestoreSource.



25653
25654
25655
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25653

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#collection_idString

Required. The Firestore collection (or entity) to copy the data from with a length limit of 1,500 characters. Corresponds to the JSON property collectionId

Returns:

  • (String)


25630
25631
25632
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25630

def collection_id
  @collection_id
end

#database_idString

Required. The Firestore database to copy the data from with a length limit of 256 characters. Corresponds to the JSON property databaseId

Returns:

  • (String)


25636
25637
25638
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25636

def database_id
  @database_id
end

#gcs_staging_dirString

Intermediate Cloud Storage directory used for the import with a length limit of 2,000 characters. Can be specified if one wants to have the Firestore export to a specific Cloud Storage directory. Ensure that the Firestore service account has the necessary Cloud Storage Admin permissions to access the specified Cloud Storage directory. Corresponds to the JSON property gcsStagingDir

Returns:

  • (String)


25645
25646
25647
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25645

def gcs_staging_dir
  @gcs_staging_dir
end

#project_idString

The project ID that the Cloud SQL source is in with a length limit of 128 characters. If not specified, inherits the project ID from the parent request. Corresponds to the JSON property projectId

Returns:

  • (String)


25651
25652
25653
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25651

def project_id
  @project_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25658
25659
25660
25661
25662
25663
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25658

def update!(**args)
  @collection_id = args[:collection_id] if args.key?(:collection_id)
  @database_id = args[:database_id] if args.key?(:database_id)
  @gcs_staging_dir = args[:gcs_staging_dir] if args.key?(:gcs_staging_dir)
  @project_id = args[:project_id] if args.key?(:project_id)
end