Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaIdentityMappingEntry
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaIdentityMappingEntry
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Identity Mapping Entry that maps an external identity to an internal identity.
Instance Attribute Summary collapse
-
#external_identity ⇒ String
Required.
-
#external_identity_name ⇒ String
Optional.
-
#group_id ⇒ String
Group identifier.
-
#user_id ⇒ String
User identifier.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaIdentityMappingEntry
constructor
A new instance of GoogleCloudDiscoveryengineV1betaIdentityMappingEntry.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaIdentityMappingEntry
Returns a new instance of GoogleCloudDiscoveryengineV1betaIdentityMappingEntry.
26450 26451 26452 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26450 def initialize(**args) update!(**args) end |
Instance Attribute Details
#external_identity ⇒ String
Required. Identity outside the customer identity provider. The length limit of
external identity will be of 100 characters.
Corresponds to the JSON property externalIdentity
26429 26430 26431 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26429 def external_identity @external_identity end |
#external_identity_name ⇒ String
Optional. The name of the external identity.
Corresponds to the JSON property externalIdentityName
26434 26435 26436 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26434 def external_identity_name @external_identity_name end |
#group_id ⇒ String
Group identifier. For Google Workspace user account, group_id should be the
google workspace group email. For non-google identity provider, group_id is
the mapped group identifier configured during the workforcepool config.
Corresponds to the JSON property groupId
26441 26442 26443 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26441 def group_id @group_id end |
#user_id ⇒ String
User identifier. For Google Workspace user account, user_id should be the
google workspace user email. For non-google identity provider, user_id is the
mapped user identifier configured during the workforcepool config.
Corresponds to the JSON property userId
26448 26449 26450 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26448 def user_id @user_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26455 26456 26457 26458 26459 26460 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26455 def update!(**args) @external_identity = args[:external_identity] if args.key?(:external_identity) @external_identity_name = args[:external_identity_name] if args.key?(:external_identity_name) @group_id = args[:group_id] if args.key?(:group_id) @user_id = args[:user_id] if args.key?(:user_id) end |