Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaIdentityMappingEntry

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Identity Mapping Entry that maps an external identity to an internal identity.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaIdentityMappingEntry

Returns a new instance of GoogleCloudDiscoveryengineV1betaIdentityMappingEntry.



25804
25805
25806
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25804

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#external_identityString

Required. Identity outside the customer identity provider. The length limit of external identity will be of 100 characters. Corresponds to the JSON property externalIdentity

Returns:

  • (String)


25783
25784
25785
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25783

def external_identity
  @external_identity
end

#external_identity_nameString

Optional. The name of the external identity. Corresponds to the JSON property externalIdentityName

Returns:

  • (String)


25788
25789
25790
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25788

def external_identity_name
  @external_identity_name
end

#group_idString

Group identifier. For Google Workspace user account, group_id should be the google workspace group email. For non-google identity provider, group_id is the mapped group identifier configured during the workforcepool config. Corresponds to the JSON property groupId

Returns:

  • (String)


25795
25796
25797
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25795

def group_id
  @group_id
end

#user_idString

User identifier. For Google Workspace user account, user_id should be the google workspace user email. For non-google identity provider, user_id is the mapped user identifier configured during the workforcepool config. Corresponds to the JSON property userId

Returns:

  • (String)


25802
25803
25804
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25802

def user_id
  @user_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25809
25810
25811
25812
25813
25814
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25809

def update!(**args)
  @external_identity = args[:external_identity] if args.key?(:external_identity)
  @external_identity_name = args[:external_identity_name] if args.key?(:external_identity_name)
  @group_id = args[:group_id] if args.key?(:group_id)
  @user_id = args[:user_id] if args.key?(:user_id)
end