Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaIdentityMappingStore

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Identity Mapping Store which contains Identity Mapping Entries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaIdentityMappingStore

Returns a new instance of GoogleCloudDiscoveryengineV1betaIdentityMappingStore.



26577
26578
26579
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26577

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cmek_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCmekConfig

Configurations used to enable CMEK data encryption with Cloud KMS keys. Corresponds to the JSON property cmekConfig



26558
26559
26560
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26558

def cmek_config
  @cmek_config
end

#kms_key_nameString

Input only. The KMS key to be used to protect this Identity Mapping Store at creation time. Must be set for requests that need to comply with CMEK Org Policy protections. If this field is set and processed successfully, the Identity Mapping Store will be protected by the KMS key, as indicated in the cmek_config field. Corresponds to the JSON property kmsKeyName

Returns:

  • (String)


26567
26568
26569
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26567

def kms_key_name
  @kms_key_name
end

#nameString

Immutable. The full resource name of the identity mapping store. Format: projects/project/locations/location/identityMappingStores/ identity_mapping_store`. This field must be a UTF-8 encoded string with a length limit of 1024 characters. Corresponds to the JSON propertyname`

Returns:

  • (String)


26575
26576
26577
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26575

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26582
26583
26584
26585
26586
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26582

def update!(**args)
  @cmek_config = args[:cmek_config] if args.key?(:cmek_config)
  @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name)
  @name = args[:name] if args.key?(:name)
end