Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaIdentityMappingStore
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaIdentityMappingStore
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Identity Mapping Store which contains Identity Mapping Entries.
Instance Attribute Summary collapse
-
#cmek_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCmekConfig
Configurations used to enable CMEK data encryption with Cloud KMS keys.
-
#kms_key_name ⇒ String
Input only.
-
#name ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaIdentityMappingStore
constructor
A new instance of GoogleCloudDiscoveryengineV1betaIdentityMappingStore.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaIdentityMappingStore
Returns a new instance of GoogleCloudDiscoveryengineV1betaIdentityMappingStore.
26553 26554 26555 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26553 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cmek_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCmekConfig
Configurations used to enable CMEK data encryption with Cloud KMS keys.
Corresponds to the JSON property cmekConfig
26534 26535 26536 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26534 def cmek_config @cmek_config end |
#kms_key_name ⇒ String
Input only. The KMS key to be used to protect this Identity Mapping Store at
creation time. Must be set for requests that need to comply with CMEK Org
Policy protections. If this field is set and processed successfully, the
Identity Mapping Store will be protected by the KMS key, as indicated in the
cmek_config field.
Corresponds to the JSON property kmsKeyName
26543 26544 26545 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26543 def kms_key_name @kms_key_name end |
#name ⇒ String
Immutable. The full resource name of the identity mapping store. Format:
projects/project/locations/location/identityMappingStores/
identity_mapping_store`. This field must be a UTF-8 encoded string with a
length limit of 1024 characters.
Corresponds to the JSON propertyname`
26551 26552 26553 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26551 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26558 26559 26560 26561 26562 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26558 def update!(**args) @cmek_config = args[:cmek_config] if args.key?(:cmek_config) @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name) @name = args[:name] if args.key?(:name) end |