Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaImportDocumentsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Request message for Import methods.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaImportDocumentsRequest

Returns a new instance of GoogleCloudDiscoveryengineV1betaImportDocumentsRequest.



27020
27021
27022
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27020

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#alloy_db_sourceGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAlloyDbSource

AlloyDB source import data from. Corresponds to the JSON property alloyDbSource



26919
26920
26921
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26919

def alloy_db_source
  @alloy_db_source
end

#auto_generate_idsBoolean Also known as: auto_generate_ids?

Whether to automatically generate IDs for the documents if absent. If set to true, Document.ids are automatically generated based on the hash of the payload, where IDs may not be consistent during multiple imports. In which case ReconciliationMode.FULL is highly recommended to avoid duplicate contents. If unset or set to false, Document.ids have to be specified using id_field, otherwise, documents without IDs fail to be imported. Supported data sources: * GcsSource. GcsSource.data_schema must be custom or csv. Otherwise, an INVALID_ARGUMENT error is thrown. * BigQuerySource. BigQuerySource.data_schema must be custom or csv. Otherwise, an INVALID_ARGUMENT error is thrown. * SpannerSource. * CloudSqlSource. * FirestoreSource. * BigtableSource. Corresponds to the JSON property autoGenerateIds

Returns:

  • (Boolean)


26933
26934
26935
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26933

def auto_generate_ids
  @auto_generate_ids
end

#bigquery_sourceGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaBigQuerySource

BigQuery source import data from. Corresponds to the JSON property bigquerySource



26939
26940
26941
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26939

def bigquery_source
  @bigquery_source
end

#bigtable_sourceGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaBigtableSource

The Cloud Bigtable source for importing data. Corresponds to the JSON property bigtableSource



26944
26945
26946
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26944

def bigtable_source
  @bigtable_source
end

#cloud_sql_sourceGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCloudSqlSource

Cloud SQL source import data from. Corresponds to the JSON property cloudSqlSource



26949
26950
26951
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26949

def cloud_sql_source
  @cloud_sql_source
end

#error_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaImportErrorConfig

Configuration of destination for Import related errors. Corresponds to the JSON property errorConfig



26954
26955
26956
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26954

def error_config
  @error_config
end

#fhir_store_sourceGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaFhirStoreSource

Cloud FhirStore source import data from. Corresponds to the JSON property fhirStoreSource



26959
26960
26961
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26959

def fhir_store_source
  @fhir_store_source
end

#firestore_sourceGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaFirestoreSource

Firestore source import data from. Corresponds to the JSON property firestoreSource



26964
26965
26966
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26964

def firestore_source
  @firestore_source
end

#force_refresh_contentBoolean Also known as: force_refresh_content?

Optional. Whether to force refresh the unstructured content of the documents. If set to true, the content part of the documents will be refreshed regardless of the update status of the referencing content. Corresponds to the JSON property forceRefreshContent

Returns:

  • (Boolean)


26971
26972
26973
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26971

def force_refresh_content
  @force_refresh_content
end

#gcs_sourceGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaGcsSource

Cloud Storage location for input content. Corresponds to the JSON property gcsSource



26977
26978
26979
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26977

def gcs_source
  @gcs_source
end

#id_fieldString

The field indicates the ID field or column to be used as unique IDs of the documents. For GcsSource it is the key of the JSON field. For instance, my_id for JSON "my_id": "some_uuid". For others, it may be the column name of the table where the unique ids are stored. The values of the JSON field or the table column are used as the Document.ids. The JSON field or the table column must be of string type, and the values must be set as valid strings conform to RFC-1034 with 1-63 characters. Otherwise, documents without valid IDs fail to be imported. Only set this field when auto_generate_ids is unset or set as false. Otherwise, an INVALID_ARGUMENT error is thrown. If it is unset, a default value _id is used when importing from the allowed data sources. Supported data sources: * GcsSource. GcsSource.data_schema must be custom or csv. Otherwise, an INVALID_ARGUMENT error is thrown. * BigQuerySource. BigQuerySource.data_schema must be custom or csv. Otherwise, an INVALID_ARGUMENT error is thrown. * SpannerSource. * CloudSqlSource. * BigtableSource. Corresponds to the JSON property idField

Returns:

  • (String)


26996
26997
26998
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26996

def id_field
  @id_field
end

#inline_sourceGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaImportDocumentsRequestInlineSource

The inline source for the input config for ImportDocuments method. Corresponds to the JSON property inlineSource



27001
27002
27003
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27001

def inline_source
  @inline_source
end

#reconciliation_modeString

The mode of reconciliation between existing documents and the documents to be imported. Defaults to ReconciliationMode.INCREMENTAL. Corresponds to the JSON property reconciliationMode

Returns:

  • (String)


27007
27008
27009
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27007

def reconciliation_mode
  @reconciliation_mode
end

#spanner_sourceGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSpannerSource

The Spanner source for importing data Corresponds to the JSON property spannerSource



27012
27013
27014
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27012

def spanner_source
  @spanner_source
end

#update_maskString

Indicates which fields in the provided imported documents to update. If not set, the default is to update all fields. Corresponds to the JSON property updateMask

Returns:

  • (String)


27018
27019
27020
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27018

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27025
27026
27027
27028
27029
27030
27031
27032
27033
27034
27035
27036
27037
27038
27039
27040
27041
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27025

def update!(**args)
  @alloy_db_source = args[:alloy_db_source] if args.key?(:alloy_db_source)
  @auto_generate_ids = args[:auto_generate_ids] if args.key?(:auto_generate_ids)
  @bigquery_source = args[:bigquery_source] if args.key?(:bigquery_source)
  @bigtable_source = args[:bigtable_source] if args.key?(:bigtable_source)
  @cloud_sql_source = args[:cloud_sql_source] if args.key?(:cloud_sql_source)
  @error_config = args[:error_config] if args.key?(:error_config)
  @fhir_store_source = args[:fhir_store_source] if args.key?(:fhir_store_source)
  @firestore_source = args[:firestore_source] if args.key?(:firestore_source)
  @force_refresh_content = args[:force_refresh_content] if args.key?(:force_refresh_content)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @id_field = args[:id_field] if args.key?(:id_field)
  @inline_source = args[:inline_source] if args.key?(:inline_source)
  @reconciliation_mode = args[:reconciliation_mode] if args.key?(:reconciliation_mode)
  @spanner_source = args[:spanner_source] if args.key?(:spanner_source)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end