Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaImportDocumentsRequest
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaImportDocumentsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Request message for Import methods.
Instance Attribute Summary collapse
-
#alloy_db_source ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAlloyDbSource
AlloyDB source import data from.
-
#auto_generate_ids ⇒ Boolean
(also: #auto_generate_ids?)
Whether to automatically generate IDs for the documents if absent.
-
#bigquery_source ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaBigQuerySource
BigQuery source import data from.
-
#bigtable_source ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaBigtableSource
The Cloud Bigtable source for importing data.
-
#cloud_sql_source ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCloudSqlSource
Cloud SQL source import data from.
-
#error_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaImportErrorConfig
Configuration of destination for Import related errors.
-
#fhir_store_source ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaFhirStoreSource
Cloud FhirStore source import data from.
-
#firestore_source ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaFirestoreSource
Firestore source import data from.
-
#force_refresh_content ⇒ Boolean
(also: #force_refresh_content?)
Optional.
-
#gcs_source ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaGcsSource
Cloud Storage location for input content.
-
#id_field ⇒ String
The field indicates the ID field or column to be used as unique IDs of the documents.
-
#inline_source ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaImportDocumentsRequestInlineSource
The inline source for the input config for ImportDocuments method.
-
#reconciliation_mode ⇒ String
The mode of reconciliation between existing documents and the documents to be imported.
-
#spanner_source ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSpannerSource
The Spanner source for importing data Corresponds to the JSON property
spannerSource. -
#update_mask ⇒ String
Indicates which fields in the provided imported documents to update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaImportDocumentsRequest
constructor
A new instance of GoogleCloudDiscoveryengineV1betaImportDocumentsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaImportDocumentsRequest
Returns a new instance of GoogleCloudDiscoveryengineV1betaImportDocumentsRequest.
25995 25996 25997 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25995 def initialize(**args) update!(**args) end |
Instance Attribute Details
#alloy_db_source ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAlloyDbSource
AlloyDB source import data from.
Corresponds to the JSON property alloyDbSource
25894 25895 25896 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25894 def alloy_db_source @alloy_db_source end |
#auto_generate_ids ⇒ Boolean Also known as: auto_generate_ids?
Whether to automatically generate IDs for the documents if absent. If set to
true, Document.ids are automatically generated based on the hash of the
payload, where IDs may not be consistent during multiple imports. In which
case ReconciliationMode.FULL is highly recommended to avoid duplicate contents.
If unset or set to false, Document.ids have to be specified using id_field,
otherwise, documents without IDs fail to be imported. Supported data sources: *
GcsSource. GcsSource.data_schema must be custom or csv. Otherwise, an
INVALID_ARGUMENT error is thrown. * BigQuerySource. BigQuerySource.data_schema
must be custom or csv. Otherwise, an INVALID_ARGUMENT error is thrown. *
SpannerSource. * CloudSqlSource. * FirestoreSource. * BigtableSource.
Corresponds to the JSON property autoGenerateIds
25908 25909 25910 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25908 def auto_generate_ids @auto_generate_ids end |
#bigquery_source ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaBigQuerySource
BigQuery source import data from.
Corresponds to the JSON property bigquerySource
25914 25915 25916 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25914 def bigquery_source @bigquery_source end |
#bigtable_source ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaBigtableSource
The Cloud Bigtable source for importing data.
Corresponds to the JSON property bigtableSource
25919 25920 25921 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25919 def bigtable_source @bigtable_source end |
#cloud_sql_source ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaCloudSqlSource
Cloud SQL source import data from.
Corresponds to the JSON property cloudSqlSource
25924 25925 25926 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25924 def cloud_sql_source @cloud_sql_source end |
#error_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaImportErrorConfig
Configuration of destination for Import related errors.
Corresponds to the JSON property errorConfig
25929 25930 25931 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25929 def error_config @error_config end |
#fhir_store_source ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaFhirStoreSource
Cloud FhirStore source import data from.
Corresponds to the JSON property fhirStoreSource
25934 25935 25936 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25934 def fhir_store_source @fhir_store_source end |
#firestore_source ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaFirestoreSource
Firestore source import data from.
Corresponds to the JSON property firestoreSource
25939 25940 25941 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25939 def firestore_source @firestore_source end |
#force_refresh_content ⇒ Boolean Also known as: force_refresh_content?
Optional. Whether to force refresh the unstructured content of the documents.
If set to true, the content part of the documents will be refreshed
regardless of the update status of the referencing content.
Corresponds to the JSON property forceRefreshContent
25946 25947 25948 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25946 def force_refresh_content @force_refresh_content end |
#gcs_source ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaGcsSource
Cloud Storage location for input content.
Corresponds to the JSON property gcsSource
25952 25953 25954 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25952 def gcs_source @gcs_source end |
#id_field ⇒ String
The field indicates the ID field or column to be used as unique IDs of the
documents. For GcsSource it is the key of the JSON field. For instance, my_id
for JSON "my_id": "some_uuid". For others, it may be the column name of
the table where the unique ids are stored. The values of the JSON field or the
table column are used as the Document.ids. The JSON field or the table column
must be of string type, and the values must be set as valid strings conform to
RFC-1034 with 1-63 characters.
Otherwise, documents without valid IDs fail to be imported. Only set this
field when auto_generate_ids is unset or set as false. Otherwise, an
INVALID_ARGUMENT error is thrown. If it is unset, a default value _id is
used when importing from the allowed data sources. Supported data sources: *
GcsSource. GcsSource.data_schema must be custom or csv. Otherwise, an
INVALID_ARGUMENT error is thrown. * BigQuerySource. BigQuerySource.data_schema
must be custom or csv. Otherwise, an INVALID_ARGUMENT error is thrown. *
SpannerSource. * CloudSqlSource. * BigtableSource.
Corresponds to the JSON property idField
25971 25972 25973 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25971 def id_field @id_field end |
#inline_source ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaImportDocumentsRequestInlineSource
The inline source for the input config for ImportDocuments method.
Corresponds to the JSON property inlineSource
25976 25977 25978 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25976 def inline_source @inline_source end |
#reconciliation_mode ⇒ String
The mode of reconciliation between existing documents and the documents to be
imported. Defaults to ReconciliationMode.INCREMENTAL.
Corresponds to the JSON property reconciliationMode
25982 25983 25984 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25982 def reconciliation_mode @reconciliation_mode end |
#spanner_source ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSpannerSource
The Spanner source for importing data
Corresponds to the JSON property spannerSource
25987 25988 25989 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25987 def spanner_source @spanner_source end |
#update_mask ⇒ String
Indicates which fields in the provided imported documents to update. If not
set, the default is to update all fields.
Corresponds to the JSON property updateMask
25993 25994 25995 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 25993 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26000 26001 26002 26003 26004 26005 26006 26007 26008 26009 26010 26011 26012 26013 26014 26015 26016 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26000 def update!(**args) @alloy_db_source = args[:alloy_db_source] if args.key?(:alloy_db_source) @auto_generate_ids = args[:auto_generate_ids] if args.key?(:auto_generate_ids) @bigquery_source = args[:bigquery_source] if args.key?(:bigquery_source) @bigtable_source = args[:bigtable_source] if args.key?(:bigtable_source) @cloud_sql_source = args[:cloud_sql_source] if args.key?(:cloud_sql_source) @error_config = args[:error_config] if args.key?(:error_config) @fhir_store_source = args[:fhir_store_source] if args.key?(:fhir_store_source) @firestore_source = args[:firestore_source] if args.key?(:firestore_source) @force_refresh_content = args[:force_refresh_content] if args.key?(:force_refresh_content) @gcs_source = args[:gcs_source] if args.key?(:gcs_source) @id_field = args[:id_field] if args.key?(:id_field) @inline_source = args[:inline_source] if args.key?(:inline_source) @reconciliation_mode = args[:reconciliation_mode] if args.key?(:reconciliation_mode) @spanner_source = args[:spanner_source] if args.key?(:spanner_source) @update_mask = args[:update_mask] if args.key?(:update_mask) end |