Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaImportSampleQueriesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Response of the SampleQueryService.ImportSampleQueries method. If the long running operation is done, this message is returned by the google.longrunning. Operations.response field if the operation is successful.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaImportSampleQueriesResponse

Returns a new instance of GoogleCloudDiscoveryengineV1betaImportSampleQueriesResponse.



26261
26262
26263
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26261

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaImportErrorConfig

Configuration of destination for Import related errors. Corresponds to the JSON property errorConfig



26254
26255
26256
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26254

def error_config
  @error_config
end

#error_samplesArray<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>

A sample of errors encountered while processing the request. Corresponds to the JSON property errorSamples



26259
26260
26261
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26259

def error_samples
  @error_samples
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26266
26267
26268
26269
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26266

def update!(**args)
  @error_config = args[:error_config] if args.key?(:error_config)
  @error_samples = args[:error_samples] if args.key?(:error_samples)
end