Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaImportUserEventsMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Metadata related to the progress of the Import operation. This is returned by the google.longrunning.Operation.metadata field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaImportUserEventsMetadata

Returns a new instance of GoogleCloudDiscoveryengineV1betaImportUserEventsMetadata.



26612
26613
26614
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26612

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Operation create time. Corresponds to the JSON property createTime

Returns:

  • (String)


26594
26595
26596
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26594

def create_time
  @create_time
end

#failure_countFixnum

Count of entries that encountered errors while processing. Corresponds to the JSON property failureCount

Returns:

  • (Fixnum)


26599
26600
26601
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26599

def failure_count
  @failure_count
end

#success_countFixnum

Count of entries that were processed successfully. Corresponds to the JSON property successCount

Returns:

  • (Fixnum)


26604
26605
26606
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26604

def success_count
  @success_count
end

#update_timeString

Output only. Operation last update time. If the operation is done, this is also the finish time. Corresponds to the JSON property updateTime

Returns:

  • (String)


26610
26611
26612
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26610

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26617
26618
26619
26620
26621
26622
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26617

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @failure_count = args[:failure_count] if args.key?(:failure_count)
  @success_count = args[:success_count] if args.key?(:success_count)
  @update_time = args[:update_time] if args.key?(:update_time)
end