Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaImportUserEventsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Response of the ImportUserEventsRequest. If the long running operation was successful, then this message is returned by the google.longrunning.Operations. response field if the operation was successful.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaImportUserEventsResponse

Returns a new instance of GoogleCloudDiscoveryengineV1betaImportUserEventsResponse.



27354
27355
27356
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27354

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaImportErrorConfig

Configuration of destination for Import related errors. Corresponds to the JSON property errorConfig



27336
27337
27338
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27336

def error_config
  @error_config
end

#error_samplesArray<Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus>

A sample of errors encountered while processing the request. Corresponds to the JSON property errorSamples



27341
27342
27343
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27341

def error_samples
  @error_samples
end

#joined_events_countFixnum

Count of user events imported with complete existing Documents. Corresponds to the JSON property joinedEventsCount

Returns:

  • (Fixnum)


27346
27347
27348
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27346

def joined_events_count
  @joined_events_count
end

#unjoined_events_countFixnum

Count of user events imported, but with Document information not found in the existing Branch. Corresponds to the JSON property unjoinedEventsCount

Returns:

  • (Fixnum)


27352
27353
27354
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27352

def unjoined_events_count
  @unjoined_events_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27359
27360
27361
27362
27363
27364
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27359

def update!(**args)
  @error_config = args[:error_config] if args.key?(:error_config)
  @error_samples = args[:error_samples] if args.key?(:error_samples)
  @joined_events_count = args[:joined_events_count] if args.key?(:joined_events_count)
  @unjoined_events_count = args[:unjoined_events_count] if args.key?(:unjoined_events_count)
end