Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaLicenseConfig
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaLicenseConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Information about users' licenses.
Instance Attribute Summary collapse
-
#auto_renew ⇒ Boolean
(also: #auto_renew?)
Optional.
-
#early_terminated ⇒ Boolean
(also: #early_terminated?)
Output only.
-
#early_termination_date ⇒ Google::Apis::DiscoveryengineV1beta::GoogleTypeDate
Represents a whole or partial calendar date, such as a birthday.
-
#end_date ⇒ Google::Apis::DiscoveryengineV1beta::GoogleTypeDate
Represents a whole or partial calendar date, such as a birthday.
-
#free_trial ⇒ Boolean
(also: #free_trial?)
Optional.
-
#gemini_bundle ⇒ Boolean
(also: #gemini_bundle?)
Output only.
-
#last_user_update_time ⇒ String
Optional.
-
#license_count ⇒ Fixnum
Required.
-
#name ⇒ String
Immutable.
-
#start_date ⇒ Google::Apis::DiscoveryengineV1beta::GoogleTypeDate
Represents a whole or partial calendar date, such as a birthday.
-
#state ⇒ String
Output only.
-
#subscription_term ⇒ String
Required.
-
#subscription_tier ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaLicenseConfig
constructor
A new instance of GoogleCloudDiscoveryengineV1betaLicenseConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaLicenseConfig
Returns a new instance of GoogleCloudDiscoveryengineV1betaLicenseConfig.
27717 27718 27719 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27717 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_renew ⇒ Boolean Also known as: auto_renew?
Optional. Whether the license config should be auto renewed when it reaches
the end date.
Corresponds to the JSON property autoRenew
27622 27623 27624 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27622 def auto_renew @auto_renew end |
#early_terminated ⇒ Boolean Also known as: early_terminated?
Output only. Indication of whether the subscription is terminated earlier than
the expiration date. This is usually terminated by pipeline once the
subscription gets terminated from subsv3.
Corresponds to the JSON property earlyTerminated
27630 27631 27632 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27630 def early_terminated @early_terminated end |
#early_termination_date ⇒ Google::Apis::DiscoveryengineV1beta::GoogleTypeDate
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property earlyTerminationDate
27643 27644 27645 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27643 def early_termination_date @early_termination_date end |
#end_date ⇒ Google::Apis::DiscoveryengineV1beta::GoogleTypeDate
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property endDate
27655 27656 27657 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27655 def end_date @end_date end |
#free_trial ⇒ Boolean Also known as: free_trial?
Optional. Whether the license config is for free trial.
Corresponds to the JSON property freeTrial
27660 27661 27662 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27660 def free_trial @free_trial end |
#gemini_bundle ⇒ Boolean Also known as: gemini_bundle?
Output only. Whether the license config is for Gemini bundle.
Corresponds to the JSON property geminiBundle
27666 27667 27668 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27666 def gemini_bundle @gemini_bundle end |
#last_user_update_time ⇒ String
Optional. Timestamp of the most recent user-initiated update (seat count
change or subscription term change). Unlike update_time, this field is only
stamped when a customer explicitly updates the license (e.g. via the UI), and
is not touched by system-driven writes (subscription pipeline, BALC
propagation, etc.).
Corresponds to the JSON property lastUserUpdateTime
27676 27677 27678 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27676 def last_user_update_time @last_user_update_time end |
#license_count ⇒ Fixnum
Required. Number of licenses purchased.
Corresponds to the JSON property licenseCount
27681 27682 27683 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27681 def license_count @license_count end |
#name ⇒ String
Immutable. Identifier. The fully qualified resource name of the license config.
Format: projects/project/locations/location/licenseConfigs/
license_config`
Corresponds to the JSON propertyname`
27688 27689 27690 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27688 def name @name end |
#start_date ⇒ Google::Apis::DiscoveryengineV1beta::GoogleTypeDate
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property startDate
27700 27701 27702 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27700 def start_date @start_date end |
#state ⇒ String
Output only. The state of the license config.
Corresponds to the JSON property state
27705 27706 27707 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27705 def state @state end |
#subscription_term ⇒ String
Required. Subscription term.
Corresponds to the JSON property subscriptionTerm
27710 27711 27712 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27710 def subscription_term @subscription_term end |
#subscription_tier ⇒ String
Required. Subscription tier information for the license config.
Corresponds to the JSON property subscriptionTier
27715 27716 27717 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27715 def subscription_tier @subscription_tier end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27722 27723 27724 27725 27726 27727 27728 27729 27730 27731 27732 27733 27734 27735 27736 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27722 def update!(**args) @auto_renew = args[:auto_renew] if args.key?(:auto_renew) @early_terminated = args[:early_terminated] if args.key?(:early_terminated) @early_termination_date = args[:early_termination_date] if args.key?(:early_termination_date) @end_date = args[:end_date] if args.key?(:end_date) @free_trial = args[:free_trial] if args.key?(:free_trial) @gemini_bundle = args[:gemini_bundle] if args.key?(:gemini_bundle) @last_user_update_time = args[:last_user_update_time] if args.key?(:last_user_update_time) @license_count = args[:license_count] if args.key?(:license_count) @name = args[:name] if args.key?(:name) @start_date = args[:start_date] if args.key?(:start_date) @state = args[:state] if args.key?(:state) @subscription_term = args[:subscription_term] if args.key?(:subscription_term) @subscription_tier = args[:subscription_tier] if args.key?(:subscription_tier) end |