Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaLicenseConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Information about users' licenses.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaLicenseConfig

Returns a new instance of GoogleCloudDiscoveryengineV1betaLicenseConfig.



26681
26682
26683
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26681

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_renewBoolean Also known as: auto_renew?

Optional. Whether the license config should be auto renewed when it reaches the end date. Corresponds to the JSON property autoRenew

Returns:

  • (Boolean)


26595
26596
26597
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26595

def auto_renew
  @auto_renew
end

#early_terminatedBoolean Also known as: early_terminated?

Output only. Indication of whether the subscription is terminated earlier than the expiration date. This is usually terminated by pipeline once the subscription gets terminated from subsv3. Corresponds to the JSON property earlyTerminated

Returns:

  • (Boolean)


26603
26604
26605
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26603

def early_terminated
  @early_terminated
end

#early_termination_dateGoogle::Apis::DiscoveryengineV1beta::GoogleTypeDate

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property earlyTerminationDate



26616
26617
26618
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26616

def early_termination_date
  @early_termination_date
end

#end_dateGoogle::Apis::DiscoveryengineV1beta::GoogleTypeDate

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property endDate



26628
26629
26630
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26628

def end_date
  @end_date
end

#free_trialBoolean Also known as: free_trial?

Optional. Whether the license config is for free trial. Corresponds to the JSON property freeTrial

Returns:

  • (Boolean)


26633
26634
26635
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26633

def free_trial
  @free_trial
end

#gemini_bundleBoolean Also known as: gemini_bundle?

Output only. Whether the license config is for Gemini bundle. Corresponds to the JSON property geminiBundle

Returns:

  • (Boolean)


26639
26640
26641
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26639

def gemini_bundle
  @gemini_bundle
end

#license_countFixnum

Required. Number of licenses purchased. Corresponds to the JSON property licenseCount

Returns:

  • (Fixnum)


26645
26646
26647
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26645

def license_count
  @license_count
end

#nameString

Immutable. Identifier. The fully qualified resource name of the license config. Format: projects/project/locations/location/licenseConfigs/ license_config` Corresponds to the JSON propertyname`

Returns:

  • (String)


26652
26653
26654
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26652

def name
  @name
end

#start_dateGoogle::Apis::DiscoveryengineV1beta::GoogleTypeDate

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property startDate



26664
26665
26666
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26664

def start_date
  @start_date
end

#stateString

Output only. The state of the license config. Corresponds to the JSON property state

Returns:

  • (String)


26669
26670
26671
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26669

def state
  @state
end

#subscription_termString

Required. Subscription term. Corresponds to the JSON property subscriptionTerm

Returns:

  • (String)


26674
26675
26676
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26674

def subscription_term
  @subscription_term
end

#subscription_tierString

Required. Subscription tier information for the license config. Corresponds to the JSON property subscriptionTier

Returns:

  • (String)


26679
26680
26681
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26679

def subscription_tier
  @subscription_tier
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26686
26687
26688
26689
26690
26691
26692
26693
26694
26695
26696
26697
26698
26699
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 26686

def update!(**args)
  @auto_renew = args[:auto_renew] if args.key?(:auto_renew)
  @early_terminated = args[:early_terminated] if args.key?(:early_terminated)
  @early_termination_date = args[:early_termination_date] if args.key?(:early_termination_date)
  @end_date = args[:end_date] if args.key?(:end_date)
  @free_trial = args[:free_trial] if args.key?(:free_trial)
  @gemini_bundle = args[:gemini_bundle] if args.key?(:gemini_bundle)
  @license_count = args[:license_count] if args.key?(:license_count)
  @name = args[:name] if args.key?(:name)
  @start_date = args[:start_date] if args.key?(:start_date)
  @state = args[:state] if args.key?(:state)
  @subscription_term = args[:subscription_term] if args.key?(:subscription_term)
  @subscription_tier = args[:subscription_tier] if args.key?(:subscription_tier)
end