Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaPageInfo
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaPageInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Detailed page information.
Instance Attribute Summary collapse
-
#page_category ⇒ String
The most specific category associated with a category page.
-
#pageview_id ⇒ String
A unique ID of a web page view.
-
#referrer_uri ⇒ String
The referrer URL of the current page.
-
#uri ⇒ String
Complete URL (window.location.href) of the user's current page.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaPageInfo
constructor
A new instance of GoogleCloudDiscoveryengineV1betaPageInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaPageInfo
Returns a new instance of GoogleCloudDiscoveryengineV1betaPageInfo.
28398 28399 28400 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28398 def initialize(**args) update!(**args) end |
Instance Attribute Details
#page_category ⇒ String
The most specific category associated with a category page. To represent full
path of category, use '>' sign to separate different hierarchies. If '>' is
part of the category name, replace it with other character(s). Category pages
include special pages such as sales or promotions. For instance, a special
sale page may have the category hierarchy: "pageCategory" : "Sales > 2017
Black Friday Deals". Required for view-category-page events. Other event
types should not set this field. Otherwise, an INVALID_ARGUMENT error is
returned.
Corresponds to the JSON property pageCategory
28370 28371 28372 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28370 def page_category @page_category end |
#pageview_id ⇒ String
A unique ID of a web page view. This should be kept the same for all user
events triggered from the same pageview. For example, an item detail page view
could trigger multiple events as the user is browsing the page. The
pageview_id property should be kept the same for all these events so that
they can be grouped together properly. When using the client side event
reporting with JavaScript pixel and Google Tag Manager, this value is filled
in automatically.
Corresponds to the JSON property pageviewId
28381 28382 28383 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28381 def pageview_id @pageview_id end |
#referrer_uri ⇒ String
The referrer URL of the current page. When using the client side event
reporting with JavaScript pixel and Google Tag Manager, this value is filled
in automatically. However, some browser privacy restrictions may cause this
field to be empty.
Corresponds to the JSON property referrerUri
28389 28390 28391 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28389 def referrer_uri @referrer_uri end |
#uri ⇒ String
Complete URL (window.location.href) of the user's current page. When using the
client side event reporting with JavaScript pixel and Google Tag Manager, this
value is filled in automatically. Maximum length 5,000 characters.
Corresponds to the JSON property uri
28396 28397 28398 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28396 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28403 28404 28405 28406 28407 28408 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28403 def update!(**args) @page_category = args[:page_category] if args.key?(:page_category) @pageview_id = args[:pageview_id] if args.key?(:pageview_id) @referrer_uri = args[:referrer_uri] if args.key?(:referrer_uri) @uri = args[:uri] if args.key?(:uri) end |