Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaPanelInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Detailed panel information associated with a user event.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaPanelInfo

Returns a new instance of GoogleCloudDiscoveryengineV1betaPanelInfo.



28401
28402
28403
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28401

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

The display name of the panel. Corresponds to the JSON property displayName

Returns:

  • (String)


28377
28378
28379
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28377

def display_name
  @display_name
end

#documentsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocumentInfo>

Optional. The document IDs associated with this panel. Corresponds to the JSON property documents



28382
28383
28384
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28382

def documents
  @documents
end

#panel_idString

Required. The panel ID. Corresponds to the JSON property panelId

Returns:

  • (String)


28387
28388
28389
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28387

def panel_id
  @panel_id
end

#panel_positionFixnum

The ordered position of the panel, if shown to the user with other panels. If set, then total_panels must also be set. Corresponds to the JSON property panelPosition

Returns:

  • (Fixnum)


28393
28394
28395
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28393

def panel_position
  @panel_position
end

#total_panelsFixnum

The total number of panels, including this one, shown to the user. Must be set if panel_position is set. Corresponds to the JSON property totalPanels

Returns:

  • (Fixnum)


28399
28400
28401
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28399

def total_panels
  @total_panels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28406
28407
28408
28409
28410
28411
28412
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28406

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @documents = args[:documents] if args.key?(:documents)
  @panel_id = args[:panel_id] if args.key?(:panel_id)
  @panel_position = args[:panel_position] if args.key?(:panel_position)
  @total_panels = args[:total_panels] if args.key?(:total_panels)
end