Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaPrincipal

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Principal identifier of a user or a group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaPrincipal

Returns a new instance of GoogleCloudDiscoveryengineV1betaPrincipal.



28454
28455
28456
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28454

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#external_entity_idString

For 3P application identities which are not present in the customer identity provider. Corresponds to the JSON property externalEntityId

Returns:

  • (String)


28436
28437
28438
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28436

def external_entity_id
  @external_entity_id
end

#group_idString

Group identifier. For Google Workspace user account, group_id should be the google workspace group email. For non-google identity provider user account, group_id is the mapped group identifier configured during the workforcepool config. Corresponds to the JSON property groupId

Returns:

  • (String)


28444
28445
28446
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28444

def group_id
  @group_id
end

#user_idString

User identifier. For Google Workspace user account, user_id should be the google workspace user email. For non-google identity provider user account, user_id is the mapped user identifier configured during the workforcepool config. Corresponds to the JSON property userId

Returns:

  • (String)


28452
28453
28454
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28452

def user_id
  @user_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28459
28460
28461
28462
28463
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28459

def update!(**args)
  @external_entity_id = args[:external_entity_id] if args.key?(:external_entity_id)
  @group_id = args[:group_id] if args.key?(:group_id)
  @user_id = args[:user_id] if args.key?(:user_id)
end