Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaPrincipal

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Principal identifier of a user or a group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaPrincipal

Returns a new instance of GoogleCloudDiscoveryengineV1betaPrincipal.



27596
27597
27598
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27596

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#external_entity_idString

For 3P application identities which are not present in the customer identity provider. Corresponds to the JSON property externalEntityId

Returns:

  • (String)


27578
27579
27580
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27578

def external_entity_id
  @external_entity_id
end

#group_idString

Group identifier. For Google Workspace user account, group_id should be the google workspace group email. For non-google identity provider user account, group_id is the mapped group identifier configured during the workforcepool config. Corresponds to the JSON property groupId

Returns:

  • (String)


27586
27587
27588
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27586

def group_id
  @group_id
end

#user_idString

User identifier. For Google Workspace user account, user_id should be the google workspace user email. For non-google identity provider user account, user_id is the mapped user identifier configured during the workforcepool config. Corresponds to the JSON property userId

Returns:

  • (String)


27594
27595
27596
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27594

def user_id
  @user_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27601
27602
27603
27604
27605
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27601

def update!(**args)
  @external_entity_id = args[:external_entity_id] if args.key?(:external_entity_id)
  @group_id = args[:group_id] if args.key?(:group_id)
  @user_id = args[:user_id] if args.key?(:user_id)
end