Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaProject
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaProject
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Metadata and configurations for a Google Cloud project in the service.
Instance Attribute Summary collapse
-
#configurable_billing_status ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaProjectConfigurableBillingStatus
Represents the currently effective configurable billing parameters.
-
#create_time ⇒ String
Output only.
-
#customer_provided_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaProjectCustomerProvidedConfig
Customer provided configurations.
-
#name ⇒ String
Output only.
-
#provision_completion_time ⇒ String
Output only.
-
#service_terms_map ⇒ Hash<String,Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaProjectServiceTerms>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaProject
constructor
A new instance of GoogleCloudDiscoveryengineV1betaProject.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaProject
Returns a new instance of GoogleCloudDiscoveryengineV1betaProject.
28687 28688 28689 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28687 def initialize(**args) update!(**args) end |
Instance Attribute Details
#configurable_billing_status ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaProjectConfigurableBillingStatus
Represents the currently effective configurable billing parameters. These
values are derived from the customer's subscription history stored internally
and reflect the thresholds actively being used for billing purposes at the
time of the GetProject call. This includes the start_time of the subscription
and may differ from the values in customer_provided_config due to billing
rules (e.g., scale-downs taking effect only at the start of a new month). We
also include the update type to indicate the type of update performed on the
configurable billing configuration in the UpdateProject operation.
Corresponds to the JSON property configurableBillingStatus
28657 28658 28659 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28657 def configurable_billing_status @configurable_billing_status end |
#create_time ⇒ String
Output only. The timestamp when this project is created.
Corresponds to the JSON property createTime
28662 28663 28664 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28662 def create_time @create_time end |
#customer_provided_config ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaProjectCustomerProvidedConfig
Customer provided configurations.
Corresponds to the JSON property customerProvidedConfig
28667 28668 28669 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28667 def customer_provided_config @customer_provided_config end |
#name ⇒ String
Output only. Full resource name of the project, for example projects/project
. Note that when making requests, project number and project id are both
acceptable, but the server will always respond in project number.
Corresponds to the JSON property name
28674 28675 28676 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28674 def name @name end |
#provision_completion_time ⇒ String
Output only. The timestamp when this project is successfully provisioned.
Empty value means this project is still provisioning and is not ready for use.
Corresponds to the JSON property provisionCompletionTime
28680 28681 28682 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28680 def provision_completion_time @provision_completion_time end |
#service_terms_map ⇒ Hash<String,Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaProjectServiceTerms>
Output only. A map of terms of services. The key is the id of ServiceTerms.
Corresponds to the JSON property serviceTermsMap
28685 28686 28687 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28685 def service_terms_map @service_terms_map end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28692 28693 28694 28695 28696 28697 28698 28699 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28692 def update!(**args) @configurable_billing_status = args[:configurable_billing_status] if args.key?(:configurable_billing_status) @create_time = args[:create_time] if args.key?(:create_time) @customer_provided_config = args[:customer_provided_config] if args.key?(:customer_provided_config) @name = args[:name] if args.key?(:name) @provision_completion_time = args[:provision_completion_time] if args.key?(:provision_completion_time) @service_terms_map = args[:service_terms_map] if args.key?(:service_terms_map) end |