Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaProjectConfigurableBillingStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Represents the currently effective configurable billing parameters. These values are derived from the customer's subscription history stored internally and reflect the thresholds actively being used for billing purposes at the time of the GetProject call. This includes the start_time of the subscription and may differ from the values in customer_provided_config due to billing rules (e.g., scale-downs taking effect only at the start of a new month). We also include the update type to indicate the type of update performed on the configurable billing configuration in the UpdateProject operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaProjectConfigurableBillingStatus

Returns a new instance of GoogleCloudDiscoveryengineV1betaProjectConfigurableBillingStatus.



28629
28630
28631
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28629

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_search_token_subscription_statusesArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaProjectConfigurableBillingStatusAgentSearchTokenSubscriptionStatus>

Output only. Per-model Agent Search TPM subscription status. Corresponds to the JSON property agentSearchTokenSubscriptionStatuses



28580
28581
28582
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28580

def agent_search_token_subscription_statuses
  @agent_search_token_subscription_statuses
end

#effective_indexing_core_thresholdFixnum

Optional. The currently effective Indexing Core threshold. This is the threshold against which Indexing Core usage is compared for overage calculations. Corresponds to the JSON property effectiveIndexingCoreThreshold

Returns:

  • (Fixnum)


28587
28588
28589
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28587

def effective_indexing_core_threshold
  @effective_indexing_core_threshold
end

#effective_search_qpm_thresholdFixnum

Optional. The currently effective Search QPM threshold in queries per minute. This is the threshold against which QPM usage is compared for overage calculations. Corresponds to the JSON property effectiveSearchQpmThreshold

Returns:

  • (Fixnum)


28594
28595
28596
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28594

def effective_search_qpm_threshold
  @effective_search_qpm_threshold
end

#indexing_core_threshold_next_update_timeString

Output only. The earliest next update time for the indexing core subscription threshold. This is based on the next_update_time returned by the underlying Cloud Billing Subscription V3 API. This field is populated only if an update indexing core subscription threshold request is succeeded. Corresponds to the JSON property indexingCoreThresholdNextUpdateTime

Returns:

  • (String)


28602
28603
28604
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28602

def indexing_core_threshold_next_update_time
  @indexing_core_threshold_next_update_time
end

#search_qpm_threshold_next_update_timeString

Output only. The earliest next update time for the search QPM subscription threshold. This is based on the next_update_time returned by the underlying Cloud Billing Subscription V3 API. This field is populated only if an update QPM subscription threshold request is succeeded. Corresponds to the JSON property searchQpmThresholdNextUpdateTime

Returns:

  • (String)


28610
28611
28612
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28610

def search_qpm_threshold_next_update_time
  @search_qpm_threshold_next_update_time
end

#start_timeString

Optional. The start time of the currently active billing subscription. Corresponds to the JSON property startTime

Returns:

  • (String)


28615
28616
28617
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28615

def start_time
  @start_time
end

#terminate_timeString

Output only. The latest terminate effective time of search qpm and indexing core subscriptions. Corresponds to the JSON property terminateTime

Returns:

  • (String)


28621
28622
28623
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28621

def terminate_time
  @terminate_time
end

#update_typeString

Output only. The type of update performed in this operation. This field is populated in the response of UpdateProject. Corresponds to the JSON property updateType

Returns:

  • (String)


28627
28628
28629
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28627

def update_type
  @update_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28634
28635
28636
28637
28638
28639
28640
28641
28642
28643
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28634

def update!(**args)
  @agent_search_token_subscription_statuses = args[:agent_search_token_subscription_statuses] if args.key?(:agent_search_token_subscription_statuses)
  @effective_indexing_core_threshold = args[:effective_indexing_core_threshold] if args.key?(:effective_indexing_core_threshold)
  @effective_search_qpm_threshold = args[:effective_search_qpm_threshold] if args.key?(:effective_search_qpm_threshold)
  @indexing_core_threshold_next_update_time = args[:indexing_core_threshold_next_update_time] if args.key?(:indexing_core_threshold_next_update_time)
  @search_qpm_threshold_next_update_time = args[:search_qpm_threshold_next_update_time] if args.key?(:search_qpm_threshold_next_update_time)
  @start_time = args[:start_time] if args.key?(:start_time)
  @terminate_time = args[:terminate_time] if args.key?(:terminate_time)
  @update_type = args[:update_type] if args.key?(:update_type)
end