Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaProjectServiceTerms

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Metadata about the terms of service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaProjectServiceTerms

Returns a new instance of GoogleCloudDiscoveryengineV1betaProjectServiceTerms.



27907
27908
27909
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27907

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accept_timeString

The last time when the project agreed to the terms of service. Corresponds to the JSON property acceptTime

Returns:

  • (String)


27879
27880
27881
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27879

def accept_time
  @accept_time
end

#decline_timeString

The last time when the project declined or revoked the agreement to terms of service. Corresponds to the JSON property declineTime

Returns:

  • (String)


27885
27886
27887
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27885

def decline_time
  @decline_time
end

#idString

The unique identifier of this terms of service. Available terms: * GA_DATA_USE_TERMS: Terms for data use. When using this as id, the acceptable version to provide is 2022-11-23. Corresponds to the JSON property id

Returns:

  • (String)


27893
27894
27895
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27893

def id
  @id
end

#stateString

Whether the project has accepted/rejected the service terms or it is still pending. Corresponds to the JSON property state

Returns:

  • (String)


27899
27900
27901
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27899

def state
  @state
end

#versionString

The version string of the terms of service. For acceptable values, see the comments for id above. Corresponds to the JSON property version

Returns:

  • (String)


27905
27906
27907
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27905

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27912
27913
27914
27915
27916
27917
27918
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27912

def update!(**args)
  @accept_time = args[:accept_time] if args.key?(:accept_time)
  @decline_time = args[:decline_time] if args.key?(:decline_time)
  @id = args[:id] if args.key?(:id)
  @state = args[:state] if args.key?(:state)
  @version = args[:version] if args.key?(:version)
end