Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaProvisionProjectRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Request for ProjectService.ProvisionProject method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaProvisionProjectRequest

Returns a new instance of GoogleCloudDiscoveryengineV1betaProvisionProjectRequest.



28264
28265
28266
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28264

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accept_data_use_termsBoolean Also known as: accept_data_use_terms?

Required. Set to true to specify that caller has read and would like to give consent to the Terms for data use. Corresponds to the JSON property acceptDataUseTerms

Returns:

  • (Boolean)


28249
28250
28251
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28249

def accept_data_use_terms
  @accept_data_use_terms
end

#data_use_terms_versionString

Required. The version of the Terms for data use that caller has read and would like to give consent to. Acceptable version is 2022-11-23, and this may change over time. Corresponds to the JSON property dataUseTermsVersion

Returns:

  • (String)


28257
28258
28259
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28257

def data_use_terms_version
  @data_use_terms_version
end

#saas_paramsGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaProvisionProjectRequestSaasParams

Parameters for Agentspace. Corresponds to the JSON property saasParams



28262
28263
28264
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28262

def saas_params
  @saas_params
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28269
28270
28271
28272
28273
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28269

def update!(**args)
  @accept_data_use_terms = args[:accept_data_use_terms] if args.key?(:accept_data_use_terms)
  @data_use_terms_version = args[:data_use_terms_version] if args.key?(:data_use_terms_version)
  @saas_params = args[:saas_params] if args.key?(:saas_params)
end