Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaProvisionProjectRequest
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaProvisionProjectRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Request for ProjectService.ProvisionProject method.
Instance Attribute Summary collapse
-
#accept_data_use_terms ⇒ Boolean
(also: #accept_data_use_terms?)
Required.
-
#data_use_terms_version ⇒ String
Required.
-
#saas_params ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaProvisionProjectRequestSaasParams
Parameters for Agentspace.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaProvisionProjectRequest
constructor
A new instance of GoogleCloudDiscoveryengineV1betaProvisionProjectRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaProvisionProjectRequest
Returns a new instance of GoogleCloudDiscoveryengineV1betaProvisionProjectRequest.
27958 27959 27960 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27958 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accept_data_use_terms ⇒ Boolean Also known as: accept_data_use_terms?
Required. Set to true to specify that caller has read and would like to give
consent to the Terms for data use.
Corresponds to the JSON property acceptDataUseTerms
27943 27944 27945 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27943 def accept_data_use_terms @accept_data_use_terms end |
#data_use_terms_version ⇒ String
Required. The version of the Terms for data use that caller has read and would like to give consent to.
Acceptable version is 2022-11-23, and this may change over time.
Corresponds to the JSON property dataUseTermsVersion
27951 27952 27953 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27951 def data_use_terms_version @data_use_terms_version end |
#saas_params ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaProvisionProjectRequestSaasParams
Parameters for Agentspace.
Corresponds to the JSON property saasParams
27956 27957 27958 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27956 def saas_params @saas_params end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27963 27964 27965 27966 27967 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27963 def update!(**args) @accept_data_use_terms = args[:accept_data_use_terms] if args.key?(:accept_data_use_terms) @data_use_terms_version = args[:data_use_terms_version] if args.key?(:data_use_terms_version) @saas_params = args[:saas_params] if args.key?(:saas_params) end |