Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaProvisionProjectRequestSaasParams

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Parameters for Agentspace.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaProvisionProjectRequestSaasParams

Returns a new instance of GoogleCloudDiscoveryengineV1betaProvisionProjectRequestSaasParams.



27988
27989
27990
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27988

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accept_biz_qosBoolean Also known as: accept_biz_qos?

Optional. Set to true to specify that caller has read and would like to give consent to the [Terms for Agent Space quality of service]. Corresponds to the JSON property acceptBizQos

Returns:

  • (Boolean)


27978
27979
27980
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27978

def accept_biz_qos
  @accept_biz_qos
end

#is_bizBoolean Also known as: is_biz?

Optional. Indicates if the current request is for Biz edition (= true) or not ( = false). Corresponds to the JSON property isBiz

Returns:

  • (Boolean)


27985
27986
27987
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27985

def is_biz
  @is_biz
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27993
27994
27995
27996
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 27993

def update!(**args)
  @accept_biz_qos = args[:accept_biz_qos] if args.key?(:accept_biz_qos)
  @is_biz = args[:is_biz] if args.key?(:is_biz)
end