Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaPurgeDocumentsMetadata
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaPurgeDocumentsMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Metadata related to the progress of the PurgeDocuments operation. This will be returned by the google.longrunning.Operation.metadata field.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Operation create time.
-
#failure_count ⇒ Fixnum
Count of entries that encountered errors while processing.
-
#ignored_count ⇒ Fixnum
Count of entries that were ignored as entries were not found.
-
#success_count ⇒ Fixnum
Count of entries that were deleted successfully.
-
#update_time ⇒ String
Operation last update time.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaPurgeDocumentsMetadata
constructor
A new instance of GoogleCloudDiscoveryengineV1betaPurgeDocumentsMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaPurgeDocumentsMetadata
Returns a new instance of GoogleCloudDiscoveryengineV1betaPurgeDocumentsMetadata.
28995 28996 28997 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28995 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Operation create time.
Corresponds to the JSON property createTime
28972 28973 28974 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28972 def create_time @create_time end |
#failure_count ⇒ Fixnum
Count of entries that encountered errors while processing.
Corresponds to the JSON property failureCount
28977 28978 28979 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28977 def failure_count @failure_count end |
#ignored_count ⇒ Fixnum
Count of entries that were ignored as entries were not found.
Corresponds to the JSON property ignoredCount
28982 28983 28984 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28982 def ignored_count @ignored_count end |
#success_count ⇒ Fixnum
Count of entries that were deleted successfully.
Corresponds to the JSON property successCount
28987 28988 28989 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28987 def success_count @success_count end |
#update_time ⇒ String
Operation last update time. If the operation is done, this is also the finish
time.
Corresponds to the JSON property updateTime
28993 28994 28995 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28993 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29000 29001 29002 29003 29004 29005 29006 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29000 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @failure_count = args[:failure_count] if args.key?(:failure_count) @ignored_count = args[:ignored_count] if args.key?(:ignored_count) @success_count = args[:success_count] if args.key?(:success_count) @update_time = args[:update_time] if args.key?(:update_time) end |