Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaPurgeDocumentsMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Metadata related to the progress of the PurgeDocuments operation. This will be returned by the google.longrunning.Operation.metadata field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaPurgeDocumentsMetadata

Returns a new instance of GoogleCloudDiscoveryengineV1betaPurgeDocumentsMetadata.



28043
28044
28045
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28043

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Operation create time. Corresponds to the JSON property createTime

Returns:

  • (String)


28020
28021
28022
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28020

def create_time
  @create_time
end

#failure_countFixnum

Count of entries that encountered errors while processing. Corresponds to the JSON property failureCount

Returns:

  • (Fixnum)


28025
28026
28027
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28025

def failure_count
  @failure_count
end

#ignored_countFixnum

Count of entries that were ignored as entries were not found. Corresponds to the JSON property ignoredCount

Returns:

  • (Fixnum)


28030
28031
28032
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28030

def ignored_count
  @ignored_count
end

#success_countFixnum

Count of entries that were deleted successfully. Corresponds to the JSON property successCount

Returns:

  • (Fixnum)


28035
28036
28037
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28035

def success_count
  @success_count
end

#update_timeString

Operation last update time. If the operation is done, this is also the finish time. Corresponds to the JSON property updateTime

Returns:

  • (String)


28041
28042
28043
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28041

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28048
28049
28050
28051
28052
28053
28054
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28048

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @failure_count = args[:failure_count] if args.key?(:failure_count)
  @ignored_count = args[:ignored_count] if args.key?(:ignored_count)
  @success_count = args[:success_count] if args.key?(:success_count)
  @update_time = args[:update_time] if args.key?(:update_time)
end