Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaPurgeDocumentsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Request message for DocumentService.PurgeDocuments method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaPurgeDocumentsRequest

Returns a new instance of GoogleCloudDiscoveryengineV1betaPurgeDocumentsRequest.



29083
29084
29085
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29083

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_configGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaPurgeErrorConfig

Configuration of destination for Purge related errors. Corresponds to the JSON property errorConfig



29057
29058
29059
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29057

def error_config
  @error_config
end

#filterString

Required. Filter matching documents to purge. Only currently supported value is * (all items). Corresponds to the JSON property filter

Returns:

  • (String)


29063
29064
29065
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29063

def filter
  @filter
end

#forceBoolean Also known as: force?

Actually performs the purge. If force is set to false, return the expected purge count without deleting any documents. Corresponds to the JSON property force

Returns:

  • (Boolean)


29069
29070
29071
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29069

def force
  @force
end

#gcs_sourceGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaGcsSource

Cloud Storage location for input content. Corresponds to the JSON property gcsSource



29075
29076
29077
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29075

def gcs_source
  @gcs_source
end

#inline_sourceGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaPurgeDocumentsRequestInlineSource

The inline source for the input config for DocumentService.PurgeDocuments method. Corresponds to the JSON property inlineSource



29081
29082
29083
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29081

def inline_source
  @inline_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29088
29089
29090
29091
29092
29093
29094
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29088

def update!(**args)
  @error_config = args[:error_config] if args.key?(:error_config)
  @filter = args[:filter] if args.key?(:filter)
  @force = args[:force] if args.key?(:force)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @inline_source = args[:inline_source] if args.key?(:inline_source)
end