Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaPurgeIdentityMappingsRequest
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaPurgeIdentityMappingsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Request message for IdentityMappingStoreService.PurgeIdentityMappings
Instance Attribute Summary collapse
-
#filter ⇒ String
Filter matching identity mappings to purge.
-
#force ⇒ Boolean
(also: #force?)
Actually performs the purge.
-
#inline_source ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaPurgeIdentityMappingsRequestInlineSource
The inline source to purge identity mapping entries from.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaPurgeIdentityMappingsRequest
constructor
A new instance of GoogleCloudDiscoveryengineV1betaPurgeIdentityMappingsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaPurgeIdentityMappingsRequest
Returns a new instance of GoogleCloudDiscoveryengineV1betaPurgeIdentityMappingsRequest.
29158 29159 29160 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29158 def initialize(**args) update!(**args) end |
Instance Attribute Details
#filter ⇒ String
Filter matching identity mappings to purge. The eligible field for filtering
is: * update_time: in ISO 8601 "zulu" format. * external_id Examples: *
Deleting all identity mappings updated in a time range: update_time > "2012-
04-23T18:25:43.511Z" AND update_time < "2012-04-23T18:30:43.511Z" * Deleting
all identity mappings for a given external_id: external_id = "id1" *
Deleting all identity mappings inside an identity mapping store: * The
filtering fields are assumed to have an implicit AND. Should not be used with
source. An error will be thrown, if both are provided.
Corresponds to the JSON property filter
29142 29143 29144 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29142 def filter @filter end |
#force ⇒ Boolean Also known as: force?
Actually performs the purge. If force is set to false, return the expected
purge count without deleting any identity mappings. This field is only
supported for purge with filter. For input source this field is ignored and
data will be purged regardless of the value of this field.
Corresponds to the JSON property force
29150 29151 29152 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29150 def force @force end |
#inline_source ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaPurgeIdentityMappingsRequestInlineSource
The inline source to purge identity mapping entries from.
Corresponds to the JSON property inlineSource
29156 29157 29158 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29156 def inline_source @inline_source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29163 29164 29165 29166 29167 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29163 def update!(**args) @filter = args[:filter] if args.key?(:filter) @force = args[:force] if args.key?(:force) @inline_source = args[:inline_source] if args.key?(:inline_source) end |