Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaPurgeIdentityMappingsRequestInlineSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

The inline source to purge identity mapping entries from.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaPurgeIdentityMappingsRequestInlineSource

Returns a new instance of GoogleCloudDiscoveryengineV1betaPurgeIdentityMappingsRequestInlineSource.



28533
28534
28535
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28533

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#identity_mapping_entriesArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaIdentityMappingEntry>

A maximum of 10000 entries can be purged at one time Corresponds to the JSON property identityMappingEntries



28531
28532
28533
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28531

def identity_mapping_entries
  @identity_mapping_entries
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28538
28539
28540
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28538

def update!(**args)
  @identity_mapping_entries = args[:identity_mapping_entries] if args.key?(:identity_mapping_entries)
end