Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaPurgeUserEventsRequest
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaPurgeUserEventsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Request message for PurgeUserEvents method.
Instance Attribute Summary collapse
-
#filter ⇒ String
Required.
-
#force ⇒ Boolean
(also: #force?)
The
forcefield is currently not supported.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaPurgeUserEventsRequest
constructor
A new instance of GoogleCloudDiscoveryengineV1betaPurgeUserEventsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaPurgeUserEventsRequest
Returns a new instance of GoogleCloudDiscoveryengineV1betaPurgeUserEventsRequest.
29450 29451 29452 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29450 def initialize(**args) update!(**args) end |
Instance Attribute Details
#filter ⇒ String
Required. The filter string to specify the events to be deleted with a length
limit of 5,000 characters. The eligible fields for filtering are: * eventType
: Double quoted UserEvent.event_type string. * eventTime: in ISO 8601 "zulu"
format. * userPseudoId: Double quoted string. Specifying this will delete
all events associated with a visitor. * userId: Double quoted string.
Specifying this will delete all events associated with a user. Note: This API
only supports purging a max range of 30 days. Examples: * Deleting all events
in a time range: eventTime > "2012-04-23T18:25:43.511Z" eventTime < "2012-04-
23T18:30:43.511Z" * Deleting specific eventType in a time range: eventTime >
"2012-04-23T18:25:43.511Z" eventTime < "2012-04-23T18:30:43.511Z" eventType = "
search" * Deleting all events for a specific visitor in a time range:
eventTime > "2012-04-23T18:25:43.511Z" eventTime < "2012-04-23T18:30:43.511Z"
userPseudoId = "visitor1024" * Deleting the past 30 days of events inside a
DataStore: * The filtering fields are assumed to have an implicit AND.
Corresponds to the JSON property filter
29438 29439 29440 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29438 def filter @filter end |
#force ⇒ Boolean Also known as: force?
The force field is currently not supported. Purge user event requests will
permanently delete all purgeable events. Once the development is complete: If
force is set to false, the method will return the expected purge count
without deleting any user events. This field will default to false if not
included in the request.
Corresponds to the JSON property force
29447 29448 29449 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29447 def force @force end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29455 29456 29457 29458 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29455 def update!(**args) @filter = args[:filter] if args.key?(:filter) @force = args[:force] if args.key?(:force) end |