Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaRankingRecord

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Record message for RankService.Rank method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaRankingRecord

Returns a new instance of GoogleCloudDiscoveryengineV1betaRankingRecord.



29513
29514
29515
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29513

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentString

The content of the record. Empty by default. At least one of title or content should be set otherwise an INVALID_ARGUMENT error is thrown. Corresponds to the JSON property content

Returns:

  • (String)


29493
29494
29495
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29493

def content
  @content
end

#idString

The unique ID to represent the record. Corresponds to the JSON property id

Returns:

  • (String)


29498
29499
29500
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29498

def id
  @id
end

#scoreFloat

The score of this record based on the given query and selected model. The score will be rounded to 4 decimal places. If the score is close to 0, it will be rounded to 0.00001 to avoid returning unset. Corresponds to the JSON property score

Returns:

  • (Float)


29505
29506
29507
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29505

def score
  @score
end

#titleString

The title of the record. Empty by default. At least one of title or content should be set otherwise an INVALID_ARGUMENT error is thrown. Corresponds to the JSON property title

Returns:

  • (String)


29511
29512
29513
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29511

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29518
29519
29520
29521
29522
29523
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29518

def update!(**args)
  @content = args[:content] if args.key?(:content)
  @id = args[:id] if args.key?(:id)
  @score = args[:score] if args.key?(:score)
  @title = args[:title] if args.key?(:title)
end