Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaRecommendResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Response message for Recommend method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaRecommendResponse

Returns a new instance of GoogleCloudDiscoveryengineV1betaRecommendResponse.



29001
29002
29003
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29001

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attribution_tokenString

A unique attribution token. This should be included in the UserEvent logs resulting from this recommendation, which enables accurate attribution of recommendation model performance. Corresponds to the JSON property attributionToken

Returns:

  • (String)


28981
28982
28983
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28981

def attribution_token
  @attribution_token
end

#missing_idsArray<String>

IDs of documents in the request that were missing from the default Branch associated with the requested ServingConfig. Corresponds to the JSON property missingIds

Returns:

  • (Array<String>)


28987
28988
28989
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28987

def missing_ids
  @missing_ids
end

#resultsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaRecommendResponseRecommendationResult>

A list of recommended Documents. The order represents the ranking (from the most relevant Document to the least). Corresponds to the JSON property results



28993
28994
28995
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28993

def results
  @results
end

#validate_onlyBoolean Also known as: validate_only?

True if RecommendRequest.validate_only was set. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


28998
28999
29000
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28998

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29006
29007
29008
29009
29010
29011
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29006

def update!(**args)
  @attribution_token = args[:attribution_token] if args.key?(:attribution_token)
  @missing_ids = args[:missing_ids] if args.key?(:missing_ids)
  @results = args[:results] if args.key?(:results)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end