Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaRemoveDedicatedCrawlRateRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Request message for CrawlRateManagementService.RemoveDedicatedCrawlRate method. The user can remove the dedicated crawl rate for a crawl_rate_scope they own, and Google will fall back to organic crawl, and the crawl rate will be determined by Google.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaRemoveDedicatedCrawlRateRequest

Returns a new instance of GoogleCloudDiscoveryengineV1betaRemoveDedicatedCrawlRateRequest.



29118
29119
29120
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29118

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#crawl_rate_scopeString

Required. The scope of the crawl rate change. Currently, only domain and host name are supported. A domain name example: example.com. A host name example: www.example.com. Please do not include / in the domain or host name. Corresponds to the JSON property crawlRateScope

Returns:

  • (String)


29116
29117
29118
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29116

def crawl_rate_scope
  @crawl_rate_scope
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29123
29124
29125
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29123

def update!(**args)
  @crawl_rate_scope = args[:crawl_rate_scope] if args.key?(:crawl_rate_scope)
end