Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaRemoveDedicatedCrawlRateResponse
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaRemoveDedicatedCrawlRateResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Response message for CrawlRateManagementService.RemoveDedicatedCrawlRate method. It simply returns the state of the response, and an error message if the state is FAILED.
Instance Attribute Summary collapse
-
#error ⇒ Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaRemoveDedicatedCrawlRateResponse
constructor
A new instance of GoogleCloudDiscoveryengineV1betaRemoveDedicatedCrawlRateResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaRemoveDedicatedCrawlRateResponse
Returns a new instance of GoogleCloudDiscoveryengineV1betaRemoveDedicatedCrawlRateResponse.
29795 29796 29797 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29795 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error ⇒ Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
29788 29789 29790 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29788 def error @error end |
#state ⇒ String
Output only. The state of the response.
Corresponds to the JSON property state
29793 29794 29795 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29793 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29800 29801 29802 29803 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29800 def update!(**args) @error = args[:error] if args.key?(:error) @state = args[:state] if args.key?(:state) end |