Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaRemoveSuggestionRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Request message for CompletionService.RemoveSuggestion method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaRemoveSuggestionRequest

Returns a new instance of GoogleCloudDiscoveryengineV1betaRemoveSuggestionRequest.



29843
29844
29845
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29843

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#remove_all_search_history_suggestionsBoolean Also known as: remove_all_search_history_suggestions?

Remove all search history suggestions for the user. Corresponds to the JSON property removeAllSearchHistorySuggestions

Returns:

  • (Boolean)


29813
29814
29815
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29813

def remove_all_search_history_suggestions
  @remove_all_search_history_suggestions
end

#remove_timeString

Required. Time at which the suggestion was removed. If not set, the current time will be used. Corresponds to the JSON property removeTime

Returns:

  • (String)


29820
29821
29822
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29820

def remove_time
  @remove_time
end

#search_history_suggestionString

The search history suggestion to be removed. Corresponds to the JSON property searchHistorySuggestion

Returns:

  • (String)


29825
29826
29827
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29825

def search_history_suggestion
  @search_history_suggestion
end

#user_infoGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaUserInfo

Information of an end user. Corresponds to the JSON property userInfo



29830
29831
29832
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29830

def 
  @user_info
end

#user_pseudo_idString

Required. A unique identifier for tracking visitors. For example, this could be implemented with an HTTP cookie, which should be able to uniquely identify a visitor on a single device. This unique identifier should not change if the visitor logs in or out of the website. This field should NOT have a fixed value such as unknown_visitor. This should be the same identifier as UserEvent.user_pseudo_id and SearchRequest.user_pseudo_id. The field must be a UTF-8 encoded string with a length limit of 128. Corresponds to the JSON property userPseudoId

Returns:

  • (String)


29841
29842
29843
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29841

def user_pseudo_id
  @user_pseudo_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29848
29849
29850
29851
29852
29853
29854
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29848

def update!(**args)
  @remove_all_search_history_suggestions = args[:remove_all_search_history_suggestions] if args.key?(:remove_all_search_history_suggestions)
  @remove_time = args[:remove_time] if args.key?(:remove_time)
  @search_history_suggestion = args[:search_history_suggestion] if args.key?(:search_history_suggestion)
  @user_info = args[:user_info] if args.key?(:user_info)
  @user_pseudo_id = args[:user_pseudo_id] if args.key?(:user_pseudo_id)
end