Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaRemoveSuggestionRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Request message for CompletionService.RemoveSuggestion method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaRemoveSuggestionRequest

Returns a new instance of GoogleCloudDiscoveryengineV1betaRemoveSuggestionRequest.



28891
28892
28893
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28891

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#remove_all_search_history_suggestionsBoolean Also known as: remove_all_search_history_suggestions?

Remove all search history suggestions for the user. Corresponds to the JSON property removeAllSearchHistorySuggestions

Returns:

  • (Boolean)


28861
28862
28863
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28861

def remove_all_search_history_suggestions
  @remove_all_search_history_suggestions
end

#remove_timeString

Required. Time at which the suggestion was removed. If not set, the current time will be used. Corresponds to the JSON property removeTime

Returns:

  • (String)


28868
28869
28870
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28868

def remove_time
  @remove_time
end

#search_history_suggestionString

The search history suggestion to be removed. Corresponds to the JSON property searchHistorySuggestion

Returns:

  • (String)


28873
28874
28875
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28873

def search_history_suggestion
  @search_history_suggestion
end

#user_infoGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaUserInfo

Information of an end user. Corresponds to the JSON property userInfo



28878
28879
28880
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28878

def 
  @user_info
end

#user_pseudo_idString

Required. A unique identifier for tracking visitors. For example, this could be implemented with an HTTP cookie, which should be able to uniquely identify a visitor on a single device. This unique identifier should not change if the visitor logs in or out of the website. This field should NOT have a fixed value such as unknown_visitor. This should be the same identifier as UserEvent.user_pseudo_id and SearchRequest.user_pseudo_id. The field must be a UTF-8 encoded string with a length limit of 128. Corresponds to the JSON property userPseudoId

Returns:

  • (String)


28889
28890
28891
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28889

def user_pseudo_id
  @user_pseudo_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28896
28897
28898
28899
28900
28901
28902
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 28896

def update!(**args)
  @remove_all_search_history_suggestions = args[:remove_all_search_history_suggestions] if args.key?(:remove_all_search_history_suggestions)
  @remove_time = args[:remove_time] if args.key?(:remove_time)
  @search_history_suggestion = args[:search_history_suggestion] if args.key?(:search_history_suggestion)
  @user_info = args[:user_info] if args.key?(:user_info)
  @user_pseudo_id = args[:user_pseudo_id] if args.key?(:user_pseudo_id)
end