Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchLinkPromotion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Promotion proto includes uri and other helping information to display the promotion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchLinkPromotion

Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchLinkPromotion.



30473
30474
30475
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30473

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Optional. The Promotion description. Maximum length: 200 characters. Corresponds to the JSON property description

Returns:

  • (String)


30441
30442
30443
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30441

def description
  @description
end

#documentString

Optional. The Document the user wants to promote. For site search, leave unset and only populate uri. Can be set along with uri. Corresponds to the JSON property document

Returns:

  • (String)


30447
30448
30449
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30447

def document
  @document
end

#enabledBoolean Also known as: enabled?

Optional. The enabled promotion will be returned for any serving configs associated with the parent of the control this promotion is attached to. This flag is used for basic site search only. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


30454
30455
30456
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30454

def enabled
  @enabled
end

#image_uriString

Optional. The promotion thumbnail image url. Corresponds to the JSON property imageUri

Returns:

  • (String)


30460
30461
30462
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30460

def image_uri
  @image_uri
end

#titleString

Required. The title of the promotion. Maximum length: 160 characters. Corresponds to the JSON property title

Returns:

  • (String)


30465
30466
30467
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30465

def title
  @title
end

#uriString

Optional. The URL for the page the user wants to promote. Must be set for site search. For other verticals, this is optional. Corresponds to the JSON property uri

Returns:

  • (String)


30471
30472
30473
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30471

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30478
30479
30480
30481
30482
30483
30484
30485
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30478

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @document = args[:document] if args.key?(:document)
  @enabled = args[:enabled] if args.key?(:enabled)
  @image_uri = args[:image_uri] if args.key?(:image_uri)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end