Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchLinkPromotion
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchLinkPromotion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Promotion proto includes uri and other helping information to display the promotion.
Instance Attribute Summary collapse
-
#description ⇒ String
Optional.
-
#document ⇒ String
Optional.
-
#enabled ⇒ Boolean
(also: #enabled?)
Optional.
-
#image_uri ⇒ String
Optional.
-
#title ⇒ String
Required.
-
#uri ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchLinkPromotion
constructor
A new instance of GoogleCloudDiscoveryengineV1betaSearchLinkPromotion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchLinkPromotion
Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchLinkPromotion.
30486 30487 30488 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30486 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Optional. The Promotion description. Maximum length: 200 characters.
Corresponds to the JSON property description
30454 30455 30456 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30454 def description @description end |
#document ⇒ String
Optional. The Document the user wants to promote. For site search, leave unset
and only populate uri. Can be set along with uri.
Corresponds to the JSON property document
30460 30461 30462 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30460 def document @document end |
#enabled ⇒ Boolean Also known as: enabled?
Optional. The enabled promotion will be returned for any serving configs
associated with the parent of the control this promotion is attached to. This
flag is used for basic site search only.
Corresponds to the JSON property enabled
30467 30468 30469 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30467 def enabled @enabled end |
#image_uri ⇒ String
Optional. The promotion thumbnail image url.
Corresponds to the JSON property imageUri
30473 30474 30475 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30473 def image_uri @image_uri end |
#title ⇒ String
Required. The title of the promotion. Maximum length: 160 characters.
Corresponds to the JSON property title
30478 30479 30480 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30478 def title @title end |
#uri ⇒ String
Optional. The URL for the page the user wants to promote. Must be set for site
search. For other verticals, this is optional.
Corresponds to the JSON property uri
30484 30485 30486 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30484 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30491 30492 30493 30494 30495 30496 30497 30498 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30491 def update!(**args) @description = args[:description] if args.key?(:description) @document = args[:document] if args.key?(:document) @enabled = args[:enabled] if args.key?(:enabled) @image_uri = args[:image_uri] if args.key?(:image_uri) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) end |