Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchLinkPromotion
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchLinkPromotion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Promotion proto includes uri and other helping information to display the promotion.
Instance Attribute Summary collapse
-
#description ⇒ String
Optional.
-
#document ⇒ String
Optional.
-
#enabled ⇒ Boolean
(also: #enabled?)
Optional.
-
#image_uri ⇒ String
Optional.
-
#title ⇒ String
Required.
-
#uri ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchLinkPromotion
constructor
A new instance of GoogleCloudDiscoveryengineV1betaSearchLinkPromotion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchLinkPromotion
Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchLinkPromotion.
30374 30375 30376 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30374 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Optional. The Promotion description. Maximum length: 200 characters.
Corresponds to the JSON property description
30342 30343 30344 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30342 def description @description end |
#document ⇒ String
Optional. The Document the user wants to promote. For site search, leave unset
and only populate uri. Can be set along with uri.
Corresponds to the JSON property document
30348 30349 30350 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30348 def document @document end |
#enabled ⇒ Boolean Also known as: enabled?
Optional. The enabled promotion will be returned for any serving configs
associated with the parent of the control this promotion is attached to. This
flag is used for basic site search only.
Corresponds to the JSON property enabled
30355 30356 30357 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30355 def enabled @enabled end |
#image_uri ⇒ String
Optional. The promotion thumbnail image url.
Corresponds to the JSON property imageUri
30361 30362 30363 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30361 def image_uri @image_uri end |
#title ⇒ String
Required. The title of the promotion. Maximum length: 160 characters.
Corresponds to the JSON property title
30366 30367 30368 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30366 def title @title end |
#uri ⇒ String
Optional. The URL for the page the user wants to promote. Must be set for site
search. For other verticals, this is optional.
Corresponds to the JSON property uri
30372 30373 30374 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30372 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30379 30380 30381 30382 30383 30384 30385 30386 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30379 def update!(**args) @description = args[:description] if args.key?(:description) @document = args[:document] if args.key?(:document) @enabled = args[:enabled] if args.key?(:enabled) @image_uri = args[:image_uri] if args.key?(:image_uri) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) end |