Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchLinkPromotion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Promotion proto includes uri and other helping information to display the promotion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchLinkPromotion

Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchLinkPromotion.



30309
30310
30311
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30309

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Optional. The Promotion description. Maximum length: 200 characters. Corresponds to the JSON property description

Returns:

  • (String)


30277
30278
30279
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30277

def description
  @description
end

#documentString

Optional. The Document the user wants to promote. For site search, leave unset and only populate uri. Can be set along with uri. Corresponds to the JSON property document

Returns:

  • (String)


30283
30284
30285
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30283

def document
  @document
end

#enabledBoolean Also known as: enabled?

Optional. The enabled promotion will be returned for any serving configs associated with the parent of the control this promotion is attached to. This flag is used for basic site search only. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


30290
30291
30292
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30290

def enabled
  @enabled
end

#image_uriString

Optional. The promotion thumbnail image url. Corresponds to the JSON property imageUri

Returns:

  • (String)


30296
30297
30298
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30296

def image_uri
  @image_uri
end

#titleString

Required. The title of the promotion. Maximum length: 160 characters. Corresponds to the JSON property title

Returns:

  • (String)


30301
30302
30303
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30301

def title
  @title
end

#uriString

Optional. The URL for the page the user wants to promote. Must be set for site search. For other verticals, this is optional. Corresponds to the JSON property uri

Returns:

  • (String)


30307
30308
30309
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30307

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30314
30315
30316
30317
30318
30319
30320
30321
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30314

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @document = args[:document] if args.key?(:document)
  @enabled = args[:enabled] if args.key?(:enabled)
  @image_uri = args[:image_uri] if args.key?(:image_uri)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end