Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchLinkPromotion
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchLinkPromotion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Promotion proto includes uri and other helping information to display the promotion.
Instance Attribute Summary collapse
-
#description ⇒ String
Optional.
-
#document ⇒ String
Optional.
-
#enabled ⇒ Boolean
(also: #enabled?)
Optional.
-
#image_uri ⇒ String
Optional.
-
#title ⇒ String
Required.
-
#uri ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchLinkPromotion
constructor
A new instance of GoogleCloudDiscoveryengineV1betaSearchLinkPromotion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchLinkPromotion
Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchLinkPromotion.
29663 29664 29665 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29663 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Optional. The Promotion description. Maximum length: 200 characters.
Corresponds to the JSON property description
29631 29632 29633 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29631 def description @description end |
#document ⇒ String
Optional. The Document the user wants to promote. For site search, leave unset
and only populate uri. Can be set along with uri.
Corresponds to the JSON property document
29637 29638 29639 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29637 def document @document end |
#enabled ⇒ Boolean Also known as: enabled?
Optional. The enabled promotion will be returned for any serving configs
associated with the parent of the control this promotion is attached to. This
flag is used for basic site search only.
Corresponds to the JSON property enabled
29644 29645 29646 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29644 def enabled @enabled end |
#image_uri ⇒ String
Optional. The promotion thumbnail image url.
Corresponds to the JSON property imageUri
29650 29651 29652 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29650 def image_uri @image_uri end |
#title ⇒ String
Required. The title of the promotion. Maximum length: 160 characters.
Corresponds to the JSON property title
29655 29656 29657 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29655 def title @title end |
#uri ⇒ String
Optional. The URL for the page the user wants to promote. Must be set for site
search. For other verticals, this is optional.
Corresponds to the JSON property uri
29661 29662 29663 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29661 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29668 29669 29670 29671 29672 29673 29674 29675 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29668 def update!(**args) @description = args[:description] if args.key?(:description) @document = args[:document] if args.key?(:document) @enabled = args[:enabled] if args.key?(:enabled) @image_uri = args[:image_uri] if args.key?(:image_uri) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) end |