Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchLinkPromotion
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchLinkPromotion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Promotion proto includes uri and other helping information to display the promotion.
Instance Attribute Summary collapse
-
#description ⇒ String
Optional.
-
#document ⇒ String
Optional.
-
#enabled ⇒ Boolean
(also: #enabled?)
Optional.
-
#image_uri ⇒ String
Optional.
-
#title ⇒ String
Required.
-
#uri ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchLinkPromotion
constructor
A new instance of GoogleCloudDiscoveryengineV1betaSearchLinkPromotion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchLinkPromotion
Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchLinkPromotion.
29357 29358 29359 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29357 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Optional. The Promotion description. Maximum length: 200 characters.
Corresponds to the JSON property description
29325 29326 29327 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29325 def description @description end |
#document ⇒ String
Optional. The Document the user wants to promote. For site search, leave unset
and only populate uri. Can be set along with uri.
Corresponds to the JSON property document
29331 29332 29333 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29331 def document @document end |
#enabled ⇒ Boolean Also known as: enabled?
Optional. The enabled promotion will be returned for any serving configs
associated with the parent of the control this promotion is attached to. This
flag is used for basic site search only.
Corresponds to the JSON property enabled
29338 29339 29340 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29338 def enabled @enabled end |
#image_uri ⇒ String
Optional. The promotion thumbnail image url.
Corresponds to the JSON property imageUri
29344 29345 29346 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29344 def image_uri @image_uri end |
#title ⇒ String
Required. The title of the promotion. Maximum length: 160 characters.
Corresponds to the JSON property title
29349 29350 29351 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29349 def title @title end |
#uri ⇒ String
Optional. The URL for the page the user wants to promote. Must be set for site
search. For other verticals, this is optional.
Corresponds to the JSON property uri
29355 29356 29357 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29355 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29362 29363 29364 29365 29366 29367 29368 29369 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 29362 def update!(**args) @description = args[:description] if args.key?(:description) @document = args[:document] if args.key?(:document) @enabled = args[:enabled] if args.key?(:enabled) @image_uri = args[:image_uri] if args.key?(:image_uri) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) end |