Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Request message for SearchService.Search method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchRequest

Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchRequest.



30755
30756
30757
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30755

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#boost_specGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestBoostSpec

Boost specification to boost certain documents. Corresponds to the JSON property boostSpec



30372
30373
30374
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30372

def boost_spec
  @boost_spec
end

#branchString

The branch resource name, such as projects/*/locations/global/collections/ default_collection/dataStores/default_data_store/branches/0. Use default_branch as the branch ID or leave this field empty, to search documents under the default branch. Corresponds to the JSON property branch

Returns:

  • (String)


30380
30381
30382
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30380

def branch
  @branch
end

#canonical_filterString

The default filter that is applied when a user performs a search without checking any filters on the search page. The filter applied to every search request when quality improvement such as query expansion is needed. In the case a query does not have a sufficient amount of results this filter will be used to determine whether or not to enable the query expansion flow. The original filter will still be used for the query expanded search. This field is strongly recommended to achieve high search quality. For more information about filter syntax, see SearchRequest.filter. Corresponds to the JSON property canonicalFilter

Returns:

  • (String)


30392
30393
30394
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30392

def canonical_filter
  @canonical_filter
end

#content_search_specGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpec

A specification for configuring the behavior of content search. Corresponds to the JSON property contentSearchSpec



30397
30398
30399
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30397

def content_search_spec
  @content_search_spec
end

#crowding_specsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestCrowdingSpec>

Optional. Crowding specifications for improving result diversity. If multiple CrowdingSpecs are specified, crowding will be evaluated on each unique combination of the field values, and max_count will be the maximum value of max_count across all CrowdingSpecs. For example, if the first CrowdingSpec has field = "color" and max_count = 3, and the second CrowdingSpec has field = "size" and max_count = 2, then after 3 documents that share the same color AND size have been returned, subsequent ones should be removed or demoted. Corresponds to the JSON property crowdingSpecs



30409
30410
30411
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30409

def crowding_specs
  @crowding_specs
end

#custom_ranking_paramsGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestCustomRankingParams

Configuration parameters for the Custom Ranking feature. Corresponds to the JSON property customRankingParams



30414
30415
30416
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30414

def custom_ranking_params
  @custom_ranking_params
end

#data_store_specsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestDataStoreSpec>

Specifications that define the specific DataStores to be searched, along with configurations for those data stores. This is only considered for Engines with multiple data stores. For engines with a single data store, the specs directly under SearchRequest should be used. Corresponds to the JSON property dataStoreSpecs



30422
30423
30424
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30422

def data_store_specs
  @data_store_specs
end

#display_specGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestDisplaySpec

Specifies features for display, like match highlighting. Corresponds to the JSON property displaySpec



30427
30428
30429
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30427

def display_spec
  @display_spec
end

#embedding_specGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestEmbeddingSpec

The specification that uses customized query embedding vector to do semantic document retrieval. Corresponds to the JSON property embeddingSpec



30433
30434
30435
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30433

def embedding_spec
  @embedding_spec
end

#entityString

Optional. The entity for customers that may run multiple different entities, domains, sites or regions, for example, "Google US", "Google Ads", "Waymo", " google.com", "youtube.com", etc. If this is set, it should be exactly matched with UserEvent.entity to get search results boosted by entity. Corresponds to the JSON property entity

Returns:

  • (String)


30441
30442
30443
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30441

def entity
  @entity
end

#facet_specsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestFacetSpec>

Facet specifications for faceted search. If empty, no facets are returned. A maximum of 100 values are allowed. Otherwise, an INVALID_ARGUMENT error is returned. Corresponds to the JSON property facetSpecs



30448
30449
30450
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30448

def facet_specs
  @facet_specs
end

#filterString

The filter syntax consists of an expression language for constructing a predicate from one or more fields of the documents being filtered. Filter expression is case-sensitive. If this field is unrecognizable, an INVALID_ARGUMENT is returned. Filtering in Vertex AI Search is done by mapping the LHS filter key to a key property defined in the Vertex AI Search backend -- this mapping is defined by the customer in their schema. For example a media customer might have a field 'name' in their schema. In this case the filter would look like this: filter --> name:'ANY("king kong")' For more information about filtering including syntax and filter operators, see Filter Corresponds to the JSON property filter

Returns:

  • (String)


30463
30464
30465
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30463

def filter
  @filter
end

#image_queryGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestImageQuery

Specifies the image query input. Corresponds to the JSON property imageQuery



30468
30469
30470
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30468

def image_query
  @image_query
end

#language_codeString

The BCP-47 language code, such as "en-US" or "sr-Latn". For more information, see Standard fields. This field helps to better interpret the query. If a value isn't specified, the query language code is automatically detected, which may not be accurate. Corresponds to the JSON property languageCode

Returns:

  • (String)


30476
30477
30478
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30476

def language_code
  @language_code
end

#natural_language_query_understanding_specGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestNaturalLanguageQueryUnderstandingSpec

Specification to enable natural language understanding capabilities for search requests. Corresponds to the JSON property naturalLanguageQueryUnderstandingSpec



30482
30483
30484
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30482

def natural_language_query_understanding_spec
  @natural_language_query_understanding_spec
end

#num_results_per_data_storeFixnum

Optional. The maximum number of results to retrieve from each data store. If not specified, it will use the SearchRequest.DataStoreSpec.num_results if provided, otherwise there is no limit. Corresponds to the JSON property numResultsPerDataStore

Returns:

  • (Fixnum)


30489
30490
30491
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30489

def num_results_per_data_store
  @num_results_per_data_store
end

#offsetFixnum

A 0-indexed integer that specifies the current offset (that is, starting result location, amongst the Documents deemed by the API as relevant) in search results. This field is only considered if page_token is unset. If this field is negative, an INVALID_ARGUMENT is returned. A large offset may be capped to a reasonable threshold. Corresponds to the JSON property offset

Returns:

  • (Fixnum)


30498
30499
30500
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30498

def offset
  @offset
end

#one_box_page_sizeFixnum

The maximum number of results to return for OneBox. This applies to each OneBox type individually. Default number is 10. Corresponds to the JSON property oneBoxPageSize

Returns:

  • (Fixnum)


30504
30505
30506
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30504

def one_box_page_size
  @one_box_page_size
end

#order_byString

The order in which documents are returned. Documents can be ordered by a field in an Document object. Leave it unset if ordered by relevance. order_by expression is case-sensitive. For more information on ordering the website search results, see Order web search results. For more information on ordering the healthcare search results, see Order healthcare search results. If this field is unrecognizable, an INVALID_ARGUMENT is returned. Corresponds to the JSON property orderBy

Returns:

  • (String)


30516
30517
30518
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30516

def order_by
  @order_by
end

#page_categoriesArray<String>

Optional. The categories associated with a category page. Must be set for category navigation queries to achieve good search quality. The format should be the same as PageInfo.page_category. This field is the equivalent of the query for browse (navigation) queries. It's used by the browse model when the query is empty. If the field is empty, it will not be used by the browse model. If the field contains more than one element, only the first element will be used. To represent full path of a category, use '>' character to separate different hierarchies. If '>' is part of the category name, replace it with other character(s). For example, Graphics Cards > RTX>4090 > Founders Edition where "RTX > 4090" represents one level, can be rewritten as Graphics Cards > RTX_4090 > Founders Edition Corresponds to the JSON property pageCategories

Returns:

  • (Array<String>)


30531
30532
30533
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30531

def page_categories
  @page_categories
end

#page_sizeFixnum

Maximum number of Documents to return. The maximum allowed value depends on the data type. Values above the maximum value are coerced to the maximum value.

  • Websites with basic indexing: Default 10, Maximum 25. * Websites with advanced indexing: Default 25, Maximum 50. * Other: Default 50, Maximum 100. If this field is negative, an INVALID_ARGUMENT is returned. Corresponds to the JSON property pageSize

Returns:

  • (Fixnum)


30540
30541
30542
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30540

def page_size
  @page_size
end

#page_tokenString

A page token received from a previous SearchService.Search call. Provide this to retrieve the subsequent page. When paginating, all other parameters provided to SearchService.Search must match the call that provided the page token. Otherwise, an INVALID_ARGUMENT error is returned. Corresponds to the JSON property pageToken

Returns:

  • (String)


30548
30549
30550
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30548

def page_token
  @page_token
end

#paramsHash<String,Object>

Additional search parameters. For public website search only, supported values are: * user_country_code: string. Default empty. If set to non-empty, results are restricted or boosted based on the location provided. For example, user_country_code: "au" For available codes see Country Codes * search_type: double. Default empty. Enables non-webpage searching depending on the value. The only valid non-default value is 1, which enables image searching. For example, search_type: 1 Corresponds to the JSON property params

Returns:

  • (Hash<String,Object>)


30560
30561
30562
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30560

def params
  @params
end

#personalization_specGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestPersonalizationSpec

The specification for personalization. Corresponds to the JSON property personalizationSpec



30565
30566
30567
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30565

def personalization_spec
  @personalization_spec
end

#queryString

Raw search query. Corresponds to the JSON property query

Returns:

  • (String)


30570
30571
30572
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30570

def query
  @query
end

#query_expansion_specGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestQueryExpansionSpec

Specification to determine under which conditions query expansion should occur. Corresponds to the JSON property queryExpansionSpec



30575
30576
30577
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30575

def query_expansion_spec
  @query_expansion_spec
end

#ranking_expressionString

Optional. The ranking expression controls the customized ranking on retrieval documents. This overrides ServingConfig.ranking_expression. The syntax and supported features depend on the ranking_expression_backend value. If ranking_expression_backend is not provided, it defaults to RANK_BY_EMBEDDING . If ranking_expression_backend is not provided or set to RANK_BY_EMBEDDING, it should be a single function or multiple functions that are joined by "+". * ranking_expression = function, " + ", function; Supported functions: * double * relevance_score * double * dotProduct(embedding_field_path) Function variables: * relevance_score: pre-defined keywords, used for measure relevance between query and document. * embedding_field_path: the document embedding field used with query embedding vector. * dotProduct: embedding function between embedding_field_path and query embedding vector. Example ranking expression: If document has an embedding field doc_embedding, the ranking expression could be 0.5 * relevance_score + 0.3 * dotProduct( doc_embedding). If ranking_expression_backend is set to RANK_BY_FORMULA, the following expression types (and combinations of those chained using + or * operators) are supported: * double * signal * log(signal) * exp(signal)

  • rr(signal, double > 0) -- reciprocal rank transformation with second argument being a denominator constant. * is_nan(signal) -- returns 0 if signal is NaN, 1 otherwise. * fill_nan(signal1, signal2 | double) -- if signal1 is NaN, returns signal2 | double, else returns signal1. Here are a few examples of ranking formulas that use the supported ranking expression types: - 0.2 * semantic_similarity_score + 0.8 * log(keyword_similarity_score) -- mostly rank by the logarithm of keyword_similarity_score with slight semantic_smilarity_score adjustment. - 0.2 * exp(fill_nan( semantic_similarity_score, 0)) + 0.3 * is_nan(keyword_similarity_score) -- rank by the exponent of semantic_similarity_score filling the value with 0 if it's NaN, also add constant 0.3 adjustment to the final score if semantic_similarity_score is NaN. - 0.2 * rr(semantic_similarity_score, 16) + 0.8 * rr(keyword_similarity_score, 16) -- mostly rank by the reciprocal rank of keyword_similarity_score with slight adjustment of reciprocal rank of semantic_smilarity_score. The following signals are supported: * semantic_similarity_score: semantic similarity adjustment that is calculated using the embeddings generated by a proprietary Google model. This score determines how semantically similar a search query is to a document. * keyword_similarity_score: keyword match adjustment uses the Best Match 25 ( BM25) ranking function. This score is calculated using a probabilistic model to estimate the probability that a document is relevant to a given query. * relevance_score: semantic relevance adjustment that uses a proprietary Google model to determine the meaning and intent behind a user's query in context with the content in the documents. * pctr_rank: predicted conversion rate adjustment as a rank use predicted Click-through rate (pCTR) to gauge the relevance and attractiveness of a search result from a user's perspective. A higher pCTR suggests that the result is more likely to satisfy the user's query and intent, making it a valuable signal for ranking. * freshness_rank: freshness adjustment as a rank * document_age: The time in hours elapsed since the document was last updated, a floating-point number (e.g., 0.25 means 15 minutes). * topicality_rank: topicality adjustment as a rank. Uses proprietary Google model to determine the keyword-based overlap between the query and the document. * base_rank: the default rank of the result * media_actor_match: whether the media actor matches the query * media_director_match: whether the media director matches the query * media_genre_match: whether the media genre matches the query * media_language_match: whether the media language matches the query * media_title_match: whether the media title matches the query * media_prefix_similarity_rank: prefix similarity rank for media results * media_semantic_similarity_rank: semantic similarity rank for media results Corresponds to the JSON property rankingExpression

Returns:

  • (String)


30636
30637
30638
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30636

def ranking_expression
  @ranking_expression
end

#ranking_expression_backendString

Optional. The backend to use for the ranking expression evaluation. Corresponds to the JSON property rankingExpressionBackend

Returns:

  • (String)


30641
30642
30643
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30641

def ranking_expression_backend
  @ranking_expression_backend
end

#region_codeString

The Unicode country/region code (CLDR) of a location, such as "US" and "419". For more information, see Standard fields. If set, then results will be boosted based on the region_code provided. Corresponds to the JSON property regionCode

Returns:

  • (String)


30649
30650
30651
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30649

def region_code
  @region_code
end

#relevance_filter_specGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestRelevanceFilterSpec

Relevance filtering specification. Corresponds to the JSON property relevanceFilterSpec



30654
30655
30656
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30654

def relevance_filter_spec
  @relevance_filter_spec
end

#relevance_score_specGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestRelevanceScoreSpec

The specification for returning the document relevance score. Corresponds to the JSON property relevanceScoreSpec



30659
30660
30661
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30659

def relevance_score_spec
  @relevance_score_spec
end

#relevance_thresholdString

The global relevance threshold of the search results. Defaults to Google defined threshold, leveraging a balance of precision and recall to deliver both highly accurate results and comprehensive coverage of relevant information. If more granular relevance filtering is required, use the relevance_filter_spec instead. This feature is not supported for healthcare search. Corresponds to the JSON property relevanceThreshold

Returns:

  • (String)


30669
30670
30671
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30669

def relevance_threshold
  @relevance_threshold
end

#safe_searchBoolean Also known as: safe_search?

Whether to turn on safe search. This is only supported for website search. Corresponds to the JSON property safeSearch

Returns:

  • (Boolean)


30674
30675
30676
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30674

def safe_search
  @safe_search
end

#search_addon_specGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestSearchAddonSpec

SearchAddonSpec is used to disable add-ons for search as per new repricing model. By default if the SearchAddonSpec is not specified, we consider that the customer wants to enable them wherever applicable. Corresponds to the JSON property searchAddonSpec



30682
30683
30684
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30682

def search_addon_spec
  @search_addon_spec
end

#search_as_you_type_specGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestSearchAsYouTypeSpec

Specification for search as you type in search requests. Corresponds to the JSON property searchAsYouTypeSpec



30687
30688
30689
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30687

def search_as_you_type_spec
  @search_as_you_type_spec
end

#serving_configString

Required. The resource name of the Search serving config, such as projects/*/ locations/global/collections/default_collection/engines/*/servingConfigs/ default_serving_config, or projects/*/locations/global/collections/ default_collection/dataStores/default_data_store/servingConfigs/ default_serving_config. This field is used to identify the serving configuration name, set of models used to make the search. Corresponds to the JSON property servingConfig

Returns:

  • (String)


30697
30698
30699
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30697

def serving_config
  @serving_config
end

#sessionString

The session resource name. Optional. Session allows users to do multi-turn / search API calls or coordination between /search API calls and /answer API calls. Example #1 (multi-turn /search API calls): Call /search API with the session ID generated in the first call. Here, the previous search query gets considered in query standing. I.e., if the first query is "How did Alphabet do in 2022?" and the current query is "How about 2023?", the current query will be interpreted as "How did Alphabet do in 2023?". Example #2 (coordination between /search API calls and /answer API calls): Call /answer API with the session ID generated in the first call. Here, the answer generation happens in the context of the search results from the first search call. Corresponds to the JSON property session

Returns:

  • (String)


30711
30712
30713
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30711

def session
  @session
end

#session_specGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestSessionSpec

Session specification. Corresponds to the JSON property sessionSpec



30716
30717
30718
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30716

def session_spec
  @session_spec
end

#spell_correction_specGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestSpellCorrectionSpec

The specification for query spell correction. Corresponds to the JSON property spellCorrectionSpec



30721
30722
30723
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30721

def spell_correction_spec
  @spell_correction_spec
end

#user_infoGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaUserInfo

Information of an end user. Corresponds to the JSON property userInfo



30726
30727
30728
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30726

def 
  @user_info
end

#user_labelsHash<String,String>

The user labels applied to a resource must meet the following requirements: * Each resource can have multiple labels, up to a maximum of 64. * Each label must be a key-value pair. * Keys have a minimum length of 1 character and a maximum length of 63 characters and cannot be empty. Values can be empty and have a maximum length of 63 characters. * Keys and values can contain only lowercase letters, numeric characters, underscores, and dashes. All characters must use UTF-8 encoding, and international characters are allowed. * The key portion of a label must be unique. However, you can use the same key with multiple resources. * Keys must start with a lowercase letter or international character. See Google Cloud Document for more details. Corresponds to the JSON property userLabels

Returns:

  • (Hash<String,String>)


30741
30742
30743
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30741

def user_labels
  @user_labels
end

#user_pseudo_idString

Optional. A unique identifier for tracking visitors. For example, this could be implemented with an HTTP cookie, which should be able to uniquely identify a visitor on a single device. This unique identifier should not change if the visitor logs in or out of the website. This field should NOT have a fixed value such as unknown_visitor. This should be the same identifier as UserEvent.user_pseudo_id and CompleteQueryRequest.user_pseudo_id The field must be a UTF-8 encoded string with a length limit of 128 characters. Otherwise, an INVALID_ARGUMENT error is returned. Corresponds to the JSON property userPseudoId

Returns:

  • (String)


30753
30754
30755
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30753

def user_pseudo_id
  @user_pseudo_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30760
30761
30762
30763
30764
30765
30766
30767
30768
30769
30770
30771
30772
30773
30774
30775
30776
30777
30778
30779
30780
30781
30782
30783
30784
30785
30786
30787
30788
30789
30790
30791
30792
30793
30794
30795
30796
30797
30798
30799
30800
30801
30802
30803
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30760

def update!(**args)
  @boost_spec = args[:boost_spec] if args.key?(:boost_spec)
  @branch = args[:branch] if args.key?(:branch)
  @canonical_filter = args[:canonical_filter] if args.key?(:canonical_filter)
  @content_search_spec = args[:content_search_spec] if args.key?(:content_search_spec)
  @crowding_specs = args[:crowding_specs] if args.key?(:crowding_specs)
  @custom_ranking_params = args[:custom_ranking_params] if args.key?(:custom_ranking_params)
  @data_store_specs = args[:data_store_specs] if args.key?(:data_store_specs)
  @display_spec = args[:display_spec] if args.key?(:display_spec)
  @embedding_spec = args[:embedding_spec] if args.key?(:embedding_spec)
  @entity = args[:entity] if args.key?(:entity)
  @facet_specs = args[:facet_specs] if args.key?(:facet_specs)
  @filter = args[:filter] if args.key?(:filter)
  @image_query = args[:image_query] if args.key?(:image_query)
  @language_code = args[:language_code] if args.key?(:language_code)
  @natural_language_query_understanding_spec = args[:natural_language_query_understanding_spec] if args.key?(:natural_language_query_understanding_spec)
  @num_results_per_data_store = args[:num_results_per_data_store] if args.key?(:num_results_per_data_store)
  @offset = args[:offset] if args.key?(:offset)
  @one_box_page_size = args[:one_box_page_size] if args.key?(:one_box_page_size)
  @order_by = args[:order_by] if args.key?(:order_by)
  @page_categories = args[:page_categories] if args.key?(:page_categories)
  @page_size = args[:page_size] if args.key?(:page_size)
  @page_token = args[:page_token] if args.key?(:page_token)
  @params = args[:params] if args.key?(:params)
  @personalization_spec = args[:personalization_spec] if args.key?(:personalization_spec)
  @query = args[:query] if args.key?(:query)
  @query_expansion_spec = args[:query_expansion_spec] if args.key?(:query_expansion_spec)
  @ranking_expression = args[:ranking_expression] if args.key?(:ranking_expression)
  @ranking_expression_backend = args[:ranking_expression_backend] if args.key?(:ranking_expression_backend)
  @region_code = args[:region_code] if args.key?(:region_code)
  @relevance_filter_spec = args[:relevance_filter_spec] if args.key?(:relevance_filter_spec)
  @relevance_score_spec = args[:relevance_score_spec] if args.key?(:relevance_score_spec)
  @relevance_threshold = args[:relevance_threshold] if args.key?(:relevance_threshold)
  @safe_search = args[:safe_search] if args.key?(:safe_search)
  @search_addon_spec = args[:search_addon_spec] if args.key?(:search_addon_spec)
  @search_as_you_type_spec = args[:search_as_you_type_spec] if args.key?(:search_as_you_type_spec)
  @serving_config = args[:serving_config] if args.key?(:serving_config)
  @session = args[:session] if args.key?(:session)
  @session_spec = args[:session_spec] if args.key?(:session_spec)
  @spell_correction_spec = args[:spell_correction_spec] if args.key?(:spell_correction_spec)
  @user_info = args[:user_info] if args.key?(:user_info)
  @user_labels = args[:user_labels] if args.key?(:user_labels)
  @user_pseudo_id = args[:user_pseudo_id] if args.key?(:user_pseudo_id)
end