Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestBoostSpecConditionBoostSpecBoostControlSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Specification for custom ranking based on customer specified attribute value. It provides more controls for customized ranking than the simple (condition, boost) combination above.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchRequestBoostSpecConditionBoostSpecBoostControlSpec

Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchRequestBoostSpecConditionBoostSpecBoostControlSpec.



31033
31034
31035
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31033

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attribute_typeString

The attribute type to be used to determine the boost amount. The attribute value can be derived from the field value of the specified field_name. In the case of numerical it is straightforward i.e. attribute_value = numerical_field_value. In the case of freshness however, attribute_value = ( time.now() - datetime_field_value). Corresponds to the JSON property attributeType

Returns:

  • (String)


31013
31014
31015
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31013

def attribute_type
  @attribute_type
end

#control_pointsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestBoostSpecConditionBoostSpecBoostControlSpecControlPoint>

The control points used to define the curve. The monotonic function (defined through the interpolation_type above) passes through the control points listed here. Corresponds to the JSON property controlPoints



31020
31021
31022
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31020

def control_points
  @control_points
end

#field_nameString

The name of the field whose value will be used to determine the boost amount. Corresponds to the JSON property fieldName

Returns:

  • (String)


31025
31026
31027
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31025

def field_name
  @field_name
end

#interpolation_typeString

The interpolation type to be applied to connect the control points listed below. Corresponds to the JSON property interpolationType

Returns:

  • (String)


31031
31032
31033
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31031

def interpolation_type
  @interpolation_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31038
31039
31040
31041
31042
31043
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31038

def update!(**args)
  @attribute_type = args[:attribute_type] if args.key?(:attribute_type)
  @control_points = args[:control_points] if args.key?(:control_points)
  @field_name = args[:field_name] if args.key?(:field_name)
  @interpolation_type = args[:interpolation_type] if args.key?(:interpolation_type)
end