Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestBoostSpecConditionBoostSpecBoostControlSpecControlPoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

The control points used to define the curve. The curve defined through these control points can only be monotonically increasing or decreasing(constant values are acceptable).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchRequestBoostSpecConditionBoostSpecBoostControlSpecControlPoint

Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchRequestBoostSpecConditionBoostSpecBoostControlSpecControlPoint.



30256
30257
30258
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30256

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attribute_valueString

Can be one of: 1. The numerical field value. 2. The duration spec for freshness: The value must be formatted as an XSD dayTimeDuration value (a restricted subset of an ISO 8601 duration value). The pattern for this is: nDnM]. Corresponds to the JSON property attributeValue

Returns:

  • (String)


30248
30249
30250
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30248

def attribute_value
  @attribute_value
end

#boost_amountFloat

The value between -1 to 1 by which to boost the score if the attribute_value evaluates to the value specified above. Corresponds to the JSON property boostAmount

Returns:

  • (Float)


30254
30255
30256
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30254

def boost_amount
  @boost_amount
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30261
30262
30263
30264
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30261

def update!(**args)
  @attribute_value = args[:attribute_value] if args.key?(:attribute_value)
  @boost_amount = args[:boost_amount] if args.key?(:boost_amount)
end