Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpecChunkSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Specifies the chunk spec to be returned from the search response. Only available if the SearchRequest.ContentSearchSpec.search_result_mode is set to CHUNKS

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpecChunkSpec

Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpecChunkSpec.



31018
31019
31020
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31018

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#num_next_chunksFixnum

The number of next chunks to be returned of the current chunk. The maximum allowed value is 3. If not specified, no next chunks will be returned. Corresponds to the JSON property numNextChunks

Returns:

  • (Fixnum)


31010
31011
31012
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31010

def num_next_chunks
  @num_next_chunks
end

#num_previous_chunksFixnum

The number of previous chunks to be returned of the current chunk. The maximum allowed value is 3. If not specified, no previous chunks will be returned. Corresponds to the JSON property numPreviousChunks

Returns:

  • (Fixnum)


31016
31017
31018
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31016

def num_previous_chunks
  @num_previous_chunks
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31023
31024
31025
31026
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31023

def update!(**args)
  @num_next_chunks = args[:num_next_chunks] if args.key?(:num_next_chunks)
  @num_previous_chunks = args[:num_previous_chunks] if args.key?(:num_previous_chunks)
end