Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpecChunkSpec
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpecChunkSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Specifies the chunk spec to be returned from the search response. Only available if the SearchRequest.ContentSearchSpec.search_result_mode is set to CHUNKS
Instance Attribute Summary collapse
-
#num_next_chunks ⇒ Fixnum
The number of next chunks to be returned of the current chunk.
-
#num_previous_chunks ⇒ Fixnum
The number of previous chunks to be returned of the current chunk.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpecChunkSpec
constructor
A new instance of GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpecChunkSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpecChunkSpec
Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpecChunkSpec.
30331 30332 30333 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30331 def initialize(**args) update!(**args) end |
Instance Attribute Details
#num_next_chunks ⇒ Fixnum
The number of next chunks to be returned of the current chunk. The maximum
allowed value is 3. If not specified, no next chunks will be returned.
Corresponds to the JSON property numNextChunks
30323 30324 30325 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30323 def num_next_chunks @num_next_chunks end |
#num_previous_chunks ⇒ Fixnum
The number of previous chunks to be returned of the current chunk. The maximum
allowed value is 3. If not specified, no previous chunks will be returned.
Corresponds to the JSON property numPreviousChunks
30329 30330 30331 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30329 def num_previous_chunks @num_previous_chunks end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30336 30337 30338 30339 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30336 def update!(**args) @num_next_chunks = args[:num_next_chunks] if args.key?(:num_next_chunks) @num_previous_chunks = args[:num_previous_chunks] if args.key?(:num_previous_chunks) end |