Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpecExtractiveContentSpec
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpecExtractiveContentSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
A specification for configuring the extractive content in a search response.
Instance Attribute Summary collapse
-
#max_extractive_answer_count ⇒ Fixnum
The maximum number of extractive answers returned in each search result.
-
#max_extractive_segment_count ⇒ Fixnum
The max number of extractive segments returned in each search result.
-
#num_next_segments ⇒ Fixnum
Return at most
num_next_segmentssegments after each selected segments. -
#num_previous_segments ⇒ Fixnum
Specifies whether to also include the adjacent from each selected segments.
-
#return_extractive_segment_score ⇒ Boolean
(also: #return_extractive_segment_score?)
Specifies whether to return the confidence score from the extractive segments in each search result.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpecExtractiveContentSpec
constructor
A new instance of GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpecExtractiveContentSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpecExtractiveContentSpec
Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpecExtractiveContentSpec.
30084 30085 30086 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30084 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_extractive_answer_count ⇒ Fixnum
The maximum number of extractive answers returned in each search result. An
extractive answer is a verbatim answer extracted from the original document,
which provides a precise and contextually relevant answer to the search query.
If the number of matching answers is less than the
max_extractive_answer_count, return all of the answers. Otherwise, return the
max_extractive_answer_count. At most five answers are returned for each
SearchResult.
Corresponds to the JSON property maxExtractiveAnswerCount
30049 30050 30051 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30049 def max_extractive_answer_count @max_extractive_answer_count end |
#max_extractive_segment_count ⇒ Fixnum
The max number of extractive segments returned in each search result. Only
applied if the DataStore is set to DataStore.ContentConfig.CONTENT_REQUIRED or
DataStore.solution_types is SOLUTION_TYPE_CHAT. An extractive segment is a
text segment extracted from the original document that is relevant to the
search query, and, in general, more verbose than an extractive answer. The
segment could then be used as input for LLMs to generate summaries and answers.
If the number of matching segments is less than max_extractive_segment_count
, return all of the segments. Otherwise, return the
max_extractive_segment_count.
Corresponds to the JSON property maxExtractiveSegmentCount
30062 30063 30064 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30062 def max_extractive_segment_count @max_extractive_segment_count end |
#num_next_segments ⇒ Fixnum
Return at most num_next_segments segments after each selected segments.
Corresponds to the JSON property numNextSegments
30067 30068 30069 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30067 def num_next_segments @num_next_segments end |
#num_previous_segments ⇒ Fixnum
Specifies whether to also include the adjacent from each selected segments.
Return at most num_previous_segments segments before each selected segments.
Corresponds to the JSON property numPreviousSegments
30073 30074 30075 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30073 def num_previous_segments @num_previous_segments end |
#return_extractive_segment_score ⇒ Boolean Also known as: return_extractive_segment_score?
Specifies whether to return the confidence score from the extractive segments
in each search result. This feature is available only for new or allowlisted
data stores. To allowlist your data store, contact your Customer Engineer. The
default value is false.
Corresponds to the JSON property returnExtractiveSegmentScore
30081 30082 30083 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30081 def return_extractive_segment_score @return_extractive_segment_score end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30089 30090 30091 30092 30093 30094 30095 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30089 def update!(**args) @max_extractive_answer_count = args[:max_extractive_answer_count] if args.key?(:max_extractive_answer_count) @max_extractive_segment_count = args[:max_extractive_segment_count] if args.key?(:max_extractive_segment_count) @num_next_segments = args[:num_next_segments] if args.key?(:num_next_segments) @num_previous_segments = args[:num_previous_segments] if args.key?(:num_previous_segments) @return_extractive_segment_score = args[:return_extractive_segment_score] if args.key?(:return_extractive_segment_score) end |