Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpecSummarySpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

A specification for configuring a summary returned in a search response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpecSummarySpec

Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpecSummarySpec.



30242
30243
30244
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30242

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ignore_adversarial_queryBoolean Also known as: ignore_adversarial_query?

Specifies whether to filter out adversarial queries. The default value is false. Google employs search-query classification to detect adversarial queries. No summary is returned if the search query is classified as an adversarial query. For example, a user might ask a question regarding negative comments about the company or submit a query designed to generate unsafe, policy-violating output. If this field is set to true, we skip generating summaries for adversarial queries and return fallback messages instead. Corresponds to the JSON property ignoreAdversarialQuery

Returns:

  • (Boolean)


30148
30149
30150
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30148

def ignore_adversarial_query
  @ignore_adversarial_query
end

#ignore_jail_breaking_queryBoolean Also known as: ignore_jail_breaking_query?

Optional. Specifies whether to filter out jail-breaking queries. The default value is false. Google employs search-query classification to detect jail- breaking queries. No summary is returned if the search query is classified as a jail-breaking query. A user might add instructions to the query to change the tone, style, language, content of the answer, or ask the model to act as a different entity, e.g. "Reply in the tone of a competing company's CEO". If this field is set to true, we skip generating summaries for jail-breaking queries and return fallback messages instead. Corresponds to the JSON property ignoreJailBreakingQuery

Returns:

  • (Boolean)


30161
30162
30163
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30161

def ignore_jail_breaking_query
  @ignore_jail_breaking_query
end

#ignore_low_relevant_contentBoolean Also known as: ignore_low_relevant_content?

Specifies whether to filter out queries that have low relevance. The default value is false. If this field is set to false, all search results are used regardless of relevance to generate answers. If set to true, only queries with high relevance search results will generate answers. Corresponds to the JSON property ignoreLowRelevantContent

Returns:

  • (Boolean)


30170
30171
30172
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30170

def ignore_low_relevant_content
  @ignore_low_relevant_content
end

#ignore_non_summary_seeking_queryBoolean Also known as: ignore_non_summary_seeking_query?

Specifies whether to filter out queries that are not summary-seeking. The default value is false. Google employs search-query classification to detect summary-seeking queries. No summary is returned if the search query is classified as a non-summary seeking query. For example, why is the sky blue and Who is the best soccer player in the world? are summary-seeking queries, but SFO airport and world cup 2026 are not. They are most likely navigational queries. If this field is set to true, we skip generating summaries for non-summary seeking queries and return fallback messages instead. Corresponds to the JSON property ignoreNonSummarySeekingQuery

Returns:

  • (Boolean)


30183
30184
30185
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30183

def ignore_non_summary_seeking_query
  @ignore_non_summary_seeking_query
end

#include_citationsBoolean Also known as: include_citations?

Specifies whether to include citations in the summary. The default value is false. When this field is set to true, summaries include in-line citation numbers. Example summary including citations: BigQuery is Google Cloud's fully managed and completely serverless enterprise data warehouse [1]. BigQuery supports all data types, works across clouds, and has built-in machine learning and business intelligence, all within a unified platform [2, 3]. The citation numbers refer to the returned search results and are 1-indexed. For example, [1] means that the sentence is attributed to the first search result. [2, 3] means that the sentence is attributed to both the second and third search results. Corresponds to the JSON property includeCitations

Returns:

  • (Boolean)


30198
30199
30200
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30198

def include_citations
  @include_citations
end

#language_codeString

Language code for Summary. Use language tags defined by BCP47. Note: This is an experimental feature. Corresponds to the JSON property languageCode

Returns:

  • (String)


30205
30206
30207
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30205

def language_code
  @language_code
end

#model_prompt_specGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpecSummarySpecModelPromptSpec

Specification of the prompt to use with the model. Corresponds to the JSON property modelPromptSpec



30210
30211
30212
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30210

def model_prompt_spec
  @model_prompt_spec
end

#model_specGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpecSummarySpecModelSpec

Specification of the model. Corresponds to the JSON property modelSpec



30215
30216
30217
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30215

def model_spec
  @model_spec
end

#multimodal_specGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpecSummarySpecMultiModalSpec

Multimodal specification: Will return an image from specified source. If multiple sources are specified, the pick is a quality based decision. Corresponds to the JSON property multimodalSpec



30221
30222
30223
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30221

def multimodal_spec
  @multimodal_spec
end

#summary_result_countFixnum

The number of top results to generate the summary from. If the number of results returned is less than summaryResultCount, the summary is generated from all of the results. At most 10 results for documents mode, or 50 for chunks mode, can be used to generate a summary. The chunks mode is used when SearchRequest.ContentSearchSpec.search_result_mode is set to CHUNKS. Corresponds to the JSON property summaryResultCount

Returns:

  • (Fixnum)


30230
30231
30232
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30230

def summary_result_count
  @summary_result_count
end

#use_semantic_chunksBoolean Also known as: use_semantic_chunks?

If true, answer will be generated from most relevant chunks from top search results. This feature will improve summary quality. Note that with this feature enabled, not all top search results will be referenced and included in the reference list, so the citation source index only points to the search results listed in the reference list. Corresponds to the JSON property useSemanticChunks

Returns:

  • (Boolean)


30239
30240
30241
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30239

def use_semantic_chunks
  @use_semantic_chunks
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30247
30248
30249
30250
30251
30252
30253
30254
30255
30256
30257
30258
30259
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30247

def update!(**args)
  @ignore_adversarial_query = args[:ignore_adversarial_query] if args.key?(:ignore_adversarial_query)
  @ignore_jail_breaking_query = args[:ignore_jail_breaking_query] if args.key?(:ignore_jail_breaking_query)
  @ignore_low_relevant_content = args[:ignore_low_relevant_content] if args.key?(:ignore_low_relevant_content)
  @ignore_non_summary_seeking_query = args[:ignore_non_summary_seeking_query] if args.key?(:ignore_non_summary_seeking_query)
  @include_citations = args[:include_citations] if args.key?(:include_citations)
  @language_code = args[:language_code] if args.key?(:language_code)
  @model_prompt_spec = args[:model_prompt_spec] if args.key?(:model_prompt_spec)
  @model_spec = args[:model_spec] if args.key?(:model_spec)
  @multimodal_spec = args[:multimodal_spec] if args.key?(:multimodal_spec)
  @summary_result_count = args[:summary_result_count] if args.key?(:summary_result_count)
  @use_semantic_chunks = args[:use_semantic_chunks] if args.key?(:use_semantic_chunks)
end