Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpecSummarySpecModelPromptSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Specification of the prompt to use with the model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpecSummarySpecModelPromptSpec

Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchRequestContentSearchSpecSummarySpecModelPromptSpec.



30578
30579
30580
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30578

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#preambleString

Text at the beginning of the prompt that instructs the assistant. Examples are available in the user guide. Corresponds to the JSON property preamble

Returns:

  • (String)


30576
30577
30578
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30576

def preamble
  @preamble
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30583
30584
30585
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30583

def update!(**args)
  @preamble = args[:preamble] if args.key?(:preamble)
end