Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestDataStoreSpec
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestDataStoreSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
A struct to define data stores to filter on in a search call and
configurations for those data stores. Otherwise, an INVALID_ARGUMENT error
is returned.
Instance Attribute Summary collapse
-
#boost_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestBoostSpec
Boost specification to boost certain documents.
-
#custom_search_operators ⇒ String
Optional.
-
#data_store ⇒ String
Required.
-
#filter ⇒ String
Optional.
-
#num_results ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchRequestDataStoreSpec
constructor
A new instance of GoogleCloudDiscoveryengineV1betaSearchRequestDataStoreSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchRequestDataStoreSpec
Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchRequestDataStoreSpec.
31546 31547 31548 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31546 def initialize(**args) update!(**args) end |
Instance Attribute Details
#boost_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestBoostSpec
Boost specification to boost certain documents.
Corresponds to the JSON property boostSpec
31513 31514 31515 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31513 def boost_spec @boost_spec end |
#custom_search_operators ⇒ String
Optional. Custom search operators which if specified will be used to filter
results from workspace data stores. For more information on custom search
operators, see SearchOperators.
Corresponds to the JSON property customSearchOperators
31521 31522 31523 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31521 def custom_search_operators @custom_search_operators end |
#data_store ⇒ String
Required. Full resource name of DataStore, such as projects/project/
locations/location/collections/collection_id/dataStores/data_store_id`.
The path must include the project number, project id is not supported for this
field.
Corresponds to the JSON propertydataStore`
31529 31530 31531 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31529 def data_store @data_store end |
#filter ⇒ String
Optional. Filter specification to filter documents in the data store specified
by data_store field. For more information on filtering, see Filtering
Corresponds to the JSON property filter
31536 31537 31538 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31536 def filter @filter end |
#num_results ⇒ Fixnum
Optional. The maximum number of results to retrieve from this data store. If
not specified, it will use the SearchRequest.num_results_per_data_store if
provided, otherwise there is no limit. If both this field and SearchRequest.
num_results_per_data_store are specified, this field will be used.
Corresponds to the JSON property numResults
31544 31545 31546 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31544 def num_results @num_results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31551 31552 31553 31554 31555 31556 31557 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31551 def update!(**args) @boost_spec = args[:boost_spec] if args.key?(:boost_spec) @custom_search_operators = args[:custom_search_operators] if args.key?(:custom_search_operators) @data_store = args[:data_store] if args.key?(:data_store) @filter = args[:filter] if args.key?(:filter) @num_results = args[:num_results] if args.key?(:num_results) end |