Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestDataStoreSpec
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestDataStoreSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
A struct to define data stores to filter on in a search call and
configurations for those data stores. Otherwise, an INVALID_ARGUMENT error
is returned.
Instance Attribute Summary collapse
-
#boost_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestBoostSpec
Boost specification to boost certain documents.
-
#custom_search_operators ⇒ String
Optional.
-
#data_store ⇒ String
Required.
-
#filter ⇒ String
Optional.
-
#num_results ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchRequestDataStoreSpec
constructor
A new instance of GoogleCloudDiscoveryengineV1betaSearchRequestDataStoreSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchRequestDataStoreSpec
Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchRequestDataStoreSpec.
30736 30737 30738 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30736 def initialize(**args) update!(**args) end |
Instance Attribute Details
#boost_spec ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestBoostSpec
Boost specification to boost certain documents.
Corresponds to the JSON property boostSpec
30703 30704 30705 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30703 def boost_spec @boost_spec end |
#custom_search_operators ⇒ String
Optional. Custom search operators which if specified will be used to filter
results from workspace data stores. For more information on custom search
operators, see SearchOperators.
Corresponds to the JSON property customSearchOperators
30711 30712 30713 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30711 def custom_search_operators @custom_search_operators end |
#data_store ⇒ String
Required. Full resource name of DataStore, such as projects/project/
locations/location/collections/collection_id/dataStores/data_store_id`.
The path must include the project number, project id is not supported for this
field.
Corresponds to the JSON propertydataStore`
30719 30720 30721 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30719 def data_store @data_store end |
#filter ⇒ String
Optional. Filter specification to filter documents in the data store specified
by data_store field. For more information on filtering, see Filtering
Corresponds to the JSON property filter
30726 30727 30728 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30726 def filter @filter end |
#num_results ⇒ Fixnum
Optional. The maximum number of results to retrieve from this data store. If
not specified, it will use the SearchRequest.num_results_per_data_store if
provided, otherwise there is no limit. If both this field and SearchRequest.
num_results_per_data_store are specified, this field will be used.
Corresponds to the JSON property numResults
30734 30735 30736 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30734 def num_results @num_results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30741 30742 30743 30744 30745 30746 30747 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30741 def update!(**args) @boost_spec = args[:boost_spec] if args.key?(:boost_spec) @custom_search_operators = args[:custom_search_operators] if args.key?(:custom_search_operators) @data_store = args[:data_store] if args.key?(:data_store) @filter = args[:filter] if args.key?(:filter) @num_results = args[:num_results] if args.key?(:num_results) end |