Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestFacetSpecFacetKey

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Specifies how a facet is computed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchRequestFacetSpecFacetKey

Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchRequestFacetSpecFacetKey.



31771
31772
31773
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31771

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#case_insensitiveBoolean Also known as: case_insensitive?

True to make facet keys case insensitive when getting faceting values with prefixes or contains; false otherwise. Corresponds to the JSON property caseInsensitive

Returns:

  • (Boolean)


31719
31720
31721
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31719

def case_insensitive
  @case_insensitive
end

#containsArray<String>

Only get facet values that contain the given strings. For example, suppose " category" has three values "Action > 2022", "Action > 2021" and "Sci-Fi > 2022" . If set "contains" to "2022", the "category" facet only contains "Action > 2022" and "Sci-Fi > 2022". Only supported on textual fields. Maximum is 10. Corresponds to the JSON property contains

Returns:

  • (Array<String>)


31728
31729
31730
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31728

def contains
  @contains
end

#intervalsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaInterval>

Set only if values should be bucketed into intervals. Must be set for facets with numerical values. Must not be set for facet with text values. Maximum number of intervals is 30. Corresponds to the JSON property intervals



31735
31736
31737
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31735

def intervals
  @intervals
end

#keyString

Required. Supported textual and numerical facet keys in Document object, over which the facet values are computed. Facet key is case-sensitive. Corresponds to the JSON property key

Returns:

  • (String)


31741
31742
31743
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31741

def key
  @key
end

#order_byString

The order in which documents are returned. Allowed values are: * "count desc", which means order by SearchResponse.Facet.values.count descending. * "value desc", which means order by SearchResponse.Facet.values.value descending. Only applies to textual facets. If not set, textual values are sorted in natural order; numerical intervals are sorted in the order given by FacetSpec.FacetKey.intervals. Corresponds to the JSON property orderBy

Returns:

  • (String)


31751
31752
31753
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31751

def order_by
  @order_by
end

#prefixesArray<String>

Only get facet values that start with the given string prefix. For example, suppose "category" has three values "Action > 2022", "Action > 2021" and "Sci- Fi > 2022". If set "prefixes" to "Action", the "category" facet only contains " Action > 2022" and "Action > 2021". Only supported on textual fields. Maximum is 10. Corresponds to the JSON property prefixes

Returns:

  • (Array<String>)


31760
31761
31762
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31760

def prefixes
  @prefixes
end

#restricted_valuesArray<String>

Only get facet for the given restricted values. Only supported on textual fields. For example, suppose "category" has three values "Action > 2022", " Action > 2021" and "Sci-Fi > 2022". If set "restricted_values" to "Action > 2022", the "category" facet only contains "Action > 2022". Only supported on textual fields. Maximum is 10. Corresponds to the JSON property restrictedValues

Returns:

  • (Array<String>)


31769
31770
31771
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31769

def restricted_values
  @restricted_values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31776
31777
31778
31779
31780
31781
31782
31783
31784
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31776

def update!(**args)
  @case_insensitive = args[:case_insensitive] if args.key?(:case_insensitive)
  @contains = args[:contains] if args.key?(:contains)
  @intervals = args[:intervals] if args.key?(:intervals)
  @key = args[:key] if args.key?(:key)
  @order_by = args[:order_by] if args.key?(:order_by)
  @prefixes = args[:prefixes] if args.key?(:prefixes)
  @restricted_values = args[:restricted_values] if args.key?(:restricted_values)
end