Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestFacetSpecFacetKey
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestFacetSpecFacetKey
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Specifies how a facet is computed.
Instance Attribute Summary collapse
-
#case_insensitive ⇒ Boolean
(also: #case_insensitive?)
True to make facet keys case insensitive when getting faceting values with prefixes or contains; false otherwise.
-
#contains ⇒ Array<String>
Only get facet values that contain the given strings.
-
#intervals ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaInterval>
Set only if values should be bucketed into intervals.
-
#key ⇒ String
Required.
-
#order_by ⇒ String
The order in which documents are returned.
-
#prefixes ⇒ Array<String>
Only get facet values that start with the given string prefix.
-
#restricted_values ⇒ Array<String>
Only get facet for the given restricted values.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchRequestFacetSpecFacetKey
constructor
A new instance of GoogleCloudDiscoveryengineV1betaSearchRequestFacetSpecFacetKey.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchRequestFacetSpecFacetKey
Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchRequestFacetSpecFacetKey.
31659 31660 31661 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31659 def initialize(**args) update!(**args) end |
Instance Attribute Details
#case_insensitive ⇒ Boolean Also known as: case_insensitive?
True to make facet keys case insensitive when getting faceting values with
prefixes or contains; false otherwise.
Corresponds to the JSON property caseInsensitive
31607 31608 31609 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31607 def case_insensitive @case_insensitive end |
#contains ⇒ Array<String>
Only get facet values that contain the given strings. For example, suppose "
category" has three values "Action > 2022", "Action > 2021" and "Sci-Fi > 2022"
. If set "contains" to "2022", the "category" facet only contains "Action >
2022" and "Sci-Fi > 2022". Only supported on textual fields. Maximum is 10.
Corresponds to the JSON property contains
31616 31617 31618 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31616 def contains @contains end |
#intervals ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaInterval>
Set only if values should be bucketed into intervals. Must be set for facets
with numerical values. Must not be set for facet with text values. Maximum
number of intervals is 30.
Corresponds to the JSON property intervals
31623 31624 31625 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31623 def intervals @intervals end |
#key ⇒ String
Required. Supported textual and numerical facet keys in Document object, over
which the facet values are computed. Facet key is case-sensitive.
Corresponds to the JSON property key
31629 31630 31631 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31629 def key @key end |
#order_by ⇒ String
The order in which documents are returned. Allowed values are: * "count desc",
which means order by SearchResponse.Facet.values.count descending. * "value
desc", which means order by SearchResponse.Facet.values.value descending. Only
applies to textual facets. If not set, textual values are sorted in natural
order; numerical intervals
are sorted in the order given by FacetSpec.FacetKey.intervals.
Corresponds to the JSON property orderBy
31639 31640 31641 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31639 def order_by @order_by end |
#prefixes ⇒ Array<String>
Only get facet values that start with the given string prefix. For example,
suppose "category" has three values "Action > 2022", "Action > 2021" and "Sci-
Fi > 2022". If set "prefixes" to "Action", the "category" facet only contains "
Action > 2022" and "Action > 2021". Only supported on textual fields. Maximum
is 10.
Corresponds to the JSON property prefixes
31648 31649 31650 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31648 def prefixes @prefixes end |
#restricted_values ⇒ Array<String>
Only get facet for the given restricted values. Only supported on textual
fields. For example, suppose "category" has three values "Action > 2022", "
Action > 2021" and "Sci-Fi > 2022". If set "restricted_values" to "Action >
2022", the "category" facet only contains "Action > 2022". Only supported on
textual fields. Maximum is 10.
Corresponds to the JSON property restrictedValues
31657 31658 31659 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31657 def restricted_values @restricted_values end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31664 31665 31666 31667 31668 31669 31670 31671 31672 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31664 def update!(**args) @case_insensitive = args[:case_insensitive] if args.key?(:case_insensitive) @contains = args[:contains] if args.key?(:contains) @intervals = args[:intervals] if args.key?(:intervals) @key = args[:key] if args.key?(:key) @order_by = args[:order_by] if args.key?(:order_by) @prefixes = args[:prefixes] if args.key?(:prefixes) @restricted_values = args[:restricted_values] if args.key?(:restricted_values) end |