Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestQueryExpansionSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Specification to determine under which conditions query expansion should occur.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchRequestQueryExpansionSpec

Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchRequestQueryExpansionSpec.



31896
31897
31898
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31896

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conditionString

The condition under which query expansion should occur. Default to Condition. DISABLED. Corresponds to the JSON property condition

Returns:

  • (String)


31886
31887
31888
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31886

def condition
  @condition
end

#pin_unexpanded_resultsBoolean Also known as: pin_unexpanded_results?

Whether to pin unexpanded results. If this field is set to true, unexpanded products are always at the top of the search results, followed by the expanded results. Corresponds to the JSON property pinUnexpandedResults

Returns:

  • (Boolean)


31893
31894
31895
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31893

def pin_unexpanded_results
  @pin_unexpanded_results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31901
31902
31903
31904
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31901

def update!(**args)
  @condition = args[:condition] if args.key?(:condition)
  @pin_unexpanded_results = args[:pin_unexpanded_results] if args.key?(:pin_unexpanded_results)
end