Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestQueryExpansionSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Specification to determine under which conditions query expansion should occur.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchRequestQueryExpansionSpec

Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchRequestQueryExpansionSpec.



31784
31785
31786
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31784

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conditionString

The condition under which query expansion should occur. Default to Condition. DISABLED. Corresponds to the JSON property condition

Returns:

  • (String)


31774
31775
31776
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31774

def condition
  @condition
end

#pin_unexpanded_resultsBoolean Also known as: pin_unexpanded_results?

Whether to pin unexpanded results. If this field is set to true, unexpanded products are always at the top of the search results, followed by the expanded results. Corresponds to the JSON property pinUnexpandedResults

Returns:

  • (Boolean)


31781
31782
31783
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31781

def pin_unexpanded_results
  @pin_unexpanded_results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31789
31790
31791
31792
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31789

def update!(**args)
  @condition = args[:condition] if args.key?(:condition)
  @pin_unexpanded_results = args[:pin_unexpanded_results] if args.key?(:pin_unexpanded_results)
end