Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestRelevanceScoreSpec
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchRequestRelevanceScoreSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
The specification for returning the document relevance score.
Instance Attribute Summary collapse
-
#return_relevance_score ⇒ Boolean
(also: #return_relevance_score?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchRequestRelevanceScoreSpec
constructor
A new instance of GoogleCloudDiscoveryengineV1betaSearchRequestRelevanceScoreSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchRequestRelevanceScoreSpec
Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchRequestRelevanceScoreSpec.
31145 31146 31147 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31145 def initialize(**args) update!(**args) end |
Instance Attribute Details
#return_relevance_score ⇒ Boolean Also known as: return_relevance_score?
Optional. Whether to return the relevance score for search results. The higher
the score, the more relevant the document is to the query.
Corresponds to the JSON property returnRelevanceScore
31142 31143 31144 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31142 def return_relevance_score @return_relevance_score end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31150 31151 31152 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31150 def update!(**args) @return_relevance_score = args[:return_relevance_score] if args.key?(:return_relevance_score) end |