Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponse
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Response message for SearchService.Search method.
Instance Attribute Summary collapse
-
#applied_controls ⇒ Array<String>
Optional.
-
#attribution_token ⇒ String
A unique search token.
-
#corrected_query ⇒ String
Contains the spell corrected query, if found.
-
#facets ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseFacet>
Results of facets requested by user.
-
#geo_search_debug_info ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseGeoSearchDebugInfo>
Corresponds to the JSON property
geoSearchDebugInfo. -
#guided_search_result ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseGuidedSearchResult
Guided search result.
-
#natural_language_query_understanding_info ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfo
Information describing what natural language understanding was done on the input query.
-
#next_page_token ⇒ String
A token that can be sent as SearchRequest.page_token to retrieve the next page.
-
#one_box_results ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseOneBoxResult>
A list of One Box results.
-
#query_expansion_info ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseQueryExpansionInfo
Information describing query expansion including whether expansion has occurred.
-
#redirect_uri ⇒ String
The URI of a customer-defined redirect page.
-
#results ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSearchResult>
A list of matched documents.
-
#search_link_promotions ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchLinkPromotion>
Promotions for site search.
-
#semantic_state ⇒ String
Output only.
-
#session_info ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSessionInfo
Information about the session.
-
#suggested_query ⇒ String
Corrected query with low confidence, AKA did you mean query.
-
#summary ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSummary
Summary of the top N search results specified by the summary spec.
-
#total_size ⇒ Fixnum
The estimated total count of matched items irrespective of pagination.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchResponse
constructor
A new instance of GoogleCloudDiscoveryengineV1betaSearchResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchResponse
Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchResponse.
32209 32210 32211 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32209 def initialize(**args) update!(**args) end |
Instance Attribute Details
#applied_controls ⇒ Array<String>
Optional. Controls applied as part of the Control service.
Corresponds to the JSON property appliedControls
32104 32105 32106 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32104 def applied_controls @applied_controls end |
#attribution_token ⇒ String
A unique search token. This should be included in the UserEvent logs resulting
from this search, which enables accurate attribution of search model
performance. This also helps to identify a request during the customer support
scenarios.
Corresponds to the JSON property attributionToken
32112 32113 32114 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32112 def attribution_token @attribution_token end |
#corrected_query ⇒ String
Contains the spell corrected query, if found. If the spell correction type is
AUTOMATIC, then the search results are based on corrected_query. Otherwise the
original query is used for search.
Corresponds to the JSON property correctedQuery
32119 32120 32121 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32119 def corrected_query @corrected_query end |
#facets ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseFacet>
Results of facets requested by user.
Corresponds to the JSON property facets
32124 32125 32126 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32124 def facets @facets end |
#geo_search_debug_info ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseGeoSearchDebugInfo>
Corresponds to the JSON property geoSearchDebugInfo
32129 32130 32131 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32129 def geo_search_debug_info @geo_search_debug_info end |
#guided_search_result ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseGuidedSearchResult
Guided search result. The guided search helps user to refine the search
results and narrow down to the real needs from a broaded search results.
Corresponds to the JSON property guidedSearchResult
32135 32136 32137 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32135 def guided_search_result @guided_search_result end |
#natural_language_query_understanding_info ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfo
Information describing what natural language understanding was done on the
input query.
Corresponds to the JSON property naturalLanguageQueryUnderstandingInfo
32141 32142 32143 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32141 def natural_language_query_understanding_info @natural_language_query_understanding_info end |
#next_page_token ⇒ String
A token that can be sent as SearchRequest.page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
Corresponds to the JSON property nextPageToken
32147 32148 32149 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32147 def next_page_token @next_page_token end |
#one_box_results ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseOneBoxResult>
A list of One Box results. There can be multiple One Box results of different
types.
Corresponds to the JSON property oneBoxResults
32153 32154 32155 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32153 def one_box_results @one_box_results end |
#query_expansion_info ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseQueryExpansionInfo
Information describing query expansion including whether expansion has
occurred.
Corresponds to the JSON property queryExpansionInfo
32159 32160 32161 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32159 def query_expansion_info @query_expansion_info end |
#redirect_uri ⇒ String
The URI of a customer-defined redirect page. If redirect action is triggered,
no search is performed, and only redirect_uri and attribution_token are set in
the response.
Corresponds to the JSON property redirectUri
32166 32167 32168 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32166 def redirect_uri @redirect_uri end |
#results ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSearchResult>
A list of matched documents. The order represents the ranking.
Corresponds to the JSON property results
32171 32172 32173 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32171 def results @results end |
#search_link_promotions ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchLinkPromotion>
Promotions for site search.
Corresponds to the JSON property searchLinkPromotions
32176 32177 32178 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32176 def search_link_promotions @search_link_promotions end |
#semantic_state ⇒ String
Output only. Indicates the semantic state of the search response.
Corresponds to the JSON property semanticState
32181 32182 32183 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32181 def semantic_state @semantic_state end |
#session_info ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSessionInfo
Information about the session.
Corresponds to the JSON property sessionInfo
32186 32187 32188 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32186 def session_info @session_info end |
#suggested_query ⇒ String
Corrected query with low confidence, AKA did you mean query. Compared with
corrected_query, this field is set when SpellCorrector returned a response,
but FPR(full page replacement) is not triggered because the corrction is of
low confidence(eg, reversed because there are matches of the original query in
document corpus).
Corresponds to the JSON property suggestedQuery
32195 32196 32197 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32195 def suggested_query @suggested_query end |
#summary ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSummary
Summary of the top N search results specified by the summary spec.
Corresponds to the JSON property summary
32200 32201 32202 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32200 def summary @summary end |
#total_size ⇒ Fixnum
The estimated total count of matched items irrespective of pagination. The
count of results returned by pagination may be less than the total_size that
matches.
Corresponds to the JSON property totalSize
32207 32208 32209 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32207 def total_size @total_size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32214 32215 32216 32217 32218 32219 32220 32221 32222 32223 32224 32225 32226 32227 32228 32229 32230 32231 32232 32233 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32214 def update!(**args) @applied_controls = args[:applied_controls] if args.key?(:applied_controls) @attribution_token = args[:attribution_token] if args.key?(:attribution_token) @corrected_query = args[:corrected_query] if args.key?(:corrected_query) @facets = args[:facets] if args.key?(:facets) @geo_search_debug_info = args[:geo_search_debug_info] if args.key?(:geo_search_debug_info) @guided_search_result = args[:guided_search_result] if args.key?(:guided_search_result) @natural_language_query_understanding_info = args[:natural_language_query_understanding_info] if args.key?(:natural_language_query_understanding_info) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @one_box_results = args[:one_box_results] if args.key?(:one_box_results) @query_expansion_info = args[:query_expansion_info] if args.key?(:query_expansion_info) @redirect_uri = args[:redirect_uri] if args.key?(:redirect_uri) @results = args[:results] if args.key?(:results) @search_link_promotions = args[:search_link_promotions] if args.key?(:search_link_promotions) @semantic_state = args[:semantic_state] if args.key?(:semantic_state) @session_info = args[:session_info] if args.key?(:session_info) @suggested_query = args[:suggested_query] if args.key?(:suggested_query) @summary = args[:summary] if args.key?(:summary) @total_size = args[:total_size] if args.key?(:total_size) end |