Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Response message for SearchService.Search method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchResponse

Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchResponse.



32095
32096
32097
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32095

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#applied_controlsArray<String>

Controls applied as part of the Control service. Corresponds to the JSON property appliedControls

Returns:

  • (Array<String>)


31990
31991
31992
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31990

def applied_controls
  @applied_controls
end

#attribution_tokenString

A unique search token. This should be included in the UserEvent logs resulting from this search, which enables accurate attribution of search model performance. This also helps to identify a request during the customer support scenarios. Corresponds to the JSON property attributionToken

Returns:

  • (String)


31998
31999
32000
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31998

def attribution_token
  @attribution_token
end

#corrected_queryString

Contains the spell corrected query, if found. If the spell correction type is AUTOMATIC, then the search results are based on corrected_query. Otherwise the original query is used for search. Corresponds to the JSON property correctedQuery

Returns:

  • (String)


32005
32006
32007
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32005

def corrected_query
  @corrected_query
end

#facetsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseFacet>

Results of facets requested by user. Corresponds to the JSON property facets



32010
32011
32012
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32010

def facets
  @facets
end

#geo_search_debug_infoArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseGeoSearchDebugInfo>

Corresponds to the JSON property geoSearchDebugInfo



32015
32016
32017
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32015

def geo_search_debug_info
  @geo_search_debug_info
end

#guided_search_resultGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseGuidedSearchResult

Guided search result. The guided search helps user to refine the search results and narrow down to the real needs from a broaded search results. Corresponds to the JSON property guidedSearchResult



32021
32022
32023
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32021

def guided_search_result
  @guided_search_result
end

#natural_language_query_understanding_infoGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfo

Information describing what natural language understanding was done on the input query. Corresponds to the JSON property naturalLanguageQueryUnderstandingInfo



32027
32028
32029
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32027

def natural_language_query_understanding_info
  @natural_language_query_understanding_info
end

#next_page_tokenString

A token that can be sent as SearchRequest.page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


32033
32034
32035
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32033

def next_page_token
  @next_page_token
end

#one_box_resultsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseOneBoxResult>

A list of One Box results. There can be multiple One Box results of different types. Corresponds to the JSON property oneBoxResults



32039
32040
32041
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32039

def one_box_results
  @one_box_results
end

#query_expansion_infoGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseQueryExpansionInfo

Information describing query expansion including whether expansion has occurred. Corresponds to the JSON property queryExpansionInfo



32045
32046
32047
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32045

def query_expansion_info
  @query_expansion_info
end

#redirect_uriString

The URI of a customer-defined redirect page. If redirect action is triggered, no search is performed, and only redirect_uri and attribution_token are set in the response. Corresponds to the JSON property redirectUri

Returns:

  • (String)


32052
32053
32054
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32052

def redirect_uri
  @redirect_uri
end

#resultsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSearchResult>

A list of matched documents. The order represents the ranking. Corresponds to the JSON property results



32057
32058
32059
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32057

def results
  @results
end

Promotions for site search. Corresponds to the JSON property searchLinkPromotions



32062
32063
32064
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32062

def search_link_promotions
  @search_link_promotions
end

#semantic_stateString

Output only. Indicates the semantic state of the search response. Corresponds to the JSON property semanticState

Returns:

  • (String)


32067
32068
32069
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32067

def semantic_state
  @semantic_state
end

#session_infoGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSessionInfo

Information about the session. Corresponds to the JSON property sessionInfo



32072
32073
32074
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32072

def session_info
  @session_info
end

#suggested_queryString

Corrected query with low confidence, AKA did you mean query. Compared with corrected_query, this field is set when SpellCorrector returned a response, but FPR(full page replacement) is not triggered because the corrction is of low confidence(eg, reversed because there are matches of the original query in document corpus). Corresponds to the JSON property suggestedQuery

Returns:

  • (String)


32081
32082
32083
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32081

def suggested_query
  @suggested_query
end

#summaryGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSummary

Summary of the top N search results specified by the summary spec. Corresponds to the JSON property summary



32086
32087
32088
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32086

def summary
  @summary
end

#total_sizeFixnum

The estimated total count of matched items irrespective of pagination. The count of results returned by pagination may be less than the total_size that matches. Corresponds to the JSON property totalSize

Returns:

  • (Fixnum)


32093
32094
32095
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32093

def total_size
  @total_size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32100
32101
32102
32103
32104
32105
32106
32107
32108
32109
32110
32111
32112
32113
32114
32115
32116
32117
32118
32119
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32100

def update!(**args)
  @applied_controls = args[:applied_controls] if args.key?(:applied_controls)
  @attribution_token = args[:attribution_token] if args.key?(:attribution_token)
  @corrected_query = args[:corrected_query] if args.key?(:corrected_query)
  @facets = args[:facets] if args.key?(:facets)
  @geo_search_debug_info = args[:geo_search_debug_info] if args.key?(:geo_search_debug_info)
  @guided_search_result = args[:guided_search_result] if args.key?(:guided_search_result)
  @natural_language_query_understanding_info = args[:natural_language_query_understanding_info] if args.key?(:natural_language_query_understanding_info)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @one_box_results = args[:one_box_results] if args.key?(:one_box_results)
  @query_expansion_info = args[:query_expansion_info] if args.key?(:query_expansion_info)
  @redirect_uri = args[:redirect_uri] if args.key?(:redirect_uri)
  @results = args[:results] if args.key?(:results)
  @search_link_promotions = args[:search_link_promotions] if args.key?(:search_link_promotions)
  @semantic_state = args[:semantic_state] if args.key?(:semantic_state)
  @session_info = args[:session_info] if args.key?(:session_info)
  @suggested_query = args[:suggested_query] if args.key?(:suggested_query)
  @summary = args[:summary] if args.key?(:summary)
  @total_size = args[:total_size] if args.key?(:total_size)
end