Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponse
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Response message for SearchService.Search method.
Instance Attribute Summary collapse
-
#applied_controls ⇒ Array<String>
Controls applied as part of the Control service.
-
#attribution_token ⇒ String
A unique search token.
-
#corrected_query ⇒ String
Contains the spell corrected query, if found.
-
#facets ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseFacet>
Results of facets requested by user.
-
#geo_search_debug_info ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseGeoSearchDebugInfo>
Corresponds to the JSON property
geoSearchDebugInfo. -
#guided_search_result ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseGuidedSearchResult
Guided search result.
-
#natural_language_query_understanding_info ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfo
Information describing what natural language understanding was done on the input query.
-
#next_page_token ⇒ String
A token that can be sent as SearchRequest.page_token to retrieve the next page.
-
#one_box_results ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseOneBoxResult>
A list of One Box results.
-
#query_expansion_info ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseQueryExpansionInfo
Information describing query expansion including whether expansion has occurred.
-
#redirect_uri ⇒ String
The URI of a customer-defined redirect page.
-
#results ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSearchResult>
A list of matched documents.
-
#search_link_promotions ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchLinkPromotion>
Promotions for site search.
-
#semantic_state ⇒ String
Output only.
-
#session_info ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSessionInfo
Information about the session.
-
#suggested_query ⇒ String
Corrected query with low confidence, AKA did you mean query.
-
#summary ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSummary
Summary of the top N search results specified by the summary spec.
-
#total_size ⇒ Fixnum
The estimated total count of matched items irrespective of pagination.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchResponse
constructor
A new instance of GoogleCloudDiscoveryengineV1betaSearchResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchResponse
Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchResponse.
31078 31079 31080 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31078 def initialize(**args) update!(**args) end |
Instance Attribute Details
#applied_controls ⇒ Array<String>
Controls applied as part of the Control service.
Corresponds to the JSON property appliedControls
30973 30974 30975 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30973 def applied_controls @applied_controls end |
#attribution_token ⇒ String
A unique search token. This should be included in the UserEvent logs resulting
from this search, which enables accurate attribution of search model
performance. This also helps to identify a request during the customer support
scenarios.
Corresponds to the JSON property attributionToken
30981 30982 30983 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30981 def attribution_token @attribution_token end |
#corrected_query ⇒ String
Contains the spell corrected query, if found. If the spell correction type is
AUTOMATIC, then the search results are based on corrected_query. Otherwise the
original query is used for search.
Corresponds to the JSON property correctedQuery
30988 30989 30990 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30988 def corrected_query @corrected_query end |
#facets ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseFacet>
Results of facets requested by user.
Corresponds to the JSON property facets
30993 30994 30995 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30993 def facets @facets end |
#geo_search_debug_info ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseGeoSearchDebugInfo>
Corresponds to the JSON property geoSearchDebugInfo
30998 30999 31000 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 30998 def geo_search_debug_info @geo_search_debug_info end |
#guided_search_result ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseGuidedSearchResult
Guided search result. The guided search helps user to refine the search
results and narrow down to the real needs from a broaded search results.
Corresponds to the JSON property guidedSearchResult
31004 31005 31006 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31004 def guided_search_result @guided_search_result end |
#natural_language_query_understanding_info ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfo
Information describing what natural language understanding was done on the
input query.
Corresponds to the JSON property naturalLanguageQueryUnderstandingInfo
31010 31011 31012 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31010 def natural_language_query_understanding_info @natural_language_query_understanding_info end |
#next_page_token ⇒ String
A token that can be sent as SearchRequest.page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
Corresponds to the JSON property nextPageToken
31016 31017 31018 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31016 def next_page_token @next_page_token end |
#one_box_results ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseOneBoxResult>
A list of One Box results. There can be multiple One Box results of different
types.
Corresponds to the JSON property oneBoxResults
31022 31023 31024 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31022 def one_box_results @one_box_results end |
#query_expansion_info ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseQueryExpansionInfo
Information describing query expansion including whether expansion has
occurred.
Corresponds to the JSON property queryExpansionInfo
31028 31029 31030 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31028 def query_expansion_info @query_expansion_info end |
#redirect_uri ⇒ String
The URI of a customer-defined redirect page. If redirect action is triggered,
no search is performed, and only redirect_uri and attribution_token are set in
the response.
Corresponds to the JSON property redirectUri
31035 31036 31037 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31035 def redirect_uri @redirect_uri end |
#results ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSearchResult>
A list of matched documents. The order represents the ranking.
Corresponds to the JSON property results
31040 31041 31042 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31040 def results @results end |
#search_link_promotions ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchLinkPromotion>
Promotions for site search.
Corresponds to the JSON property searchLinkPromotions
31045 31046 31047 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31045 def search_link_promotions @search_link_promotions end |
#semantic_state ⇒ String
Output only. Indicates the semantic state of the search response.
Corresponds to the JSON property semanticState
31050 31051 31052 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31050 def semantic_state @semantic_state end |
#session_info ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSessionInfo
Information about the session.
Corresponds to the JSON property sessionInfo
31055 31056 31057 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31055 def session_info @session_info end |
#suggested_query ⇒ String
Corrected query with low confidence, AKA did you mean query. Compared with
corrected_query, this field is set when SpellCorrector returned a response,
but FPR(full page replacement) is not triggered because the corrction is of
low confidence(eg, reversed because there are matches of the original query in
document corpus).
Corresponds to the JSON property suggestedQuery
31064 31065 31066 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31064 def suggested_query @suggested_query end |
#summary ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSummary
Summary of the top N search results specified by the summary spec.
Corresponds to the JSON property summary
31069 31070 31071 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31069 def summary @summary end |
#total_size ⇒ Fixnum
The estimated total count of matched items irrespective of pagination. The
count of results returned by pagination may be less than the total_size that
matches.
Corresponds to the JSON property totalSize
31076 31077 31078 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31076 def total_size @total_size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31083 31084 31085 31086 31087 31088 31089 31090 31091 31092 31093 31094 31095 31096 31097 31098 31099 31100 31101 31102 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31083 def update!(**args) @applied_controls = args[:applied_controls] if args.key?(:applied_controls) @attribution_token = args[:attribution_token] if args.key?(:attribution_token) @corrected_query = args[:corrected_query] if args.key?(:corrected_query) @facets = args[:facets] if args.key?(:facets) @geo_search_debug_info = args[:geo_search_debug_info] if args.key?(:geo_search_debug_info) @guided_search_result = args[:guided_search_result] if args.key?(:guided_search_result) @natural_language_query_understanding_info = args[:natural_language_query_understanding_info] if args.key?(:natural_language_query_understanding_info) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @one_box_results = args[:one_box_results] if args.key?(:one_box_results) @query_expansion_info = args[:query_expansion_info] if args.key?(:query_expansion_info) @redirect_uri = args[:redirect_uri] if args.key?(:redirect_uri) @results = args[:results] if args.key?(:results) @search_link_promotions = args[:search_link_promotions] if args.key?(:search_link_promotions) @semantic_state = args[:semantic_state] if args.key?(:semantic_state) @session_info = args[:session_info] if args.key?(:session_info) @suggested_query = args[:suggested_query] if args.key?(:suggested_query) @summary = args[:summary] if args.key?(:summary) @total_size = args[:total_size] if args.key?(:total_size) end |