Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Information describing what natural language understanding was done on the input query.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfo

Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfo.



32224
32225
32226
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32224

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#classified_intentsArray<String>

The classified intents from the input query. Corresponds to the JSON property classifiedIntents

Returns:

  • (Array<String>)


32206
32207
32208
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32206

def classified_intents
  @classified_intents
end

#extracted_filtersString

The filters that were extracted from the input query. Corresponds to the JSON property extractedFilters

Returns:

  • (String)


32211
32212
32213
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32211

def extracted_filters
  @extracted_filters
end

#rewritten_queryString

Rewritten input query minus the extracted filters. Corresponds to the JSON property rewrittenQuery

Returns:

  • (String)


32216
32217
32218
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32216

def rewritten_query
  @rewritten_query
end

#structured_extracted_filterGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilter

The filters that were extracted from the input query represented in a structured form. Corresponds to the JSON property structuredExtractedFilter



32222
32223
32224
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32222

def structured_extracted_filter
  @structured_extracted_filter
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32229
32230
32231
32232
32233
32234
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32229

def update!(**args)
  @classified_intents = args[:classified_intents] if args.key?(:classified_intents)
  @extracted_filters = args[:extracted_filters] if args.key?(:extracted_filters)
  @rewritten_query = args[:rewritten_query] if args.key?(:rewritten_query)
  @structured_extracted_filter = args[:structured_extracted_filter] if args.key?(:structured_extracted_filter)
end