Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterExpression

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

The expression denoting the filter that was extracted from the input query.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterExpression

Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterExpression.



32306
32307
32308
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32306

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#geolocation_constraintGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterGeolocationConstraint

Constraint of a geolocation field. Name of the geolocation field as defined in the schema. Corresponds to the JSON property geolocationConstraint



32289
32290
32291
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32289

def geolocation_constraint
  @geolocation_constraint
end

#number_constraintGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterNumberConstraint

Constraint expression of a number field. Example: price < 100. Corresponds to the JSON property numberConstraint



32294
32295
32296
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32294

def number_constraint
  @number_constraint
end

#string_constraintGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterStringConstraint

Constraint expression of a string field. Corresponds to the JSON property stringConstraint



32304
32305
32306
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32304

def string_constraint
  @string_constraint
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32311
32312
32313
32314
32315
32316
32317
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32311

def update!(**args)
  @and_expr = args[:and_expr] if args.key?(:and_expr)
  @geolocation_constraint = args[:geolocation_constraint] if args.key?(:geolocation_constraint)
  @number_constraint = args[:number_constraint] if args.key?(:number_constraint)
  @or_expr = args[:or_expr] if args.key?(:or_expr)
  @string_constraint = args[:string_constraint] if args.key?(:string_constraint)
end