Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterExpression

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

The expression denoting the filter that was extracted from the input query.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterExpression

Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterExpression.



31354
31355
31356
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31354

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#geolocation_constraintGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterGeolocationConstraint

Constraint of a geolocation field. Name of the geolocation field as defined in the schema. Corresponds to the JSON property geolocationConstraint



31337
31338
31339
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31337

def geolocation_constraint
  @geolocation_constraint
end

#number_constraintGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterNumberConstraint

Constraint expression of a number field. Example: price < 100. Corresponds to the JSON property numberConstraint



31342
31343
31344
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31342

def number_constraint
  @number_constraint
end

#string_constraintGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterStringConstraint

Constraint expression of a string field. Corresponds to the JSON property stringConstraint



31352
31353
31354
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31352

def string_constraint
  @string_constraint
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31359
31360
31361
31362
31363
31364
31365
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31359

def update!(**args)
  @and_expr = args[:and_expr] if args.key?(:and_expr)
  @geolocation_constraint = args[:geolocation_constraint] if args.key?(:geolocation_constraint)
  @number_constraint = args[:number_constraint] if args.key?(:number_constraint)
  @or_expr = args[:or_expr] if args.key?(:or_expr)
  @string_constraint = args[:string_constraint] if args.key?(:string_constraint)
end