Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterGeolocationConstraint
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterGeolocationConstraint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Constraint of a geolocation field. Name of the geolocation field as defined in the schema.
Instance Attribute Summary collapse
-
#address ⇒ String
The reference address that was inferred from the input query.
-
#field_name ⇒ String
The name of the geolocation field as defined in the schema.
-
#latitude ⇒ Float
The latitude of the geolocation inferred from the input query.
-
#longitude ⇒ Float
The longitude of the geolocation inferred from the input query.
-
#radius_in_meters ⇒ Float
The radius in meters around the address.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterGeolocationConstraint
constructor
A new instance of GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterGeolocationConstraint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterGeolocationConstraint
Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterGeolocationConstraint.
32517 32518 32519 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32517 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address ⇒ String
The reference address that was inferred from the input query. The proximity of
the reference address to the geolocation field will be used to filter the
results.
Corresponds to the JSON property address
32494 32495 32496 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32494 def address @address end |
#field_name ⇒ String
The name of the geolocation field as defined in the schema.
Corresponds to the JSON property fieldName
32499 32500 32501 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32499 def field_name @field_name end |
#latitude ⇒ Float
The latitude of the geolocation inferred from the input query.
Corresponds to the JSON property latitude
32504 32505 32506 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32504 def latitude @latitude end |
#longitude ⇒ Float
The longitude of the geolocation inferred from the input query.
Corresponds to the JSON property longitude
32509 32510 32511 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32509 def longitude @longitude end |
#radius_in_meters ⇒ Float
The radius in meters around the address. The record is returned if the
location of the geolocation field is within the radius.
Corresponds to the JSON property radiusInMeters
32515 32516 32517 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32515 def radius_in_meters @radius_in_meters end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32522 32523 32524 32525 32526 32527 32528 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32522 def update!(**args) @address = args[:address] if args.key?(:address) @field_name = args[:field_name] if args.key?(:field_name) @latitude = args[:latitude] if args.key?(:latitude) @longitude = args[:longitude] if args.key?(:longitude) @radius_in_meters = args[:radius_in_meters] if args.key?(:radius_in_meters) end |