Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterGeolocationConstraint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Constraint of a geolocation field. Name of the geolocation field as defined in the schema.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterGeolocationConstraint

Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterGeolocationConstraint.



32530
32531
32532
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32530

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addressString

The reference address that was inferred from the input query. The proximity of the reference address to the geolocation field will be used to filter the results. Corresponds to the JSON property address

Returns:

  • (String)


32507
32508
32509
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32507

def address
  @address
end

#field_nameString

The name of the geolocation field as defined in the schema. Corresponds to the JSON property fieldName

Returns:

  • (String)


32512
32513
32514
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32512

def field_name
  @field_name
end

#latitudeFloat

The latitude of the geolocation inferred from the input query. Corresponds to the JSON property latitude

Returns:

  • (Float)


32517
32518
32519
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32517

def latitude
  @latitude
end

#longitudeFloat

The longitude of the geolocation inferred from the input query. Corresponds to the JSON property longitude

Returns:

  • (Float)


32522
32523
32524
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32522

def longitude
  @longitude
end

#radius_in_metersFloat

The radius in meters around the address. The record is returned if the location of the geolocation field is within the radius. Corresponds to the JSON property radiusInMeters

Returns:

  • (Float)


32528
32529
32530
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32528

def radius_in_meters
  @radius_in_meters
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32535
32536
32537
32538
32539
32540
32541
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32535

def update!(**args)
  @address = args[:address] if args.key?(:address)
  @field_name = args[:field_name] if args.key?(:field_name)
  @latitude = args[:latitude] if args.key?(:latitude)
  @longitude = args[:longitude] if args.key?(:longitude)
  @radius_in_meters = args[:radius_in_meters] if args.key?(:radius_in_meters)
end