Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterGeolocationConstraint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Constraint of a geolocation field. Name of the geolocation field as defined in the schema.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterGeolocationConstraint

Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterGeolocationConstraint.



31707
31708
31709
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31707

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addressString

The reference address that was inferred from the input query. The proximity of the reference address to the geolocation field will be used to filter the results. Corresponds to the JSON property address

Returns:

  • (String)


31684
31685
31686
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31684

def address
  @address
end

#field_nameString

The name of the geolocation field as defined in the schema. Corresponds to the JSON property fieldName

Returns:

  • (String)


31689
31690
31691
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31689

def field_name
  @field_name
end

#latitudeFloat

The latitude of the geolocation inferred from the input query. Corresponds to the JSON property latitude

Returns:

  • (Float)


31694
31695
31696
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31694

def latitude
  @latitude
end

#longitudeFloat

The longitude of the geolocation inferred from the input query. Corresponds to the JSON property longitude

Returns:

  • (Float)


31699
31700
31701
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31699

def longitude
  @longitude
end

#radius_in_metersFloat

The radius in meters around the address. The record is returned if the location of the geolocation field is within the radius. Corresponds to the JSON property radiusInMeters

Returns:

  • (Float)


31705
31706
31707
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31705

def radius_in_meters
  @radius_in_meters
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31712
31713
31714
31715
31716
31717
31718
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31712

def update!(**args)
  @address = args[:address] if args.key?(:address)
  @field_name = args[:field_name] if args.key?(:field_name)
  @latitude = args[:latitude] if args.key?(:latitude)
  @longitude = args[:longitude] if args.key?(:longitude)
  @radius_in_meters = args[:radius_in_meters] if args.key?(:radius_in_meters)
end