Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterGeolocationConstraint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Constraint of a geolocation field. Name of the geolocation field as defined in the schema.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterGeolocationConstraint

Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterGeolocationConstraint.



31401
31402
31403
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31401

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addressString

The reference address that was inferred from the input query. The proximity of the reference address to the geolocation field will be used to filter the results. Corresponds to the JSON property address

Returns:

  • (String)


31378
31379
31380
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31378

def address
  @address
end

#field_nameString

The name of the geolocation field as defined in the schema. Corresponds to the JSON property fieldName

Returns:

  • (String)


31383
31384
31385
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31383

def field_name
  @field_name
end

#latitudeFloat

The latitude of the geolocation inferred from the input query. Corresponds to the JSON property latitude

Returns:

  • (Float)


31388
31389
31390
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31388

def latitude
  @latitude
end

#longitudeFloat

The longitude of the geolocation inferred from the input query. Corresponds to the JSON property longitude

Returns:

  • (Float)


31393
31394
31395
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31393

def longitude
  @longitude
end

#radius_in_metersFloat

The radius in meters around the address. The record is returned if the location of the geolocation field is within the radius. Corresponds to the JSON property radiusInMeters

Returns:

  • (Float)


31399
31400
31401
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31399

def radius_in_meters
  @radius_in_meters
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31406
31407
31408
31409
31410
31411
31412
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31406

def update!(**args)
  @address = args[:address] if args.key?(:address)
  @field_name = args[:field_name] if args.key?(:field_name)
  @latitude = args[:latitude] if args.key?(:latitude)
  @longitude = args[:longitude] if args.key?(:longitude)
  @radius_in_meters = args[:radius_in_meters] if args.key?(:radius_in_meters)
end