Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterNumberConstraint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Constraint expression of a number field. Example: price < 100.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterNumberConstraint

Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterNumberConstraint.



31440
31441
31442
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31440

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#comparisonString

The comparison operation performed between the field value and the value specified in the constraint. Corresponds to the JSON property comparison

Returns:

  • (String)


31423
31424
31425
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31423

def comparison
  @comparison
end

#field_nameString

Name of the numerical field as defined in the schema. Corresponds to the JSON property fieldName

Returns:

  • (String)


31428
31429
31430
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31428

def field_name
  @field_name
end

#query_segmentString

Identifies the keywords within the search query that match a filter. Corresponds to the JSON property querySegment

Returns:

  • (String)


31433
31434
31435
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31433

def query_segment
  @query_segment
end

#valueFloat

The value specified in the numerical constraint. Corresponds to the JSON property value

Returns:

  • (Float)


31438
31439
31440
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31438

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31445
31446
31447
31448
31449
31450
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31445

def update!(**args)
  @comparison = args[:comparison] if args.key?(:comparison)
  @field_name = args[:field_name] if args.key?(:field_name)
  @query_segment = args[:query_segment] if args.key?(:query_segment)
  @value = args[:value] if args.key?(:value)
end