Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterStringConstraint
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterStringConstraint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Constraint expression of a string field.
Instance Attribute Summary collapse
-
#field_name ⇒ String
Name of the string field as defined in the schema.
-
#query_segment ⇒ String
Identifies the keywords within the search query that match a filter.
-
#values ⇒ Array<String>
Values of the string field.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterStringConstraint
constructor
A new instance of GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterStringConstraint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterStringConstraint
Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterStringConstraint.
32621 32622 32623 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32621 def initialize(**args) update!(**args) end |
Instance Attribute Details
#field_name ⇒ String
Name of the string field as defined in the schema.
Corresponds to the JSON property fieldName
32608 32609 32610 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32608 def field_name @field_name end |
#query_segment ⇒ String
Identifies the keywords within the search query that match a filter.
Corresponds to the JSON property querySegment
32613 32614 32615 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32613 def query_segment @query_segment end |
#values ⇒ Array<String>
Values of the string field. The record will only be returned if the field
value matches one of the values specified here.
Corresponds to the JSON property values
32619 32620 32621 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32619 def values @values end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32626 32627 32628 32629 32630 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32626 def update!(**args) @field_name = args[:field_name] if args.key?(:field_name) @query_segment = args[:query_segment] if args.key?(:query_segment) @values = args[:values] if args.key?(:values) end |