Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterStringConstraint
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterStringConstraint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Constraint expression of a string field.
Instance Attribute Summary collapse
-
#field_name ⇒ String
Name of the string field as defined in the schema.
-
#query_segment ⇒ String
Identifies the keywords within the search query that match a filter.
-
#values ⇒ Array<String>
Values of the string field.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterStringConstraint
constructor
A new instance of GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterStringConstraint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterStringConstraint
Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterStringConstraint.
31798 31799 31800 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31798 def initialize(**args) update!(**args) end |
Instance Attribute Details
#field_name ⇒ String
Name of the string field as defined in the schema.
Corresponds to the JSON property fieldName
31785 31786 31787 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31785 def field_name @field_name end |
#query_segment ⇒ String
Identifies the keywords within the search query that match a filter.
Corresponds to the JSON property querySegment
31790 31791 31792 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31790 def query_segment @query_segment end |
#values ⇒ Array<String>
Values of the string field. The record will only be returned if the field
value matches one of the values specified here.
Corresponds to the JSON property values
31796 31797 31798 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31796 def values @values end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31803 31804 31805 31806 31807 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31803 def update!(**args) @field_name = args[:field_name] if args.key?(:field_name) @query_segment = args[:query_segment] if args.key?(:query_segment) @values = args[:values] if args.key?(:values) end |