Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterStringConstraint
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterStringConstraint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Constraint expression of a string field.
Instance Attribute Summary collapse
-
#field_name ⇒ String
Name of the string field as defined in the schema.
-
#query_segment ⇒ String
Identifies the keywords within the search query that match a filter.
-
#values ⇒ Array<String>
Values of the string field.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterStringConstraint
constructor
A new instance of GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterStringConstraint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterStringConstraint
Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchResponseNaturalLanguageQueryUnderstandingInfoStructuredExtractedFilterStringConstraint.
31492 31493 31494 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31492 def initialize(**args) update!(**args) end |
Instance Attribute Details
#field_name ⇒ String
Name of the string field as defined in the schema.
Corresponds to the JSON property fieldName
31479 31480 31481 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31479 def field_name @field_name end |
#query_segment ⇒ String
Identifies the keywords within the search query that match a filter.
Corresponds to the JSON property querySegment
31484 31485 31486 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31484 def query_segment @query_segment end |
#values ⇒ Array<String>
Values of the string field. The record will only be returned if the field
value matches one of the values specified here.
Corresponds to the JSON property values
31490 31491 31492 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31490 def values @values end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31497 31498 31499 31500 31501 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31497 def update!(**args) @field_name = args[:field_name] if args.key?(:field_name) @query_segment = args[:query_segment] if args.key?(:query_segment) @values = args[:values] if args.key?(:values) end |