Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSearchResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Represents the search results.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchResponseSearchResult

Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchResponseSearchResult.



32710
32711
32712
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32710

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chunkGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaChunk

Chunk captures all raw metadata information of items to be recommended or searched in the chunk mode. Corresponds to the JSON property chunk



32682
32683
32684
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32682

def chunk
  @chunk
end

#documentGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocument

Document captures all raw metadata information of items to be recommended or searched. Corresponds to the JSON property document



32688
32689
32690
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32688

def document
  @document
end

#idString

Document.id of the searched Document. Corresponds to the JSON property id

Returns:

  • (String)


32693
32694
32695
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32693

def id
  @id
end

#model_scoresHash<String,Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDoubleList>

Output only. Google provided available scores. Corresponds to the JSON property modelScores



32698
32699
32700
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32698

def model_scores
  @model_scores
end

#rank_signalsGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSearchResultRankSignals

A set of ranking signals. Corresponds to the JSON property rankSignals



32703
32704
32705
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32703

def rank_signals
  @rank_signals
end

#retrieval_signalsGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSearchResultRetrievalSignals

Contains a set of signals used by the relevance filter. Corresponds to the JSON property retrievalSignals



32708
32709
32710
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32708

def retrieval_signals
  @retrieval_signals
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32715
32716
32717
32718
32719
32720
32721
32722
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32715

def update!(**args)
  @chunk = args[:chunk] if args.key?(:chunk)
  @document = args[:document] if args.key?(:document)
  @id = args[:id] if args.key?(:id)
  @model_scores = args[:model_scores] if args.key?(:model_scores)
  @rank_signals = args[:rank_signals] if args.key?(:rank_signals)
  @retrieval_signals = args[:retrieval_signals] if args.key?(:retrieval_signals)
end