Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSearchResult
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSearchResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Represents the search results.
Instance Attribute Summary collapse
-
#chunk ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaChunk
Chunk captures all raw metadata information of items to be recommended or searched in the chunk mode.
-
#document ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocument
Document captures all raw metadata information of items to be recommended or searched.
-
#id ⇒ String
Document.id of the searched Document.
-
#model_scores ⇒ Hash<String,Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDoubleList>
Output only.
-
#rank_signals ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSearchResultRankSignals
A set of ranking signals.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchResponseSearchResult
constructor
A new instance of GoogleCloudDiscoveryengineV1betaSearchResponseSearchResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchResponseSearchResult
Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchResponseSearchResult.
32582 32583 32584 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32582 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chunk ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaChunk
Chunk captures all raw metadata information of items to be recommended or
searched in the chunk mode.
Corresponds to the JSON property chunk
32559 32560 32561 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32559 def chunk @chunk end |
#document ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocument
Document captures all raw metadata information of items to be recommended or
searched.
Corresponds to the JSON property document
32565 32566 32567 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32565 def document @document end |
#id ⇒ String
Document.id of the searched Document.
Corresponds to the JSON property id
32570 32571 32572 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32570 def id @id end |
#model_scores ⇒ Hash<String,Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDoubleList>
Output only. Google provided available scores.
Corresponds to the JSON property modelScores
32575 32576 32577 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32575 def model_scores @model_scores end |
#rank_signals ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSearchResultRankSignals
A set of ranking signals.
Corresponds to the JSON property rankSignals
32580 32581 32582 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32580 def rank_signals @rank_signals end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32587 32588 32589 32590 32591 32592 32593 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32587 def update!(**args) @chunk = args[:chunk] if args.key?(:chunk) @document = args[:document] if args.key?(:document) @id = args[:id] if args.key?(:id) @model_scores = args[:model_scores] if args.key?(:model_scores) @rank_signals = args[:rank_signals] if args.key?(:rank_signals) end |