Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSearchResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Represents the search results.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchResponseSearchResult

Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchResponseSearchResult.



32541
32542
32543
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32541

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chunkGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaChunk

Chunk captures all raw metadata information of items to be recommended or searched in the chunk mode. Corresponds to the JSON property chunk



32518
32519
32520
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32518

def chunk
  @chunk
end

#documentGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocument

Document captures all raw metadata information of items to be recommended or searched. Corresponds to the JSON property document



32524
32525
32526
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32524

def document
  @document
end

#idString

Document.id of the searched Document. Corresponds to the JSON property id

Returns:

  • (String)


32529
32530
32531
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32529

def id
  @id
end

#model_scoresHash<String,Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDoubleList>

Output only. Google provided available scores. Corresponds to the JSON property modelScores



32534
32535
32536
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32534

def model_scores
  @model_scores
end

#rank_signalsGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSearchResultRankSignals

A set of ranking signals. Corresponds to the JSON property rankSignals



32539
32540
32541
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32539

def rank_signals
  @rank_signals
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32546
32547
32548
32549
32550
32551
32552
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32546

def update!(**args)
  @chunk = args[:chunk] if args.key?(:chunk)
  @document = args[:document] if args.key?(:document)
  @id = args[:id] if args.key?(:id)
  @model_scores = args[:model_scores] if args.key?(:model_scores)
  @rank_signals = args[:rank_signals] if args.key?(:rank_signals)
end