Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSearchResult
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSearchResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Represents the search results.
Instance Attribute Summary collapse
-
#chunk ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaChunk
Chunk captures all raw metadata information of items to be recommended or searched in the chunk mode.
-
#document ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocument
Document captures all raw metadata information of items to be recommended or searched.
-
#id ⇒ String
Document.id of the searched Document.
-
#model_scores ⇒ Hash<String,Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDoubleList>
Output only.
-
#rank_signals ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSearchResultRankSignals
A set of ranking signals.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchResponseSearchResult
constructor
A new instance of GoogleCloudDiscoveryengineV1betaSearchResponseSearchResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchResponseSearchResult
Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchResponseSearchResult.
32541 32542 32543 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32541 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chunk ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaChunk
Chunk captures all raw metadata information of items to be recommended or
searched in the chunk mode.
Corresponds to the JSON property chunk
32518 32519 32520 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32518 def chunk @chunk end |
#document ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocument
Document captures all raw metadata information of items to be recommended or
searched.
Corresponds to the JSON property document
32524 32525 32526 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32524 def document @document end |
#id ⇒ String
Document.id of the searched Document.
Corresponds to the JSON property id
32529 32530 32531 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32529 def id @id end |
#model_scores ⇒ Hash<String,Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDoubleList>
Output only. Google provided available scores.
Corresponds to the JSON property modelScores
32534 32535 32536 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32534 def model_scores @model_scores end |
#rank_signals ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSearchResultRankSignals
A set of ranking signals.
Corresponds to the JSON property rankSignals
32539 32540 32541 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32539 def rank_signals @rank_signals end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32546 32547 32548 32549 32550 32551 32552 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32546 def update!(**args) @chunk = args[:chunk] if args.key?(:chunk) @document = args[:document] if args.key?(:document) @id = args[:id] if args.key?(:id) @model_scores = args[:model_scores] if args.key?(:model_scores) @rank_signals = args[:rank_signals] if args.key?(:rank_signals) end |