Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSearchResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Represents the search results.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchResponseSearchResult

Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchResponseSearchResult.



31895
31896
31897
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31895

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chunkGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaChunk

Chunk captures all raw metadata information of items to be recommended or searched in the chunk mode. Corresponds to the JSON property chunk



31872
31873
31874
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31872

def chunk
  @chunk
end

#documentGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocument

Document captures all raw metadata information of items to be recommended or searched. Corresponds to the JSON property document



31878
31879
31880
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31878

def document
  @document
end

#idString

Document.id of the searched Document. Corresponds to the JSON property id

Returns:

  • (String)


31883
31884
31885
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31883

def id
  @id
end

#model_scoresHash<String,Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDoubleList>

Output only. Google provided available scores. Corresponds to the JSON property modelScores



31888
31889
31890
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31888

def model_scores
  @model_scores
end

#rank_signalsGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSearchResultRankSignals

A set of ranking signals. Corresponds to the JSON property rankSignals



31893
31894
31895
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31893

def rank_signals
  @rank_signals
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31900
31901
31902
31903
31904
31905
31906
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31900

def update!(**args)
  @chunk = args[:chunk] if args.key?(:chunk)
  @document = args[:document] if args.key?(:document)
  @id = args[:id] if args.key?(:id)
  @model_scores = args[:model_scores] if args.key?(:model_scores)
  @rank_signals = args[:rank_signals] if args.key?(:rank_signals)
end