Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSearchResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Represents the search results.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchResponseSearchResult

Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchResponseSearchResult.



31589
31590
31591
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31589

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chunkGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaChunk

Chunk captures all raw metadata information of items to be recommended or searched in the chunk mode. Corresponds to the JSON property chunk



31566
31567
31568
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31566

def chunk
  @chunk
end

#documentGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDocument

Document captures all raw metadata information of items to be recommended or searched. Corresponds to the JSON property document



31572
31573
31574
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31572

def document
  @document
end

#idString

Document.id of the searched Document. Corresponds to the JSON property id

Returns:

  • (String)


31577
31578
31579
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31577

def id
  @id
end

#model_scoresHash<String,Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaDoubleList>

Output only. Google provided available scores. Corresponds to the JSON property modelScores



31582
31583
31584
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31582

def model_scores
  @model_scores
end

#rank_signalsGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSearchResultRankSignals

A set of ranking signals. Corresponds to the JSON property rankSignals



31587
31588
31589
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31587

def rank_signals
  @rank_signals
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31594
31595
31596
31597
31598
31599
31600
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31594

def update!(**args)
  @chunk = args[:chunk] if args.key?(:chunk)
  @document = args[:document] if args.key?(:document)
  @id = args[:id] if args.key?(:id)
  @model_scores = args[:model_scores] if args.key?(:model_scores)
  @rank_signals = args[:rank_signals] if args.key?(:rank_signals)
end