Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSessionInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Information about the session.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchResponseSessionInfo

Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchResponseSessionInfo.



31721
31722
31723
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31721

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Name of the session. If the auto-session mode is used (when SearchRequest. session ends with "-"), this field holds the newly generated session name. Corresponds to the JSON property name

Returns:

  • (String)


31711
31712
31713
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31711

def name
  @name
end

#query_idString

Query ID that corresponds to this search API call. One session can have multiple turns, each with a unique query ID. By specifying the session name and this query ID in the Answer API call, the answer generation happens in the context of the search results from this search call. Corresponds to the JSON property queryId

Returns:

  • (String)


31719
31720
31721
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31719

def query_id
  @query_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31726
31727
31728
31729
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31726

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @query_id = args[:query_id] if args.key?(:query_id)
end