Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Summary of the top N search results specified by the summary spec.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchResponseSummary

Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchResponseSummary.



31757
31758
31759
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31757

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#safety_attributesGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSummarySafetyAttributes

Safety Attribute categories and their associated confidence scores. Corresponds to the JSON property safetyAttributes



31739
31740
31741
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31739

def safety_attributes
  @safety_attributes
end

#summary_skipped_reasonsArray<String>

Additional summary-skipped reasons. This provides the reason for ignored cases. If nothing is skipped, this field is not set. Corresponds to the JSON property summarySkippedReasons

Returns:

  • (Array<String>)


31745
31746
31747
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31745

def summary_skipped_reasons
  @summary_skipped_reasons
end

#summary_textString

The summary content. Corresponds to the JSON property summaryText

Returns:

  • (String)


31750
31751
31752
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31750

def summary_text
  @summary_text
end

#summary_with_metadataGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSummarySummaryWithMetadata

Summary with metadata information. Corresponds to the JSON property summaryWithMetadata



31755
31756
31757
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31755

def 
  @summary_with_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31762
31763
31764
31765
31766
31767
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31762

def update!(**args)
  @safety_attributes = args[:safety_attributes] if args.key?(:safety_attributes)
  @summary_skipped_reasons = args[:summary_skipped_reasons] if args.key?(:summary_skipped_reasons)
  @summary_text = args[:summary_text] if args.key?(:summary_text)
  @summary_with_metadata = args[:summary_with_metadata] if args.key?(:summary_with_metadata)
end