Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSummaryReference

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Document reference.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchResponseSummaryReference

Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchResponseSummaryReference.



32934
32935
32936
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32934

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chunk_contentsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSummaryReferenceChunkContent>

List of cited chunk contents derived from document content. Corresponds to the JSON property chunkContents



32915
32916
32917
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32915

def chunk_contents
  @chunk_contents
end

#documentString

Required. Document.name of the document. Full resource name of the referenced document, in the format projects/*/locations/*/collections/*/dataStores/*/ branches/*/documents/*. Corresponds to the JSON property document

Returns:

  • (String)


32922
32923
32924
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32922

def document
  @document
end

#titleString

Title of the document. Corresponds to the JSON property title

Returns:

  • (String)


32927
32928
32929
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32927

def title
  @title
end

#uriString

Cloud Storage or HTTP uri for the document. Corresponds to the JSON property uri

Returns:

  • (String)


32932
32933
32934
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32932

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32939
32940
32941
32942
32943
32944
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32939

def update!(**args)
  @chunk_contents = args[:chunk_contents] if args.key?(:chunk_contents)
  @document = args[:document] if args.key?(:document)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end