Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSummaryReference
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSummaryReference
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Document reference.
Instance Attribute Summary collapse
-
#chunk_contents ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSummaryReferenceChunkContent>
List of cited chunk contents derived from document content.
-
#document ⇒ String
Required.
-
#title ⇒ String
Title of the document.
-
#uri ⇒ String
Cloud Storage or HTTP uri for the document.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchResponseSummaryReference
constructor
A new instance of GoogleCloudDiscoveryengineV1betaSearchResponseSummaryReference.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchResponseSummaryReference
Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchResponseSummaryReference.
32223 32224 32225 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32223 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chunk_contents ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSummaryReferenceChunkContent>
List of cited chunk contents derived from document content.
Corresponds to the JSON property chunkContents
32204 32205 32206 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32204 def chunk_contents @chunk_contents end |
#document ⇒ String
Required. Document.name of the document. Full resource name of the referenced
document, in the format projects/*/locations/*/collections/*/dataStores/*/
branches/*/documents/*.
Corresponds to the JSON property document
32211 32212 32213 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32211 def document @document end |
#title ⇒ String
Title of the document.
Corresponds to the JSON property title
32216 32217 32218 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32216 def title @title end |
#uri ⇒ String
Cloud Storage or HTTP uri for the document.
Corresponds to the JSON property uri
32221 32222 32223 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32221 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32228 32229 32230 32231 32232 32233 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32228 def update!(**args) @chunk_contents = args[:chunk_contents] if args.key?(:chunk_contents) @document = args[:document] if args.key?(:document) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) end |