Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSummaryReference
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSummaryReference
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Document reference.
Instance Attribute Summary collapse
-
#chunk_contents ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSummaryReferenceChunkContent>
List of cited chunk contents derived from document content.
-
#document ⇒ String
Required.
-
#title ⇒ String
Title of the document.
-
#uri ⇒ String
Cloud Storage or HTTP uri for the document.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchResponseSummaryReference
constructor
A new instance of GoogleCloudDiscoveryengineV1betaSearchResponseSummaryReference.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchResponseSummaryReference
Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchResponseSummaryReference.
31917 31918 31919 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31917 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chunk_contents ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSummaryReferenceChunkContent>
List of cited chunk contents derived from document content.
Corresponds to the JSON property chunkContents
31898 31899 31900 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31898 def chunk_contents @chunk_contents end |
#document ⇒ String
Required. Document.name of the document. Full resource name of the referenced
document, in the format projects/*/locations/*/collections/*/dataStores/*/
branches/*/documents/*.
Corresponds to the JSON property document
31905 31906 31907 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31905 def document @document end |
#title ⇒ String
Title of the document.
Corresponds to the JSON property title
31910 31911 31912 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31910 def title @title end |
#uri ⇒ String
Cloud Storage or HTTP uri for the document.
Corresponds to the JSON property uri
31915 31916 31917 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31915 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31922 31923 31924 31925 31926 31927 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 31922 def update!(**args) @chunk_contents = args[:chunk_contents] if args.key?(:chunk_contents) @document = args[:document] if args.key?(:document) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) end |