Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSummarySafetyAttributes
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSummarySafetyAttributes
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Safety Attribute categories and their associated confidence scores.
Instance Attribute Summary collapse
-
#categories ⇒ Array<String>
The display names of Safety Attribute categories associated with the generated content.
-
#scores ⇒ Array<Float>
The confidence scores of the each category, higher value means higher confidence.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchResponseSummarySafetyAttributes
constructor
A new instance of GoogleCloudDiscoveryengineV1betaSearchResponseSummarySafetyAttributes.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchResponseSummarySafetyAttributes
Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchResponseSummarySafetyAttributes.
32970 32971 32972 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32970 def initialize(**args) update!(**args) end |
Instance Attribute Details
#categories ⇒ Array<String>
The display names of Safety Attribute categories associated with the generated
content. Order matches the Scores.
Corresponds to the JSON property categories
32962 32963 32964 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32962 def categories @categories end |
#scores ⇒ Array<Float>
The confidence scores of the each category, higher value means higher
confidence. Order matches the Categories.
Corresponds to the JSON property scores
32968 32969 32970 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32968 def scores @scores end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32975 32976 32977 32978 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32975 def update!(**args) @categories = args[:categories] if args.key?(:categories) @scores = args[:scores] if args.key?(:scores) end |