Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSearchResponseSummarySafetyAttributes

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Safety Attribute categories and their associated confidence scores.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSearchResponseSummarySafetyAttributes

Returns a new instance of GoogleCloudDiscoveryengineV1betaSearchResponseSummarySafetyAttributes.



32929
32930
32931
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32929

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#categoriesArray<String>

The display names of Safety Attribute categories associated with the generated content. Order matches the Scores. Corresponds to the JSON property categories

Returns:

  • (Array<String>)


32921
32922
32923
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32921

def categories
  @categories
end

#scoresArray<Float>

The confidence scores of the each category, higher value means higher confidence. Order matches the Categories. Corresponds to the JSON property scores

Returns:

  • (Array<Float>)


32927
32928
32929
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32927

def scores
  @scores
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32934
32935
32936
32937
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32934

def update!(**args)
  @categories = args[:categories] if args.key?(:categories)
  @scores = args[:scores] if args.key?(:scores)
end