Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaServingConfigMediaConfig
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaServingConfigMediaConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Specifies the configurations needed for Media Discovery. Currently we support:
demote_content_watched: Threshold for watched content demotion. Customers can specify if using watched content demotion or use viewed detail page. Using the content watched demotion, customers need to specify the watched minutes or percentage exceeds the threshold, the content will be demoted in the recommendation result. *promote_fresh_content: cutoff days for fresh content promotion. Customers can specify if using content freshness promotion. If the content was published within the cutoff days, the content will be promoted in the recommendation result. Can only be set if SolutionType is SOLUTION_TYPE_RECOMMENDATION.
Instance Attribute Summary collapse
-
#content_freshness_cutoff_days ⇒ Fixnum
Specifies the content freshness used for recommendation result.
-
#content_watched_percentage_threshold ⇒ Float
Specifies the content watched percentage threshold for demotion.
-
#content_watched_seconds_threshold ⇒ Float
Specifies the content watched minutes threshold for demotion.
-
#demote_content_watched_past_days ⇒ Fixnum
Optional.
-
#demotion_event_type ⇒ String
Specifies the event type used for demoting recommendation result.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaServingConfigMediaConfig
constructor
A new instance of GoogleCloudDiscoveryengineV1betaServingConfigMediaConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaServingConfigMediaConfig
Returns a new instance of GoogleCloudDiscoveryengineV1betaServingConfigMediaConfig.
33441 33442 33443 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33441 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content_freshness_cutoff_days ⇒ Fixnum
Specifies the content freshness used for recommendation result. Contents will
be demoted if contents were published for more than content freshness cutoff
days.
Corresponds to the JSON property contentFreshnessCutoffDays
33413 33414 33415 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33413 def content_freshness_cutoff_days @content_freshness_cutoff_days end |
#content_watched_percentage_threshold ⇒ Float
Specifies the content watched percentage threshold for demotion. Threshold
value must be between [0, 1.0] inclusive.
Corresponds to the JSON property contentWatchedPercentageThreshold
33419 33420 33421 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33419 def content_watched_percentage_threshold @content_watched_percentage_threshold end |
#content_watched_seconds_threshold ⇒ Float
Specifies the content watched minutes threshold for demotion.
Corresponds to the JSON property contentWatchedSecondsThreshold
33424 33425 33426 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33424 def content_watched_seconds_threshold @content_watched_seconds_threshold end |
#demote_content_watched_past_days ⇒ Fixnum
Optional. Specifies the number of days to look back for demoting watched
content. If set to zero or unset, defaults to the maximum of 365 days.
Corresponds to the JSON property demoteContentWatchedPastDays
33430 33431 33432 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33430 def demote_content_watched_past_days @demote_content_watched_past_days end |
#demotion_event_type ⇒ String
Specifies the event type used for demoting recommendation result. Currently
supported values: * view-item: Item viewed. * media-play: Start/resume
watching a video, playing a song, etc. * media-complete: Finished or stopped
midway through a video, song, etc. If unset, watch history demotion will not
be applied. Content freshness demotion will still be applied.
Corresponds to the JSON property demotionEventType
33439 33440 33441 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33439 def demotion_event_type @demotion_event_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33446 33447 33448 33449 33450 33451 33452 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33446 def update!(**args) @content_freshness_cutoff_days = args[:content_freshness_cutoff_days] if args.key?(:content_freshness_cutoff_days) @content_watched_percentage_threshold = args[:content_watched_percentage_threshold] if args.key?(:content_watched_percentage_threshold) @content_watched_seconds_threshold = args[:content_watched_seconds_threshold] if args.key?(:content_watched_seconds_threshold) @demote_content_watched_past_days = args[:demote_content_watched_past_days] if args.key?(:demote_content_watched_past_days) @demotion_event_type = args[:demotion_event_type] if args.key?(:demotion_event_type) end |