Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSession
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSession
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
External session proto definition.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Optional.
-
#end_time ⇒ String
Output only.
-
#is_pinned ⇒ Boolean
(also: #is_pinned?)
Optional.
-
#labels ⇒ Array<String>
Optional.
-
#name ⇒ String
Immutable.
-
#pending_async_assist_operation_id ⇒ String
Output only.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
The state of the session.
-
#turns ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSessionTurn>
Turns.
-
#user_pseudo_id ⇒ String
A unique identifier for tracking users.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSession
constructor
A new instance of GoogleCloudDiscoveryengineV1betaSession.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSession
Returns a new instance of GoogleCloudDiscoveryengineV1betaSession.
33517 33518 33519 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33517 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Optional. The display name of the session. This field is used to identify the
session in the UI. By default, the display name is the first turn query text
in the session.
Corresponds to the JSON property displayName
33464 33465 33466 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33464 def display_name @display_name end |
#end_time ⇒ String
Output only. The time the session finished.
Corresponds to the JSON property endTime
33469 33470 33471 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33469 def end_time @end_time end |
#is_pinned ⇒ Boolean Also known as: is_pinned?
Optional. Whether the session is pinned, pinned session will be displayed on
the top of the session list.
Corresponds to the JSON property isPinned
33475 33476 33477 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33475 def is_pinned @is_pinned end |
#labels ⇒ Array<String>
Optional. The labels for the session. Can be set as filter in
ListSessionsRequest.
Corresponds to the JSON property labels
33482 33483 33484 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33482 def labels @labels end |
#name ⇒ String
Immutable. Fully qualified name projects/project/locations/global/
collections/collection/engines/engine/sessions/*
Corresponds to the JSON property name
33488 33489 33490 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33488 def name @name end |
#pending_async_assist_operation_id ⇒ String
Output only. Full resource name of an in-progress AsyncAssist operation for
this session, e.g. projects/*/locations/*/collections/*/engines/*/sessions/*/
operations/*. Set when the operation starts and cleared when it finishes.
Corresponds to the JSON property pendingAsyncAssistOperationId
33495 33496 33497 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33495 def pending_async_assist_operation_id @pending_async_assist_operation_id end |
#start_time ⇒ String
Output only. The time the session started.
Corresponds to the JSON property startTime
33500 33501 33502 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33500 def start_time @start_time end |
#state ⇒ String
The state of the session.
Corresponds to the JSON property state
33505 33506 33507 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33505 def state @state end |
#turns ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSessionTurn>
Turns.
Corresponds to the JSON property turns
33510 33511 33512 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33510 def turns @turns end |
#user_pseudo_id ⇒ String
A unique identifier for tracking users.
Corresponds to the JSON property userPseudoId
33515 33516 33517 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33515 def user_pseudo_id @user_pseudo_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33522 33523 33524 33525 33526 33527 33528 33529 33530 33531 33532 33533 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33522 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @end_time = args[:end_time] if args.key?(:end_time) @is_pinned = args[:is_pinned] if args.key?(:is_pinned) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @pending_async_assist_operation_id = args[:pending_async_assist_operation_id] if args.key?(:pending_async_assist_operation_id) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @turns = args[:turns] if args.key?(:turns) @user_pseudo_id = args[:user_pseudo_id] if args.key?(:user_pseudo_id) end |