Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSession

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

External session proto definition.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSession

Returns a new instance of GoogleCloudDiscoveryengineV1betaSession.



33386
33387
33388
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33386

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Optional. The display name of the session. This field is used to identify the session in the UI. By default, the display name is the first turn query text in the session. Corresponds to the JSON property displayName

Returns:

  • (String)


33333
33334
33335
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33333

def display_name
  @display_name
end

#end_timeString

Output only. The time the session finished. Corresponds to the JSON property endTime

Returns:

  • (String)


33338
33339
33340
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33338

def end_time
  @end_time
end

#is_pinnedBoolean Also known as: is_pinned?

Optional. Whether the session is pinned, pinned session will be displayed on the top of the session list. Corresponds to the JSON property isPinned

Returns:

  • (Boolean)


33344
33345
33346
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33344

def is_pinned
  @is_pinned
end

#labelsArray<String>

Optional. The labels for the session. Can be set as filter in ListSessionsRequest. Corresponds to the JSON property labels

Returns:

  • (Array<String>)


33351
33352
33353
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33351

def labels
  @labels
end

#nameString

Immutable. Fully qualified name projects/project/locations/global/ collections/collection/engines/engine/sessions/* Corresponds to the JSON property name

Returns:

  • (String)


33357
33358
33359
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33357

def name
  @name
end

#pending_async_assist_operation_idString

Output only. Full resource name of an in-progress AsyncAssist operation for this session, e.g. projects/*/locations/*/collections/*/engines/*/sessions/*/ operations/*. Set when the operation starts and cleared when it finishes. Corresponds to the JSON property pendingAsyncAssistOperationId

Returns:

  • (String)


33364
33365
33366
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33364

def pending_async_assist_operation_id
  @pending_async_assist_operation_id
end

#start_timeString

Output only. The time the session started. Corresponds to the JSON property startTime

Returns:

  • (String)


33369
33370
33371
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33369

def start_time
  @start_time
end

#stateString

The state of the session. Corresponds to the JSON property state

Returns:

  • (String)


33374
33375
33376
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33374

def state
  @state
end

#turnsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSessionTurn>

Turns. Corresponds to the JSON property turns



33379
33380
33381
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33379

def turns
  @turns
end

#user_pseudo_idString

A unique identifier for tracking users. Corresponds to the JSON property userPseudoId

Returns:

  • (String)


33384
33385
33386
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33384

def user_pseudo_id
  @user_pseudo_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33391
33392
33393
33394
33395
33396
33397
33398
33399
33400
33401
33402
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33391

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @end_time = args[:end_time] if args.key?(:end_time)
  @is_pinned = args[:is_pinned] if args.key?(:is_pinned)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @pending_async_assist_operation_id = args[:pending_async_assist_operation_id] if args.key?(:pending_async_assist_operation_id)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @turns = args[:turns] if args.key?(:turns)
  @user_pseudo_id = args[:user_pseudo_id] if args.key?(:user_pseudo_id)
end