Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSession
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSession
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
External session proto definition.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Optional.
-
#end_time ⇒ String
Output only.
-
#is_pinned ⇒ Boolean
(also: #is_pinned?)
Optional.
-
#labels ⇒ Array<String>
Optional.
-
#name ⇒ String
Immutable.
-
#pending_async_assist_operation_id ⇒ String
Output only.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
The state of the session.
-
#turns ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSessionTurn>
Turns.
-
#user_pseudo_id ⇒ String
A unique identifier for tracking users.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSession
constructor
A new instance of GoogleCloudDiscoveryengineV1betaSession.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSession
Returns a new instance of GoogleCloudDiscoveryengineV1betaSession.
33362 33363 33364 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33362 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Optional. The display name of the session. This field is used to identify the
session in the UI. By default, the display name is the first turn query text
in the session.
Corresponds to the JSON property displayName
33309 33310 33311 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33309 def display_name @display_name end |
#end_time ⇒ String
Output only. The time the session finished.
Corresponds to the JSON property endTime
33314 33315 33316 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33314 def end_time @end_time end |
#is_pinned ⇒ Boolean Also known as: is_pinned?
Optional. Whether the session is pinned, pinned session will be displayed on
the top of the session list.
Corresponds to the JSON property isPinned
33320 33321 33322 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33320 def is_pinned @is_pinned end |
#labels ⇒ Array<String>
Optional. The labels for the session. Can be set as filter in
ListSessionsRequest.
Corresponds to the JSON property labels
33327 33328 33329 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33327 def labels @labels end |
#name ⇒ String
Immutable. Fully qualified name projects/project/locations/global/
collections/collection/engines/engine/sessions/*
Corresponds to the JSON property name
33333 33334 33335 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33333 def name @name end |
#pending_async_assist_operation_id ⇒ String
Output only. Full resource name of an in-progress AsyncAssist operation for
this session, e.g. projects/*/locations/*/collections/*/engines/*/sessions/*/
operations/*. Set when the operation starts and cleared when it finishes.
Corresponds to the JSON property pendingAsyncAssistOperationId
33340 33341 33342 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33340 def pending_async_assist_operation_id @pending_async_assist_operation_id end |
#start_time ⇒ String
Output only. The time the session started.
Corresponds to the JSON property startTime
33345 33346 33347 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33345 def start_time @start_time end |
#state ⇒ String
The state of the session.
Corresponds to the JSON property state
33350 33351 33352 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33350 def state @state end |
#turns ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSessionTurn>
Turns.
Corresponds to the JSON property turns
33355 33356 33357 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33355 def turns @turns end |
#user_pseudo_id ⇒ String
A unique identifier for tracking users.
Corresponds to the JSON property userPseudoId
33360 33361 33362 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33360 def user_pseudo_id @user_pseudo_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33367 33368 33369 33370 33371 33372 33373 33374 33375 33376 33377 33378 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33367 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @end_time = args[:end_time] if args.key?(:end_time) @is_pinned = args[:is_pinned] if args.key?(:is_pinned) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @pending_async_assist_operation_id = args[:pending_async_assist_operation_id] if args.key?(:pending_async_assist_operation_id) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @turns = args[:turns] if args.key?(:turns) @user_pseudo_id = args[:user_pseudo_id] if args.key?(:user_pseudo_id) end |