Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSession
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSession
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
External session proto definition.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Optional.
-
#end_time ⇒ String
Output only.
-
#is_pinned ⇒ Boolean
(also: #is_pinned?)
Optional.
-
#labels ⇒ Array<String>
Optional.
-
#name ⇒ String
Immutable.
-
#pending_async_assist_operation_id ⇒ String
Output only.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
The state of the session.
-
#turns ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSessionTurn>
Turns.
-
#user_pseudo_id ⇒ String
A unique identifier for tracking users.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSession
constructor
A new instance of GoogleCloudDiscoveryengineV1betaSession.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSession
Returns a new instance of GoogleCloudDiscoveryengineV1betaSession.
32675 32676 32677 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32675 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Optional. The display name of the session. This field is used to identify the
session in the UI. By default, the display name is the first turn query text
in the session.
Corresponds to the JSON property displayName
32622 32623 32624 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32622 def display_name @display_name end |
#end_time ⇒ String
Output only. The time the session finished.
Corresponds to the JSON property endTime
32627 32628 32629 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32627 def end_time @end_time end |
#is_pinned ⇒ Boolean Also known as: is_pinned?
Optional. Whether the session is pinned, pinned session will be displayed on
the top of the session list.
Corresponds to the JSON property isPinned
32633 32634 32635 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32633 def is_pinned @is_pinned end |
#labels ⇒ Array<String>
Optional. The labels for the session. Can be set as filter in
ListSessionsRequest.
Corresponds to the JSON property labels
32640 32641 32642 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32640 def labels @labels end |
#name ⇒ String
Immutable. Fully qualified name projects/project/locations/global/
collections/collection/engines/engine/sessions/*
Corresponds to the JSON property name
32646 32647 32648 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32646 def name @name end |
#pending_async_assist_operation_id ⇒ String
Output only. Full resource name of an in-progress AsyncAssist operation for
this session, e.g. projects/*/locations/*/collections/*/engines/*/sessions/*/
operations/*. Set when the operation starts and cleared when it finishes.
Corresponds to the JSON property pendingAsyncAssistOperationId
32653 32654 32655 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32653 def pending_async_assist_operation_id @pending_async_assist_operation_id end |
#start_time ⇒ String
Output only. The time the session started.
Corresponds to the JSON property startTime
32658 32659 32660 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32658 def start_time @start_time end |
#state ⇒ String
The state of the session.
Corresponds to the JSON property state
32663 32664 32665 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32663 def state @state end |
#turns ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSessionTurn>
Turns.
Corresponds to the JSON property turns
32668 32669 32670 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32668 def turns @turns end |
#user_pseudo_id ⇒ String
A unique identifier for tracking users.
Corresponds to the JSON property userPseudoId
32673 32674 32675 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32673 def user_pseudo_id @user_pseudo_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32680 32681 32682 32683 32684 32685 32686 32687 32688 32689 32690 32691 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32680 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @end_time = args[:end_time] if args.key?(:end_time) @is_pinned = args[:is_pinned] if args.key?(:is_pinned) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @pending_async_assist_operation_id = args[:pending_async_assist_operation_id] if args.key?(:pending_async_assist_operation_id) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @turns = args[:turns] if args.key?(:turns) @user_pseudo_id = args[:user_pseudo_id] if args.key?(:user_pseudo_id) end |