Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSetDedicatedCrawlRateRequest
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSetDedicatedCrawlRateRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Request message for CrawlRateManagementService.SetDedicatedCrawlRate method. The user can set the crawl rate for a crawl_rate_scope they own. They can set up an overall crawl rate, or set up a user-triggered crawl rate and a auto- refresh crawl rate separately. If an overall crawl rate is set, Vertex AI will automatically splits crawl_rate into user-triggered and auto-refresh.
Instance Attribute Summary collapse
-
#crawl_rate ⇒ Fixnum
Optional.
-
#crawl_rate_scope ⇒ String
Required.
-
#crawl_type ⇒ String
Optional.
-
#mode ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSetDedicatedCrawlRateRequest
constructor
A new instance of GoogleCloudDiscoveryengineV1betaSetDedicatedCrawlRateRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSetDedicatedCrawlRateRequest
Returns a new instance of GoogleCloudDiscoveryengineV1betaSetDedicatedCrawlRateRequest.
33651 33652 33653 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33651 def initialize(**args) update!(**args) end |
Instance Attribute Details
#crawl_rate ⇒ Fixnum
Optional. The crawl QPS set by the user. It is not guaranteed that Vertex
crawl bot will crawl at this QPS. If the crawl rate is too high, the real QPS
may be lower than the value set by the user to avoid overloading the user's
website.
Corresponds to the JSON property crawlRate
33631 33632 33633 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33631 def crawl_rate @crawl_rate end |
#crawl_rate_scope ⇒ String
Required. The scope of the crawl rate that the user wants to config. Currently,
only domain and host name are supported. A domain name example: example.com.
A host name example: www.example.com. Please do not include / in the
domain or host name.
Corresponds to the JSON property crawlRateScope
33639 33640 33641 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33639 def crawl_rate_scope @crawl_rate_scope end |
#crawl_type ⇒ String
Optional. Whether it's the crawl rate of user-triggered or auto-refresh.
Corresponds to the JSON property crawlType
33644 33645 33646 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33644 def crawl_type @crawl_type end |
#mode ⇒ String
Optional. Whether the rate is explicitly set by users, or set by vertex AI.
Corresponds to the JSON property mode
33649 33650 33651 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33649 def mode @mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33656 33657 33658 33659 33660 33661 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33656 def update!(**args) @crawl_rate = args[:crawl_rate] if args.key?(:crawl_rate) @crawl_rate_scope = args[:crawl_rate_scope] if args.key?(:crawl_rate_scope) @crawl_type = args[:crawl_type] if args.key?(:crawl_type) @mode = args[:mode] if args.key?(:mode) end |