Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSetDedicatedCrawlRateRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Request message for CrawlRateManagementService.SetDedicatedCrawlRate method. The user can set the crawl rate for a crawl_rate_scope they own. They can set up an overall crawl rate, or set up a user-triggered crawl rate and a auto- refresh crawl rate separately. If an overall crawl rate is set, Vertex AI will automatically splits crawl_rate into user-triggered and auto-refresh.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSetDedicatedCrawlRateRequest

Returns a new instance of GoogleCloudDiscoveryengineV1betaSetDedicatedCrawlRateRequest.



33632
33633
33634
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33632

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#crawl_rateFixnum

Optional. The crawl QPS set by the user. It is not guaranteed that Vertex crawl bot will crawl at this QPS. If the crawl rate is too high, the real QPS may be lower than the value set by the user to avoid overloading the user's website. Corresponds to the JSON property crawlRate

Returns:

  • (Fixnum)


33612
33613
33614
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33612

def crawl_rate
  @crawl_rate
end

#crawl_rate_scopeString

Required. The scope of the crawl rate that the user wants to config. Currently, only domain and host name are supported. A domain name example: example.com. A host name example: www.example.com. Please do not include / in the domain or host name. Corresponds to the JSON property crawlRateScope

Returns:

  • (String)


33620
33621
33622
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33620

def crawl_rate_scope
  @crawl_rate_scope
end

#crawl_typeString

Optional. Whether it's the crawl rate of user-triggered or auto-refresh. Corresponds to the JSON property crawlType

Returns:

  • (String)


33625
33626
33627
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33625

def crawl_type
  @crawl_type
end

#modeString

Optional. Whether the rate is explicitly set by users, or set by vertex AI. Corresponds to the JSON property mode

Returns:

  • (String)


33630
33631
33632
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33630

def mode
  @mode
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33637
33638
33639
33640
33641
33642
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33637

def update!(**args)
  @crawl_rate = args[:crawl_rate] if args.key?(:crawl_rate)
  @crawl_rate_scope = args[:crawl_rate_scope] if args.key?(:crawl_rate_scope)
  @crawl_type = args[:crawl_type] if args.key?(:crawl_type)
  @mode = args[:mode] if args.key?(:mode)
end