Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSetDedicatedCrawlRateResponse
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSetDedicatedCrawlRateResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Response message for CrawlRateManagementService.SetDedicatedCrawlRate method. It simply returns the state of the response, and an error message if the state is FAILED.
Instance Attribute Summary collapse
-
#error ⇒ Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSetDedicatedCrawlRateResponse
constructor
A new instance of GoogleCloudDiscoveryengineV1betaSetDedicatedCrawlRateResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaSetDedicatedCrawlRateResponse
Returns a new instance of GoogleCloudDiscoveryengineV1betaSetDedicatedCrawlRateResponse.
33489 33490 33491 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33489 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error ⇒ Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
33482 33483 33484 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33482 def error @error end |
#state ⇒ String
Output only. The state of the response.
Corresponds to the JSON property state
33487 33488 33489 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33487 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33494 33495 33496 33497 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33494 def update!(**args) @error = args[:error] if args.key?(:error) @state = args[:state] if args.key?(:state) end |