Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaStreamAssistRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Request for the AssistantService.StreamAssist method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaStreamAssistRequest

Returns a new instance of GoogleCloudDiscoveryengineV1betaStreamAssistRequest.



33747
33748
33749
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33747

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#generation_specGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaStreamAssistRequestGenerationSpec

Assistant generation specification for the request. This allows to override the default generation configuration at the engine level. Corresponds to the JSON property generationSpec



33720
33721
33722
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33720

def generation_spec
  @generation_spec
end

#queryGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaQuery

Defines a user inputed query. Corresponds to the JSON property query



33725
33726
33727
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33725

def query
  @query
end

#sessionString

Optional. The session to use for the request. If specified, the assistant has access to the session history, and the query and the answer are stored there. If - is specified as the session ID, or it is left empty, then a new session is created with an automatically generated ID. Format: projects/project/ locations/location/collections/collection/engines/engine/sessions/ session` Corresponds to the JSON propertysession`

Returns:

  • (String)


33735
33736
33737
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33735

def session
  @session
end

#tools_specGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaStreamAssistRequestToolsSpec

Specification of tools that are used to serve the request. Corresponds to the JSON property toolsSpec



33740
33741
33742
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33740

def tools_spec
  @tools_spec
end

#user_metadataGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistUserMetadata

User metadata of the request. Corresponds to the JSON property userMetadata



33745
33746
33747
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33745

def 
  @user_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33752
33753
33754
33755
33756
33757
33758
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33752

def update!(**args)
  @generation_spec = args[:generation_spec] if args.key?(:generation_spec)
  @query = args[:query] if args.key?(:query)
  @session = args[:session] if args.key?(:session)
  @tools_spec = args[:tools_spec] if args.key?(:tools_spec)
  @user_metadata = args[:user_metadata] if args.key?(:user_metadata)
end