Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaStreamAssistRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Request for the AssistantService.StreamAssist method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaStreamAssistRequest

Returns a new instance of GoogleCloudDiscoveryengineV1betaStreamAssistRequest.



32730
32731
32732
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32730

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#generation_specGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaStreamAssistRequestGenerationSpec

Assistant generation specification for the request. This allows to override the default generation configuration at the engine level. Corresponds to the JSON property generationSpec



32703
32704
32705
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32703

def generation_spec
  @generation_spec
end

#queryGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaQuery

Defines a user inputed query. Corresponds to the JSON property query



32708
32709
32710
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32708

def query
  @query
end

#sessionString

Optional. The session to use for the request. If specified, the assistant has access to the session history, and the query and the answer are stored there. If - is specified as the session ID, or it is left empty, then a new session is created with an automatically generated ID. Format: projects/project/ locations/location/collections/collection/engines/engine/sessions/ session` Corresponds to the JSON propertysession`

Returns:

  • (String)


32718
32719
32720
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32718

def session
  @session
end

#tools_specGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaStreamAssistRequestToolsSpec

Specification of tools that are used to serve the request. Corresponds to the JSON property toolsSpec



32723
32724
32725
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32723

def tools_spec
  @tools_spec
end

#user_metadataGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistUserMetadata

User metadata of the request. Corresponds to the JSON property userMetadata



32728
32729
32730
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32728

def 
  @user_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32735
32736
32737
32738
32739
32740
32741
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 32735

def update!(**args)
  @generation_spec = args[:generation_spec] if args.key?(:generation_spec)
  @query = args[:query] if args.key?(:query)
  @session = args[:session] if args.key?(:session)
  @tools_spec = args[:tools_spec] if args.key?(:tools_spec)
  @user_metadata = args[:user_metadata] if args.key?(:user_metadata)
end