Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaStreamAssistResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Response for the AssistantService.StreamAssist method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaStreamAssistResponse

Returns a new instance of GoogleCloudDiscoveryengineV1betaStreamAssistResponse.



34044
34045
34046
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34044

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#answerGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistAnswer

AssistAnswer resource, main part of AssistResponse. Corresponds to the JSON property answer



34014
34015
34016
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34014

def answer
  @answer
end

#assist_tokenString

A global unique ID that identifies the current pair of request and stream of responses. Used for feedback and support. Corresponds to the JSON property assistToken

Returns:

  • (String)


34020
34021
34022
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34020

def assist_token
  @assist_token
end

#connector_auth_errorsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaStreamAssistResponseConnectorAuthError>

Per-connector authentication errors encountered during the request. Present when one or more connectors failed authentication but the request proceeded with the remaining connectors. Corresponds to the JSON property connectorAuthErrors



34027
34028
34029
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34027

def connector_auth_errors
  @connector_auth_errors
end

#invocation_toolsArray<String>

The tool names of the tools that were invoked. Corresponds to the JSON property invocationTools

Returns:

  • (Array<String>)


34032
34033
34034
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34032

def invocation_tools
  @invocation_tools
end

#invoked_skillsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaStreamAssistResponseInvokedSkill>

The skills executed during the turn. Corresponds to the JSON property invokedSkills



34037
34038
34039
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34037

def invoked_skills
  @invoked_skills
end

#session_infoGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaStreamAssistResponseSessionInfo

Information about the session. Corresponds to the JSON property sessionInfo



34042
34043
34044
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34042

def session_info
  @session_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34049
34050
34051
34052
34053
34054
34055
34056
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34049

def update!(**args)
  @answer = args[:answer] if args.key?(:answer)
  @assist_token = args[:assist_token] if args.key?(:assist_token)
  @connector_auth_errors = args[:connector_auth_errors] if args.key?(:connector_auth_errors)
  @invocation_tools = args[:invocation_tools] if args.key?(:invocation_tools)
  @invoked_skills = args[:invoked_skills] if args.key?(:invoked_skills)
  @session_info = args[:session_info] if args.key?(:session_info)
end