Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaStreamAssistResponse
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaStreamAssistResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Response for the AssistantService.StreamAssist method.
Instance Attribute Summary collapse
-
#answer ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistAnswer
AssistAnswer resource, main part of AssistResponse.
-
#assist_token ⇒ String
A global unique ID that identifies the current pair of request and stream of responses.
-
#connector_auth_errors ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaStreamAssistResponseConnectorAuthError>
Per-connector authentication errors encountered during the request.
-
#invocation_tools ⇒ Array<String>
The tool names of the tools that were invoked.
-
#invoked_skills ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaStreamAssistResponseInvokedSkill>
The skills executed during the turn.
-
#session_info ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaStreamAssistResponseSessionInfo
Information about the session.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaStreamAssistResponse
constructor
A new instance of GoogleCloudDiscoveryengineV1betaStreamAssistResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaStreamAssistResponse
Returns a new instance of GoogleCloudDiscoveryengineV1betaStreamAssistResponse.
33908 33909 33910 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33908 def initialize(**args) update!(**args) end |
Instance Attribute Details
#answer ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistAnswer
AssistAnswer resource, main part of AssistResponse.
Corresponds to the JSON property answer
33878 33879 33880 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33878 def answer @answer end |
#assist_token ⇒ String
A global unique ID that identifies the current pair of request and stream of
responses. Used for feedback and support.
Corresponds to the JSON property assistToken
33884 33885 33886 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33884 def assist_token @assist_token end |
#connector_auth_errors ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaStreamAssistResponseConnectorAuthError>
Per-connector authentication errors encountered during the request. Present
when one or more connectors failed authentication but the request proceeded
with the remaining connectors.
Corresponds to the JSON property connectorAuthErrors
33891 33892 33893 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33891 def connector_auth_errors @connector_auth_errors end |
#invocation_tools ⇒ Array<String>
The tool names of the tools that were invoked.
Corresponds to the JSON property invocationTools
33896 33897 33898 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33896 def invocation_tools @invocation_tools end |
#invoked_skills ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaStreamAssistResponseInvokedSkill>
The skills executed during the turn.
Corresponds to the JSON property invokedSkills
33901 33902 33903 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33901 def invoked_skills @invoked_skills end |
#session_info ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaStreamAssistResponseSessionInfo
Information about the session.
Corresponds to the JSON property sessionInfo
33906 33907 33908 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33906 def session_info @session_info end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33913 33914 33915 33916 33917 33918 33919 33920 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33913 def update!(**args) @answer = args[:answer] if args.key?(:answer) @assist_token = args[:assist_token] if args.key?(:assist_token) @connector_auth_errors = args[:connector_auth_errors] if args.key?(:connector_auth_errors) @invocation_tools = args[:invocation_tools] if args.key?(:invocation_tools) @invoked_skills = args[:invoked_skills] if args.key?(:invoked_skills) @session_info = args[:session_info] if args.key?(:session_info) end |