Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaStreamAssistResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Response for the AssistantService.StreamAssist method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaStreamAssistResponse

Returns a new instance of GoogleCloudDiscoveryengineV1betaStreamAssistResponse.



33221
33222
33223
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33221

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#answerGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaAssistAnswer

AssistAnswer resource, main part of AssistResponse. Corresponds to the JSON property answer



33191
33192
33193
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33191

def answer
  @answer
end

#assist_tokenString

A global unique ID that identifies the current pair of request and stream of responses. Used for feedback and support. Corresponds to the JSON property assistToken

Returns:

  • (String)


33197
33198
33199
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33197

def assist_token
  @assist_token
end

#connector_auth_errorsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaStreamAssistResponseConnectorAuthError>

Per-connector authentication errors encountered during the request. Present when one or more connectors failed authentication but the request proceeded with the remaining connectors. Corresponds to the JSON property connectorAuthErrors



33204
33205
33206
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33204

def connector_auth_errors
  @connector_auth_errors
end

#invocation_toolsArray<String>

The tool names of the tools that were invoked. Corresponds to the JSON property invocationTools

Returns:

  • (Array<String>)


33209
33210
33211
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33209

def invocation_tools
  @invocation_tools
end

#invoked_skillsArray<Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaStreamAssistResponseInvokedSkill>

The skills executed during the turn. Corresponds to the JSON property invokedSkills



33214
33215
33216
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33214

def invoked_skills
  @invoked_skills
end

#session_infoGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaStreamAssistResponseSessionInfo

Information about the session. Corresponds to the JSON property sessionInfo



33219
33220
33221
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33219

def session_info
  @session_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33226
33227
33228
33229
33230
33231
33232
33233
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33226

def update!(**args)
  @answer = args[:answer] if args.key?(:answer)
  @assist_token = args[:assist_token] if args.key?(:assist_token)
  @connector_auth_errors = args[:connector_auth_errors] if args.key?(:connector_auth_errors)
  @invocation_tools = args[:invocation_tools] if args.key?(:invocation_tools)
  @invoked_skills = args[:invoked_skills] if args.key?(:invoked_skills)
  @session_info = args[:session_info] if args.key?(:session_info)
end