Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaStreamAssistResponseConnectorAuthError

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Describes an authentication error for a specific data connector.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaStreamAssistResponseConnectorAuthError

Returns a new instance of GoogleCloudDiscoveryengineV1betaStreamAssistResponseConnectorAuthError.



33250
33251
33252
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33250

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_connectorString

Resource name of the data connector that failed authentication. Corresponds to the JSON property dataConnector

Returns:

  • (String)


33243
33244
33245
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33243

def data_connector
  @data_connector
end

#error_messageString

Human-readable error message describing the auth failure. Corresponds to the JSON property errorMessage

Returns:

  • (String)


33248
33249
33250
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33248

def error_message
  @error_message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33255
33256
33257
33258
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33255

def update!(**args)
  @data_connector = args[:data_connector] if args.key?(:data_connector)
  @error_message = args[:error_message] if args.key?(:error_message)
end