Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaTargetSite

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

A target site for the SiteSearchEngine.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaTargetSite

Returns a new instance of GoogleCloudDiscoveryengineV1betaTargetSite.



34046
34047
34048
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34046

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#exact_matchBoolean Also known as: exact_match?

Immutable. If set to false, a uri_pattern is generated to include all pages whose address contains the provided_uri_pattern. If set to true, an uri_pattern is generated to try to be an exact match of the provided_uri_pattern or just the specific page if the provided_uri_pattern is a specific one. provided_uri_pattern is always normalized to generate the URI pattern to be used by the search engine. Corresponds to the JSON property exactMatch

Returns:

  • (Boolean)


33993
33994
33995
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33993

def exact_match
  @exact_match
end

#failure_reasonGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaTargetSiteFailureReason

Site search indexing failure reasons. Corresponds to the JSON property failureReason



33999
34000
34001
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33999

def failure_reason
  @failure_reason
end

#generated_uri_patternString

Output only. This is system-generated based on the provided_uri_pattern. Corresponds to the JSON property generatedUriPattern

Returns:

  • (String)


34004
34005
34006
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34004

def generated_uri_pattern
  @generated_uri_pattern
end

#indexing_statusString

Output only. Indexing status. Corresponds to the JSON property indexingStatus

Returns:

  • (String)


34009
34010
34011
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34009

def indexing_status
  @indexing_status
end

#nameString

Output only. The fully qualified resource name of the target site. projects/ project/locations/location/collections/collection/dataStores/data_store/ siteSearchEngine/targetSites/target_site`Thetarget_site_idis system- generated. Corresponds to the JSON propertyname`

Returns:

  • (String)


34017
34018
34019
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34017

def name
  @name
end

#provided_uri_patternString

Required. Input only. The user provided URI pattern from which the generated_uri_pattern is generated. Corresponds to the JSON property providedUriPattern

Returns:

  • (String)


34023
34024
34025
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34023

def provided_uri_pattern
  @provided_uri_pattern
end

#root_domain_uriString

Output only. Root domain of the provided_uri_pattern. Corresponds to the JSON property rootDomainUri

Returns:

  • (String)


34028
34029
34030
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34028

def root_domain_uri
  @root_domain_uri
end

#site_verification_infoGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaSiteVerificationInfo

Verification information for target sites in advanced site search. Corresponds to the JSON property siteVerificationInfo



34033
34034
34035
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34033

def site_verification_info
  @site_verification_info
end

#typeString

The type of the target site, e.g., whether the site is to be included or excluded. Corresponds to the JSON property type

Returns:

  • (String)


34039
34040
34041
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34039

def type
  @type
end

#update_timeString

Output only. The target site's last updated time. Corresponds to the JSON property updateTime

Returns:

  • (String)


34044
34045
34046
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34044

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34051
34052
34053
34054
34055
34056
34057
34058
34059
34060
34061
34062
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34051

def update!(**args)
  @exact_match = args[:exact_match] if args.key?(:exact_match)
  @failure_reason = args[:failure_reason] if args.key?(:failure_reason)
  @generated_uri_pattern = args[:generated_uri_pattern] if args.key?(:generated_uri_pattern)
  @indexing_status = args[:indexing_status] if args.key?(:indexing_status)
  @name = args[:name] if args.key?(:name)
  @provided_uri_pattern = args[:provided_uri_pattern] if args.key?(:provided_uri_pattern)
  @root_domain_uri = args[:root_domain_uri] if args.key?(:root_domain_uri)
  @site_verification_info = args[:site_verification_info] if args.key?(:site_verification_info)
  @type = args[:type] if args.key?(:type)
  @update_time = args[:update_time] if args.key?(:update_time)
end