Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaTransactionInfo
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaTransactionInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
A transaction represents the entire purchase transaction.
Instance Attribute Summary collapse
-
#cost ⇒ Float
All the costs associated with the products.
-
#currency ⇒ String
Required.
-
#discount_value ⇒ Float
The total discount(s) value applied to this transaction.
-
#tax ⇒ Float
All the taxes associated with the transaction.
-
#transaction_id ⇒ String
The transaction ID with a length limit of 128 characters.
-
#value ⇒ Float
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaTransactionInfo
constructor
A new instance of GoogleCloudDiscoveryengineV1betaTransactionInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaTransactionInfo
Returns a new instance of GoogleCloudDiscoveryengineV1betaTransactionInfo.
34532 34533 34534 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34532 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cost ⇒ Float
All the costs associated with the products. These can be manufacturing costs,
shipping expenses not borne by the end user, or any other costs, such that: *
Profit = value - tax - cost
Corresponds to the JSON property cost
34497 34498 34499 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34497 def cost @cost end |
#currency ⇒ String
Required. Currency code. Use three-character ISO-4217 code.
Corresponds to the JSON property currency
34502 34503 34504 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34502 def currency @currency end |
#discount_value ⇒ Float
The total discount(s) value applied to this transaction. This figure should be
excluded from TransactionInfo.value For example, if a user paid
TransactionInfo.value amount, then nominal (pre-discount) value of the
transaction is the sum of TransactionInfo.value and TransactionInfo.
discount_value This means that profit is calculated the same way, regardless
of the discount value, and that TransactionInfo.discount_value can be larger
than TransactionInfo.value: * Profit = value - tax - cost
Corresponds to the JSON property discountValue
34513 34514 34515 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34513 def discount_value @discount_value end |
#tax ⇒ Float
All the taxes associated with the transaction.
Corresponds to the JSON property tax
34518 34519 34520 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34518 def tax @tax end |
#transaction_id ⇒ String
The transaction ID with a length limit of 128 characters.
Corresponds to the JSON property transactionId
34523 34524 34525 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34523 def transaction_id @transaction_id end |
#value ⇒ Float
Required. Total non-zero value associated with the transaction. This value may
include shipping, tax, or other adjustments to the total value that you want
to include.
Corresponds to the JSON property value
34530 34531 34532 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34530 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34537 34538 34539 34540 34541 34542 34543 34544 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34537 def update!(**args) @cost = args[:cost] if args.key?(:cost) @currency = args[:currency] if args.key?(:currency) @discount_value = args[:discount_value] if args.key?(:discount_value) @tax = args[:tax] if args.key?(:tax) @transaction_id = args[:transaction_id] if args.key?(:transaction_id) @value = args[:value] if args.key?(:value) end |