Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaTransactionInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

A transaction represents the entire purchase transaction.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaTransactionInfo

Returns a new instance of GoogleCloudDiscoveryengineV1betaTransactionInfo.



34513
34514
34515
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34513

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#costFloat

All the costs associated with the products. These can be manufacturing costs, shipping expenses not borne by the end user, or any other costs, such that: * Profit = value - tax - cost Corresponds to the JSON property cost

Returns:

  • (Float)


34478
34479
34480
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34478

def cost
  @cost
end

#currencyString

Required. Currency code. Use three-character ISO-4217 code. Corresponds to the JSON property currency

Returns:

  • (String)


34483
34484
34485
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34483

def currency
  @currency
end

#discount_valueFloat

The total discount(s) value applied to this transaction. This figure should be excluded from TransactionInfo.value For example, if a user paid TransactionInfo.value amount, then nominal (pre-discount) value of the transaction is the sum of TransactionInfo.value and TransactionInfo. discount_value This means that profit is calculated the same way, regardless of the discount value, and that TransactionInfo.discount_value can be larger than TransactionInfo.value: * Profit = value - tax - cost Corresponds to the JSON property discountValue

Returns:

  • (Float)


34494
34495
34496
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34494

def discount_value
  @discount_value
end

#taxFloat

All the taxes associated with the transaction. Corresponds to the JSON property tax

Returns:

  • (Float)


34499
34500
34501
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34499

def tax
  @tax
end

#transaction_idString

The transaction ID with a length limit of 128 characters. Corresponds to the JSON property transactionId

Returns:

  • (String)


34504
34505
34506
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34504

def transaction_id
  @transaction_id
end

#valueFloat

Required. Total non-zero value associated with the transaction. This value may include shipping, tax, or other adjustments to the total value that you want to include. Corresponds to the JSON property value

Returns:

  • (Float)


34511
34512
34513
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34511

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34518
34519
34520
34521
34522
34523
34524
34525
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34518

def update!(**args)
  @cost = args[:cost] if args.key?(:cost)
  @currency = args[:currency] if args.key?(:currency)
  @discount_value = args[:discount_value] if args.key?(:discount_value)
  @tax = args[:tax] if args.key?(:tax)
  @transaction_id = args[:transaction_id] if args.key?(:transaction_id)
  @value = args[:value] if args.key?(:value)
end