Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaTransactionInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

A transaction represents the entire purchase transaction.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaTransactionInfo

Returns a new instance of GoogleCloudDiscoveryengineV1betaTransactionInfo.



34401
34402
34403
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34401

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#costFloat

All the costs associated with the products. These can be manufacturing costs, shipping expenses not borne by the end user, or any other costs, such that: * Profit = value - tax - cost Corresponds to the JSON property cost

Returns:

  • (Float)


34366
34367
34368
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34366

def cost
  @cost
end

#currencyString

Required. Currency code. Use three-character ISO-4217 code. Corresponds to the JSON property currency

Returns:

  • (String)


34371
34372
34373
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34371

def currency
  @currency
end

#discount_valueFloat

The total discount(s) value applied to this transaction. This figure should be excluded from TransactionInfo.value For example, if a user paid TransactionInfo.value amount, then nominal (pre-discount) value of the transaction is the sum of TransactionInfo.value and TransactionInfo. discount_value This means that profit is calculated the same way, regardless of the discount value, and that TransactionInfo.discount_value can be larger than TransactionInfo.value: * Profit = value - tax - cost Corresponds to the JSON property discountValue

Returns:

  • (Float)


34382
34383
34384
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34382

def discount_value
  @discount_value
end

#taxFloat

All the taxes associated with the transaction. Corresponds to the JSON property tax

Returns:

  • (Float)


34387
34388
34389
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34387

def tax
  @tax
end

#transaction_idString

The transaction ID with a length limit of 128 characters. Corresponds to the JSON property transactionId

Returns:

  • (String)


34392
34393
34394
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34392

def transaction_id
  @transaction_id
end

#valueFloat

Required. Total non-zero value associated with the transaction. This value may include shipping, tax, or other adjustments to the total value that you want to include. Corresponds to the JSON property value

Returns:

  • (Float)


34399
34400
34401
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34399

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34406
34407
34408
34409
34410
34411
34412
34413
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34406

def update!(**args)
  @cost = args[:cost] if args.key?(:cost)
  @currency = args[:currency] if args.key?(:currency)
  @discount_value = args[:discount_value] if args.key?(:discount_value)
  @tax = args[:tax] if args.key?(:tax)
  @transaction_id = args[:transaction_id] if args.key?(:transaction_id)
  @value = args[:value] if args.key?(:value)
end