Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaTransactionInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

A transaction represents the entire purchase transaction.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaTransactionInfo

Returns a new instance of GoogleCloudDiscoveryengineV1betaTransactionInfo.



34336
34337
34338
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34336

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#costFloat

All the costs associated with the products. These can be manufacturing costs, shipping expenses not borne by the end user, or any other costs, such that: * Profit = value - tax - cost Corresponds to the JSON property cost

Returns:

  • (Float)


34301
34302
34303
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34301

def cost
  @cost
end

#currencyString

Required. Currency code. Use three-character ISO-4217 code. Corresponds to the JSON property currency

Returns:

  • (String)


34306
34307
34308
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34306

def currency
  @currency
end

#discount_valueFloat

The total discount(s) value applied to this transaction. This figure should be excluded from TransactionInfo.value For example, if a user paid TransactionInfo.value amount, then nominal (pre-discount) value of the transaction is the sum of TransactionInfo.value and TransactionInfo. discount_value This means that profit is calculated the same way, regardless of the discount value, and that TransactionInfo.discount_value can be larger than TransactionInfo.value: * Profit = value - tax - cost Corresponds to the JSON property discountValue

Returns:

  • (Float)


34317
34318
34319
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34317

def discount_value
  @discount_value
end

#taxFloat

All the taxes associated with the transaction. Corresponds to the JSON property tax

Returns:

  • (Float)


34322
34323
34324
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34322

def tax
  @tax
end

#transaction_idString

The transaction ID with a length limit of 128 characters. Corresponds to the JSON property transactionId

Returns:

  • (String)


34327
34328
34329
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34327

def transaction_id
  @transaction_id
end

#valueFloat

Required. Total non-zero value associated with the transaction. This value may include shipping, tax, or other adjustments to the total value that you want to include. Corresponds to the JSON property value

Returns:

  • (Float)


34334
34335
34336
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34334

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34341
34342
34343
34344
34345
34346
34347
34348
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34341

def update!(**args)
  @cost = args[:cost] if args.key?(:cost)
  @currency = args[:currency] if args.key?(:currency)
  @discount_value = args[:discount_value] if args.key?(:discount_value)
  @tax = args[:tax] if args.key?(:tax)
  @transaction_id = args[:transaction_id] if args.key?(:transaction_id)
  @value = args[:value] if args.key?(:value)
end