Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaUserInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Information of an end user.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaUserInfo

Returns a new instance of GoogleCloudDiscoveryengineV1betaUserInfo.



34934
34935
34936
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34934

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#precise_locationGoogle::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaUserInfoPreciseLocation

Precise location info with multiple representation options. Corresponds to the JSON property preciseLocation



34905
34906
34907
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34905

def precise_location
  @precise_location
end

#time_zoneString

Optional. IANA time zone, e.g. Europe/Budapest. Corresponds to the JSON property timeZone

Returns:

  • (String)


34910
34911
34912
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34910

def time_zone
  @time_zone
end

#user_agentString

User agent as included in the HTTP header. The field must be a UTF-8 encoded string with a length limit of 1,000 characters. Otherwise, an INVALID_ARGUMENT error is returned. This should not be set when using the client side event reporting with GTM or JavaScript tag in UserEventService. CollectUserEvent or if UserEvent.direct_user_request is set. Corresponds to the JSON property userAgent

Returns:

  • (String)


34919
34920
34921
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34919

def user_agent
  @user_agent
end

#user_idString

Highly recommended for logged-in users. Unique identifier for logged-in user, such as a user name. Don't set for anonymous users. Always use a hashed value for this ID. Don't set the field to the same fixed ID for different users. This mixes the event history of those users together, which results in degraded model quality. The field must be a UTF-8 encoded string with a length limit of 128 characters. Otherwise, an INVALID_ARGUMENT error is returned. Represents an opaque ID to the Search API. The Search API doesn't interpret the value in any way. This field is used to associate events with a user across sessions if the events are being uploaded. Corresponds to the JSON property userId

Returns:

  • (String)


34932
34933
34934
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34932

def user_id
  @user_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34939
34940
34941
34942
34943
34944
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34939

def update!(**args)
  @precise_location = args[:precise_location] if args.key?(:precise_location)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
  @user_agent = args[:user_agent] if args.key?(:user_agent)
  @user_id = args[:user_id] if args.key?(:user_id)
end