Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaUserInfo
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaUserInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Information of an end user.
Instance Attribute Summary collapse
-
#precise_location ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaUserInfoPreciseLocation
Precise location info with multiple representation options.
-
#time_zone ⇒ String
Optional.
-
#user_agent ⇒ String
User agent as included in the HTTP header.
-
#user_id ⇒ String
Highly recommended for logged-in users.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaUserInfo
constructor
A new instance of GoogleCloudDiscoveryengineV1betaUserInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaUserInfo
Returns a new instance of GoogleCloudDiscoveryengineV1betaUserInfo.
34804 34805 34806 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34804 def initialize(**args) update!(**args) end |
Instance Attribute Details
#precise_location ⇒ Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaUserInfoPreciseLocation
Precise location info with multiple representation options. Currently only
latitude and longitude point is supported.
Corresponds to the JSON property preciseLocation
34775 34776 34777 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34775 def precise_location @precise_location end |
#time_zone ⇒ String
Optional. IANA time zone, e.g. Europe/Budapest.
Corresponds to the JSON property timeZone
34780 34781 34782 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34780 def time_zone @time_zone end |
#user_agent ⇒ String
User agent as included in the HTTP header. The field must be a UTF-8 encoded
string with a length limit of 1,000 characters. Otherwise, an
INVALID_ARGUMENT error is returned. This should not be set when using the
client side event reporting with GTM or JavaScript tag in UserEventService.
CollectUserEvent or if UserEvent.direct_user_request is set.
Corresponds to the JSON property userAgent
34789 34790 34791 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34789 def user_agent @user_agent end |
#user_id ⇒ String
Highly recommended for logged-in users. Unique identifier for logged-in user,
such as a user name. Don't set for anonymous users. Always use a hashed value
for this ID. Don't set the field to the same fixed ID for different users.
This mixes the event history of those users together, which results in
degraded model quality. The field must be a UTF-8 encoded string with a length
limit of 128 characters. Otherwise, an INVALID_ARGUMENT error is returned.
Represents an opaque ID to the Search API. The Search API doesn't interpret
the value in any way. This field is used to associate events with a user
across sessions if the events are being uploaded.
Corresponds to the JSON property userId
34802 34803 34804 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34802 def user_id @user_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34809 34810 34811 34812 34813 34814 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34809 def update!(**args) @precise_location = args[:precise_location] if args.key?(:precise_location) @time_zone = args[:time_zone] if args.key?(:time_zone) @user_agent = args[:user_agent] if args.key?(:user_agent) @user_id = args[:user_id] if args.key?(:user_id) end |