Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaUserInfoPreciseLocation
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaUserInfoPreciseLocation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Precise location info with multiple representation options.
Instance Attribute Summary collapse
-
#address ⇒ String
Location represented by a natural language address.
-
#point ⇒ Google::Apis::DiscoveryengineV1beta::GoogleTypeLatLng
An object that represents a latitude/longitude pair.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaUserInfoPreciseLocation
constructor
A new instance of GoogleCloudDiscoveryengineV1betaUserInfoPreciseLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaUserInfoPreciseLocation
Returns a new instance of GoogleCloudDiscoveryengineV1betaUserInfoPreciseLocation.
34946 34947 34948 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34946 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address ⇒ String
Location represented by a natural language address. Will later be geocoded and
converted to either a point or a polygon.
Corresponds to the JSON property address
34936 34937 34938 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34936 def address @address end |
#point ⇒ Google::Apis::DiscoveryengineV1beta::GoogleTypeLatLng
An object that represents a latitude/longitude pair. This is expressed as a
pair of doubles to represent degrees latitude and degrees longitude. Unless
specified otherwise, this object must conform to the WGS84 standard. Values
must be within normalized ranges.
Corresponds to the JSON property point
34944 34945 34946 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34944 def point @point end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34951 34952 34953 34954 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34951 def update!(**args) @address = args[:address] if args.key?(:address) @point = args[:point] if args.key?(:point) end |