Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaUserInfoPreciseLocation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Precise location info with multiple representation options. Currently only latitude and longitude point is supported.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaUserInfoPreciseLocation

Returns a new instance of GoogleCloudDiscoveryengineV1betaUserInfoPreciseLocation.



34812
34813
34814
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34812

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addressString

Optional. Location represented by a natural language address. Will later be geocoded and converted to either a point or a polygon. Corresponds to the JSON property address

Returns:

  • (String)


34802
34803
34804
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34802

def address
  @address
end

#pointGoogle::Apis::DiscoveryengineV1beta::GoogleTypeLatLng

An object that represents a latitude/longitude pair. This is expressed as a pair of doubles to represent degrees latitude and degrees longitude. Unless specified otherwise, this object must conform to the WGS84 standard. Values must be within normalized ranges. Corresponds to the JSON property point



34810
34811
34812
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34810

def point
  @point
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34817
34818
34819
34820
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34817

def update!(**args)
  @address = args[:address] if args.key?(:address)
  @point = args[:point] if args.key?(:point)
end