Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaUserInfoPreciseLocation
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaUserInfoPreciseLocation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Precise location info with multiple representation options. Currently only latitude and longitude point is supported.
Instance Attribute Summary collapse
-
#address ⇒ String
Optional.
-
#point ⇒ Google::Apis::DiscoveryengineV1beta::GoogleTypeLatLng
An object that represents a latitude/longitude pair.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaUserInfoPreciseLocation
constructor
A new instance of GoogleCloudDiscoveryengineV1betaUserInfoPreciseLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaUserInfoPreciseLocation
Returns a new instance of GoogleCloudDiscoveryengineV1betaUserInfoPreciseLocation.
33786 33787 33788 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33786 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address ⇒ String
Optional. Location represented by a natural language address. Will later be
geocoded and converted to either a point or a polygon.
Corresponds to the JSON property address
33776 33777 33778 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33776 def address @address end |
#point ⇒ Google::Apis::DiscoveryengineV1beta::GoogleTypeLatLng
An object that represents a latitude/longitude pair. This is expressed as a
pair of doubles to represent degrees latitude and degrees longitude. Unless
specified otherwise, this object must conform to the WGS84 standard. Values
must be within normalized ranges.
Corresponds to the JSON property point
33784 33785 33786 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33784 def point @point end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33791 33792 33793 33794 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33791 def update!(**args) @address = args[:address] if args.key?(:address) @point = args[:point] if args.key?(:point) end |