Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaUserLicense
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaUserLicense
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
User License information assigned by the admin.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#last_login_time ⇒ String
Output only.
-
#license_assignment_state ⇒ String
Output only.
-
#license_config ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
-
#user_principal ⇒ String
Required.
-
#user_profile ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaUserLicense
constructor
A new instance of GoogleCloudDiscoveryengineV1betaUserLicense.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaUserLicense
Returns a new instance of GoogleCloudDiscoveryengineV1betaUserLicense.
33844 33845 33846 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33844 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. User created timestamp.
Corresponds to the JSON property createTime
33804 33805 33806 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33804 def create_time @create_time end |
#last_login_time ⇒ String
Output only. User last logged in time. If the user has not logged in yet, this
field will be empty.
Corresponds to the JSON property lastLoginTime
33810 33811 33812 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33810 def last_login_time @last_login_time end |
#license_assignment_state ⇒ String
Output only. License assignment state of the user. If the user is assigned
with a license config, the user login will be assigned with the license; If
the user's license assignment state is unassigned or unspecified, no license
config will be associated to the user;
Corresponds to the JSON property licenseAssignmentState
33818 33819 33820 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33818 def license_assignment_state @license_assignment_state end |
#license_config ⇒ String
Optional. The full resource name of the Subscription(LicenseConfig) assigned
to the user.
Corresponds to the JSON property licenseConfig
33824 33825 33826 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33824 def license_config @license_config end |
#update_time ⇒ String
Output only. User update timestamp.
Corresponds to the JSON property updateTime
33829 33830 33831 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33829 def update_time @update_time end |
#user_principal ⇒ String
Required. Immutable. The user principal of the User, could be email address or
other prinical identifier. This field is immutable. Admin assign licenses
based on the user principal.
Corresponds to the JSON property userPrincipal
33836 33837 33838 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33836 def user_principal @user_principal end |
#user_profile ⇒ String
Optional. The user profile. We user user full name(First name + Last name) as
user profile.
Corresponds to the JSON property userProfile
33842 33843 33844 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33842 def user_profile @user_profile end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33849 33850 33851 33852 33853 33854 33855 33856 33857 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 33849 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @last_login_time = args[:last_login_time] if args.key?(:last_login_time) @license_assignment_state = args[:license_assignment_state] if args.key?(:license_assignment_state) @license_config = args[:license_config] if args.key?(:license_config) @update_time = args[:update_time] if args.key?(:update_time) @user_principal = args[:user_principal] if args.key?(:user_principal) @user_profile = args[:user_profile] if args.key?(:user_profile) end |