Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaUserStore

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Configures metadata that is used for End User entities.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaUserStore

Returns a new instance of GoogleCloudDiscoveryengineV1betaUserStore.



34887
34888
34889
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34887

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#default_license_configString

Optional. The default subscription LicenseConfig for the UserStore, if UserStore.enable_license_auto_register is true, new users will automatically register under the default subscription. If default LicenseConfig doesn't have remaining license seats left, new users will not be assigned with license and will be blocked for Vertex AI Search features. This is used if license_assignment_tier_rules is not configured. Corresponds to the JSON property defaultLicenseConfig

Returns:

  • (String)


34857
34858
34859
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34857

def default_license_config
  @default_license_config
end

#display_nameString

The display name of the User Store. Corresponds to the JSON property displayName

Returns:

  • (String)


34862
34863
34864
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34862

def display_name
  @display_name
end

#enable_expired_license_auto_updateBoolean Also known as: enable_expired_license_auto_update?

Optional. Whether to enable license auto update for users in this User Store. If true, users with expired licenses will automatically be updated to use the default license config as long as the default license config has seats left. Corresponds to the JSON property enableExpiredLicenseAutoUpdate

Returns:

  • (Boolean)


34869
34870
34871
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34869

def enable_expired_license_auto_update
  @enable_expired_license_auto_update
end

#enable_license_auto_registerBoolean Also known as: enable_license_auto_register?

Optional. Whether to enable license auto register for users in this User Store. If true, new users will automatically register under the default license config as long as the default license config has seats left. Corresponds to the JSON property enableLicenseAutoRegister

Returns:

  • (Boolean)


34877
34878
34879
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34877

def enable_license_auto_register
  @enable_license_auto_register
end

#nameString

Immutable. The full resource name of the User Store, in the format of projects/project/locations/location/userStores/user_store`. This field must be a UTF-8 encoded string with a length limit of 1024 characters. Corresponds to the JSON propertyname`

Returns:

  • (String)


34885
34886
34887
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34885

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34892
34893
34894
34895
34896
34897
34898
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34892

def update!(**args)
  @default_license_config = args[:default_license_config] if args.key?(:default_license_config)
  @display_name = args[:display_name] if args.key?(:display_name)
  @enable_expired_license_auto_update = args[:enable_expired_license_auto_update] if args.key?(:enable_expired_license_auto_update)
  @enable_license_auto_register = args[:enable_license_auto_register] if args.key?(:enable_license_auto_register)
  @name = args[:name] if args.key?(:name)
end