Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaWorkspaceConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

Config to store data store type configuration for workspace data

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaWorkspaceConfig

Returns a new instance of GoogleCloudDiscoveryengineV1betaWorkspaceConfig.



35106
35107
35108
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35106

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dasher_customer_idString

Output only. Obfuscated Dasher customer ID. Derived by the server from the project's GCP organization at data store creation time; any value supplied in the request payload is ignored. Corresponds to the JSON property dasherCustomerId

Returns:

  • (String)


35085
35086
35087
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35085

def dasher_customer_id
  @dasher_customer_id
end

#super_admin_email_addressString

Optional. The super admin email address for the workspace that will be used for access token generation. For now we only use it for Native Google Drive connector data ingestion. Corresponds to the JSON property superAdminEmailAddress

Returns:

  • (String)


35092
35093
35094
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35092

def super_admin_email_address
  @super_admin_email_address
end

#super_admin_service_accountString

Optional. The super admin service account for the workspace that will be used for access token generation. For now we only use it for Native Google Drive connector data ingestion. Corresponds to the JSON property superAdminServiceAccount

Returns:

  • (String)


35099
35100
35101
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35099

def 
  @super_admin_service_account
end

#typeString

The Google Workspace data source. Corresponds to the JSON property type

Returns:

  • (String)


35104
35105
35106
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35104

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35111
35112
35113
35114
35115
35116
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35111

def update!(**args)
  @dasher_customer_id = args[:dasher_customer_id] if args.key?(:dasher_customer_id)
  @super_admin_email_address = args[:super_admin_email_address] if args.key?(:super_admin_email_address)
  @super_admin_service_account = args[:super_admin_service_account] if args.key?(:super_admin_service_account)
  @type = args[:type] if args.key?(:type)
end