Class: Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaWorkspaceConfig
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleCloudDiscoveryengineV1betaWorkspaceConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
Config to store data store type configuration for workspace data
Instance Attribute Summary collapse
-
#dasher_customer_id ⇒ String
Output only.
-
#super_admin_email_address ⇒ String
Optional.
-
#super_admin_service_account ⇒ String
Optional.
-
#type ⇒ String
The Google Workspace data source.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaWorkspaceConfig
constructor
A new instance of GoogleCloudDiscoveryengineV1betaWorkspaceConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDiscoveryengineV1betaWorkspaceConfig
Returns a new instance of GoogleCloudDiscoveryengineV1betaWorkspaceConfig.
34931 34932 34933 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34931 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dasher_customer_id ⇒ String
Output only. Obfuscated Dasher customer ID. Derived by the server from the
project's GCP organization at data store creation time; any value supplied in
the request payload is ignored.
Corresponds to the JSON property dasherCustomerId
34910 34911 34912 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34910 def dasher_customer_id @dasher_customer_id end |
#super_admin_email_address ⇒ String
Optional. The super admin email address for the workspace that will be used
for access token generation. For now we only use it for Native Google Drive
connector data ingestion.
Corresponds to the JSON property superAdminEmailAddress
34917 34918 34919 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34917 def super_admin_email_address @super_admin_email_address end |
#super_admin_service_account ⇒ String
Optional. The super admin service account for the workspace that will be used
for access token generation. For now we only use it for Native Google Drive
connector data ingestion.
Corresponds to the JSON property superAdminServiceAccount
34924 34925 34926 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34924 def super_admin_service_account @super_admin_service_account end |
#type ⇒ String
The Google Workspace data source.
Corresponds to the JSON property type
34929 34930 34931 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34929 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34936 34937 34938 34939 34940 34941 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34936 def update!(**args) @dasher_customer_id = args[:dasher_customer_id] if args.key?(:dasher_customer_id) @super_admin_email_address = args[:super_admin_email_address] if args.key?(:super_admin_email_address) @super_admin_service_account = args[:super_admin_service_account] if args.key?(:super_admin_service_account) @type = args[:type] if args.key?(:type) end |