Class: Google::Apis::DiscoveryengineV1beta::GoogleLongrunningListOperationsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

The response message for Operations.ListOperations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleLongrunningListOperationsResponse

Returns a new instance of GoogleLongrunningListOperationsResponse.



35214
35215
35216
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35214

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

The standard List next-page token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


35199
35200
35201
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35199

def next_page_token
  @next_page_token
end

#operationsArray<Google::Apis::DiscoveryengineV1beta::GoogleLongrunningOperation>

A list of operations that matches the specified filter in the request. Corresponds to the JSON property operations



35204
35205
35206
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35204

def operations
  @operations
end

#unreachableArray<String>

Unordered list. Unreachable resources. Populated when the request sets ListOperationsRequest.return_partial_success and reads across collections. For example, when attempting to list all resources across all supported locations. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


35212
35213
35214
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35212

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35219
35220
35221
35222
35223
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35219

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @operations = args[:operations] if args.key?(:operations)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end