Class: Google::Apis::DiscoveryengineV1beta::GoogleLongrunningOperation
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleLongrunningOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
This resource represents a long-running operation that is the result of a network API call.
Instance Attribute Summary collapse
-
#done ⇒ Boolean
(also: #done?)
If the value is
false, it means the operation is still in progress. -
#error ⇒ Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#metadata ⇒ Hash<String,Object>
Service-specific metadata associated with the operation.
-
#name ⇒ String
The server-assigned name, which is only unique within the same service that originally returns it.
-
#response ⇒ Hash<String,Object>
The normal, successful response of the operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleLongrunningOperation
constructor
A new instance of GoogleLongrunningOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleLongrunningOperation
Returns a new instance of GoogleLongrunningOperation.
35468 35469 35470 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35468 def initialize(**args) update!(**args) end |
Instance Attribute Details
#done ⇒ Boolean Also known as: done?
If the value is false, it means the operation is still in progress. If true
, the operation is completed, and either error or response is available.
Corresponds to the JSON property done
35429 35430 35431 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35429 def done @done end |
#error ⇒ Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
35440 35441 35442 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35440 def error @error end |
#metadata ⇒ Hash<String,Object>
Service-specific metadata associated with the operation. It typically contains
progress information and common metadata such as create time. Some services
might not provide such metadata. Any method that returns a long-running
operation should document the metadata type, if any.
Corresponds to the JSON property metadata
35448 35449 35450 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35448 def @metadata end |
#name ⇒ String
The server-assigned name, which is only unique within the same service that
originally returns it. If you use the default HTTP mapping, the name should
be a resource name ending with operations/unique_id`.
Corresponds to the JSON propertyname`
35455 35456 35457 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35455 def name @name end |
#response ⇒ Hash<String,Object>
The normal, successful response of the operation. If the original method
returns no data on success, such as Delete, the response is google.protobuf.
Empty. If the original method is standard Get/Create/Update, the
response should be the resource. For other methods, the response should have
the type XxxResponse, where Xxx is the original method name. For example,
if the original method name is TakeSnapshot(), the inferred response type is
TakeSnapshotResponse.
Corresponds to the JSON property response
35466 35467 35468 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35466 def response @response end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35473 35474 35475 35476 35477 35478 35479 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35473 def update!(**args) @done = args[:done] if args.key?(:done) @error = args[:error] if args.key?(:error) @metadata = args[:metadata] if args.key?(:metadata) @name = args[:name] if args.key?(:name) @response = args[:response] if args.key?(:response) end |