Class: Google::Apis::DiscoveryengineV1beta::GoogleMonitoringV3Point

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

A single data point in a time series.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleMonitoringV3Point

Returns a new instance of GoogleMonitoringV3Point.



35479
35480
35481
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35479

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#intervalGoogle::Apis::DiscoveryengineV1beta::GoogleMonitoringV3TimeInterval

A time interval extending just after a start time through an end time. If the start time is the same as the end time, then the interval represents a single point in time. Corresponds to the JSON property interval



35472
35473
35474
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35472

def interval
  @interval
end

#valueGoogle::Apis::DiscoveryengineV1beta::GoogleMonitoringV3TypedValue

A single strongly-typed value. Corresponds to the JSON property value



35477
35478
35479
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35477

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35484
35485
35486
35487
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35484

def update!(**args)
  @interval = args[:interval] if args.key?(:interval)
  @value = args[:value] if args.key?(:value)
end