Class: Google::Apis::DiscoveryengineV1beta::GoogleMonitoringV3TimeInterval

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

A time interval extending just after a start time through an end time. If the start time is the same as the end time, then the interval represents a single point in time.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleMonitoringV3TimeInterval

Returns a new instance of GoogleMonitoringV3TimeInterval.



34686
34687
34688
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34686

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_timeString

Required. The end of the time interval. Corresponds to the JSON property endTime

Returns:

  • (String)


34678
34679
34680
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34678

def end_time
  @end_time
end

#start_timeString

Optional. The beginning of the time interval. The default value for the start time is the end time. The start time must not be later than the end time. Corresponds to the JSON property startTime

Returns:

  • (String)


34684
34685
34686
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34684

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34691
34692
34693
34694
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34691

def update!(**args)
  @end_time = args[:end_time] if args.key?(:end_time)
  @start_time = args[:start_time] if args.key?(:start_time)
end