Class: Google::Apis::DiscoveryengineV1beta::GoogleMonitoringV3TimeInterval
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleMonitoringV3TimeInterval
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
A time interval extending just after a start time through an end time. If the start time is the same as the end time, then the interval represents a single point in time.
Instance Attribute Summary collapse
-
#end_time ⇒ String
Required.
-
#start_time ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleMonitoringV3TimeInterval
constructor
A new instance of GoogleMonitoringV3TimeInterval.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleMonitoringV3TimeInterval
Returns a new instance of GoogleMonitoringV3TimeInterval.
34347 34348 34349 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34347 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time ⇒ String
Required. The end of the time interval.
Corresponds to the JSON property endTime
34339 34340 34341 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34339 def end_time @end_time end |
#start_time ⇒ String
Optional. The beginning of the time interval. The default value for the start
time is the end time. The start time must not be later than the end time.
Corresponds to the JSON property startTime
34345 34346 34347 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34345 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34352 34353 34354 34355 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 34352 def update!(**args) @end_time = args[:end_time] if args.key?(:end_time) @start_time = args[:start_time] if args.key?(:start_time) end |