Class: Google::Apis::DiscoveryengineV1beta::GoogleMonitoringV3TimeSeries
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleMonitoringV3TimeSeries
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
A collection of data points that describes the time-varying values of a metric. A time series is identified by a combination of a fully-specified monitored resource and a fully-specified metric. This type is used for both listing and creating time series.
Instance Attribute Summary collapse
-
#description ⇒ String
Input only.
-
#metadata ⇒ Google::Apis::DiscoveryengineV1beta::GoogleApiMonitoredResourceMetadata
Auxiliary metadata for a MonitoredResource object.
-
#metric ⇒ Google::Apis::DiscoveryengineV1beta::GoogleApiMetric
A specific metric, identified by specifying values for all of the labels of a
MetricDescriptor. -
#metric_kind ⇒ String
The metric kind of the time series.
-
#points ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleMonitoringV3Point>
The data points of this time series.
-
#resource ⇒ Google::Apis::DiscoveryengineV1beta::GoogleApiMonitoredResource
An object representing a resource that can be used for monitoring, logging, billing, or other purposes.
-
#unit ⇒ String
The units in which the metric value is reported.
-
#value_type ⇒ String
The value type of the time series.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleMonitoringV3TimeSeries
constructor
A new instance of GoogleMonitoringV3TimeSeries.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleMonitoringV3TimeSeries
Returns a new instance of GoogleMonitoringV3TimeSeries.
35465 35466 35467 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35465 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Input only. A detailed description of the time series that will be associated
with the google.api.MetricDescriptor for the metric. Once set, this field
cannot be changed through CreateTimeSeries.
Corresponds to the JSON property description
35396 35397 35398 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35396 def description @description end |
#metadata ⇒ Google::Apis::DiscoveryengineV1beta::GoogleApiMonitoredResourceMetadata
Auxiliary metadata for a MonitoredResource object. MonitoredResource objects
contain the minimum set of information to uniquely identify a monitored
resource instance. There is some other useful auxiliary metadata. Monitoring
and Logging use an ingestion pipeline to extract metadata for cloud resources
of all types, and store the metadata in this message.
Corresponds to the JSON property metadata
35405 35406 35407 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35405 def @metadata end |
#metric ⇒ Google::Apis::DiscoveryengineV1beta::GoogleApiMetric
A specific metric, identified by specifying values for all of the labels of a
MetricDescriptor.
Corresponds to the JSON property metric
35411 35412 35413 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35411 def metric @metric end |
#metric_kind ⇒ String
The metric kind of the time series. When listing time series, this metric kind
might be different from the metric kind of the associated metric if this time
series is an alignment or reduction of other time series. When creating a time
series, this field is optional. If present, it must be the same as the metric
kind of the associated metric. If the associated metric's descriptor must be
auto-created, then this field specifies the metric kind of the new descriptor
and must be either GAUGE (the default) or CUMULATIVE.
Corresponds to the JSON property metricKind
35422 35423 35424 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35422 def metric_kind @metric_kind end |
#points ⇒ Array<Google::Apis::DiscoveryengineV1beta::GoogleMonitoringV3Point>
The data points of this time series. When listing time series, points are
returned in reverse time order. When creating a time series, this field must
contain exactly one point and the point's type must be the same as the value
type of the associated metric. If the associated metric's descriptor must be
auto-created, then the value type of the descriptor is determined by the point'
s type, which must be BOOL, INT64, DOUBLE, or DISTRIBUTION.
Corresponds to the JSON property points
35432 35433 35434 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35432 def points @points end |
#resource ⇒ Google::Apis::DiscoveryengineV1beta::GoogleApiMonitoredResource
An object representing a resource that can be used for monitoring, logging,
billing, or other purposes. Examples include virtual machine instances,
databases, and storage devices such as disks. The type field identifies a
MonitoredResourceDescriptor object that describes the resource's schema.
Information in the labels field identifies the actual resource and its
attributes according to the schema. For example, a particular Compute Engine
VM instance could be represented by the following object, because the
MonitoredResourceDescriptor for "gce_instance" has labels "project_id", "
instance_id" and "zone": "type": "gce_instance", "labels": "project_id":
"my-project", "instance_id": "12345678901234", "zone": "us-central1-a" `
Corresponds to the JSON propertyresource`
35446 35447 35448 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35446 def resource @resource end |
#unit ⇒ String
The units in which the metric value is reported. It is only applicable if the
value_type is INT64, DOUBLE, or DISTRIBUTION. The unit defines the
representation of the stored metric values. This field can only be changed
through CreateTimeSeries when it is empty.
Corresponds to the JSON property unit
35454 35455 35456 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35454 def unit @unit end |
#value_type ⇒ String
The value type of the time series. When listing time series, this value type
might be different from the value type of the associated metric if this time
series is an alignment or reduction of other time series. When creating a time
series, this field is optional. If present, it must be the same as the type of
the data in the points field.
Corresponds to the JSON property valueType
35463 35464 35465 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35463 def value_type @value_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35470 35471 35472 35473 35474 35475 35476 35477 35478 35479 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35470 def update!(**args) @description = args[:description] if args.key?(:description) @metadata = args[:metadata] if args.key?(:metadata) @metric = args[:metric] if args.key?(:metric) @metric_kind = args[:metric_kind] if args.key?(:metric_kind) @points = args[:points] if args.key?(:points) @resource = args[:resource] if args.key?(:resource) @unit = args[:unit] if args.key?(:unit) @value_type = args[:value_type] if args.key?(:value_type) end |