Class: Google::Apis::DiscoveryengineV1beta::GoogleRpcStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb

Overview

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleRpcStatus

Returns a new instance of GoogleRpcStatus.



35580
35581
35582
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35580

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeFixnum

The status code, which should be an enum value of google.rpc.Code. Corresponds to the JSON property code

Returns:

  • (Fixnum)


35565
35566
35567
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35565

def code
  @code
end

#detailsArray<Hash<String,Object>>

A list of messages that carry the error details. There is a common set of message types for APIs to use. Corresponds to the JSON property details

Returns:

  • (Array<Hash<String,Object>>)


35571
35572
35573
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35571

def details
  @details
end

#messageString

A developer-facing error message, which should be in English. Any user-facing error message should be localized and sent in the google.rpc.Status.details field, or localized by the client. Corresponds to the JSON property message

Returns:

  • (String)


35578
35579
35580
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35578

def message
  @message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35585
35586
35587
35588
35589
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35585

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @details = args[:details] if args.key?(:details)
  @message = args[:message] if args.key?(:message)
end