Class: Google::Apis::DiscoveryengineV1beta::GoogleTypeLatLng
- Inherits:
-
Object
- Object
- Google::Apis::DiscoveryengineV1beta::GoogleTypeLatLng
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/discoveryengine_v1beta/classes.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb,
lib/google/apis/discoveryengine_v1beta/representations.rb
Overview
An object that represents a latitude/longitude pair. This is expressed as a pair of doubles to represent degrees latitude and degrees longitude. Unless specified otherwise, this object must conform to the WGS84 standard. Values must be within normalized ranges.
Instance Attribute Summary collapse
-
#latitude ⇒ Float
The latitude in degrees.
-
#longitude ⇒ Float
The longitude in degrees.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleTypeLatLng
constructor
A new instance of GoogleTypeLatLng.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleTypeLatLng
Returns a new instance of GoogleTypeLatLng.
35793 35794 35795 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35793 def initialize(**args) update!(**args) end |
Instance Attribute Details
#latitude ⇒ Float
The latitude in degrees. It must be in the range [-90.0, +90.0].
Corresponds to the JSON property latitude
35786 35787 35788 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35786 def latitude @latitude end |
#longitude ⇒ Float
The longitude in degrees. It must be in the range [-180.0, +180.0].
Corresponds to the JSON property longitude
35791 35792 35793 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35791 def longitude @longitude end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35798 35799 35800 35801 |
# File 'lib/google/apis/discoveryengine_v1beta/classes.rb', line 35798 def update!(**args) @latitude = args[:latitude] if args.key?(:latitude) @longitude = args[:longitude] if args.key?(:longitude) end |